---
title: "Enterprise Applications Team G&A (Finance Systems)"
description: "The Enterprise Applications Team for General and Administrative (G&A) functions specializes in implementing and supporting critical applications that streamline and optimize GitLab’s internal business processes. 
Our primary focus is on enabling efficiency and scalability across the procure-to-pay and record-to-report processes, ensuring seamless operations in alignment with GitLab’s growth and compliance requirements."
---

<link rel="stylesheet" type="text/css" href="/stylesheets/biztech.css" />

## <i class="fas fa-users" id="biz-tech-icons"></i> About Us

The **Enterprise Applications, G&A Team** is responsible for administering and expanding GitLab's financial systems to meet the demands of scalability, automation, and regulatory compliance. Through proactive monitoring, alerting, and continuous iteration, we ensure the stability and reliability of GitLab’s internal applications ecosystem.

Our suite of financial tools includes:

- **NetSuite** (ERP)
- **Coupa** (Procurement)
- **Zip** (Vendor Management)
- **Navan Travel & Expense** (Travel Management)
- **Adaptive Planning** (Financial Planning)

Additionally, we oversee **IT Audit and Compliance** processes, ensuring adherence to IT General Controls (ITGC) to meet **SOX** and other regulatory standards.

## <i class="fas fa-bullseye" id="biz-tech-icons"></i> Mission

Our mission is to empower GitLab’s business processes by delivering an integrated and efficient application landscape. We strive to:

- **Enable seamless workflows:** Create a cohesive ecosystem where enterprise applications work together, delivering a superior user experience for business partners.
- **Ensure data integrity and security:** Maintain robust processes to protect sensitive data and ensure consistent accuracy across systems.
- **Drive efficiency through automation:** Simplify workflows and maximize automation by leveraging industry best practices.
- **Focus on core competencies:** Adopt and extend third-party solutions where appropriate, allowing GitLab’s engineering resources to focus on core product innovations.
- **Maintain audit and compliance standards:** Safeguard customer and business data to meet key audit requirements, including SOX and SOC compliance.

## <i class="fas fa-users" id="biz-tech-icons"></i> Our Team (Org Chart)

[Our Team (Org Chart)](https://internal.gitlab.com/handbook/it-enterprise-applications/about-us/finance-ops/)

## <i class="fas fa-bullhorn" id="biz-tech-icons"></i> Our Services

### System Evaluations & Implementations

We collaborate with the Program Management Office (PMO) to evaluate, implement, or configure new applications or major updates. By gathering and validating user requirements, we ensure applications align with business needs, driving automation and efficiency.

### Finance Systems Administration

Our team ensures smooth operations of GitLab’s financial systems, including:

- User provisioning and offboarding
- Chart of Accounts (COA) updates
- Financial report creation and maintenance
- Release upgrade testing
- Daily system upkeep to ensure operational continuity

### Non-Project Operational Enhancements

We prioritize and address smaller-scale, non-project tasks to enhance system functionality. These include:

- Workflow updates and custom field enhancements
- Enabling quick features
- Policy updates for expenses and other configurations

## <i class="fas fa-bullhorn" id="biz-tech-icons"></i> How We Operate

### Request Submission Process

- **Projects:** For initiatives requiring several weeks, cross-functional impact, or project management support, contact the [PMO team](../business-technology/pmo/) to include the request in the project roadmap.

- **Operational Enhancements:** Submit smaller system changes through the **CM: Configuration Change**  template linked [here](https://gitlab.com/gitlab-com/business-technology/enterprise-apps/financeops/finance-systems/-/issues/new#). Requests are evaluated and prioritized using the ~BT:Backlog label [here](https://gitlab.com/groups/gitlab-com/-/issues/?sort=created_date&state=opened&label_name%5B%5D=BT%3A%3ABacklog&first_page_size=100).

### Milestone Planning

Our team works on a bi-weekly milestone schedule (Wednesday–Tuesday).

- Open milestones are tracked [here](https://gitlab.com/groups/gitlab-com/-/milestones?search_title=entapps&state=&sort=).
- At the close of each milestone, unresolved issues roll over to the next milestone. Additionally, new issues in the [backlog](https://gitlab.com/groups/gitlab-com/-/issues/?sort=created_date&state=opened&label_name%5B%5D=BT%3A%3ABacklog&first_page_size=100) will be evaluated to determine the resources required and feasibility of starting it in the new milestone.

**Note:** Requests tied to operational continuity (KTLO) or financial impact are prioritized over non-critical enhancements.

## <i class="fas fa-bullhorn" id="biz-tech-icons"></i> Our Commitment

Through proactive support, strategic improvements, and adherence to compliance standards, the Enterprise Applications, G&A team ensures that GitLab’s financial systems not only meet today’s demands but are also prepared to support future growth. By maintaining robust processes and fostering collaboration across departments, we empower GitLab to operate with agility and excellence.
