---
title: "Office of the CEO"
description: "Details about Office of the CEO (OCEO) at GitLab"
---

## Office of the CEO Overview

GitLab is a [functionally organized](/handbook/company/structure/#gitlabcom-isnt-a-role) company in which functions are as mutally exclusive as possible to be efficient. Without a COO or central operating department reporting into the CEO, the CEO gets leverage through an [Office of the CEO](/handbook/ceo/office-of-the-ceo/) (OCEO for short) led by the Chief of Staff (CoS) to the CEO. While the Chief of Staff to the CEO is not a part of GitLab's executive team, this senior person reports directly to the CEO and manages a team that supports the CEO and/or cross-functional projects of importance to GitLab.

## Team Mission

Help the CEO be more effective and lead select cross-functional initiatives of importance to GitLab.

## Team Composition

The [Office to the CEO](/handbook/ceo/office-of-the-ceo/) consists of:

1. The [Chief of Staff to the CEO](/job-families/chief-executive-officer/chief-of-staff/): the person responsible for running this group and supporting the success of the CEO.
1. [Strategy and Operations team members](job-families/chief-executive-officer/strategy-and-operations/): internal consultants and doers who support priority cross-functional projects within GitLab. Roles vary based on business needs, but these folks can be specialists (for example, focused on China or technology) or generalists.
1. [EBAs](/handbook/eba/) to the CEO: EBAs who support the CEO and the Chief of Staff to the CEO.

When there are gaps, the Office may expand to include additional roles and responsibilities. For example, at times this Office has included our [TeamOps](/teamops/) initiative, [internal communications](/handbook/communication/#internal-communication), and [handbook maintenance](/). As GitLab is a functionally organized company, the goal in most cases is to own an area until another function is prepared to own and support it.

## Kinds of projects Strategy and Operations team members work on {#what-projects-does-the-cost-work-on}

Given the cross-functional nature of the [company OKRs](/handbook/company/okrs/#okr-process-at-gitlab) and given these projects are important to the CEO, the Strategy and Operators team members are often involved in these initiatives.

### Project Criteria

The Chief of Staff to the CEO and their team may work on projects that fit *any combination* of the following:

1. projects which build or improve organizational design, infrastructure, and operations
1. cross-functional projects that need ownership until a maintainer or exit criteria is identified
1. projects that are so broad that they can't live within a function but are too much work for the CEO or Chief of Staff to the CEO
1. projects that are important to the CEO

This is not an exhaustive list of the types of work the Office of the CEO might do.

#### Many Functional

GitLab is a [functional organization](/handbook/leadership/#no-matrix-organization), which means the [people are organized by function](https://comp-calculator.gitlab.net/org_chart).
When a cross-functional project arises between multiple different Departments, Office of the CEO team members may be included to help with the planning and execution.
In many cases, a member of the Office of the CEO will be the [directly responsible individual (DRI)](/handbook/people-group/directly-responsible-individuals/) for the project.
Whether it's a product feature proposal, a new initiative roll-out, or questions from the board, the Office of the CEO is the group that can be trusted to get things done, get them done quickly, and get them done right.

Examples of a cross-functional project:

- Helping shepherd KPI and/or OKR progress
- Helping to launch a foreign entity
- Supporting pricing and packaging change initiatives
- Efforts to increase customer use case adoption
- Providing guidance around how to use GitLab's [internal handbook](https://internal.gitlab.com/)

#### Under-resourced

Projects come up that are both important and under-resourced.
The Strategy and Operations team members within the Office of the CEO should be known for its ability to become 80% effective on any subject quickly.
They are generalists at their core and, while they bring special skills to the table, they are meant to be able to address important problems as they come up.
A member of the Office of the CEO might help source candidates for a strategic hire, fix grammatical errors in the handbook, and build a financial model all in the same day based on what is important or top of mind for the CEO at a given point.
The team helps with work that other teams may not have the bandwidth to do but is important to the organization and/or the CEO.

Examples of an under-resourced project:

- Creating materials for a keynote the CEO will deliver in a rushed timeline
- Supporting planning for a global conference
- Supporting launch of a new SKU

#### No clear leader

There may be projects with no clear leader for a myriad of reasons, including that we're still hiring the point person or the lead is on leave.
Because of the team's ability to come up to speed quickly, they may be tasked with something totally out of their domain with the expectation that they bring their leadership experience to the table, will do the work to make good decisions, and will lean on team members who are subject-matter experts.

For example, there has historically been no DRI for the [handbook or related content sites](/handbook/about/maintenance/). As it became clear that this was a GitLab priority, but no function planned to prioritize this within the coming year, the Office of the CEO stepped in to take on handbook ownership until an owner could be identified.

Examples of projects with no clear leader:

- Managing our ongoing relationship with [JiHu](https://about.gitlab.com/pricing/faq-jihu/) in China
- Stepping in to fill a senior level role in another function in a temporary capacity

#### Broad

Some projects or initiatives are very broad and cross-functional and *make sense* to belong to the CEO but would be inefficient uses of the CEO's time if fully owned by the CEO.
OKRs are a prime example. OKRs need to happen and are key to the business but it is not efficient for the CEO to shepherd the process along.
The Office of the CEO is the shepherd for these sorts of projects and collaborates with all team members at GitLab to achieve success on such initiatives.

Examples of broad projects:

- E-group offsite prep
- Board meeting prep
- OKR shepherding
- Planning activities on behalf of the CEO

#### Important to the CEO

The CEO will have other projects that come up that they will task the Office of the CEO with, such as following up on something or carrying on a conversation on their behalf.

Examples of tasks or initiatives that are important to the CEO:

- Handbook MRs
- Values updates
- Preparing for calls
- Special projects. These have included:
  - Operationalizing charitable donations
  - Supporting updates to GitLab's expense policy
  - Quantifying the value of transparency
  - Auditing training resources and creating an accessible source of truth
  - Calculating GitLab's carbon emissions and leading a first iteration of a carbon reduction initiative
  - Identifying the underlying reasons for why we didn't meet targets for a core GTM KPI and identifying optimizations
  - Supporting an initiative to increase customer CI adoption
  - Serving as the DRI for the [SaaS free user initiative](https://docs.gitlab.com/ee/user/free_user_limit.html#:~:text=A%20five%2Duser%20limit%20applies,applied%20on%20June%2013%2C%202023)

## How to Work

The team uses a limited access Google doc called "Sid, Stella, and the Office of the CEO" to collaborate and share progress with the CEO.
It's format is structured like the [1-1 Suggested Agenda Format](/handbook/leadership/1-1/suggested-agenda-format/).
Many of the tasks on the sheet are quick asks: handbook MRs, formatting changes, or questions to be answered.
Small asks should be handled as quickly as possible.
Other asks, such as OKR-related planning or an initiative that requires alignment with multiple stakeholders, require forethought and more appropriate timing.
Some amount of time each week needs to be spent moving these sorts of tasks forward.

As a rule, everything in the doc is a TODO for the Office of the CEO.
When tasks are DONE, they should be labeled as such.
The CEO will review and delete the item once it's been assessed as completed.

### Prioritization

Since the team has limited capacity to lean into everything that it may want or be asked to, it is thoughtful about team and individual capacity. Members of the Office of the CEO will be expected to manage both directed and leadership (largely self-directed) work. You can find definitions and examples of directed and leadership work on the [CoS to the CEO handbook page]({{< ref "chief-of-staff#responsibilities" >}}).

When newly initiated, self-directed, leadership work entails a significant time commitment (>20% capacity for more than a week), the work being done should be flagged to the CEO in a 1:1 or team meeting. This work should stay on the 1:1 agenda between the CoS to the CEO and the team member for the duration of the activity. If needed, activities may be reprioritized based on top demands and priorities.

More senior roles within the Office of the CEO can expect to have more leadership than directed work, but all roles should have a mix within a fiscal year.

Office of the CEO members should monitor the mix of directed and leadership work that they are doing and provide as appropriate in Office of the CEO Meetings, so the CoS to the CEO and CEO are aware of the current balance and can make adjustments, if needed.

## Board Meetings

The Chief of Staff to the CEO supports Board activities as specified in the [Board Meeting](/handbook/board-meetings/) section of the handbook and as directed by the CEO.

In addition, the CoS to the CEO helps the CEO in preparing for the CEO's closed session. The CoS to the CEO should coordinate with the EBA to the CEO to schedule a 25 minute session with the CEO and the CoS to the CEO a week before the Board of Directors Meeting. The CoS to the CEO should prepare an agenda that includes an outline for what the CEO may want to cover. For each discussion topic, the following should be captured:

1. What are we discussing?
1. Why are we discussing it?
1. Where should we focus our feedback and suggestions?
1. Who should be thanked for their work?

Designated meeting time will be used to review and make adjustments to the proposal. The CoS to the CEO will coordinate with the EBA to the CEO to ensure that there is a "FYI" on the closed session agenda that links to the prepared material.

## OKRs

The Office of the CEO runs the [OKR process](/handbook/company/okrs/).
We set OKRs on a [fiscal quarter](/handbook/finance/#fiscal-year) basis.

There is an [OKR schedule](/handbook/company/okrs/#schedule) that dictates the timeline of events.
We use a handbook page for each quarter.
The CEO's Objectives every quarter map to the [sequence](/handbook/company/strategy/#sequence) of our [strategy](/handbook/company/strategy/#strategy).
The CEO's KRs are what we're measuring for the company for that quarter.

## Collaborating on Cross-Functional Initiatives

While there are rare exceptions, members of the Office of the CEO are not forever owners of initiatives. They plug in to help achieve critical milestones or fill gaps. When a member of the Office of the CEO joins an initiative, there should be agreement from key stakeholders around:

1. The level of support required
1. The Office of the CEO members' scope and responsibilities
1. The exit criteria for the Office of the CEO
1. If required, the long-term plan for ongoing initiative or project support

Office of the CEO members can be reassigned based on the needs of the business and priorities of the CEO. In most cases, a member of the Office of the CEO will remain with a project until the exit criteria for the Office of the CEO is achieved. If a project extends beyond its anticipated timeframe or priorities change, a member may have to leave a project before the agreed upon exit criteria is achieved.

When a member of the Office of the CEO exits an ongoing intitiative they will:

1. Provide as much notice as possible that the Office of the CEO will no longer support the initiative
1. Document their key responsibilities
1. Support a project DRI in identifying new owners
1. When possible, stay engaged in the initiative in a limited capacity during an agreed upon transition period

There may be instances in which the Office of the CEO leaving leads to a project scope being reduced or deprioritized. In these instances, the Office of the CEO member will be responsible for engaging key stakeholders around the keep/expand scope or go/no-go decision. It will be clearly documented and key folks will be involved in the decision and aware of the outcome.

## Quarterly Kickoff

The CEO does a Quarterly Kickoff in the first month of each quarter. The Office of the CEO plays a role in creating materials, recording content, and preparing the CEO. Details can be found on the [All-Company Meetings page](/handbook/company/gitlab-all-company-meetings/#quarterly-kickoff) of the handbook.

## E-Group Offsite

The executives get together every quarter for the [e-group offsite](/handbook/company/offsite/).
The CoS to the CEO plays an important [role](/handbook/company/offsite/#roles).
It's [3 to 4 days long](/handbook/company/offsite/#schedule) with a [Functional Leaders Meeting](/handbook/company/offsite/#functional-leaders-meeting) within the following days.
There are [recurring discussion topics](/handbook/company/offsite/#recurring-discussion-topics) as well as a [discussion on content](/handbook/company/offsite/#content-choice) chosen by the CEO.

In addition, the CoS to the CEO is responsible for preparing the CEO for offsites by:

1. Finalizing the agenda to include CEO input
1. Working with the CEO on what to cover in offsite introductions and closings
1. Helping the CEO to prepare for sessions that the CEO will facilitate

## CEO Performance Evaluation

In Q1 of a new fiscal year, the Chairperson of the Compensation Committee conducts the annual CEO Evaluation. The Chairperson meets with all members of GitLab's Board and E-Group for their feedback on the CEO's performance over the past Fiscal Year. The Chairperson meets with the CEO for their self-assessment at the beginning of the evaluation cycle.

The CEO's self-assessment is centered on three main areas

1. Areas of Notable Success
1. Areas of Disappointment
1. Areas for Improvement and Focus in the next fiscal year

The Staff EBA to the CEO assists the Chairperson to schedule the performance review meetings with each Board Member (50 minutes, 1:1) and E-Group member (25 minutes, 1:1). These are conducted in an interview format to capture the richest possible feedback regarding the CEO's performance. During these calls, Board Members can expect to share their perspectives on the CEO's major accomplishments and disappointments in areas such as vision, strategy, operations, management team development, company culture, and relationship with the Board. General areas of strength. Areas for improvement and/or additional focus. Key fiscal year strategic/operational, non-financial goals.

The results from the Board and E-Group team interviews are summarized (without attribution) by the Chairperson and shared for discussion at the March Board of Directors meeting.

The CoS to the CEO is responsible for a mid-year and an end-of-year update to the Board on the progress made across focus areas. This will come in the form of a progress scorecard.
For example, if one area of focus is "set 3-year strategy", the CoS to the CEO will evaluate whether the activity is on track or needs attention. The scorecard will be updated with a progress score (on track, needs attention, or at risk) and a high-level summary of relevant key activities.

Feedback from the Board will be shared and discussed in the Q1 E-Group Offsite. Progress will be discussed in the Q3 E-Group Offsite.

The CoS to the CEO will also assist the CEO in prepping for the CEO's end of year review and areas for focus in the coming year.

## Managing the Functional Leaders

Functional Leaders is a group comprised of all [CEO-Skips](/handbook/company/structure/#ceo-skips), select People Business Partners, and a few other folks as nominated by members of E-Group.
The CoS to the CEO enables and manages this group.

## Maintaining the Mitigating Concerns

We outline our [Mitigating Concerns](https://internal.gitlab.com/handbook/leadership/mitigating-concerns/) in the handbook.
The CoS to the CEO is responsible for maintaining this list.
There is an issue to also [add DRIs and review the mitigations](https://gitlab.com/gitlab-com/cos-team/-/issues/20).

## Supporting Summit Challenge

The CEO chooses to run a Summit Challenge as part of some [Summits](https://about.gitlab.com/events/). The Challenge is shared in advance of Summit or on the first day of Summit. As an example, the 2020 Challenge encouraged team members to [beautify docs](https://gitlab.com/groups/gitlab-org/-/epics/3063). The Office of the CEO is responsible for collaborating with the CEO to create and introduce the challenge. The CEO is responsible for identifying a prize for team members, but the Office of the CEO should ensure that a prize is identified and support the CEO in this if needed.

### Meeting Cleanup Day

On February 14, or the Tuesday after if this day falls over the weekend or on Monday, we have an annual calendar cleanup day.

The template Slack post includes more information about the purpose and recommended actions:

```plain
:google_calendar: :broom: YYYY-MM-DD is Meeting Cleanup Day!

At the start of each new fiscal year, we have a meeting cleanup day to encourage everyone to look at their calendars and assess the value and frequency of recurring meetings.

With the goals of increasing efficiency and looking at how to make recurring meetings more productive, this practice acts as a reminder to:

1. Cancel meetings or change the frequency if you feel that the current cadence does not add sufficient value
2. Discuss removing yourself as an attendee with the meeting owner if you don't feel that you are contributing or supporting business results through participation
3. Ask other team members to reexamine how existing meetings are managed

If you're looking for possible wording to use when taking the actions above, and for more information about the cleanup day, please look at  https://handbook.gitlab.com/handbook/ceo/office-of-the-ceo/#meeting-cleanup-day.
```

When cancelling a meeting, a team member can copy and paste this message to send to attendees:
*I evaluated the need for this meeting as part of [Meeting Cleanup Day](/handbook/communication/#meeting-cleanup-day). I have determined that the meeting is no longer needed. Please get in touch if you have any concerns.*

When changing the cadence of a meeting, a team member can copy and paste this message to send to attendees:

*I reassessed this meeting as part of [Meeting Cleanup Day](/handbook/communication/#meeting-cleanup-day). I have determined that the meeting no longer needs to happen as frequently. Please look for an updated meeting invite and get in touch if you have any concerns.*

If you are a team member who intends to decline a meeting, the [asynchronous communication](/handbook/company/culture/all-remote/asynchronous/#how-to-decline-meetings-in-favor-of-async) section of the handbook has some good suggestions for what to say when you decline.

Meeting Cleanup Day is intentionally near the start of the new fiscal year. The Office of the CEO will launch this initiative annually a week in advance through posting in the `#whats-happening-at-gitlab` Slack channel, and by re-posting a reminder at 00:00 UTC on cleanup day. Office of the CEO (or CoS) will repost in the `#managers` channel for visibility.

## Program managing JiHu

A member of the Office of the CEO is the DRI within GitLab for the success of GitLab's partnership with [JiHu](https://about.gitlab.com/pricing/faq-jihu/). Coordination with JiHu requires engagement from multiple functions within GitLab. The Office of the CEO ensures that the appropriate folks are engaged at the right times and that GitLab provides appropriate support to this separate entity.

For example, this member ensures that there is an aligned process among relevant GitLab functions after a customer requests to [transit to JiHu](https://about.gitlab.com/pricing/faq-jihu/#customer-details):

1. After the Customer's request of novation from GitLab to JiHu is approved, the member of the Office of the CEO opens a new issue as soon as the contract is issued, and assigns the issue to GitLab Accounting department.
1. This issue triggers the Accounting development to update SFDC, Zuora and NS.
1. If there is no issue raised in the month, it means there is no novation in that month.
1. This process takes effects from 2023-02-01, and replaces the previous process that an issue is created each month regardless whether there is novation in the month or not.

## Organizational pulse

Due to its cross-functional scope and access to information, the Office of the CEO is uniquely positioned to see what is happening across the company. Members of the Office of the CEO are encouraged to regularly have [coffee chats](/handbook/company/culture/all-remote/informal-communication/#coffee-chats) with folks outside of the team and share key insights and feedback from these conversations.

## Measuring results

We are evaluating different ways to measure our success as a team. These include:

1. A company-wide team satisfaction score
1. A pulse survey sent to a few targeted folks who have worked closely with the Office of the CEO team members in the past quarter
1. Score against team quarterly goals
1. Score on success in a few top initiatives within a quarter

## Chief of Staff Shadow

The Chief of Staff to the CEO may occasionally have a Chief of Staff Shadow, a GitLab team member who will participate in a specific project or initiative for a fixed time. Depending on the projec or initiative, the team member may spend most of their time with an Office of the CEO team member instead.

Shadow responsibilities could include: taking notes, providing feedback, and/or supporting the overall initiative success. This role would be in addition to any existing responsibilities at GitLab. Participants would opt in to experience another function within GitLab and contribute to a different part of the business. Since participation would be in addition to an existing workload, managers must sign off before a CoS to the CEO Shadow can participate. Interested team members can share their interest with the Chief of Staff to the CEO in the `#ceo-chief-of-staff-team` Slack channel. The CoS to the CEO will follow up with you to understand what you are looking to get out of the experience and review projects that may be a good match. If there is not an existing project, you will be kept in mind for future opportunities.

Once a project or initiative to Shadow has been identified and the team member decides to participate, the team member should open a merge request to add their name to the below table. The MR should be shared through Slack in the `#ceo-chief-of-staff-team` channel for review and merge. Optionally, the team member can make use of the [internship for learning](/handbook/people-group/learning-and-development/internship-for-learning/) as a framework to guide the Shadow period.

| Start Date | End Date   | First & Last Name | GitLab Handle | Project/Initiative |
| ---------- | ---------- | ----------------- | ------------- | ------------------ |
| 2020-05-23 | 2020-08-21 | Mike Miranda      | @mmiranda     |  |
| 2020-08-31 | 2021-07-18 | Jerome Ng         | @jeromezng    | JiHu |
| 2021-06-02 | 2021-09-01 | Samantha Lee      | @slee24       | Shadow Michelle Lee |
| 2023-03-06 | 2023-11-01 | Cynthia "Arty" Ng | @cynthia      | [TeamOps](https://gitlab.com/gitlab-com/people-group/Training/-/issues/2178) and [OKRs](https://gitlab.com/gitlab-com/people-group/Training/-/issues/2249) (internal links) |

### Important things to note

1. This is not a performance evaluation
1. Plan to observe and ask questions.
1. Participating in the shadow program is a privilege where you will be exposed to confidential information. This is underpinned by trust in the shadows to honor the confidentiality of topics being discussed and information shared. The continuation of this program is entirely dependent on shadows past, present, and future honoring this trust placed in them.
1. Give feedback to and receive feedback from the Chief of Staff to the CEO. Participants in the shadow program are encouraged to deliver [candid feedback](/handbook/people-group/guidance-on-feedback/#guidelines-for-delivering-feedback). Shadows maintaining confidentiality during the program is separate from shadows being able to provide candid feedback.

## Quick Links and Fun Facts

- [Chief of Staff to the CEO Job Family](/job-families/chief-executive-officer/chief-of-staff/)
- [Strategy & Operations Job Family]({{< ref strategy-and-operations >}})
- [GitLab Strategy and Operations (Workplace) Team Handbook]({{< ref workplace >}})
- [Performance Indicators]({{< ref performance-indicators >}})
- [GitLab Team Project](https://gitlab.com/gitlab-com/office-of-the-ceo/cos-team)
- [Team READMEs]({{< ref readmes >}})

## Contact Us

- `#ceo-chief-of-staff-team` on Slack (GitLab Team Members only)

### GitLab / Google Groups

The Office of the CEO maintains a [GitLab Group](https://gitlab.com/groups/gitlab-com/office-of-the-ceo/-/group_members?with_inherited_permissions=exclude) and [Google Group](https://groups.google.com/a/gitlab.com/g/office-of-the-ceo/members) to ensure the appropriate level of access is granted or removed as team members join and leave the team. The following mapping of permission levels from GitLab Groups to Google Groups is being used:

1. `Owner` -> `Owner`
1. `Maintainer` -> `Manager`
1. `Developer` -> `Member`

As of 2023-08 there's no automatic syncing between these groups so Office of the CEO team members who have the appropriate permission level in each group should add or remove team members as they join and leave the team.

#### GitLab Project

The primary project used by the Office of the CEO to track work specific to our team is [Office of the CEO](https://gitlab.com/gitlab-com/office-of-the-ceo/cos-team). Please file issues here as needed to track work being done.
