---
title: Ask Me Anything
description: "Learn and ask questions at GitLab's Ask Me Anything (AMA) meetings"
---

## Purpose

Ask Me Anything (AMA) meetings are arranged to allow team members the opportunity to learn from and ask questions of our [E-Group](/handbook/company/structure/#e-group), [Board of Directors](/handbook/board-meetings/#board-of-directors), and others groups who would like to host an AMA on a specific topic. AMAs can be arranged for many purposes, including the following:

- Allow team members to meet new leaders joining the company
- Clarify a company-wide initiative or change that requires more discussion
- Allow team members to learn more about current leaders
- Spark insightful discussions
- Initiate a retrospective discussion

### Who's Involved

AMA meetings typically include the whole company, and are usually initiated by a leader, team member, or a group of leaders.

They can be initiated by anyone who wants to schedule an AMA, but are typically initiated by one of the following:

- [GitLab E-Group Member](/handbook/company/team/?department=executive)
- Director + Leaders
- [Board Member](/handbook/board-meetings/#board-of-directors)
- [GitLab TMRG group](/handbook/company/culture/inclusion/erg-guide/)

AMAs do not need to have a host, but there should be a person or people available to answer questions related to the AMA topic.

Occasionally an AMA might be held for a smaller audience. It is encouraged for all AMAs to be open to the full company whenever possible. Occasionally an AMA may not make sense to be sent to the whole company. In those instances, it is still encouraged to add the calendar invitation to the GitLab Team Meetings Calendar as sometimes team members may want to join a call that may not be directly applicable to them. Whenever creating an AMA for a smaller group, be sure to invite the team directly in the calendar invite.

### AMA Kick off (best practices when starting an AMA)

This guidance is primarily for the person or people who will be answering questions at a given AMA.

Adding context to the AMA agenda and using the first 1-2 minutes of an AMA to ensure the audience understands how the time will be used has shown to lead to more engaging AMAs.

Ensure the following items are added to the AMA agenda and follow these steps to set your AMA up for success:

- The person or people responsible for answering questions should be listed in the AMA agenda and start the AMA by introducing themselves and their roles at GitLab.
- If a brief explanation about *why* this AMA is being hosted may help the audience understand the purpose for the session, add a first agenda item that adds context and verbalize that point after introducing yourself.
  - If multiple people will be responding to questions, identify one person to speak about *why* this AMA is being hosted by adding their name to the agenda item.
- Information about how and where questions can be asked by the audience should be captured in the AMA agenda.
  - For most AMAs, questions will be asked in an agenda doc, if this is the case please share that questions can also be asked in the Zoom chat if the agenda doc cannot be accessed.
  - If sli.do or another platform is being used to ask questions, this should be noted.
- If there is additional context the audience should be aware of to fully participate in the AMA or any documents that provide additional information that the audience should know about, it's a good practice to highlight these things up front by adding them as agenda items.
- After that, onto the first question!

### Agenda document recommendations

A lot of team members attend AMAs which can lead to the agenda document becoming overloaded. Since this can mean that notes can't be taken for the discussion, it's recommended that team members add their questions to the document and then close the document unless they're actively taking notes.

Team members who require the written notes in order to participate and/or retain information are encouraged to remain in the document.

If the Google document becomes overloaded, people should add their questions to the zoom chat so that a notetaker or moderator of the AMA with access to the document can copy their questions into the agenda.

For team members who are watching the AMA but don't have questions, consider opening the agenda document to gain any initial context but then closing the document in advance of any discussion.

The intention of this is to make sure we're enabling asynchronous communication by allowing team members not in attendance to read a complete record of the AMA at a later time.

### Process for initiating a Reverse AMA

#### E-Group Initiated

- If an E-Group team member would like a Reverse AMA, they or their EBA will contact an associated TMRG. If there isn't an associated TMRG the E-Group member or EBA will broadcast a message through their Slack channel to see if there is a population of members for the AMA.
- The E-Group member or EBA will create an issue (template to follow) tagging the [TMRG Leads](/handbook/company/culture/inclusion/erg-guide/#how-to-join-current-tmrgs-and-their-slack-channels) or a nominated facilitator for a non-tmrg AMA (facilitator group to be determined), a [DIB Team Member](https://gitlab.slack.com/archives/CLLDY3L8P/p1617863963093900), and Stella Treas (Chief of Staff to the CEO)
- The TMRG Leads will consult with the TMRG membership and accept or reject the request. If accepted the TMRG leads will provide an ideal timeframe for the AMA, ideally within 4 weeks from the date of the request.
- Once accepted the EBA will provide a series of times that are suitable
- The E-Group member or EBA will ensure that there is a Reverse AMA facilitator for the session. (Facilitator Group link to follow)
- The EBA will create a calendar invite and Agenda for the agreed time

#### Team Member Initiated

- A team member of a particular underrepresented group will create an issue (Template link to follow)
- The team member will tag a [DIB Team Member](https://gitlab.slack.com/archives/CLLDY3L8P/p1617863963093900), the [E-Group Members EBA](/handbook/eba/) and Stella Treas (Chief of Staff to the CEO)
- The E-Group member will review the request, the E-Group member can suggest an alternative member including a direct report to host the AMA or may reject the AMA based on the information provided in the issue.
- If accepted the E-Group EBA will work with the E-Group member or direct report to find a time and date that is suitable.
- The team member will work the EBA to ensure an agenda and facilitator are in place.

#### Reverse AMA Facilitators

It is near impossible to be an effective facilitator while also being a participant.  So if you have been identified as a facilitator but would rather participate in the conversation, we encourage you to ask one of your designated facilitator team members (Facilitator Group link to follow) to take your place.

Before facilitating a session, all facilitators will complete the following steps:

1. Complete the [LinkedIn Learning Facilitator Training](https://www.linkedin.com/learning/meeting-facilitation/)
1. Complete the [LinkedIn Learning Empathy Training](https://www.linkedin.com/learning/communicating-with-empathy/empathy-as-a-path-to-productive-conversations?u=2255073)
1. Watch the purpose of Reverse AMA's Video (too come)
1. Shadow a current facilitator when they are running and AMA
1. Be shadowed by a current facilitator in your first AMA

**Current Facilitators:**
Template: "Name" - "Role", **Self Identified (Optional):**

- Liam McNally - Diversity, Inclusion & Belonging Partner, **Self Identified (Optional):** CIS gender Man, Gay, Black, No Diverseabilities, Age: 31; **Region: APAC**
- Amanda Rueda - Diversity, Inclusion & Belonging Advisory Group Member, **Self Identified (Optional):** CIS gender Woman, Age: 45; **Region: NORAM**
- Giuliana Lucchesi - People Business Partner, **Self Identified (Optional):** CIS gender woman; **Region: NORAM**
- Carolyn Bednarz - People Business Partner, **Self Identified (Optional):** CIS gender woman; **Region: NORAM**
- Roos Takken - People Business Partner, **Self Identified (Optional):** CIS gender woman; **Region: EMEA**

#### Reverse AMA Hosts

Every Reverse AMA will be hosted by the Executive Business Partner for the E-Group Leader even when the leader is not an E-Group Member

The Executive Business Partner alignment can be found [here](/handbook/eba/)

**Things to remember:**

- Remain impartial
- Ensure the call stays on track
- Keep a track of time
- Ensure that a number of voices are heard, including agenda points

#### Scheduling a Reverse AMA

AMAs are generally coordinated, scheduled, and planned by the [Executive Business Administrator](/handbook/eba/) team when an E-Group member is the host. Anytime that an AMA is to be hosted by an executive, VP, or Director at GitLab, it should be arranged and scheduled by that functions EBA. AMAs of Board Members are scheduled by the Staff EBA to the CEO.

Other non-Executive AMAs are scheduled by the [People Operations](/handbook/people-group/#people-experience-vs-people-operations-core-responsibilities--response-timeline) team. These AMAs are typically a result of a change that impacts the company as a whole and may often be hosted by multiple leadership members in the company. Whenever there is an open slot in the Group Conversation calendar, the People Operations Team will reach out to the EBA team to create an AMA.

When scheduling an AMA, be mindful of timezones.  Generally it is best to have two AMAs, one for the Americas/EMEA time zone, and one for the APAC time zones.

Once a Reverse AMA takes place, a 15-30 minutes debrief meeting should be scheduled immediately following to ensure there is a timely discussion and DRIs are assigned to all actions.

Immediately should be within the week or following the Reverse AMA for best practices.  Understanding there are time zones and schedules to consider.  When possible scheduling the debrief ahead of time for immediately following the Reverse AMA would be an effective approach.  The debrief template includes the DRI and target to complete and should be updated accordingly.

The debrief should include the People Business Partner, AMA Facilitator and DIB team member.  There are times where the Debrief is scheduled with the E-group leader however this is optional and as needed.

### Setup

AMA meetings always start with an [agenda](https://docs.google.com/document/d/1-wrI4GB8N74O5AUmdnj916uhCbrL2adM8wbD_unrbac/edit?usp=sharing). Ensure that the agenda document is added to the calendar invite at the initial time it is sent to allow everyone to be involved. All questions and answers should be documented in the agenda to allow those who can not attend to catch up as well as to avoid team members talking over each other.

Whenever possible AMAs should be private or publicly [live streamed](/handbook/marketing/marketing-operations/youtube/#public-or-private-streaming). Please strive to remain [public by default](/handbook/values/#public-by-default) when hosting an AMA unless it is centered around a topic that is [not-public](/handbook/values/#not-public)

The DIB Team and the EBAs will ensure that each Reverse AMA has the correct team members invited, the DIB team will ask People Connect to run this [Report](https://docs.google.com/spreadsheets/d/1Ai8Trh0FOr5O7CJfhdTDsPM517NCEwzkiJcytLETOHk/edit#gid=1182431189) monthly (this is private please request if you need access with your reasoning) to ensure we keep attendees up to date.

### Process Once Reverse AMA is Setup

1. Determine all the roles for the call.
    - Note taker - this role should be assumed by the Business Partner for that group.  If you are the note taker, please reach out to the facilitator to ensure there isn't a concern of confidentiality in the note taker as a presence on the call.
    - Facilitator - reach out to the facilitator of choice based on regions from the list above
1. Create follow up actions google doc leveraging the following [template here](https://docs.google.com/document/d/1oTiRS99IokoQ4CQYWalVXzW8BAL3wq8gr1RZFIQAbpI/edit?usp=sharing).
1. Schedule the follow up call for actions with the leader, DIB team member Candace or Liam and the Business Partner for the group.
1. Create a confidential slack channel if needed for that Reverse AMA to communicate transparently action items and or ongoing feedback, etc.

## Reverse Ask Me Anything

The Reverse AMA format was launched in Sales with our [Black](/handbook/company/culture/inclusion/#definitions) team members. We wanted to start with this with Black team members to show support and to stand in solidarity, in response to domestic events in the US, and globally. One of our core [values](/handbook/values/) is DIB (Diversity, Inclusion and Belonging), and part of embracing that value means being better [allies](/handbook/communication/ally-resources/). These can be scheduled to facilitate meaningful conversations with any underrepresented group.

**Benefits**

- Improve efforts at driving inclusion and belonging at every level
- Enhance open communication
- Direct access to the leadership
- Opportunity to share experiences and provide feedback
- Improve Talent Acquisition, Retention and Mobility of underrepresented groups
- Continue to grow our great network of diverse talent

**Goals**

- To continue the momentum of conveying genuine empathy and solidarity for our underrepresented team members
- To address areas of challenges and opportunities identified by underrepresented team members
- To allow for open, honest communication within a specific format
- To increase interaction between Sales Leadership and team members
- To identify opportunities to implement specific DI&B initiatives with leadership support

**Format**

- A 50 minute closed Zoom call
- Attendees: E-Group member and interested team members in the relevant department who identify as part of the underrepresented group
- Questions asked by the E-Group member, answered by underrepresented group team members
- Format facilitated by People Business Partners

**Schedule**

- Quarterly

## Actions and follow ups

All actions and follow up items should live in the [Reverse AMA EPIC](https://gitlab.com/groups/gitlab-com/people-group/dib-diversity-inclusion-and-belonging/-/epics/17) under the child EPIC for the Reverse AMA

If your underrepresented group has not been assigned a Diversity, Inclusion & Belonging team directly responsible individual please contact Candace or Liam.
