---
title: "GitLab Communication Chat"
---

## Introduction

At GitLab, Slack is critical to our communication with each other.  While it enables real-time communication, we also are careful to remain true to our asynchronous mindset, suggesting that GitLab team-members set "do not disturb" and not expect real-time answers from others all the time.

There are groups of channels that can help with various areas of GitLab. This page speaks to a few subsets of those channel groups.

## Search

Search for channels using either the `Search GitLab` toolbar, using a channel name with the `#channel-name` format, **or** go the left sidebar, click on `More` and then `Channel browser`.

## Channels

### Key Slack channels

The alphabetically sorted starter list below spotlights a few of GitLab's many Slack channels in an effort to provide guidance to team members regarding the best places to ask specific questions and/or engage in discussion on a variety of topics. See Slack's [Help Center](https://slack.com/help/articles/205239967-Join-a-channel) for instructions on browsing all available channels.

| Channel                              | Purpose                                                                                                                                                                                                                              |
| ------------------------------------ | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ |
| `#company-fyi`                       | Official company announcements, restricted permission levels to ensure high-signal; all GitLab team members are automatically added to this channel.                                                      |
| `#whats-happening-at-gitlab`         | Open to all team members for unofficial updates which are important and/or useful to **most or all** of GitLab, including reminders, events, project updates, etc.; all GitLab team members are automatically added to this channel. |
| `#diversity_inclusion_and_belonging` | Stay up to date on GitLab's latest [Diversity, Inclusion and Belonging](/handbook/company/culture/inclusion/) initiatives and share feedback and thoughts about how we can make our environment even more inclusive.                          |
| `#expense-reporting-inquiries`       | For questions pertaining to [expenses](/handbook/finance/spending-company-money/) (e.g. Navan).                                                                                                                                          |
| `#git-help`                          | Specific questions about using Git in the terminal.                                                                                                                                                                                  |
| `#is-this-known`                     | Get help in finding existing issues for existing problems.                                                                                                                                                                           |
| `#it_help`                           | Create a Help Request in this channel should you have any IT general questions or trouble with setup (e.g. 2FA, accounts, etc.). |
| `#mr-buddies`                        | For any questions regarding merge requests.                                                                                                                                                                                          |
| `#new_team_members`                  | For new GitLab team members to introduce themselves to the company and for existing team members to share updates with new hires.                                                                                                    |
| `#new-vacancies`                  | For all GitLab team members to be aware of internal opportunities, as well as all job openings as they are listed. Please review the [referral process](/handbook/hiring/referral-process/) page to find out more about referring someone for a role.                                                                                                   |
| `#payroll`                           | For questions pertaining to [payroll](/handbook/finance/payroll/) and [contractor invoices](/handbook/finance/payroll/#non-us) (e.g. ADP, etc.).                                                                                     |
| `#safe`                            | SAFE                                                                                  |
| `#security`                            | Security                                                                                  |
| `#talent-acquisition`                | For questions about [referrals](/handbook/hiring/referral-process/), the [hiring process](/handbook/hiring/), and/or candidate status.                                                                                               |
| `#team-member-updates`               | To stay updated on transitions/promotions, new GitLab team members joining, work anniversaries, etc.                                                                                                                                 |

### General Channels {#random-room}

There are a lot of general channels, just to name a few:

- **[`#questions`](https://gitlab.slack.com/archives/questions)**: Ask all of GitLab for help with any question you have... and then go document it after you find the answer :)
- **[`#thanks`](https://gitlab.slack.com/archives/thanks)**: Where GitLab team-members can [say thanks](/handbook/communication/#say-thanks) to those GitLab team-members who did a great job, helped a customer, or helped you! Also where managers recoginze discretionary bonuses for their teams.
- **[`#office-today`](https://gitlab.slack.com/archives/office-today)**: GitLab is an [all-remote](/handbook/company/culture/all-remote/) organization. Where's your office today?
- **[`#remote`](https://gitlab.slack.com/archives/travel)**: To share news, thoughts, feedback and anything else pertaining to remote work! Learn more about [GitLab's approach to remote work](/handbook/company/culture/all-remote/)
- **[`#travel`](https://gitlab.slack.com/archives/travel)**: A place to discuss all things [travel](/handbook/company/culture/all-remote/people/#travelers)
- **[`#women`](https://gitlab.slack.com/archives/travel)**: Employee resource group for members and allies.
- **[`#values`](https://gitlab.slack.com/archives/travel)**: Channel to discuss iterations on GitLab values
- **[`#random`](https://gitlab.slack.com/archives/random)**:  Socialize and share random snippets with your fellow GitLab team-members.

### Getting in touch with the e-group

To get in touch with the [e-group](/handbook/company/team/?department=executive) on Slack, you can use the following channels. When in doubt, you can use the general `#e-group` channel to reach out to the entire group.

| Member | Channel      |
| ------ | ------------ |
| CEO    | `#ceo`       |
| CFO    | `#finance`   |
| CProdO | `#product`   |
| CTO    | `#cto`       |
| CRO    | `#cro`       |
| CMO    | `#cmo` |
| CPO    | `#cpo` |
| CLO    | `#legal`     |
| CISO   | `#ciso`      |

### Team Channels

To raise an issue with a specific team, please use below most commonly used channels;

- **`#it_help`**: For IT related queries, Okta, issues with hardware, software, system access requests and user permissions etc
- **`#talent-acquisition`**: For referrals based questions, candidate alignments, general talent acquisition etc

### Channel Categories

#### Account Channels (a_)

These channels (prefixed with a `a_`) are for team members to collaborate and communicate regarding the account for a customer organization. Depending on the customer, they are sometimes internal, marked as private or we shared with the customer by connecting to customer's own Slack workspace. In order to clearly differentiate between these shared and internal channels, we recommend using `a_XYZ-internal` and `a_XYZ-external` naming conventions to be explicitly clear (as the shared symbol can be easily missed in Slack).

To request a new channel or to make changes to existing channels, please use the [access request process](/handbook/it/end-user-services/onboarding-access-requests/access-requests/#slack-google-groups-1password-vaults-or-groups-access-requests).

Commercial (Mid-Market and SMB) accounts have specific guidelines around having Slack channels with customers.

#### External Channels (ext-)

These channels (prefixed with `ext-`) are used for communication with vendors or partners. They are typically shared channels between GitLab's Slack workspace and the external organization's Slack workspace.

**Example**

- **`#ext-gitlab-abc`**: Shared channel with Customer/Vendor ABC for project collaboration and support.

When using an external channel, ensure that you follow GitLab's guidelines for external communication, including keeping information [SAFE](/handbook/legal/safe-framework/). External channels with no activity in the last year will be removed by CorpSec.

Steps:

1. Create an [access request](https://gitlab.com/gitlab-com/team-member-epics/access-requests/-/issues/new#) with template "slack_googlegroup_1Passwordgroupvault".
1. After the access request is approved by your manager, please invite the external party to our Slack workspace. This will generate a message in #shared-channels.
1. Please share that access request by replying to the message generated in #shared-channels. An administrator will then approve the request.

#### Feature Channels (f_)

These channels are for teams and GitLab team-members interested in a specific feature that exists in GitLab or is being built today!

**Examples**

- **[`#f_web_ide`](https://gitlab.slack.com/archives/f_web_ide)**: Share ideas and feedback about our [Web IDE](https://about.gitlab.com/blog/2018/06/15/introducing-gitlab-s-integrated-development-environment/)
- **[`#f_ldap`](https://gitlab.slack.com/archives/f_ldap)**: Talk about our integration with [LDAP providers](https://docs.gitlab.com/ee/administration/auth/ldap/index.html).

#### Group Channels (g_)

Group channels (prefixed with a `g_`) correspond to a [DevOps Stage group](/handbook/product/categories/#hierarchy) and other [engineering departments and teams](/handbook/engineering/#engineering-departments--teams).

**Example**

- **[`#g_create`](https://gitlab.slack.com/archives/g_create)**: Channel for the [Create](/handbook/product/categories/#create-stage) development group.
- **[`#g_create_source-code`](https://gitlab.slack.com/archives/g_create_source-code)**: Channel for the [Source Code](/handbook/product/categories/#source-code-group) development group.
- **[`#g_geo`](https://gitlab.slack.com/archives/g_geo)**: Dedicated to the [Geo group](/handbook/engineering/development/enablement/systems/geo/).

#### Location Channels (loc_)

These channels are used to help GitLab team-members who are in the same general region of the world to talk about get-togethers and other location-specific items. They are also instrumental if you're going to be visiting somewhere else in the world - there might be a GitLab team-member or two nearby! Feel free to join the channel temporarily to chat with GitLab team-members who live there, and see if there is an opportunity to leverage the [visiting grant](/handbook/total-rewards/incentives/#visiting-grant) to add value to your trip.

If there's a channel not listed below, please add in alphabetical order with an MR.

| Channel Name | Description |
|---|---|
| [`#loc_4corners`](https://app.slack.com/client/T02592416/C51L9MZEV) | people that live in Utah, Colorado, Arizona, and New Mexico for meet-ups |
| [`#loc_adelaide`](https://app.slack.com/client/T02592416/C03855YCQMT) | For the growing team presence in Adelaide, South Australia! |
| [`#loc_africa`](https://app.slack.com/client/T02592416/C03S002M075) | 🇸🇹🇸🇱🇸🇨🇸🇳🇸🇩🇸🇸🇿🇦🇸🇴🇸🇿🇨🇬🇨🇩🇦🇴🇩🇿🇧🇯🇧🇼🇹🇩🇨🇫🇨🇲🇧🇮🇧🇫🇨🇮🇰🇲🇪🇷🇬🇶🇪🇬🇩🇯🇬🇭... |
| [`#loc_alberta`](https://app.slack.com/client/T02592416/CN78PSCTW) | Locals to Alberta, Canada |
| [`#loc_amsterdam`](https://app.slack.com/client/T02592416/CPV03CGTV) | Amsterdam location-specific channel |
| [`#loc_annapolis`](https://app.slack.com/client/T02592416/CPZG77JA2) |  |
| [`#loc_arizona`](https://app.slack.com/client/T02592416/CTALWU0GK) | Discussion / Intro / Meetup for people in Arizona, USA |
| [`#loc_atl`](https://app.slack.com/client/T02592416/CBNQ29E90) | House channel for greater Atlanta area |
| [`#loc_atx`](https://app.slack.com/client/T02592416/CLHPXPX5W) | Austin, Texas! |
| [`#loc_australia`](https://app.slack.com/client/T02592416/CHHFS9DR7) | Australia Specific Chat |
| [`#loc_austria`](https://app.slack.com/client/T02592416/CH49EGEHM) | A channel around the beautiful city of Vienna, come and visit us! |
| [`#loc_avl`](https://app.slack.com/client/T02592416/C0477ERH8CF) | Asheville, North Carolina 🍂🏔️🍂 |
| [`#loc_bali`](https://app.slack.com/client/T02592416/CQL1DF5FX) | Channel for those traveling to Bali in 2022. |
| [`#loc_bayarea`](https://app.slack.com/client/T02592416/C03ATS0N2) | House channel for Mountain View. |
| [`#loc_bc`](https://app.slack.com/client/T02592416/C011GM1LDDW) |  |
| [`#loc_belgium`](https://app.slack.com/client/T02592416/CR2T6HHCP) | 🇧🇪🍺🍫🍟     |
| [`#loc_berlin`](https://app.slack.com/client/T02592416/C3SB0FKD4) | All things going on in Berlin, Germany. We are regularly meeting up on the 3rd Thursday of the Month. |
| [`#loc_bochum`](https://app.slack.com/client/T02592416/CFV9XLA67) | For all folks from Bochum, Germany. ⛏ https://www.youtube.com/watch?v=Gtd9Bg9S85U |
| [`#loc_brisbane`](https://app.slack.com/client/T02592416/CH436GSNM) | Discuss all the Brisbane things |
| [`#loc_canada`](https://app.slack.com/client/T02592416/CERJB2EBY) | All things Canada 🇨🇦  |
| [`#loc_cencoastca`](https://app.slack.com/client/T02592416/CLQPEBG8Y) | Connecting those living or passing through the Central Coast of California |
| [`#loc_chennai`](https://app.slack.com/client/T02592416/C029M048TFX) |  |
| [`#loc_cincy`](https://app.slack.com/client/T02592416/CG2RC06L8) |  |
| [`#loc_clt`](https://app.slack.com/client/T02592416/CSPPH6JJK) | For those who live in/near (or visit) the Charlotte, NC, USA area! |
| [`#loc_czech`](https://app.slack.com/client/T02592416/CHTCRDV2N) | 🇨🇿 living in or visiting Czech Republic?  |
| [`#loc_dallas`](https://app.slack.com/client/T02592416/CSARGT3ME) |  |
| [`#loc_delaware`](https://app.slack.com/client/T02592416/CRG5B7E59) | delaWHERE? |
| [`#loc_delhi_ncr`](https://app.slack.com/client/T02592416/CLY3PMHUP) |  |
| [`#loc_denmark`](https://app.slack.com/client/T02592416/CKC8PJP18) |  |
| [`#loc_denver`](https://app.slack.com/client/T02592416/C1S8BHWF7) | All things Denver, CO and surrounding areas! |
| [`#loc_digital-nomad`](https://app.slack.com/client/T02592416/CDHFXPNQM) | Anyone else living the digital nomad life? Maybe let's find spots to travel together! Share your travel plans if you'd like and make connections abroad 🙂 |
| [`#loc_dmv`](https://app.slack.com/client/T02592416/C7UJ658ET) | for people in and around DC, Maryland, Virginia |
| [`#loc_dontmesswithtexas`](https://app.slack.com/client/T02592416/C52UG8XL5) |  |
| [`#loc_egypt`](https://app.slack.com/client/T02592416/C02KC9Y9TMF) | 🇪🇬 Masr Heya Ommy 🇪🇬    |
| [`#loc_hamburg`](https://app.slack.com/client/T02592416/CFE1STZEH) | Local channel for Hamburg, Germany |
| [`#loc_hawaii`](https://app.slack.com/client/T02592416/CJRG60YG6) | For people traveling to, or living in Hawaii |
| [`#loc_houston`](https://app.slack.com/client/T02592416/CTBQNC693) |  |
| [`#loc_hungary`](https://app.slack.com/client/T02592416/CCKUZEX39) | For folks living in or visiting Hungary |
| [`#loc_iceland`](https://app.slack.com/client/T02592416/CMFJ0BZNZ) | GitLab team members in Iceland |
| [`#loc_india`](https://app.slack.com/client/T02592416/CDKF2QND7) | Indians at GitLab |
| [`#loc_indianapolis`](https://app.slack.com/client/T02592416/C01071LFT3J) | Local Indiana/Indianapolis GitLab team members |
| [`#loc_ireland`](https://app.slack.com/client/T02592416/CFN507G9H) |  |
| [`#loc_israel`](https://app.slack.com/client/T02592416/CLTSE8L91) | Sync Locally for GitLab team members in Israel |
| [`#loc_italy`](https://app.slack.com/client/T02592416/CCL55MRH6) |  |
| [`#loc_japan`](https://app.slack.com/client/T02592416/CSWKAJ8HF) |  |
| [`#loc_kansas-city`](https://app.slack.com/client/T02592416/CHWJVF61W) | Channel for KC GitLabbers |
| [`#loc_kerala`](https://app.slack.com/client/T02592416/CU2RGRWR0) | Anything about Kerala |
| [`#loc_korea`](https://app.slack.com/client/T02592416/C02KTP5QVJS) |  |
| [`#loc_ky`](https://app.slack.com/client/T02592416/C03EWKE264A) | Location: Kentucky - Georgetown, Lexington, and Versailles |
| [`#loc_leipzig`](https://app.slack.com/client/T02592416/CS81KREG3) | NY Times list of places to visit in 2020: https://www.nytimes.com/interactive/2020/travel/places-to-visit.html?place=leipzig |
| [`#loc_lille`](https://app.slack.com/client/T02592416/CTZ3U5AS1) |  |
| [`#loc_london-uk`](https://app.slack.com/client/T02592416/C3CEJ4DEZ) | London meetups! |
| [`#loc_manchester`](https://app.slack.com/client/T02592416/C03E9UXJXDF) | Channel for GitLab team members from Manchester (UK) and it's surrounding areas |
| [`#loc_mars`](https://app.slack.com/client/T02592416/CSB2ZVA9F) | Being optimistic |
| [`#loc_melbourne`](https://app.slack.com/client/T02592416/CBE1S2HMH) |  |
| [`#loc_mexico`](https://app.slack.com/client/T02592416/CEPQ1GBRC) | For people living/visiting Mexico 🇲🇽  |
| [`#loc_michigan`](https://app.slack.com/client/T02592416/CN2NUGTP0) | All Things "Great Lakes State" |
| [`#loc_minnesota`](https://app.slack.com/client/T02592416/C62D93RRU) |  |
| [`#loc_montreal`](https://app.slack.com/client/T02592416/CT83NVCA3) |  |
| [`#loc_moscow`](https://app.slack.com/client/T02592416/CK9LK96LE) |  |
| [`#loc_mt`](https://app.slack.com/client/T02592416/C01J5BAPPU4) | Montana GitLab Team Members |
| [`#loc_munich`](https://app.slack.com/client/T02592416/CM25953MH) | As of today none of us seems to be living in Munich. But there are Meetups and Events and maybe also occasions to meet in Munich for some co-working. Here we can team up. |
| [`#loc_n-ireland`](https://gitlab.slack.com/archives/C03V4FEEQE7) | N.Ireland slack channel, so it is |
| [`#loc_nashville`](https://gitlab.slack.com/archives/loc_nashville) | Nashvillians Unite! |
| [`#loc_newengland`](https://app.slack.com/client/T02592416/CJV0FMCH4) | Channel for those located in New England |
| [`#loc_nigeria`](https://app.slack.com/client/T02592416/CDB11DSRH) |  |
| [`#loc_noco_aka_loconoco`](https://app.slack.com/client/T02592416/CJPLQ4LEM) | Connect GitLab team members who are in Boulder, Larimer and Weld Counties of Northern Colorado |
| [`#loc_nuremberg`](https://gitlab.enterprise.slack.com/archives/C06R3T513E1) | Franconia, Germany - gingerbread, sausages, and more |
| [`#loc_nyc`](https://app.slack.com/client/T02592416/C0XBJTC00) | Coordinate NYC-area coworking days and other events. Let us know if you're coming to town, and see our visitors doc! 🇺🇸 🗽 <https://docs.google.com/document/d/1aTW4P0V44S9hBppStCOVl3bfLq6qW6hoJFW_Er6HOdA/>   |
| [`#loc_nz`](https://app.slack.com/client/T02592416/CF8MAMD39) | 🇳🇿 For those visiting, living in or interested in Aotearoa New Zealand. Also half of `#loc_australia` is in here too. https://docs.google.com/document/d/1VijZowFu8WpyV17MtRtrvz1GUqw9Y5Bcf-OkUOEU774/edit |
| [`#loc_ottawa`](https://app.slack.com/client/T02592416/C01KH7P3KBR) |  |
| [`#loc_pdx`](https://app.slack.com/client/T02592416/CS7N7UFGR) | For GitLab team members in/around Portland Oregon |
| [`#loc_perth`](https://app.slack.com/client/T02592416/CQ6LTSP4L) | Join us (me) for enthralling (adequate) Perth, Australia conversation |
| [`#loc_philadelphia`](https://app.slack.com/client/T02592416/C85RGQUFJ) | Philly local items/discussion/events |
| [`#loc_philippines`](https://app.slack.com/client/T02592416/CL95ZB8V7) |  |
| [`#loc_pittsburgh`](https://app.slack.com/client/T02592416/C02E5TJVDN2) | A city of bridges, 3 rivers and fries on top of salads |
| [`#loc_pnw`](https://app.slack.com/client/T02592416/CBFBYUCAH) | For GitLab team members living in or visiting the Pacific Northwest (Cascadia): Washington, Oregon, and BC (Canada), includes Seattle and Portland. |
| [`#loc_portugal`](https://app.slack.com/client/T02592416/C1X1KLMNH) | For anyone living or visiting Portugal 🇵🇹  |
| [`#loc_qld`](https://app.slack.com/client/T02592416/C02RGGJFY03) | Queeeeeeeenslander! |
| [`#loc_quebec`](https://app.slack.com/client/T02592416/CQV5PLEUR) | All things Quebec ⚜️ |
| [`#loc_ratingen`](https://app.slack.com/client/T02592416/C01DX6YHZU3) | I guess it's just me |
| [`#loc_rdu`](https://app.slack.com/client/T02592416/CGCCE7ZAR) | For those who live or visit the Raleigh Durham area in North Carolina, U.S.A. |
| [`#loc_romania`](https://app.slack.com/client/T02592416/CMTAGFMTR) | 🇷🇴  |
| [`#loc_russia`](https://app.slack.com/client/T02592416/CM8C6FXPC) |  |
| [`#loc_sacramento_reno`](https://app.slack.com/client/T02592416/CH4MFKWQ7) | Visiting Sacramento, Roseville, Folsom, Elk Grove, Rocklin, Reno or even Tahoe? For GitLab team members based in the area and anyone who is visiting |
| [`#loc_sanantonio`](https://app.slack.com/client/T02592416/CPPEK0E4X) | Channel for San Antonio GitLab Team Members |
| [`#loc_sask`](https://app.slack.com/client/T02592416/CR2QGNAMS) | Saskatchewan (Canada) folks. |
| [`#loc_sc`](https://app.slack.com/client/T02592416/C01BCDZV2QY) | For GitLab team members living in South Carolina. |
| [`#loc_scotland`](https://app.slack.com/client/T02592416/CA9BDV35M) | Aye |
| [`#loc_serbia`](https://app.slack.com/client/T02592416/C0113E5GXAS) |  |
| [`#loc_singapore`](https://app.slack.com/client/T02592416/CSAHCV39U) |  |
| [`#loc_slovenia`](https://app.slack.com/client/T02592416/CFC9BFEHF) |  |
| [`#loc_socal`](https://app.slack.com/client/T02592416/CBWR3E1D4) | 🌴🇺🇸   |
| [`#loc_south_africa`](https://app.slack.com/client/T02592416/CCNKEV2R0) | Mzanzi! 🇿🇦🇿🇦    |
| [`#loc_south_east_asia`](https://app.slack.com/client/T02592416/CE3SJHYN7) | Chat for people staying / visiting ASEAN |
| [`#loc_spain`](https://app.slack.com/client/T02592416/C2H5FL4QJ) |  |
| [`#loc_switzerland`](https://app.slack.com/client/T02592416/CJU43HLK1) | Everything Switzerland 🇨🇭  |
| [`#loc_sydney`](https://app.slack.com/client/T02592416/CE5Q6THK9) |  |
| [`#loc_taiwan`](https://app.slack.com/client/T02592416/CBRRCBL90) |  |
| [`#loc_tn`](https://app.slack.com/client/T02592416/CRHHU1552) | Tennessee! |
| [`#loc_tokyo`](https://app.slack.com/client/T02592416/CJEML22JD) | Location: Tokyo, Japan |
| [`#loc_toronto`](https://app.slack.com/client/T02592416/CP3UKJ9Q9) | This is a channel for the Toronto team members. |
| [`#loc_turkey`](https://app.slack.com/client/T02592416/CSCVC7Q4E) | This is a slack channel for Turkey |
| [`#loc_uk`](https://gitlab.slack.com/archives/C0SQZ6D5Y) | For folks living, visiting, or interested in the United Kingdom |
| [`#loc_us_mid-atlantic`](https://app.slack.com/client/T02592416/C03QETSKEKY) | [US Mid-Atlantic states](https://en.wikipedia.org/wiki/Mid-Atlantic_(United_States)) |
| [`#loc_vegas`](https://app.slack.com/client/T02592416/CLKCQFKC3) | Are you visiting Vegas soon for fun or a conference? Connect with Vegas locals here for coffee meet-ups or recommendations! |
| [`#loc_vermont`](https://app.slack.com/client/T02592416/C03D8PUMHRS) | For our sole Vermonter ❤️ |
| [`#loc_wales`](https://app.slack.com/client/T02592416/CPX1QPTAR) | 🏴󠁧󠁢󠁷󠁬󠁳󠁿 - Come to discuss dragons, Brains 🍺 and rain 🌧               |
| [`#loc_yugoslavia`](https://app.slack.com/client/T02592416/CLQLDQ141) | whatever you wish |
| [`#loc-budapest`](https://app.slack.com/client/T02592416/CQ4SX28GH) | For those who love, live and work in Budapest |
| [`#loc-chicagoland`](https://app.slack.com/client/T02592416/CC285QEDU) | To connect folks in the Chicagoland area of the U.S. |
| [`#loc-costa-rica`](https://app.slack.com/client/T02592416/C01TG4VLFDK) |  |
| [`#loc-dublin`](https://app.slack.com/client/T02592416/CBK3B7EGM) | Connection with the Dublin team |
| [`#loc-latam`](https://app.slack.com/client/T02592416/CTA13962D) | For all team members from Latam , rest of the world welcome as well |
| [`#loc-midwest-u-s`](https://app.slack.com/client/T02592416/CC0BVGJTT) | To connect with GitLab team members in the Midwest region of the U.S. |
| [`#loc-utah`](https://app.slack.com/client/T02592416/C1F6XRA77) |  |
| [`#loc-west-lafayette`](https://app.slack.com/client/T02592416/CQ8HG9NNA) | West Lafayette, IN GitLab team members |
| [`#locnewyork`](https://app.slack.com/client/T02592416/CPLALPZ1Q) |  |
| [`#loc_usa`](https://gitlab.slack.com/archives/C045SQKUX6X) | General channel for USA |

#### Project Channels (proj_)

These channels are temporary and used to focus communication around a specific project. As an ephemeral channel they are archived once a project is complete and can be found in Slack by searching for `proj_`

#### Working Group Channels (wg_)

These channels are temporary and used to focus communication around a specific working group. As an ephemeral channel they are archived once the working group's exit criteria is met and can be found in Slack by searching for `wg_`

#### Stage Channels (s_)

Stage channels (prefixed with `s_`) correspond to stages within sub-departments.

**Examples**

- **[`#s_enablement`](https://gitlab.slack.com/archives/s_enablement)**: For the [Enablement stage](/handbook/product/categories/#enablement-stage).
- **[`#s_create`](https://gitlab.slack.com/archives/s_create)**: For the [Create stage](/handbook/product/categories/#create-stage).

#### Sub-Department Channels (sd_)

Sub-department channels (prefixed with `sd_`) correspond to sub-departments within departments.

**Example**

- **[`#sd_dev_engineering`](https://gitlab.slack.com/archives/sd_dev_engineering)**: For the [Engineering Dev sub-department](/handbook/engineering/development/dev/).

#### Social Groups

In addition to weekly company group calls that bring us together, GitLab has Social Slack Groups. Social Groups are Slack channels that bring team members together around common interests, hobbies, and lifestyles. Think tennis club, gaming, shell collectors, movie buffs, faith groups, football. You can see a list of Social Slack Groups and their tags below. Feel free to join any that resonate with you. This is a non-exhaustive list, but if you don't see a group you'd love to see on the list, reach out to our diversity, inclusion and belonging team and we'd love to explore your idea.

**Examples:**

- **[`#all-caps`](https://gitlab.slack.com/archives/C01BC085AVB)**: Light-hearted conversation in ALL CAPS.
- **[`#bookclub`](https://gitlab.slack.com/archives/C0GDX6MK6)**: A place for bibliophiles to connect, share recommendations and discuss their latest reads.
- **[`#cats`](https://gitlab.slack.com/archives/cats), [`#dog`](https://gitlab.slack.com/archives/dog), [`#cute-animal-photos`](https://gitlab.slack.com/archives/cute-animal-photos)**: Show us your cutest pics of your pets! We love all pets, but we made special channels for cats and dog(s).
- **[`#cheerleader`](https://gitlab.slack.com/archives/C027JBHML5A)**: When you need or want to share encouragement and support!
- **[`#cooking`](https://gitlab.slack.com/archives/cooking)**: Share your favorite recipes, and brag about your homemade dishes.
- **[`#dad_jokes`](https://gitlab.slack.com/archives/dad_jokes)**: Self-explanatory really, give us your best dad jokes!
- **[`#emilys`](https://gitlab.slack.com/archives/emilys)**: For all the Emily/ie/ia/ees at GitLab.
- **[`#fitlab`](https://gitlab.slack.com/archives/fitlab)**: Channel to discuss fitness and related topics.
- **[`#gaming`](https://gitlab.slack.com/archives/gaming)**: Discuss gaming (both tabletop and video). We also have a Discord linked in the topic.
- **[`#i-made-this`](https://gitlab.slack.com/archives/i-made-this)**: Did you make a thing? Or are you in the process of making a thing? Whatever it is, tell us about it and post a photo!
- **[`#office-today`](https://gitlab.slack.com/archives/office-today)**: Where's your office today? Share a photo or use words to describe it.
- **[`#lego`](https://gitlab.slack.com/archives/lego)**: Build, inspire, play. Share your builds and invite your children.
- **[`#lgbtq`](https://gitlab.slack.com/archives/lgbtq)**: Space for LGBTQ people and allies in GitLab to chat and support each other.
- **[`#managers`](https://gitlab.slack.com/archives/managers)**: Share ideas, thoughts, and issues on all things to do with being a manager at GitLab.
- **[`#mental_health_aware`](https://gitlab.slack.com/archives/mental_health_aware)**: Mental health is [super important](/handbook/company/culture/all-remote/mental-health/) and we realize that. This is a place to discuss concerns you might be having or find someone to talk to if you're feeling alone. We aim to be supportive and available for all who need it.
- **[`#music`](https://gitlab.slack.com/archives/music)**: Share your current playlist or any interesting music you come across.
- **[`#postcrossing`](https://gitlab.slack.com/archives/C2L1HK6TV)**: Send team members postcards from your home cities, towns and villages from around the world.
