---
title: "GitLab Video Playbook"
---
## GitLab Video Playbook

The purpose of this playbook is to help those who are looking to create video content determine what type of video they should create, how to get it done, and most importantly identify *why* the video should be created in the first place.

### Everything needs a purpose, including your video

The first thing you should ask yourself when considering a video project is, "why am I doing this video?" In asking yourself that question, figure out what your purpose is for the video and why you feel there is a need for it. Also, be sure to check that a video hasn't already been created that fulfills the content gap you are seeking to fill.

### Potential challenges

Remember, you don't need to create a perfect, award-winning film short. Do not let the pressure of perfection stall your video project from coming to fruition.

In that same vein, do not get bogged down by your equipment, or lack thereof. If you have a camera on your laptop, you have enough equipment to create your video!

### Types of videos you can contribute

When you think about creating content for GitLab, think short and sweet. Majority of the content created for our channels should be micro videos, which are short snippets of content that can be used to grab viewer interest and get your message across as quickly and succinctly as possible. Even content that seems like it should be lengthier, for instance a how-to video, can and should be created as a series of short, digestible micro videos.

If you have a lengthy video, perhaps from a meeting recording, please strongly consider cutting it down to a series of micro videos that cover specific topics or talking points.

#### Here are some common types of video content that you can contribute

*Community content:* These videos are created for the greater GitLab community and can include content for meetups, user stories, community-related actions at events, etc.

*Kickoffs:* These videos will cover the monthly release kickoffs as well as kickoffs for any other project that we'd like to publicly share.

*Team meetings and office hours:* This is pretty self explanatory. :)

*Informal customer testimonials:* These are videos of customer presentations or conversations at events or webcasts.

*Instructional videos:* These videos are meant to educate the viewer to the point where they walk away with some actionable knowledge. Instructional videos go by a variety of different names. But whether you need to make a how-to video or a tutorial, the goal is the same. Unlike other forms of video, an instructional video instructs. Of course, while you don't want boring videos, the main goal is for viewers to comprehend and learn what you are teaching them.

### Don't share sensitive data

GitLab makes things [transparent by default](/handbook/values/#transparency), but there are certain things that we intentionally [keep private](/handbook/communication/confidentiality-levels/#not-public).

Please make sure you don't share any of these private items in any public video.

### GitLab YouTube channels

We currently have two GitLab YouTube channels: Branded and Unfiltered.

#### What to post on each channel

The Branded channel features marketing and event content, customer, community and user stories, employment branding, and polished sales videos and demos. Please open an issue for an issue for any video that is to be posted on the Branded channel.

The Unfiltered channel features content intended for team and community members, including (but not limited to) team meetings, discussions, monthly release kick-offs, office hours, CEO 101 meetings, and casual demos.

#### Posting to the branded YouTube channel

If you would like a video posted on the branded YouTube channel, please open a  `video-upload-request-youtube` issue in the `digital production` project in `growth marketing`. Please only use this issue template for videos that do not require any additional editing. Before opening this issue, please make sure you already have written permission to post the video on our channel from all parties involved, including those on camera as well as those who filmed and produced the video.

For videos that require editing using already existing footage, please open an issue using the `video-editing-request` template in the `corporate marketing` project. Before opening this issue, please make sure you already have written permission to post the video on our channel from all parties involved, including those on camera as well as those who filmed and produced the video.

For videos that require filming, please use the `video-request-new` template in the `digital production` project in growth marketing.

#### Posting videos that were filmed externally

If you would like to post a video on our Branded or Unfiltered channel that was filmed by a partner, service or other provider, please open a `video-upload-request-youtube` issue in the `digital production` project in `growth marketing`. Please only use this issue template for videos that do not require any additional editing and be sure to have written permission to post the video on our channel from all parties involved, including those on camera as well as those who filmed and produced the video.

For videos that require editing using already existing footage, please open an issue using the `video-editing` template in the `digital production` project in `growth marketing`. Before opening this issue, please make sure you already have written permission to post the video on our channel from all parties involved, including those on camera as well as those who filmed and produced the video.

#### Connecting A YouTube Playlist to Slack

If you record meetings for your group you can automatically have the recordings posted in a Slack channel when they are added to a specific YouTube playlist. You can do this using the Zapier integration in Slack. Search for the `Zapier` app in Slack, and on the App's `Home` menu select - `Make a New Zap`. When setting up the connection between YouTube and Slack one of the most difficult tasks is finding your playlist to retrieve the necessary ID. It's best to find all [GitLab Unfiltered Playlists](https://studio.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A/playlists) by selecting `Manage Videos` on the Unfiltered Channel page. You can see some examples of this setup in the `#ops-section` slack channels.

### Optimize the impact of your video

- **Talk about your topic like your target audience talks about it.** The best way to reach people with video is to use the same words and phrases they do. If our internal labels differ from what our audience use, we should use their words as much as possible.
- **Use your highest priority keyword or phrase in the title of your video.** SEO on YouTube is similar to about.gitlab.com.  Add supporting keywords in your description and provide additional context for visitors. You can find really valuable keyword data in **Analytics > Reach > Traffic source: YouTube search**. This will tell you the terms people used to find your videos, and help surface keywords you can optimize for future videos.
- **Link back to pages on about.gitlab.com** where appropriate and include a CTA to a relevant resource.
- **Add your keyword targets as tags on your videos.**
- **Add a custom thumbnail.** Experiment to find the best image setup for your audience. Many videos add the title to the custom thumbnail and add some other visual element from the video. YouTube uses a 1280 x 720 dimension image for videos.
- **Clean up auto-generated captions** Machine-generated captions often misspell or mangle technical terms, and the words in your video's captions can help influence SEO. Captions also [broaden the audience](https://www.boia.org/blog/youtube-closed-captioning-for-accessibility-why-and-how) for a video. [Instructions for editing captions](https://support.google.com/youtube/answer/2734705) are available.

### Need help with your video?

#### FAQs

Q: How long does it take to get a video up on one of our YouTube channels?

A: Please check the video template that you use to open an issue in order to find out how long it will take for your video to be uploaded to YT.

If you'd like to connect with someone on the Digital Production team for more help, please open an issue using one of the aforementioned templates and ping us in the `youtube` Slack channel.

### Additional resources

- The [virtual events page](/handbook/marketing/virtual-events/) and [best practices guide](/handbook/marketing/virtual-events/#best-practices) provide useful information if you intend to create videos from or for live events.
