---
title: Being a public company
---

## GitLab as a Public Company

In 2017, GitLab established aspirational milestones for a public offering, achieving $1B of annualized recurring revenue, and positive operating cash flow in order to align our efforts and investments to common goals. GitLab [began trading](https://about.gitlab.com/blog/2021/10/14/gitlab-inc-takes-the-devops-platform-public/) on the Nasdaq Global Select Market on October 14, 2021 under the ticker symbol "GTLB."

We continue to believe that being a public company is an integral part of realizing our mission. As a public company, GitLab may benefit from enhanced brand awareness, access to capital, shareholder liquidity, autonomy, and transparency.

## Public Company Readiness

To achieve fair value with limited relative volatility as a publicly traded company, we are focused on the following:

1. Ability to meet the quarter close schedule outlined on the [Investor Relations](/handbook/finance/investor-relations/#earnings-release-calendar-workback-schedule) page
1. Consistent execution against key operating metrics and initiatives
1. Demonstrate a reliable trajectory of revenue growth to operating cash flow that aligns to our target [operating model](/handbook/finance/financial-planning-and-analysis/#long-term-profitability-targets) and [hypergrowth](/handbook/finance/financial-planning-and-analysis/hypergrowth-rule/#the-hypergrowth-rule) objectives
1. Assessing the maturity of our model in conjunction with equity market volatility to determine an appropriate time for a public offering
1. Building out a fulsome compliance program which includes: securities law trainings, communications policies, handbook adjustments, required policies such as insider / [trading window](/handbook/finance/investor-relations/#trading-window)
1. Maintaining a high degree of [transparency](/handbook/values/#transparency) that we believe increases contributions and makes collaboration easier. This is a core value and may result in higher than expected volatility.

A successful public offering is a significant milestone, but it is not GitLab's [mission](/handbook/company/mission/#mission). Like graduating from high school, a great day but it shouldn't be the biggest thing you achieve in life.

## Market Capitalization

Market capitalization (stock price x shares outstanding) will be the result of a combination of factors most directly associated with the following areas:

1. Size of [total addressable market](/handbook/sales/tam/)
1. Consistency of execution
1. [Competitive position](https://internal.gitlab.com/handbook/leadership/mitigating-concerns/#introduction)
1. Clarity of [value proposition](/handbook/company/strategy/#organization)
1. Perception of management [team](/handbook/company/team/)

As GitLab team members, delivering on our annual plan and long-term strategy are the most productive ways to contribute to the company achieving full, fair value with limited relative volatility. At a departmental level, we have [key performance indicators](/handbook/company/kpis/#what-are-kpis) aligned to our plan and performance to empower "everyone to contribute" to GitLab's long term success and public market valuation.

## Short Term Focus Can Be A Distraction

A finer point on valuation: In the long run, our underlying business performance will be the fundamental driver of GitLab's stock price. Workplace conversations on the stock price can be a distraction; we should instead shift discussions to our KPIs and focus on growing [the change in annual recurring revenue (ARR)](/handbook/sales/sales-term-glossary/arr-in-practice/).

Long-term initiatives may take years to show profitable results, and in the short term they can create drag. Teams that become overly focused on stock price will tend to avoid longer-term investments, preferring to boost revenue and profit in the short term. This is why it's important that incentives are in place to grow the company over the long term.

The father of value investing, Benjamin Graham, explained this concept by saying, "In the short run, the market is like a voting machine, tallying up which firms are popular and unpopular. But in the long run, the market is like a weighing machine, assessing the substance of a company."

## Long Term Targets Underpin Efficient, Durable Growth

Our financial planning process includes setting a division's spend based on revenue growth as we move towards our long term profitability target. We view these spending objectives (as a percent of revenue) as a measure of our efficient use of capital. **These objectives are not because we aim to go public.** As we capture a larger percentage of the market, growth could moderate and shift operating cash flow margin to a more significant factor in our [hypergrowth](/handbook/finance/financial-planning-and-analysis/hypergrowth-rule/#the-hypergrowth-rule) target.

## Two Actionable Values

[Transparency](/handbook/values/#transparency) and [Iteration](/handbook/values/#iteration) are deeply ingrained in the GitLab culture. GitLab is working to be the most transparent and iterative company in the world, and we believe this will set new standards for public companies. We continue to ask ourselves to what extent being marked as an attractive employer is due to our level of transparency and commitment to iterating.

## Transparency

1. Transparency is a [core value of GitLab](/handbook/values/#transparency).
1. We want to maintain the same overall level of transparency as a public company that we have as a private company. For example, indicators of revenue such as our [win rate](/handbook/sales/#win-rate) will no longer be accessible externally, but in other areas transparency will be increased: financial profile.
1. There are high expectations to do what you say. With our level of transparency people may not be used to how much we say, and we will be held to a new level of expectations on what we do.
1. When we are required to publicly release quarterly financials, we may be required to adjust the timing of or level of detail associated with certain key metrics.

### Communicating With Shareholders & Team Members

Investors will have multiple options for engaging and keeping up to date:

1. Annual shareholder meetings and quarterly reporting calls, which will be highly structured and formal.
1. Ongoing open documentation via our handbook, issues, and other work, which can create opportunities for discussion.

In situations where we are using the standard communications channels that other companies use (such as shareholder meetings), we will communicate information in the style that a typical company would. For many investors, the broad view offered in regular reporting updates will be adequate. For those who want to dig deeper, engage, and be more actively involved, there will be additional opportunities — similar to how GitLab has already been operating.

## Iteration

1. Iteration is a [core value of GitLab](/handbook/values/#iteration).
1. We want to maintain the same velocity of iterating as a public company that we have as a private company.
1. Iteration is a key factor in shipping new [releases](https://about.gitlab.com/releases/) [every month](/handbook/engineering/releases/).

## Disclaimer

Statements on this page are being made pursuant to, and in accordance with, Rule 135 under the Securities Act of 1933, as amended (the "Securities Act") and shall not constitute an offer to sell, or the solicitation of an offer to buy, any securities. Any offers, solicitations or offers to buy, or any sales of securities will be made in accordance with the registration requirements of the Securities Act.

## Remaining an Independent Company

{{< youtube id="LIXLGyZK72c" title="Will GitLab be acquired? Kristof Eger & Sid Sijbrandij" >}}

*In the [GitLab Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A) video above, GitLab co-founder and CEO [Sid Sijbrandij](https://gitlab.com/sytses) discusses the topic of remaining independent as a company with Kristóf Éger. The [coffee chat](/handbook/company/culture/all-remote/informal-communication/#coffee-chats) is transcribed, in part, below.*

> Our intention, from the moment we took external funding, was to stay independent.
>
> The reason we want to stay independent is we think it will better allow us to preserve our culture — we have our [six values](/handbook/values/) that are important to us — and also to be a good steward of open source.
>
> Now, we're not totally in control of that. The majority of GitLab is owned by venture capitalists. But, we do have some sway. If, as an executive team, you're not interested in being acquired, it's harder to acquire a company.
>
> We're always more [optimistic](/handbook/values/#focus-on-improvement) about the future than anybody outside of the company. That means that we have to keep growing. We have to keep growing [IACV](/handbook/sales/sales-term-glossary/arr-in-practice/), and keep growing our revenue.
>
> We keep investing in the future in order to not get bought. We've been very clear with our investors what our intentions were from the start. We're doing everything we can to stay independent. - *GitLab co-founder and CEO Sid Sijbrandij*
