---
title: "GitLab Culture"
description: "Here's a look at what you can expect from our culture and all-remote environment."
twitter_image: "/images/opengraph/Talent-Brand/hiring-group-shot-sko.png"
twitter_image_alt: "GitLab Team Members gathered together at an event."
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

## Introduction

Please see our [company page]({{< ref "company" >}}) for more general information about GitLab. You can see how our team has grown at the [GitLab Contribute page.](/handbook/company/culture/summit/)

<!-- blank line -->
<figure style="padding:56.25% 0 0 0;position:relative;">
  <iframe src="https://player.vimeo.com/video/947155019" frameborder="0" allow="autoplay; fullscreen; picture-in-picture" style="position:absolute;top:0;left:0;width:100%;height:100%;"></iframe>
</figure>
<!-- blank line -->

## Life at GitLab

![GitLab collaboration illustration](/images/all-remote/gitlab-collaboration-illustration.jpg)
{.mx-auto style="max-width: 50%;"}

It's an exciting time to be part of GitLab. We're a fast-growing, all-remote team, and we're looking for people to join us around the world.
Here's a look at what you can expect from our culture and [all-remote environment](all-remote/guide/).

### Everyone can contribute

Our size and [our mission](/handbook/company/mission/#mission) (enable everyone to contribute to and co-create the software that powers our world.) mean that our team members can — and are expected to — make an impact across the company.

Because we all use our product internally, you don't have to be a developer to learn to collaborate in the GitLab tool.
From your very first week, no matter your role, you'll gain the technical skills needed to access, question, and contribute to projects far beyond your job description.

This unique approach works because we're a team of helpful, passionate people who want to see each other, the company, and the broader GitLab community succeed.
We learn from each other, challenge each other, and thank each other.

Come prepared to do meaningful work that will help shape the future of the company.

While the opportunities to contribute are boundless in a growing organization like GitLab, they may not be clearly defined.
You'll need to think creatively, speak up to see how you can help, and be willing to try something new.

### Freedom to iterate

At GitLab, our [value of iteration](/handbook/values/#iteration) has a unique impact on the way we operate and get things done.

Working this way means our team members are expected to quickly deliver the minimal valuable change in their work instead of waiting to produce a polished, completed product.

While this can be a challenging practice to adopt at first, it's liberating to be able to make mistakes, get feedback quickly, and course correct to reach a better outcome, faster.

As our company and the industry continue to grow, you'll have the freedom to change and constantly evolve everything from your schedule and your workspace to your job description and your skills.

### All-remote work

{{< youtube "eIs71f5IEUU?start=468" >}}

*In the above [interview](https://youtu.be/eIs71f5IEUU) with [Stuart Miniman](https://twitter.com/stu) of [theCUBE](https://www.thecube.net/), GitLab CEO and co-founder Sid Sijbrandij discusses the merits of operating a 100% remote organization, and why he believes it's the future of work.*

> At GitLab, we're figuring out a lot of things you have to do to be all-remote, and we're trying to share those lessons. That's anything from working [handbook-first]({{< ref "handbook-usage#why-handbook-first" >}}) to [communication styles](all-remote/effective-communication/) and being intentional about [informal communication](all-remote/informal-communication/).
>
> If you Google "*GitLab all-remote*", you'll find tons of tips. And those are based not just on what we say, but what we *do*. We have a public [handbook](/handbook) of over 3000 pages with all our internal processes. You can check out what we really do to make this work.
>
> I think it's going to be the future. In the future, companies who make digital products are going to be much more all-remote. And we want to [enable that trend]({{< ref "remote-vision" >}}). We think it's great for [team members](all-remote/people/).

GitLab is one of the world's largest all-remote companies, and being a part of our team offers unique advantages beyond the requisite flexibility you'll find in many organizations.

As a GitLab team member, you can work from anywhere with good internet. Whether you're an adventurer looking to travel the world while still pursuing your career,
a parent or caregiver who wants a job that allows you to spend more time with family, or somewhere in between, you'll have the freedom to contribute when and where you do your best work.

But there's more to our all-remote culture than the daily flexibility it provides.
By nature, having no offices or headquarters makes us more inclusive, more transparent, and more efficient in everything we do.
With a team spread across over 65 countries around the globe, we invite diverse perspectives, we document everything, and we collaborate asynchronously.

Despite all of its benefits for team members, our company, and the world, remote work isn't for everyone.
Learn more about [all-remote work](/handbook/company/culture/all-remote/) at GitLab and decide if it's right for you.

## Culture at GitLab

![GitLab values](/images/all-remote/gitlab-values-tanukis.jpg)
{.mx-auto style="max-width: 50%;"}

Culture at GitLab is composed of three things.

1. [GitLab Values](/handbook/values/)
1. Camaraderie (mutual trust and friendship). This is created and maintained by [informal communication](all-remote/informal-communication/). We also build trust by [effectively collaborating](/handbook/values/#dont-let-each-other-fail) with others.
1. Work style (how we work). This is defined and articulated in our [communication guide]({{< ref "communication" >}}) and [handbook usage guide]({{< ref "handbook-usage" >}}).

In other organizations, culture may be defined through the *personality of the group*. This includes people who have traits in common and people who you enjoy spending time with. Note that this is not something that should matter when [evaluating people for work]({{< ref "#culture-fit-is-a-bad-excuse" >}}), and this is not what we mean with Culture at GitLab.

Watch this live speaker series, hosted on 2021-11-18, with Carter Gibson and Markus Mühlbauer from Google on Building Internal Culture.

{{< youtube "fFHadx3J3oA" >}}

Some key takeaways from the call include:

1. Culture isn't preserved. Instead, it evolves. Every team member can contribute to and iterate on the company culture.
1. It's important to scale communication as companies grow to accommodate different learning styles, communities, and team member expectations.
1. Culture shouldn't look at roles or levels in the company. There's no way for a company to dictate a culture from the top down. If you manage to build up this sense of belonging in everyone in the company, it builds up resilience.

## Advantages

{{% include "includes/reasons-to-work-for-gitlab.md" %}}

## Other pages related to culture

1. [GitLab 101](gitlab-101/)
1. [GitLab Contribute](/handbook/company/culture/summit/)
1. [Internal Feedback]({{< ref "internal-feedback" >}})
1. [Diversity, Inclusion and Belonging](inclusion/)
1. [All-Remote](all-remote/)
1. [GitLab Songbook](songbook/)
1. [Still a Startup]({{< ref "still-a-startup" >}})

## Historical Anecdotes

### *October 8th, 2011*

Dmitriy started GitLab when he pushed the [initial commit](https://gitlab.com/gitlab-org/gitlab-ce/commit/9ba1224867665844b117fa037e1465bb706b3685).

### *August 24th, 2012*

Sid announced [GitLab on HN](https://news.ycombinator.com/item?id=4428278).

### *September 14th, 2012*

First 10 people get access to GitLab Cloud (now known as GitLab.com).

### *November 13th, 2012*

GitLab CI is officially announced.

### *July 22nd, 2013*

[GitLab Enterprise Edition is announced](https://about.gitlab.com/releases/2013/07/22/announcing-gitlab-enterprise-edition/).

### *April 18th, 2014*

[GitLab Cloud renamed to GitLab.com](https://about.gitlab.com/blog/2014/04/18/gitlab-cloud-becomes-gitlab-com/).

### *March 4th, 2015*

[GitLab in Y Combinator winter 2015 batch](https://about.gitlab.com/blog/2015/03/04/gitlab-is-part-of-the-y-combinator-family/).

### *August 15th, 2015*

Series A Funding was signed.

### *October 10th, 2015*

Anniversary of our first ever summit in Amsterdam with 25 GitLab team-members.

## Team Stories

What better way to convey a sense of who we are and how we work together, than by sharing the stories about it?

### The Boat

<!-- HTML blocks below - applied to make the images and the video more harmonic than 1 single column with each on a different "row" -->

{{< cardpane >}}
{{% card footer="<a href=\"https://about.gitlab.com/blog/2016/01/06/our-y-combinator-experience/\">Back then</a>, the whole team used to fit in one car. And the car was called \"the Boat\"." %}}
![The Boat](/images/culture/boat.jpg)
{{% /card %}}
{{< card footer="We even took the Boat from San Francisco to Las Vegas to celebrate Job's bachelor party, but as you can see in this video, he thought we were going to visit a customer in Los Angeles!" >}}
{{< youtube id="JZG41C0aFfA" >}}
{{< /card >}}
{{< /cardpane >}}

### The cattle

{{% cardpane %}}
{{% card header="**Staring down the cattle?**" footer="Our CFO, Paul, was on vacation on a cattle ranch, during a time of fundraising. Normally vacation is vacation of course, but in this case it was necessary to have some calls now and again which required strong internet. To get to strong internet, Paul had to cross fields with cattle in them, and stare them down. Over the course of many trips he learned that cattle are docile, mostly... but don't turn your backon them because they can't be outrun!" %}}
![Staring down cattle](/images/culture/cattle_stare.JPG)
{.text-center}
{{% /card %}}
{{% /cardpane %}}

### IPO date comes in handy... 2 years out

{{< cardpane >}}
{{< card footer="After spending a couple of days in meetings with customers in New York City, USA, Sid and Kirsten had a few hours before their flight and wanted to visit the WTC Observatory deck. It didn't work out but our IPO date did work out in their favor. In the keynote at our Cape Town event, Sid explains what happened." >}}
{{< youtube id="4BIsON95fl8" start="1825" >}}
{{< /card >}}
{{< /cardpane >}}

### So that's what it's like to work at GitLab

{{< cardpane >}}
{{< card footer="Being new to GitLab, our CRO, Michael McBride joined Sid in meeting with customers in New York City, USA where customers got a glimpse of what it's like to work at GitLab for him" >}}
{{< youtube id="4BIsON95fl8" start="1143" >}}
{{< /card >}}
{{< /cardpane >}}

{{< include "includes/take-gitlab-for-a-spin.md" >}}
