---
title: "All-Remote Benefits vs. Hybrid-Remote Benefits Checklist"
description: All-Remote Benefits vs. Hybrid-Remote Benefits Checklist
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

![GitLab all-remote at scale illustration](/images/all-remote/gitlab_all_remote_work_environment_scale.jpg)
{style="max-width: 50%" }

Not all forms of remote work are created equal. While hybrid may appear to offer the best of both worlds on the surface, many leaders underestimate its [complexities and embedded inequality](https://www.wired.com/story/hybrid-remote-work-offers-the-worst-of-both-worlds/). On this page, we'll compare and contrast benefits available to all-remote leaders and team members with those available in a hybrid-remote setting.

This page is designed to clarify the differences in workplace experience by individuals who are *remote by default* in an all-remote setting vs. a hybrid-remote setting. This page is *not* designed to compare the in-person experience with the remote experience within a hybrid-remote organization.

It is becoming more common for [job seekers](jobs/) to weigh [multiple competing offers](https://carta.com/blog/gitlab-interview-covid-19-remote-landscape/). Understanding the [nuanced differences](evaluate/) in operating within a single-tier environment (all-remote) vs. a multi-tier environment (hybrid-remote) is critical for expectation alignment. Be careful to not assume that all remote offers are equal, thereby simplifying job selection to metrics such as compensation and job title. The job selection process is [intensely personal](evaluate/), and this guide intends to help those in the process put a more [meaningful value on all-remote benefits](https://about.gitlab.com/blog/2019/08/15/all-remote-is-for-everyone/) (and conversely, arm candidates with data if negotiating a higher salary to compensate for the inbuilt [dysfunction](/handbook/values/#five-dysfunctions) and inequity present in many hybrid environments).

## Language and terminology

For the purpose of this compare and contrast exercise, we define hybrid-remote as an environment where optionality and flexibility is limited. **The moment you force a subset of people back into the office, with another subset that is always remote, you have two playing fields to administrate. This two-tier arrangement is extremely difficult to administrate and is unequal by design.**

Those who are never remote will default to working [office-first](what-not-to-do/) (e.g. using a [physical whiteboard](collaboration-and-whiteboarding/) that cannot support remote contribution) and those who are never in the office will miss out on non-transparent work conversations and promotion opportunities.

For deeper dives on this topic, read our guides below.

1. [How to evaluate a remote job](evaluate/)
1. [The stages of remote work](stages/)
1. [Hybrid-Remote: understanding nuances and pitfalls](hybrid-remote/)
1. [Why GitLab uses the term all-remote to describe its 100% remote workforce](terminology/)

## All-Remote vs. Hybrid-Remote benefits checklist

| Benefit                                                      |         All-Remote         |                              Hybrid-Remote |
| :----------------------------------------------------------- | :------------------------: | -----------------------------------------: |
| [No commute](remote-benefits/)          |            Yes             |                                        Yes |
| [Non-linear workday](non-linear-workday/) | Yes, for roles which allow | No; fixed to office schedule of colleagues |
| Ability to [relocate for personal reasons](people/) |            Yes             |                                    Limited |
| Ability to [optimize location](https://www.fastcompany.com/90548691/extremely-transparent-and-incredibly-remote-gitlabs-radical-vision-for-the-future-of-work) for something other than a commutable distance to an office |            Yes             |                                    Limited |
| Avoid [physiological stress of open-plan offices](https://theconversation.com/open-plan-office-noise-increases-stress-and-worsens-mood-weve-measured-the-effects-162843) |            Yes             |                                    Depends |
| [Equal footing by default](how-to-work-remote-first/) on access to executives and senior leaders |            Yes             |                                         No |
| Praise and promotion based on [work output](/handbook/values/#measure-impact-not-activity) vs. "face time" with the right people |            Yes             |                                         No |
| IT/support applied to everyone equally                       |            Yes             |                                         No |
| All team members use [digital tools to work, collaborate, and communicate](https://about.gitlab.com/blog/2019/06/18/day-in-the-life-remote-worker/) |            Yes             |                                         No |
| Freedom from manually chasing information shared during siloed, in-person meetings |            Yes             |                                         No |
| Freedom from "FOMO" — the fear of missing out on in-person perks, meetings, social gatherings, etc. |            Yes             |                                         No |
| Travel burden for [in-person culture and rapport building](in-person/) is on the *company*, not the *individual* |            Yes             |                                    Depends |
| Freedom from managing guilt (e.g. you don't commute; your colleagues do) |            Yes             |                                         No |
| Freedom from justifying one's remote work arrangement to managers who aren't naturally supportive of flexibility |            Yes             |                                         No |
| Freedom from demands for overperformance by in-office colleagues |            Yes             |                                         No |
| Freedom from concerns of being overlooked, forgotten, or dehumanized by in-office [managers](being-a-great-remote-manager/) |            Yes             |                                         No |
| Freedom (and likely reimbursement) to work in a "third space" (e.g. coworking center, [Codi](https://www.codi.com/), coffee shop, etc.) |            Yes             |                                    Depends |
| Freedom from [subpar hybrid video calls](meetings/#avoid-hybrid-calls) where select participants are huddled in a physical room on one camera |            Yes             |                                         No |
| Equal footing in [job interviews](interviews/) (e.g. no advantage/disadvantage from in-person interviews) |            Yes             |                                         No |
| [Learning and development](learning-and-development/) is applicable to all team members, regardless of location |            Yes             |                                         No |
| Career growth is not dependent on willingness/ability to transfer to in-person by default |            Yes             |                                         No |
| Freedom from last-minute demands to fly to an office for an in-person meeting |            Yes             |                                         No |
| [Business operations team](/handbook/business-technology/) is fully focused on upleveling tools and technology which positively impact all team members (vs. catering to one subset over another) |            Yes             |                                         No |
| Freedom from being transferred to a manager or department who is in-person and/or isn't supportive of remote arrangements |            Yes             |                                         No |
| Eclectic mix of company-wide [in-person gatherings](in-person/) (vs. congregating at a standard office) |            Yes             |                                         No |
| Hearing about water cooler chitchat and perpetual cubical drop-ins from your in-office colleagues |             No             |                                        Yes |

***Learn more through [Life at GitLab]({{< ref "culture#life-at-gitlab" >}}) and our [Out of the Office](out-of-the-office/) report. If this page resonates with you, visit GitLab's [Career Opportunities](https://about.gitlab.com/jobs/).***

## Assessing the remote workplace experience

1. While [Glassdoor](https://www.glassdoor.com/) does not yet offer a dedicated `Remote Experience` filter in reviews, you are able to sort by `COVID-19 Related`. This filter increases the chances of reading reviews relevant to one's remote work experience at an organization. It's also helpful to search for `remote` within an organization's Review section. Glassdoor also offers [remote-related content on its blog](https://www.glassdoor.com/blog/search/remote%20work/).

{{% include "includes/is_this_advice_any_good_remote.md" %}}

{{% include "includes/coursera_gitlab_remote_course.md" %}}

## Contribute your lessons

GitLab believes that all-remote is the [future of work](remote-vision/), and remote companies have a shared responsibility to show the way for other organizations who are embracing it. If you or your company has an experience that would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests/) and adding a contribution to this page.

---

Return to the main [all-remote page](_index.md).
