---
title: "Building and reinforcing a sustainable remote work culture"
description: "In this complete guide, learn how to build a strong remote work culture, and values, for both your employees and company. Learn more here!"
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

On this page, we're detailing how to build, communicate, and reinforce a sustainable culture in a remote environment.

## What is company culture?

![GitLab values illustration](/images/all-remote/illustration_gitlab-world.png)
{style="max-width: 50%;"}

**Culture is the barometer of how well values are adhered to and reinforced in an organization**. Therefore, culture can only be maintained if values are prescriptively articulated and visibly [reinforced](/handbook/values/#how-do-we-reinforce-our-values) through elements such as [discretionary bonuses]({{< ref "incentives#discretionary-bonuses" >}}) and linking promotions to values.

In a colocated setting, culture is typically formed through [tacit](https://en.wikipedia.org/wiki/Tacit_knowledge) or implicit knowledge. In a healthy remote work environment, the building blocks of culture are documented transparently, making them accessible to everyone.

If you want to build a great culture, start with your [company's core values](/handbook/values/). You should be able to hand your values to someone who doesn't work at your organization and they be so well-articulated that person would understand how to treat you and your colleagues. Ideally, [your values are public](/handbook/values/#why-our-values-are-public) so that others can contribute their own knowledge and experiences.

## Why is company culture essential for remote work?

It takes **intentionality** to build a company culture in a company that has no offices. While technology and tools are enabling companies to operate efficiently in a remote setting, it's important to focus on creating a great culture first, *then* using tools to support it.

## How do you create a remote culture?

![GitLab values illustration](/images/all-remote/remote-report-2021_who-are-the-new-remote-workers.png)
{style="max-width: 50%;"}

"How do you build and sustain culture in a remote environment?" or "[How does culture work remotely?]({{< ref "culture#culture-at-gitlab" >}})" are questions we frequently hear at GitLab. In colocated settings, culture is often implied, built from how team members treat one another, what is rewarded, what is chided, and what is deemed acceptable during in-person interactions.

In colocated companies, it's easy to let culture be shaped by office decor, the neighborhood in which a company's headquarters is located, or the loudest voice in the room. Not only is this dangerous — one's culture can oscillate based on external factors — but it's not a usable strategy in a remote environment.

In a remote team, there's no office vibe, hip coffee, or Spotify playlists that decide the culture, which is a gift. Instead, culture is written down. Culture is equal to the [values](/handbook/values/) you write down, and what you do as a leadership team to [reinforce](/handbook/values/#how-do-we-reinforce-our-values) those values.

It starts by being intentional about [informal communication](informal-communication/).

{{< youtube "IU2nTj6NSlQ" >}}

*In the [video](https://youtu.be/IU2nTj6NSlQ) above, GitLab's Head of Remote discusses the topic of scaling culture during an interview with [Stuart Miniman](https://twitter.com/stu/), host of [theCUBE](https://www.thecube.net/) and GM of Content at [SiliconANGLE Media](https://siliconangle.com/).

It's challenging to build and maintain a healthy remote culture. Despite its [advantages](remote-benefits/), all-remote work isn't for everyone. It can have disadvantages as well. In the spirit of [transparency](/handbook/values/#transparency), here are some of the [challenges and solutions to maintaining remote work culture](drawbacks/).

## Culture looks different in a pandemic

Do not conflate forced work-from-home during a pandemic with cultural degradation due to working in a remote environment.

Many companies forced into remote by external factors such as COVID-19 are recognizing that, in general, employees are not as happy. This creates a response question: "How do you maintain culture in a suddenly-remote environment?"

That *is* a valid question, but it masks the actual question: "**How do you maintain culture in *any* work environment during a global pandemic?**"

In a period of tremendous external stress, culture is less about workplace rah-rah and more about intentionally reallocating that energy to serve society. Leaders must accept that the benchmark has changed. Expecting employees and managers to maintain a pre-crisis level of cheer during a pandemic can further deflate morale, and refusing to acknowledge this reality will make it more difficult for culture to recover post-crisis.

Even a company's culture champions, the most enthusiastic of team members, are under unprecedented duress during a global crisis. Many are struggling to work while doubling as a homeschool teacher, or concerned about the well-being of neighbors and community members. The energy they once allotted to championing workplace culture is being used up elsewhere, rightly prioritized to focus on new stressors in life outside of work. Complicating matters further is that few employees are willing to state this for fear of being penalized for taking their focus away from work, and not living up to expectations. It is essential for leadership to proactively take [steps to create a non-judgmental culture](mental-health/#creating-a-non-judgemental-culture).

Rather than assuming that workplace culture is eroding, consider showcasing how people in your organization are using their energy to support others outside of the workplace. Hearing stories of colleagues supporting first-line workers, neighbors, and community members will bolster morale at work. Being open about taking time away from work to be there for others who are struggling in the midst of a pandemic will create even stronger bonds *at* work.

## Reimagining the post-pandemic workforce

GitLab's [Remote Work Report](remote-work-report/) sheds light on the current reality of remote work.

In 2021, we learned that **86% of respondents believe remote work is the future, and 62% of respondents said that they would consider leaving a co-located company for a remote role.** Contrary to popular belief, we found that most remote workers aren't digital nomads, and 52% are actually likely to travel less than their office working counterparts.

As leaders and team members were grappling with going remote, the pandemic forced many into quick adoption. The Remote Work Report provides insights on what matters to those who adopt remote work and charts a path for building culture around autonomy and flexibility.

## Why inclusion matters more than ever

GitLab believes that combining many perspectives creates a more innovative environment to work in, with more satisfied teammates, leading to a better product and increased profitability. [Diversity, Inclusion & Belonging](/handbook/values/#diversity-inclusion) is one of our company values.

Inclusion allows us to recognize, respect, and value differences in those around us. Being inclusive requires skills such as empathy, openness, and listening. Inclusion also means we are keenly aware of both [positive and negative biases]({{< ref "unconscious-bias" >}}) and how those biases impact our daily interactions, work, and employee retention.

Diversity, [Inclusion](/handbook/company/culture/inclusion/) & Belonging is fundamental to the success of GitLab as a remote organization. We include it in every way possible and in all that we do.

## Seven tips to promote inclusion in a remote workforce

### 1. Be empathetic

Empathy and [kindness](/handbook/values/#kindness) are core to being a great remote manager. It can be challenging to put yourself in the shoes of a direct report using [text communication](effective-communication/) and [Zoom calls](https://about.gitlab.com/blog/2019/08/05/tips-for-mastering-video-calls/). In-person interactions allow for body language to be more easily read. In a remote setting, managers must instead be proactive in *asking* direct reports how life is going and what their learning preferences are.

GitLab [gives people agency](/handbook/values/#give-agency) and trusts each team member to embrace [ownership](/handbook/values/#ownership), and act as a [manager of one](/handbook/values/#managers-of-one).

For a greater understanding of the importance of empathy in a manager, read [GitLab's guide to combating burnout, isolation, and anxiety](mental-health/).

### 2. Ask about needs, listen, then act

Don't underestimate a 1:1. Regularly schedule video calls to check in and ask how you can help remove roadblocks. Set up [Ask Me Anything (AMA)]({{< ref "ask-me-anything" >}}) meetings so team members can meet a new leader, learn more about an existing team member, or gain clarity on project or a recent change.

### 3. Dedicate time for networking and team building activities

Working remotely leads to mostly work-related conversations with fellow team members, so everyone at GitLab is encouraged to dedicate a few hours a week to having social calls with anyone in the company.

It's a great chance to get to know who you work with, talk about everyday things and share a coffee, tea, or your favorite beverage. We want you to make friends and build relationships with the people you work with to create a more comfortable, well-rounded environment.

### 4. Normalize challenging personal assumptions

To achieve results, team members must constantly 🤝 collaborate and work together effectively. At GitLab, helping others is a priority, even when it is not immediately related to the goals that you are trying to achieve. Similarly, you can rely on others for help and advice—in fact, you're expected to do so.

Anyone can chime in on any subject, including people who don't work at GitLab. Collaboration means providing an effective framework for challenging directly and [delivering feedback]({{< ref "guidance-on-feedback" >}}).

### 5. Encourage participation within a diverse space

  Both formal and informal communication [in-person interactions](in-person/) matters in an all-remote [culture](/handbook/company/culture/). Here's our list of more than 20 different ways to encourage a happy, healthy [informal work culture](informal-communication/).

### 6. Proactively develop and mentor all team members based on their individual requirements

Mentor relationships are an opportunity for individuals to learn from someone's personal experience, background, and perspective. Mentorships help build trust, provide safe space to make mistakes, and encourage both personal and professional development.

Mentorship is an opportunity for both the mentor and mentee to develop their leadership and communication skills and should be led by the mentee, similar to how [1:1's at GitLab]({{< ref "1-1" >}}) are driven by direct reports.

### 7. Create inclusion commitments among remote team staff

Diversity, inclusion and belonging are fundamental to the success of GitLab. We aim to foster an environment where everyone can thrive. We are designing a multidimensional approach to ensure that GitLab is a place where people from every background and circumstance feel like they belong and can contribute. We actively chose to [build and institutionalize](https://www.russellreynolds.com/en/insights/reports-surveys/diversity-and-inclusion-gamechangers) a culture that is [inclusive](/handbook/company/culture/inclusion/) and supports all team members equally in the process of achieving their professional goals.

One way to create inclusion among your remote staff is to remove time zone bias via asynchronous communication.

Take initiative to operate [asynchronously](asynchronous/) whenever possible. This shows care and consideration for those who may not be in the same time zone, are traveling outside of their usual time zone, or are [structuring their day](people/#creating-a-more-efficient-day) around pressing personal or local commitments.

For example, you can record and share team [meetings](meetings/) using GitLab Issues and Merge Requests rather than sending texts, calls, or Slack messages. Be aware of local holidays, personal vacation statuses, and encourage others to default to [documentation](/handbook/product/ux/technical-writing/documentation/) rather than pressuring team members to be online outside of their working hours.

## How do I assess culture fit remotely?

For hiring teams, a common challenge is this: "How do I assess culture fit remotely?"

To answer this question, you first need to unlearn a bit, and change your frame of mind. A hiring manager should *not* aspire to assess culture fit. Rather, you should aspire to assess *values fit*.

For many, it is assumed that culture is simply the aura, energy, or vibe one gets when walking into an office. This is largely driven by decor and personas in the room. It is dangerous to allow company culture to be dictated by such factors, as this will create an oscillating culture that changes depending on mood or socioeconomic conditions.

A company culture is a company's list of values. Culture is an assurance that each employee respects, admires, and feels invested in a company's values, and that leadership works to ensure values are not violated. As GitLab, an operating principle within our Diversity, Inclusion & Belonging  value is "[culture fit is a bad excuse](/handbook/values/#culture-fit-is-a-bad-excuse)."

Remote [interviewers](interviews/) should link a company's values during the interview and have a conversation to assess a candidate's alignment and understanding of those values. Particularly in a remote setting, [values](values) serve as the north star, guiding every business decision by people you cannot physically see and shaping how colleagues treat one another.

## No unwritten rules in a remote work culture

![GitLab values illustration](/images/all-remote/gitlab-values-tanukis.jpg)
{style="max-width: 50%;"}

There should be no unwritten rules in remote culture. Intentional documentation is essential to avoiding [dysfunction](/handbook/values/#five-dysfunctions) within a remote company, and this also applies to culture. At GitLab, this begins with our company values: [Collaboration](/handbook/values/#collaboration), [Results](/handbook/values/#results), [Efficiency](/handbook/values/#efficiency), [Diversity, Inclusion & Belonging](/handbook/values/#diversity-inclusion), [Iteration](/handbook/values/#iteration), and [Transparency](/handbook/values/#transparency).

**Culture is best defined not by how a company or team acts when all is well; rather, by the behaviors shown during times of crisis or duress**.

## Intentional onboarding

A team member's first experience with company culture is unavoidable. The [onboarding experience](learning-and-development/#how-do-you-onboard-new-team-members) serves as the first post-interview encounter with culture, and it is essential to infuse the [importance of values]({{< ref "remote-values" >}}) into that experience.

Remote onboarding should set aside time for a new team member to read and digest a company's values, which serve as a company roadmap to culture. Consider having a mentor or [onboarding buddy]({{< ref "onboarding-buddies" >}}) specifically ask questions related to values, providing opportunity for the new team member to dive deeper into how they are lived day-to-day.

### Using GitLab for remote onboarding

GitLab is a collaboration tool designed to help people work better together whether they are in the same location or spread across multiple time zones. Originally, GitLab let software developers collaborate on writing code and packaging it up into software applications. Today, GitLab has a wide range of capabilities used by people around the globe in all kinds of companies and roles.

You can learn more at GitLab's [remote team solutions page]({{< ref "gitlab-for-remote" >}}).

## Reinforcing your values

Whatever behavior you reward will become your values. New hires and promotions serve as important decisions to promote and reinforce values. GitLab reinforces its values by what:

1. [Leadership]({{< ref "leadership" >}}) does.
1. We select for during [hiring](/handbook/hiring).
1. We emphasize during [onboarding]({{< ref "general-onboarding" >}}).
1. Behavior we give each-other [360 feedback]({{< ref "360-feedback" >}}) on.
1. Behavior we [compliment](/handbook/communication/#say-thanks).
1. Criteria we use for [discretionary bonuses]({{< ref "incentives#discretionary-bonuses" >}}).
1. Criteria we use for our [annual compensation review]({{< ref "compensation-review-cycle" >}}).
1. Criteria we use for [promotions]({{< ref "promotions-transfers" >}}).
1. Criteria we use to [manage underperformance]({{< ref "underperformance" >}}).
1. We do when we [let people go](/handbook/people-group/offboarding).
1. We give value awards for during [Contribute](/handbook/company/culture/summit/).

In negative feedback, one should be specific about what the problem is. For example, saying someone is "[not living the values](https://hbr.org/2017/05/how-corporate-values-get-hijacked-and-misused)" isn't helpful.

## Never take company culture for granted

While the importance of culture is driven home during onboarding, continual reinforcement is required to keep it top-of-mind. In the course of business, it's easy to lose sight of values and culture when focusing on [OKRs](/handbook/company/okrs) and [KPIs](/handbook/company/kpis/). However, it is vital for leadership to remind themselves and other team members that values should never be pushed aside or lowered in priority.

*Every* decision a business makes should align with their values. Otherwise, values will be seen as "merely words," and culture will disintegrate.

If your company gets all team members together on a regular basis, consider resurfacing values or providing opportunities for groups to live out those values through community service. Just as certain trainings are recommended or required each year as part of a company's ongoing [learning and development](learning-and-development/) efforts, reminding team members of values is vital to sustaining a strong culture.

## How to sustain your organization's culture when everyone is remote

A healthy remote work environment clearly defines its culture and expectations. These written definitions enable team members to exemplify the organization's values regardless of their physical location.

### Embrace transparency in all interactions

Be open about as many things as possible by making information public. This transparency helps reduce confusion and makes collaboration easier. Use public issue trackers, projects, and repositories when possible.

[Transparency](/handbook/values/#transparency) creates awareness for GitLab. It does that by allowing us to recruit people that care about our values, gets us more and faster feedback from people outside the company, and makes it easier to collaborate with them. It also helps us share great software, documentation, examples, lessons, and processes in the spirit of open source, which we believe creates more value than it captures.

### Continually promote and enhance work-life balance and flexibility

From family time to travel plans, there are [many examples and stories](stories/) of how remote work has enhanced the lives of GitLab team members.

> **"The flexibility makes family life exponentially easier, which reduces stress and makes you more productive and motivated. You can't put a dollar value on it – it's priceless."** - Haydn, Regional Sales Director, GitLab

The freedom and flexibility that comes with all-remote enables employees to view work in an entirely new light.

Rather than forcing a predefined daily schedule replete with a commute, all-remote shifts allows an individual to define their schedule.

A number of studies by organizations such as [Google](https://www.forbes.com/sites/abdullahimuhammed/2019/05/18/5-important-takeaways-from-googles-two-year-study-of-remote-work/#1a536957439a), [Buffer](https://buffer.com/state-of-remote-work-2019), [FlexJobs](https://www.techrepublic.com/article/why-remote-work-has-grown-by-159-since-2005/), and [IWG](https://assets.regus.com/pdfs/iwg-workplace-survey/iwg-workplace-survey-2019.pdf) show that driven individuals who place a high degree of value on autonomy and flexibility can experience new levels of joy and productivity in an all-remote environment.

### Address employee well-being and mental health issues

Remote and asynchronous work can help alleviate stress and support mental health.

{{< youtube "IU2nTj6NSlQ?start=621" >}}

*In this video, GitLab's Head of Remote discusses the mental health benefits of asynchronous communication.*

Expectations to be online, available, and responsive during set working hours can be stressful. Our hyper-connected society has allowed this notion to seep into every hour of the day, blurring or destroying the boundaries between work time and personal time.

One benefit to working asynchronously is a [reduction of tension](building-culture#gratitude-and-transparency/). When your entire company operates with an understanding that any team member could be offline at any time, for any reason, there is no expectation for immediate replies.

This creates an environment where your [mental health](mental-health/) is prioritized, allowing team members to [set boundaries](mental-health/#be-transparent-about-boundaries) and freeing them from a perpetual assault of notifications and judgment.

## The importance of gratitude and transparency

Persistent negativity can erode culture. While [feedback]({{< ref "guidance-on-feedback" >}}) is a gift, there's a fine line between reacting with hope and determination when facing a challenge and allowing a sense of apathy or dread to permeate a company. Leaders should be cognizant of this and act swiftly if there's a noted drop in outward gratitude or [transparency](/handbook/values/#transparency) in communications.

{{< youtube "cy6WGuzArgY?start=232" >}}

Emna G., founder and CEO at Veamly, spoke with GitLab's [Darren M.](https://twitter.com/darrenmurph) on how she fosters and sustains a thriving culture within a remote-first company.

> Every Monday, we get everyone on a Zoom call for something we call "Gratitude Monday." Everyone shares what they're grateful for. It doesn't have to be work-related. The idea is to live by gratitude; we need to learn how to embrace it.
>
> Some Mondays, you've had a bad weekend or you've woken up on the wrong foot. For me, I try to push my team to take a moment, pause, and really feel it. We see the difference when we remember what we're grateful for.
>
> We also do "Meditation Wednesdays," where we get on a Zoom call and we do breathing exercises. Then we share what we're stressed about, and what we're looking forward to. The idea is that it's OK to be stressed — we're human — but we want to balance that stress and create empathy.

## Spotlight remote-work culture ambassadors

A remote culture is only as strong as it is lived. At GitLab, we encourage team members to surface culture on a regular basis through the following mechanisms.

1. [Say Thanks](/handbook/communication/#say-thanks)
1. Use values emoji — ![CREDIT emoji](/images/handbook/values-emoji.png) — to recognize messages that exemplify a company value.
1. Recommend a colleague for a [discretionary bonus]({{< ref "incentives#discretionary-bonuses" >}}). If granted, the rationale and values lived are then documented and announced during a company call, serving as a beacon to others on how to improve the lives of others by living the values.
1. Serving as a GitLab [Contribute Ambassador](/handbook/company/culture/summit/#ambassadors), which helps the entire company get the most out of a [weeklong trip](/handbook/company/culture/summit/) to spend time with each other in person every 9-12 months.
1. Everyone can contribute to strengthening GitLab's values by creating [merge requests](https://docs.gitlab.com/ee/user/project/merge_requests/) and fostering discussion.

## Put structure around culture

It may sound counterintuitive, but there is great value in putting process and structure around culture. For example, if a company has an unlimited vacation policy, but has no suggestions or process around it, you may create a culture of fear with regard to taking time off.

{{< youtube "cy6WGuzArgY?start=1021" >}}

Emna G., founder and CEO at Veamly, spoke with GitLab's [Darren M.](https://twitter.com/darrenmurph) on the importance of process in building remote culture.

> Put process around things. Studies show that when a company has unlimited vacation, people don't take vacation.
>
> It's important to be communicative about the minimum that needs to be taken. It's also important to be clear on the structure. If you give a team something without structural limits, they really don't know how to navigate it.
>
> If you put structure around this, and you document it, you eliminate the guilt and the fear of missing out. — *Emna G., founder and CEO at Veamly*

It's important for leadership to set the tone, but it's even more important to [document](/handbook/product/ux/technical-writing/documentation/) what will define your culture. Each time a scenario arises where there is no clearly defined answer, look to your company values to determine the answer, and then document.

Documentation is a shared benefit, and is something that should be embraced by all members of the organization. While it may feel inefficient to document nuances related to culture, creating good habits around this will ensure that culture is as strong in the future as it was in a company's infancy.

## Close the office

Where feasible, consider closing the office and operating as a 100% remote company. This eliminates the possibility of any remote employee being seen, intentionally or unintentionally, as [deprioritized](hybrid-remote#disadvantages-to-hybrid-remote/) within the organization.

If this is not feasible, and your company operates elsewhere on the [spectrum of remote](stages/), ensure that your culture reinforces a remote-first way of doing business. It takes a concerted effort to transcribe hallway conversations into one's handbook or Slack channels, but ensuring that each employee is seen as a remote employee is the only way to ensure equal access to information.

{{% include "includes/is_this_advice_any_good_remote.md" %}}

## Contribute your lessons

Creating and evolving company culture is something that all remote organizations must tackle. If you or your company has an experience that would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests/) and adding a contribution to this page.

## GitLab Knowledge Assessment: Building and reinforcing a sustainable culture

Complete all knowledge assessments in the [Remote Work Foundation certification](remote-certification/) to receive the [Remote Foundations Badge in GitLab Learn](https://gitlab.edcast.com/pathways/copy-of-remote-foundations-badge). If you have questions, please reach out to our [Learning & Development team](/handbook/people-group/learning-and-development) at `learning@gitlab.com`.

---

Return to the main [all-remote page]({{< ref "_index.md" >}})
