---
title: "How do you collaborate and whiteboard remotely?"
description: "This complete guide details how collaboration and whiteboarding are established and work effectively in a global all-remote company. Learn more here!"
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

On this page, we're detailing how collaboration and whiteboarding works in a global all-remote company.

## How do you collaborate and whiteboard in an all-remote environment?

![GitLab collaboration](/images/all-remote/gitlab-collaboration.jpg)
{style="max-width:50%"}

"How do you collaborate and whiteboard in a remote environment?" is a frequently asked question. In a colocated setting, collaboration often happens face-to-face with a whiteboard on hand in a conference room. Working remotely sometimes feels like working on your own, with your own calendar, and your own schedule. With a common goal, strategic planning, and the right collaboration tools, working in a remote environment can be even more productive than working in an office.

## How virtual whiteboard collaboration supports remote teams

For deep-dives on how GitLab's UX and design teams collaborate remotely, visit the [UX Team Playlist](https://www.youtube.com/playlist?list=PL05JrBw4t0KqkW0oPW3n0HqVgKcONVnO5) on GitLab Unfiltered and read the series of GitLab blog posts below.

1. [Designing in an all-remote company](https://about.gitlab.com/blog/2020/03/27/designing-in-an-all-remote-company/)
1. [Improving iteration and collaboration with user stories](https://about.gitlab.com/blog/2020/03/27/how-we-utilize-user-stories-as-a-collaborative-design-tool/)
1. [Running an asynchronous sketch workshop for UX](https://about.gitlab.com/blog/2020/03/27/async-sketching/)
1. [Synchronous collaboration as a remote designer at GitLab](https://about.gitlab.com/blog/2020/04/01/synchronous-collaboration-as-a-remote-designer-at-gitlab/)

## What are the best online whiteboards with collaboration features?

When looking for the right tool for you and your team, consider what's most important:

- people--allows your team to collaborate equally despite time zones, technology platforms etc.
- principles--supports the core vision and operating principles of your company
- process--smooth and efficient workflows
- product--achieves the outcome/s needed

## Does Google have a collaborative whiteboard?

Remote teams should aim to [minimize their tool stack]({{< ref "remote-work-emergency-plan#minimize-your-tool-stack" >}}). It's good practice to consider how you can extract additional value from tools you already use, and [Google Docs](/handbook/communication/#google-docs) is a great example of this. While Google Docs is a fantastic shared editing tool, GitLab also uses it for temporal [meeting documentation]({{< ref "../meetings#document-everything-live-yes-everything" >}}) (prior to contextualizing takeaways for placement in relevant [handbook]({{< ref "handbook-first" >}}) sections).

It also happens to be a great remote whiteboarding tool.

**Advantages of Google Docs with numbered lists and indentation**

1. Everyone can write, not just the most senior people in the room
1. Multiple people can write at the same time, allowing purer trains of thought to reach canvas versus waiting your turn
1. Can see what people are looking at in real-time via cursor indicators
1. Can make suggestions
1. Can make [low-context comments]({{< ref "../effective-communication#understanding-low-context-communication" >}}) that are time-stamped
1. Can change hierarchy with indentation
1. Can copy and paste
1. Doesn't run out of space
1. Doesn't need to be deleted after the meeting
1. Can be iterated on prior to a meeting
1. Can be iterated on after a meeting ends
1. Inline with agenda/notes of meeting
1. Font is more readable than handwriting
1. Can use URLs to link to external resources
1. Can add screenshots and embeds from other tools and platforms to visualize thoughts
1. The Google Doc itself becomes an artifact that can be linked to or embedded in other tools and platforms
1. The Google Doc can be shared globally with a link for feedback from the entire world, if so desired

## Whiteboarding Applications

When a text-based document is too limited, try a collaborative, visual-oriented tool.

[MURAL](https://app.mural.co/signin?returnUrl=%2Ft%2Fgitlab2474%2Ftemplate%2F08b992c6-1863-4f6b-8305-a584b57d3c98) is the number one sketch tool used by product designers. Mural comes preloaded with a ton of templates. It takes skill and a willingness to experiment to start to utilize them in productive ways, but it is encouraged by PMs at GitLab. The UX Research and Product Design rooms in Mural have several examples of designers doing all sorts of amazing work in Mural.

[Google JamBoard](https://edu.google.com/intl/ALL_us/jamboard/) is free, has a native application for mobile platforms and easily imports Google Slides for further animation.

[Miro](https://miro.com) has extensive conversion of pen stokes to graphics objects and real text and it includes many templates and team sharing capabilities.

## Contributed all-remote whiteboard setups

1. [Inexpensive Active Pen Tablet Setup and Three Whiteboarding Apps](setups/#samsung-8-active-pen-tablet-with-liveboard-app)

## How do I run a virtual whiteboard session?

Once you've decided which tool is best for you, here are a few tips for running a successful whiteboard session:

1. Define goals for the session
1. Set a defined amount of time for the session in general and each activity specifically
1. Start with a clean slate
1. Explain how the system works and how each member is expected to participate and contribute
1. Assign someone to keep the whiteboard organized
1. Assign deliverables and tasks

## Getting started with all-remote collaboration

![GitLab all-remote team](/images/all-remote/gitlab-com-all-remote-1280x270.png)
{style="max-width: 50%"}

Do not fixate on the medium; instead, fixate on the outcome. Instead of attempting to create a virtual whiteboard, focus on what outcomes you typically expect from a whiteboarding session. In a remote setting, a team must be intentional about everything, including a fixation on results. This requires a change of mentality.

Learn more about "the whiteboarding fixation" in our [guide to understanding the phases of remote adaptation]({{< ref "phases-of-remote-adaptation#the-whiteboarding-fixation" >}}).

### People planning

{{< youtube "xt5cxXBv1-A" >}}

*In the [GitLab Unfiltered](https://www.youtube.com/playlist?list=PL05JrBw4t0Kq7QUX-Ux5fOunQotqJbECc) video above, GitLab Head of Remote Darren M. discusses remote team collaboration with Till P. creator of remote collaboration platform [CoScreen](https://www.coscreen.co/).*

Remote collaboration starts with people. Creating a [remote culture]({{< ref "building-culture" >}}) includes trusting that the people within the company will do their work. [Documentation]({{< ref "handbook-first" >}}) is vital to the independence of employees. This includes documenting everything from company [values](/handbook/values/) to daily [meetings]({{< ref "../meetings" >}}).

Tools and technology will enable a company to operate efficiently, but ensuring that there is documentation with core standards is the first step in setting a collaborative remote environment.

Remote collaboration requires an alignment of [principles and values](/handbook/values/) as a baseline for stakeholders. Creating mental methods, or frameworks, for collaborators sets a clear roadmap for expectations, ethics, and goals.

> "Without the principles and an understanding of which decision-making framework to use and when, people could apply the wrong tool to the job," — *Mike Long, UX Manager, GitLab*

## Collaborative whiteboarding supports diversity, inclusion and belonging

Collaborative whiteboarding has positive impacts to diversity, inclusion and belonging by:

- providing substantially better shared understanding when presenter and participants do not share a common spoken language.
- assisting with neurodiversity through multi-sensory collaboration.
- improving comprehension regardless of natural differences between individuals in conceptualizing non-visual information.

### Collaborating through text

The most important aspect of collaboration meetings is to [have an agenda]({{< ref "../management#docs-instead-of-whiteboards" >}}). Creating an agenda helps to cover everything and sets a plan for the scheduled discussion. It also makes it easier for those who didn't attend to feel included by having a document they can review after the meeting. Not everyone will always be in the meeting, but they can stay up-to-date as long as the meeting is documented, [encouraging clear communication](https://about.gitlab.com/blog/2019/12/23/six-key-practices-that-improve-communication/). Google Docs is a collaborative, real-time tool to take notes, share decisions, and keep all stakeholders informed.

Most design discussions and decisions at GitLab are created and worked in [GitLab Issues]({{< ref "gitlab-for-remote" >}}). Recently, [Design Management](https://docs.gitlab.com/ee/user/project/issues/design_management.html) was released in order for designers to upload images and make comments in the same platform that Product Managers and Developers use.

> "The most important thing to remember when designing remotely is: document, document, document," — *Christie Lenneville, Director of UX, GitLab*

### Company handbook

At GitLab, we believe that "everyone can contribute." The company handbook is where everything is documented — our [single source of truth]({{< ref "handbook-first#terminology-documentation-handbook-first-single-source-of-truth" >}}) — specifically laying out the six core [values](/handbook/values/) of the company. The handbook deliberately and intentionally describes each group's role within the company, including how the [UX teams](/handbook/product/ux/product-designer/) researches, designs and writes about the product.

### Iterate and iterate some more

Since the inception of GitLab, [iteration](https://about.gitlab.com/blog/2020/02/04/power-of-iteration/) has been one of six core values and steers the creation of product development. Making many small changes has been a way to make improvements faster.

> "To a UX researcher iteration means something different to me than other people. The value of iteration should encourage people to change directions when they find answers to their questions. Iteration should be a stop-gap measure to say 'This is not the right solution. We will stop and reassess and rethink what is the right solution to this problem." — *Lorie Whitaker, Senior UX Researcher, GitLab*

### Zoom for all

Any meeting at GitLab happens over a [Zoom call](/handbook/communication/zoom). Face to face is the best way to "meet" someone in person. On top of that, press record to digitally document the meeting for future reference or for anyone who might not make the call. Zoom also has a whiteboard function in [Zoom Rooms for Touch](https://support.zoom.us/hc/en-us/articles/115004797286-Using-the-whiteboard-in-Zoom-Rooms-for-Touch). Attendees can access and annotate a whiteboard on the call and then save and share the whiteboard by email.

### Pinging on Slack

Slack is generally accepted as an [informal method of communication]({{< ref "how-to-work-remote-first#expire-your-slack-or-teams-messages-after-90-days" >}}). Slack channels can be created easily for various groups or individuals. If there are questions or comments that require a quick response, Slack is the best way to get in touch with a co-worker. Slack is a fast way to collaborate on a topic without having to schedule a meeting in advance.

> "Pinging someone on slack is like bumping into them in the hallway," — *Alexis Ginsberg, Senior Product Designer at GitLab*

## Synchronous collaboration

Synchronous work within a standard organization makes sense. Work starts and ends when people enter and leave the office. Meetings happen all together in some version of a boardroom. However, when co-workers are spread throughout the world, [sync collaboration](https://about.gitlab.com/blog/2020/04/01/synchronous-collaboration-as-a-remote-designer-at-gitlab/) can be a bit more challenging. Here are some ways that GitLab has been able to establish a level of normalcy regardless of what time zone people are in.

### Meeting in pairs

![GitLab all-remote team](/images/all-remote/gitlab-com-all-remote-v4-dark-1280x270.png)
{style="max-width:50%;"}

Schedule meetings with a co-worker. Meeting in pairs allows for some serious one-on-one face time to collaborate on challenges and goals. This time permits each attendee to share what they're working on and potentially share projects that they might not be familiar with. With Zoom, the screen sharing option lets you get hands on with your meeting partner's work.

At GitLab, the [Pair Design program](/handbook/product/ux/how-we-work/#pair-designing) was launched to connect a product designer with a design peer who is within the same time zone, but works on a different part of the product. Each pair meets for six months and then they are swapped out to give everyone exposure to different ideas, product areas, and collaborations.

> "I have loved working with each of my 'pairs' in UX! Usually we meet once a week for 30 minutes to an hour and spend about half the time each talking about something that is top of mind for us.
>
> Sometimes it is just discussing some process or higher level stuff; most of the time we are sharing our screens in Zoom and walking through Sketch, Figma, Axure, someone's branch, etc. to talk through design challenges we are having.
>
> The most exciting part of this to me is getting to really dive into a space that I don't get as much exposure to – also getting to know another designer and having that dedicated time just for us." — *Alexis Ginsberg, Senior Product Designer at GitLab*

### Group syncs

Meet with your group to get a better idea of what everyone is working on, where the status of a project is, and get a general sense of who you're working with. At GitLab, the plan designers have a dedicated time to meet and discuss what they are working on and are able to collaborate on anything they want feedback on. Some projects overlap, so this is especially helpful for all involved to stay in sync. Team members appreciate having these designer syncs on some cadence where it feels less formal (more like huddling at a desk together looking at designs) than scheduling time ad hoc.

### PM and Design hangout

Every week the Plan designs and Plan PMs meet and discuss research in-flight or any work that needs collaboration. They also discuss priorities and walk the board if there is time (this is the least important item as we have other touch points for this). The critical part of this call is discussing the goals for the week. It is another way to learn what everyone is working on — both personally and professionally.

### Social hours

Create a [social hour]({{< ref "informal-communication#team-social-calls" >}}) where everyone is welcome to join to chat or play games together. Try two social hours every other week with the purpose of capturing enough time zones so that teammates can be "in-person." This isn't exactly "work" collaboration related, but creates a bond with teammates in order to feel more comfortable together and therefore more effective and excited to collaborate.

## Asynchronous collaboration

![GitLab all-remote team](/images/all-remote/gitlab-com-all-remote-v3-dark-1280x270.png)
{style="max-width:50%;"}

[Asynchronous communication]({{< ref "asynchronous" >}}) is the process of being productive without depending on the presence of other people. Async work empowers people to work independently and to trust that others are doing the same, but not necessarily at the same time. Collaborating asynchronously frees people from calendars and time zones.

With documentation, there is transparency on workloads, project capacity, and an overall understanding of what everyone's expectations are. The focus shifts away from the hours spent doing the work, to the actual results of the work.

### Digital documentation

Digitally documented design with videos is a helpful way to keep the creative education flowing. It is also another way to keep team members up-to-date with new and upcoming projects, design ideas, and trends.

> "In these videos, we lay out the rationale behind our designs and also offer information about other options we thought about and decided against. In certain situations, it also makes sense to add additional background about our long-term vision.
>
> One of the many positive outcomes from this approach is that even team members who have only been minimally involved are now empowered to provide feedback, add their own ideas, or provide us with additional information about the amount of work our ideas will require." — *[Christie Lenneville](/handbook/company/team/#clenneville), Director of UX, GitLab*

### Sketch workshops

At GitLab, [Async sketch workshops](https://about.gitlab.com/blog/2020/03/27/async-sketching/) are another way to collaborate with peers. The process is similar to an in-person whiteboard workshop, only collaborators are using Mural instead. Guidelines are set for individual workshops, leaders are in place, and contributors have a general familiarity with the product.

### GitLab Issues and merge requests (MR)

GitLab's policy is to [dogfood everything](https://about.gitlab.com/blog/2020/01/30/insights/). Issues and merge requests are where the majority of collaboration occur. GitLab design issues are works in progress, feedback is welcome and expected, and everyone is encouraged to contribute. The platform's transparency helps remote teams interface to produce better products faster.

> "I really enjoy reviewing MRs and being able to check out branches on my own instead of relying on others to walk me through things at their desk or sending me to an app like I may have had to do in the past. I can be reviewing something for someone while they sleep...it feels like we are better able to support and collaborate with each other and work on efforts together." — *[Alexis Ginsberg](https://gitlab.com/uhlexsis), Senior Product Designer, GitLab*

## GitLab Knowledge Assessment: Remote collaboration and whiteboarding

Complete all knowledge assessments in the [Remote Work Foundation certification]({{< ref "remote-certification" >}}) to receive the [Remote Foundations Badge in GitLab Learn](https://gitlab.edcast.com/pathways/copy-of-remote-foundations-badge). If you have questions, please reach out to our [Learning & Development team](/handbook/people-group/learning-and-development) at `learning@gitlab.com`.

{{% include "includes/is_this_advice_any_good_remote.md" %}}

## Contribute your lessons

GitLab believes that all-remote is the future of work, and remote companies have a shared responsibility to show the way for other organizations who are embracing it. If you or your company has an experience that would benefit the greater world, consider creating a merge request and adding a contribution to this page.

---

Return to the main [all-remote page]({{< ref "../_index.md" >}}).
