---
title: "The definitive guide to all-remote work and its drawbacks"
description: Downsides to remote work
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

Despite all of its [advantages]({{< ref "remote-benefits" >}}), all-remote work isn't for everyone. It can have disadvantages for potential employees depending on their lifestyle and work preferences, as well as the organization. In the spirit of [transparency](/handbook/values/#transparency), we'll also highlight counterpoints and solutions to these challenges.

{{< youtube "CwOLAKSdlfs" >}}

In the [video](https://youtu.be/CwOLAKSdlfs) above, GitLab Director of Technical Evangelism [Priyanka Sharma](https://gitlab.com/pritianka) discusses pros and cons of remote working with a panel of experts from [TFiR](https://www.tfir.io/), [Arm](https://www.arm.com/) and [ISG Research](https://isg-one.com/research).

## The difference between all-remote and remote-first

[All-remote]({{< ref "stages#9-all-remote" >}}) is a work arrangement in which employees do not commute to a central place of work because there are no company-owned offices.

[Remote-first]({{< ref "stages#7-remote-first" >}}) typically means there is a physical workplace of some kind available to employees who need or prefer a traditional office space outside of the home. However, these spaces are not always company-owned, they could be a shared workspace, coffee shop, or public library.

Remote-first organizations optimize their company for remote by creating documentation, policies, and [workflows]({{< ref "how-to-work-remote-first" >}}) that assume 100% of the organization is remote.

These companies work to ensure that offices are simply [venues to work remotely from]({{< ref "how-to-work-remote-first#offices-are-simply-venues-to-work-remotely-from" >}}), and are not the epicenter of power or culture.

## Remote work challenges and solutions for employees

### Challenge: Onboarding

[Onboarding](learning-and-development/#how-do-you-onboard-new-team-members) can be difficult when you're remote, because it involves [more self-learning](learning-and-development/) and you're not physically with your new coworkers and fellow new hires.

**Solution**

Learn more about how GitLab [onboards its all-remote team members](learning-and-development/#how-do-you-onboard-new-team-members).

### Challenge: Loneliness

The first month in a remote role can feel [lonely](https://about.gitlab.com/blog/2018/04/27/remote-future-how-remote-companies-stay-connected/), especially if you're [transitioning from a traditional office setting](https://about.gitlab.com/blog/2018/03/15/working-at-gitlab-affects-my-life/).

**Solutions**

- To prevent loneliness, all-remote companies should consider an [intentional structure to informal communications](informal-communication/).
- Scheduling [coffee chats](informal-communication/#coffee-chats), [social calls](informal-communication/#social-calls), and [incentivizing in-person visits]({{< ref "incentives#visiting-grant" >}}) between team members are several of the ways in which GitLab accomplishes this.

### Challenge: Communication breakdown

Remote settings can cause a breakdown in communication skills if organizations aren't deliberate about creating ways for their people to stay connected.

**Solutions**

- All-remote companies should default to asynchronous communication to combat feelings of being left out of important discussions.
- We welcome all-remote companies to glean from [GitLab's approach to meetings](meetings/), as well as our [scheduled AMAs, group conversations, and Key Reviews](learning-and-development/#ask-me-anything-ama-group-conversations-and-key-meetings) that are open to all.

### Challenge: Work/life balance

Some may find it difficult to work in the same setting as they live and sleep, because a dedicated workspace helps to switch the context from their home life to work.

**Solutions**

- All-remote companies should not assume that team members will work from their home 100% of the time. Organizations can consider [reimbursing coworking space usage](/handbook/finance/spending-company-money/) and [creating an atmosphere](/handbook/finance/spending-company-money/) where team members are [encouraged to construct a workspace]({{< ref "inclusion#fully-distributed-and-completely-connected" >}}) that is ideal for their comfort and productivity.
- GitLab team members have shared their own solutions in a number of blog posts, including a series on [working at home with kids](https://about.gitlab.com/blog/2019/08/01/working-remotely-with-children-at-home/) and [utilizing an RV as a traveling office](https://about.gitlab.com/blog/2019/06/25/how-remote-work-at-gitlab-enables-location-independence/).

### Challenge: Different time zones

Team members in different time zones may have to compromise on meeting times.

**Solutions**

- All-remote companies should consider [meetings](meetings/) as a last resort, instead relying on asynchronous collaboration tools like Google Docs and [GitLab Issues](https://docs.gitlab.com/ee/user/project/issues/) to facilitate meaningful dialog without time zone concerns.
- To prevent [pent-up frustration](/handbook/values/#five-dysfunctions) over working odd hours to facilitate a global call, all-remote companies should consider treating each team member as a [manager of one](/handbook/values/#managers-of-one). This goes beyond the basic definition of flexibility by empowering team members to structure each day according to the needs at hand. For example, spending more time with family earlier in the day to compensate for a late-night work call.

### Challenge: Separating work from personal life

It can be hard to separate your personal and work life. It's important to encourage boundaries and make sure you don't continue to work during your family time.

**Solutions**

- [Preventing a culture of burnout starts at the top](https://about.gitlab.com/blog/2018/03/08/preventing-burnout/). In all-remote companies, it's important to reinforce this from the [interview process](https://about.gitlab.com/blog/2019/03/28/what-its-like-to-interview-at-gitlab/), to [onboarding](learning-and-development/#how-do-you-onboard-new-team-members), to regular [1:1s]({{< ref "1-1" >}}).
- All-remote companies should consider implementing a [Results value](/handbook/values/#results), where [impact (as opposed to activity) are measured](/handbook/values/#measure-impact-not-activity). Fundamentally, this requires organizational trust — believing that colleagues will do the right thing rather than implementing rigid rules.
- At GitLab, we encourage team members to [communicate with their manager when they recognize burnout]({{< ref "paid-time-off#recognizing-burnout" >}}), and to be mindful of the last time a team member [took time off from work]({{< ref "paid-time-off#paid-time-off" >}}).

### Challenge: Time management

Remote work requires you to [manage your own time](/handbook/values/#managers-of-one) and be self-motivated, disciplined, and [organized](https://about.gitlab.com/blog/2019/06/18/day-in-the-life-remote-worker/).

**Solutions**

- All-remote companies tend to attract those who place a [high degree of value on autonomy](https://about.gitlab.com/blog/2018/03/15/working-at-gitlab-affects-my-life/). To some degree, companies who are hiring can expect applicants to opt-in to [this way of working](https://about.gitlab.com/blog/2019/07/09/tips-for-working-from-home-remote-work/).
- [Screening employees](https://about.gitlab.com/blog/2019/03/28/what-its-like-to-interview-at-gitlab/) for these attributes is fairly easy [during the interview process](https://about.gitlab.com/blog/2017/01/03/how-to-prepare-for-a-virtual-interview/). Even if a prospective team member has yet to work in a remote setting, asking for examples of their mindset and performance while working from home, an event, or while traveling can provide valuable insight.
- While each team member is different, you can get a glimpse of what it's like to operate in an all-remote setting through this [GitLab blog post](https://about.gitlab.com/blog/2019/06/18/day-in-the-life-remote-worker/), entitled *[A day in the life of the "average" remote worker](https://about.gitlab.com/blog/2019/06/18/day-in-the-life-remote-worker/)*.

## Remote work challenges and solutions for organizations

  <!-- blank line -->
<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/ha4aMKl3MRA" frameborder="0" allowfullscreen="true"> </iframe>
</figure>
<!-- blank line -->

In the [video](https://youtu.be/ha4aMKl3MRA) above, GitLab co-founder and CEO Sid Sijbrandij discusses some of the organizational challenges involved in building and sustaining an all-remote company.

### Challenge: Non-traditional setup

Because it's non-traditional, all-remote work sometimes [concerns](https://about.gitlab.com/blog/2018/10/18/the-case-for-all-remote-companies/) investors, partners, and customers.

**Solutions**

- All-remote companies are welcome to glean from [GitLab's template for keeping investors in the loop](https://about.gitlab.com/blog/2018/10/17/how-we-keep-investors-in-the-loop/).
- For those in the early stages of fundraising for an all-remote company, here are [30 tips from GitLab co-founder and CEO Sid Sijbrandij](https://about.gitlab.com/blog/2016/10/14/fundraising-tips-ceo/).
- For even more on this topic, [listen](https://about.gitlab.com/blog/2019/08/16/all-remote-fundraising/) to Sid unpack why venture firms struggle to fund all-remote startups with [Maren Kate](https://www.linkedin.com/in/marenkate), host of the Remote AF podcast (link no longer available).

> "In the beginning they assess your team, then they assess your product, and then they assess your financials. When it comes to the team, [investors are] super skeptical they will be able to create something with all-remote. Then when it's about the product they say, 'Yes, maybe, but what about scaling?' And then when it's about the financials you can let the numbers speak for themselves so it's less of a concern. — *GitLab co-founder and CEO Sid Sijbrandij*

### Challenge: Compliance

Differences in currency as well as tax, immigration, and labor laws around the world can create [compliance challenges](https://www.forbes.com/sites/forbeshumanresourcescouncil/2019/07/12/remote-work-is-here-to-stay-heres-how-to-avoid-three-common-compliance-issues/) for the organization.

**Solution**

- While each organization is unique, we welcome other all-remote companies to learn from GitLab's [ever-evolving approach to hiring and remaining compliant across the globe](hiring/).

### Challenge: Company culture

You have to be more intentional about [cultivating](https://about.gitlab.com/blog/2019/06/04/contribute-wrap-up/), [sustaining](learning-and-development/#ask-me-anything-ama-group-conversations-and-key-meetings), and [documenting](learning-and-development/#the-importance-of-documenting-everything) your company culture.

**Solutions**

- While this is an obstacle for all-remote companies, colocated organizations should be deliberate about documenting their culture as well.
- All-remote organizations should document everything, including [values](/handbook/values/), and ensure that they are easily accessible to all.
- GitLab demonstrates this with its [Handbook](/handbook), a living document that is [continually iterated on]({{< ref "about#count-handbook-pages" >}}) by team members. We encourage all-remote organizations to glean from this and develop their own handbook.

## Remote work challenges and solutions for teams

Despite its many [advantages]({{< ref "remote-benefits" >}}), all-remote work can present new challenges for teams.

### Challenge: Isolation

A remote role can feel [lonely](https://about.gitlab.com/blog/2018/04/27/remote-future-how-remote-companies-stay-connected/), especially if you're [transitioning from a traditional office setting](https://about.gitlab.com/blog/2018/03/15/working-at-gitlab-affects-my-life/).

**Solutions**

- Build an [intentional structure for informal communication](informal-communication/) to help combat loneliness.
- Schedule regular [coffee chats](informal-communication/#coffee-chats), [social calls](informal-communication/#social-calls), and [incentivize in-person visits]({{< ref "incentives#visiting-grant" >}}) between team members to encourage team building and prevent isolation.

### Challenge: Communication

If teams aren't intentional about creating ways for their people to stay connected, remote settings can cause communication breakdowns.

**Solutions**

- Asynchronous communication invites everyone to be a part of important discussions.
- We welcome all-remote companies to glean from [GitLab's approach to meetings](meetings/), as well as our [scheduled AMAs, group conversations, and Key Reviews](learning-and-development/#ask-me-anything-ama-group-conversations-and-key-meetings) that are open to all.

### Challenge: Boundaries

It's not easy to separate work and personal life when working remote. It's important to model and encourage boundaries.

**Solutions**

- [Preventing a culture of burnout starts at the top](https://about.gitlab.com/blog/2018/03/08/preventing-burnout/). In all-remote companies, it's important to reinforce this from the [interview process](https://about.gitlab.com/blog/2019/03/28/what-its-like-to-interview-at-gitlab/), to [onboarding](learning-and-development/#how-do-you-onboard-new-team-members), to regular [1:1s]({{< ref "1-1" >}}).
- Focus on [impact (as opposed to activity)](/handbook/values/#measure-impact-not-activity).
- At GitLab, we encourage team members to [communicate with their manager when they recognize burnout]({{< ref "paid-time-off#recognizing-burnout" >}}), and to be mindful of the last time a team member [took time off from work]({{< ref "paid-time-off#paid-time-off" >}}).
- Remote work requires you to [manage your own time](/handbook/values/#managers-of-one) and be self-motivated, disciplined, and [organized](https://about.gitlab.com/blog/2019/06/18/day-in-the-life-remote-worker/).

## Is working remotely effective?

An all-remote job will best suit [self-motivated people](https://about.gitlab.com/blog/2019/03/28/what-its-like-to-interview-at-gitlab/). Some of the top optimizers of remote work are:

- Reduced [interruption stress](https://about.gitlab.com/blog/2018/05/17/eliminating-distractions-and-getting-things-done/) and increased [productivity](https://www.inc.com/brian-de-haaff/3-ways-remote-workers-outperform-office-workers.html).
- Remote makes it [easier to communicate](informal-communication/) with difficult colleagues remotely, [reducing distractions](https://about.gitlab.com/blog/2018/03/15/working-at-gitlab-affects-my-life/) from interpersonal drama or office politics.
- Flexibility to [choose your working hours](people/#worklife-harmony) based on when you're [most productive]({{< ref "asynchronous" >}}).

## Tips for independent remote working

Whether you're new to working remotely or have done it before, you can explore the detailed version of our [5 tips for successful remote working]({{< ref "remote-work-starter-guide" >}}):

1. Create a dedicated workspace (focus)
1. Separate work from life (avoid burnout)
1. Keep engaging with people (avoid loneliness)
1. Respect routine, but experiment with change (balance)
1. Be flexible and roll with the changes (iteration)

## When a remote team will save your business

From the cost savings on office space to more flexibility in employees' daily lives, all-remote work offers a number of advantages to organizations and their people.

{{< youtube "embed/GKMUs7WXm-E" >}}

> **"Remote is not a challenge to overcome. It's a clear business advantage."** -Victor, Product Manager, GitLab

You can view our [complete guide to the benefits of all-remote here]({{< ref "remote-benefits" >}}).

Return to the main [all-remote page]({{< ref "_index.md" >}}).
