---
title: "Communicating effectively and responsibly through text"
description: How to communicate effectively and responsibly through text
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

As an all-remote company that defaults to [asynchronous communication](management/#asynchronous), GitLab relies heavily on textual communication. This can feel unusual or even uncomfortable for those who come from a colocated environment, where in-person meetings and vocalized communiques are the norm. Embracing text communication and learning to use it effectively requires a mental shift. Mastering this should be seen as a long-term project, though there are tips to breaking down barriers and experiencing benefits.

Be sure to read GitLab's [guidelines to effective and responsible communication](/handbook/communication/#effective--responsible-communciation-guidelines) to understand the foundational elements on which this all-remote guide is built.

## Tips for better writing

Writing is a skill which can be learned. *Great* writing involves mastering proven principles and understanding how narratives influence thoughts and actions. Below, we've documented a series of principles which are commonly linked to writing procedures at Amazon (source: [Alex Garcia's X (Twitter) thread](https://twitter.com/alexgarcia_atx/status/1439597358698807312)), but are useful approaches for anyone communicating in a professional setting.

1. **Use short sentences**. Ideally, sentences should have fewer than 15 words. This improves clarity. The [Hemingway Editor](https://hemingwayapp.com/) helps achieve this.
1. **Cut common phrases**. Example: replace "due to the fact" with "because."
1. **Replace adjectives with data**. Hard figures trump descriptors like "most" or "the majority."
1. **Eliminate ambiguous words**. Actively avoid words which weaken your point (Example: "nearly" instead of an exact percentage)
1. **Use the "So What?" test**. Before sending a communique, re-read and ask "So, what?" Does your content provide value? Will your audience understand? Are you sharing enough context?
1. **Avoid adverbs**. If you spot an adverb, remove it. Example: replace "increased massively" with "added 300 new subscribers."
1. **Be objective**. Objectivity injects confidence. Example: replace "I think this change is working" with "our new approach led to a 5% increase."
1. **Cut acronyms and jargon**. Aim to explain to a child. Example: do not assume that someone understands what MR means. Instead, write out "merge request."
1. **Use Subject-Verb-Object sentences**. Follow this path when constructing sentences: Who/what are you writing about? ⮕ What did they do? ⮕ What was acted on?

## Why text communication is important for successful remote working

{{< youtube "trYrbPYOf_c" >}}

*The topics covered on this page were discussed in a GitLab Live Learning session, which was recorded and uploaded to [GitLab Unfiltered](https://youtu.be/QTPeyRW766Q), and is embedded above.*

In an all-remote organization with team members spread across an array of time zones, communicating through text is ideal. Not only is it inclusive and considerate, but a bias towards communicating through text creates a company that [documents everything](/handbook/product/ux/technical-writing/documentation/).

Documentation is an essential competitive advantage. Companies which rely on vocalizing end up repeating themselves over and over in meetings, creating an inefficient environment with tremendous opportunity for knowledge leaks. While communicating and documenting through text may feel like a burden in the moment, it prevents a toxic cycle of meetings and touch points which serve only to "bring people up to speed."

[Tim Casasola](https://twitter.com/timcasasola) of Sanctuary Computer [asserts](https://www.timcasasola.com/blog/writing) that "great writing makes remote work better. It saves time, reduces meetings, removes extrovert bias, and invites other perspectives."

Communicating answers to problems via text makes documentation easier. Rather than transcribing one's voice, one must simply copy and paste in a structured format within a company's [handbook](/handbook). It's vital to understand that nurturing this habit serves more than the person receiving the answer. It is, in essence, paying it forward. Documenting solutions makes a more efficient future for every new hire who joins and asks the same question, not to mention existing team members who join a project or conversation midstream and need to understand what steps have been taken thus far (and why).

Below are several additional reasons to master the art of textual communication in a business.

1. Allows for team members to work **asynchronously**
1. Information is **available** to all at the same time / immediate
1. Allows for **deliberate** thought and processing time
1. Inherently **inclusive** (works with screen readers and translation tools)
1. Easily **queried** via keyboard or script
1. Can be structured and formatted to showcase **a train of thought**

## Understanding low-context communication

![GitLab all-remote desk space with laptop and map](/images/all-remote/gitlab-commit-sf-2020-laptop-user.jpg)
{style="max-width: 50%;"}

At GitLab, we [communicate assuming others have low context](/handbook/communication/#internal-communication). We provide as much context as possible to avoid confusion.

1. The goal of low context is to be **considerate** of the people or audience you're speaking to. It's important to recognize that what you write — either internally or externally — may be read in the future, or by someone who is coming into the conversation at a time after the initial thread began
1. This is one of the more challenging elements to master, particularly for those coming from careers in colocated spaces. In colocated environments, high context communication is the default. High context is less direct with an emphasis on human relations, and it's more sensitive to non-verbals and the feelings of others.
1. Getting oneself in a low context frame of mind can be useful. Start by assuming that recipients of your communication **do not know anything** about the topic at hand, and wish to learn as much as possible in as little time as possible.
1. It's easy to imply your experiences with text communication, but remember that not everyone has similar life experiences to relate to, hence the need to be precise.
1. By being specific, you're forcing yourself to think through what you're saying. In general, there is value in **taking the time to be deliberate** about communications. Re-read communiques before sending, particularly if they may be perceived as negative or inflammatory to certain parties. The ability to self-edit before sending is a boon to text communication. Vocalized words cannot be unsaid once uttered.
1. Along these lines, we should be clear in proposals, especially when we are making decisions with trade-offs. For example, we shouldn’t choose between revenue versus usage or broad versus deep without fuller context. To have buy-in and alignment, we need to get into the specifics. We can’t make informed decisions without being **clear on the tradeoffs (do A or B) and the proposal (do A but not B)**. What you should pick depends on the specific situation, and you should aim for agreement on both what you are doing and not doing.
1. Aiming for precision in communication requires you to put yourself in another person's shoes and **try to understand their current perspective and worldview**. It's important to view text communication not as a way to impose your will, but as a means to listen, understand, and collaborate.
1. This isn't suggesting that your communication should be cold or soulless. In the GitLab `#thanks` Slack channel, for instance, we encourage team members to be specific about what they are thanking someone for, such that you do not need prior context to understand how a [value](/handbook/values/) was being lived.

## Why text communication can be difficult

![GitLab customer path illustration](/images/all-remote/gitlab-customer-path.jpg)
{style="max-width: 50%;"}

The internet is forever. Words have impact long after they are written, and even when you're communicating internally, the manner in which you speak with one another should be viewed through an external lens. Words have meaning, meanings have effects, and effects have consequences. Those consequences, good or bad, are the lasting impact of the words you choose.

For those who struggle with this, consider what you would type if a journalist, your manager, or a family member were in the room observing the conversation. This tip will not serve all scenarios, but it's worth considering if stakes are high in a conversation.

Below are several reasons why text communication can be difficult.

1. Cultural and communication style differences
1. Delay in immediate feedback (due to time zones or other meetings)
1. Lack of non-verbals
1. Emotional distance
1. Tough to fully consider the scope of your audience(s)

### Understanding Tone in Text-Based Communication

In February 2022, the Learning and Development team at GitLab hosted [Maria Moss](https://www.linkedin.com/in/maria-moss/) for a live speaker series on interpreting tone in text-based communication. Key points addressed in the discussion include:

1. Lead conversations with empathy and [assume positive intent](/handbook/values/#assume-positive-intent)
1. Recognize when text communication isn't working and talk about it
1. State your intent clearly and early in a conversation - leave nothing up to interpretation

Watch the recording of this disucssion with Maria:

{{< youtube "a9RNgt5u2MQ" >}}

### Letting values guide communication

Text communication can be easily derailed, and assumptions can lead to good-mannered communiques being viewed as a slight. A number of [GitLab's operating principles](/handbook/values/) are useful to reference if you end up in a scenario where you are unsure of how to communicate effectively and responsibly through text.

1. [No ego](/handbook/values/#no-ego) (Don't defend a point to win an argument or double-down on a mistake.)
1. [Assume positive intent](/handbook/values/#assume-positive-intent) (If a message feels like a slight, assume positive intent while asking for clarification.)
1. [Get to know each other](/handbook/values/#get-to-know-each-other) (Building a rapport enables trust.)
1. [Say thanks](/handbook/values/#say-thanks) (Taking every opportunity to share praise creates a climate where feedback is viewed as a gift rather than an attack.)
1. [Kindness](/handbook/values/#kindness) (It costs nothing to be kind, even if you do not believe someone deserves it.)
1. [It's impossible to know everything](/handbook/values/#its-impossible-to-know-everything) (You can't know how your words are interpreted without asking.)
1. [Short toes](/handbook/values/#short-toes) (GitLab is a place where others can feel comfortable with others contributing to their domains of expertise.)

If, during a text conversation, you feel that someone is not communicating in the spirit of a company's values, respectfully ask if they believe that they are in a [1-1 setting](/handbook/values/#negative-feedback-is-1-1). It's easiest to assume the worst and quietly disengage, but doing so creates several additional problems. One, the person communicating is not given the gift of feedback, so their perspective will not change. Two, the person concerned remains timid about communicating with someone, which can lead to toxicity and dysfunction if unaddressed.

### The power of contrition

At the speed of business, it's possible for even the most well-mannered of colleagues to say something regrettable when their heart was typing faster than their brain could regulate. In the event that you think you could have written something better, contrition is advised.

[Say sorry](/handbook/values/#say-sorry) is an operating principle at GitLab. It's simple, yet powerful. Saying sorry via Slack or email, or a quick Zoom call if two parties are online at the same time, enables trust to be rebuilt. When using asynchronous collaboration tools such as [GitLab Issues and Merge Requests]({{< ref "gitlab-for-remote" >}}), feel welcome to reply atop your message if you feel that you may have written something offensive. This will send another email notification to those tagged, whereas an edit to your original message will not.

### Using GitLab for work-related communication

GitLab is a collaboration tool designed to help people work better together whether they are in the same location or spread across multiple time zones. Originally, GitLab let software developers collaborate on writing code and packaging it up into software applications. Today, GitLab has a wide range of capabilities used by people around the globe in all kinds of companies and roles.

You can learn more at GitLab's [remote team solutions page]({{< ref "gitlab-for-remote" >}}).

### Communicating dates and time

You can learn more in GitLab's [communication handbook](/handbook/communication/#communicating-dates-and-time) as the Single Source of Truth (SSoT).

## Feedback is a gift

Managers should strive to **incorporate positive feedback** into their day-to-day work. Particularly in an all-remote setting, where people can work for days, weeks, or months without seeing a colleague [in person](in-person/), friendly words go a long way.

It's easy to brush [positive feedback]({{< ref "leadership#giving-feedback" >}}) aside as nonessential, but that is unwise in a remote setting. If the only feedback a report receives is negative — while hearing nothing when they are exceling — they are likely to view feedback as an attack. Moreover, they're likely to feel unappreciated and misunderstood, and are apt to view critical feedback as something that is being delivered to spite them rather than improve them.

Said another way, putting effort into positive feedback as well as negative feedback creates a climate where the latter is taken seriously. If you are in a situation where you need to deliver [critical feedback]({{< ref "guidance-on-feedback" >}}), consider also offering up what a person is doing well. This creates an element of trust, that you are viewing things in totality and recognize that [people are not their work](/handbook/values/#people-are-not-their-work).

Feedback is a mechanism to become more understanding and more compassionate. In remote settings where you're working with colleagues from around the globe, feedback enables you to squash misconceptions and become a more understanding human. Though challenging, you should assume positive intent when receiving feedback. If it feels like an attack, ask for clarification.

The goal is to create a two-way street of communication, so that all parties are heard, and work is put in by all sides to ensure that points are understood. It's also important to [think through your responses to feedback]({{< ref "leadership#responding-to-negative-feedback" >}}). You can't choose how you are spoken to, but you *can* control how you respond.

If your default [reaction to feedback]({{< ref "guidance-on-feedback" >}}) is to become combative, consider acknowledging feedback and respectfully asking for time to process. Then, schedule a follow-up conversation once you've had time to process it rationally and not just emotionally. This prevents you from feeling compelled to reply in haste.

## It's about your impact, not your intention

![GitLab puzzle illustration](/images/all-remote/gitlab-review-and-collaborate.jpg)
{style="max-width: 50%;"}

We judge ourselves by our intentions, but people judge us by our actions.

In an all-remote setting, it's important to have a healthy amount of perspective on words that you type. Ask for clarification, and ask if your communication could be delivered in a different or more effective way.

For [managers]({{< ref "leadership" >}}) of multiple people, you may find that one report prefers a certain delivery while another has a different idea of what is ideal. There are multiple ways to deliver a message. Similarly, there are multiple ways to *interpret* a message. It's worth being proactive to ensure that your intentions are delivered.

When communicating, it's your responsibility to own how something impacted someone, regardless of how you intended it. If you're surprised by how a given communique impacts someone, ask for clarity without being combative. These moments are ideal for learning more about yourself, and how you can tweak your approach to communicating via text to be more considerate.

## GitLab Knowledge Assessment: Communicating effectively and responsibly through text

Complete all knowledge assessments in the [Remote Work Foundation certification]({{< ref "remote-certification" >}}) to receive the [Remote Foundations Badge in GitLab Learn](https://gitlab.edcast.com/pathways/copy-of-remote-foundations-badge). If you have questions, please reach out to our [Learning & Development team](/handbook/people-group/learning-and-development) at `learning@gitlab.com`.

{{% include "includes/is_this_advice_any_good_remote.md" %}}

## Contribute your lessons

Specific examples of using text effectively are ideal for showing new hires how to learn this skill. If you or your company has an experience that would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests/) and adding a contribution to this page.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
