---
title: "How to evaluate a remote job"
description: How to evaluate a remote job
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

<!-- markdownlint-disable MD013 -->
On this page, we're detailing how to evaluate a remote job.

## Not every remote job is created equal

{{< youtube "4bO-wxLQtJQ" >}}

*In the [GitLab Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A) video above, Darren (GitLab) and Rodolphe (Remotive) discuss several remote work topics: favorite things about remote work, how to find/start/thrive in your first remote role, and the impact of the growing remote work community.*

While [job sites](jobs/) and common conversation can lump each remote role into a single category, it's important to realize that not every remote role is created equal. Just as colocated roles need to be evaluated in totality, those seeking to transition into a remote role for the first time should ask certain questions during the interview or evaluation phase.

There are [various stages of remote work](stages/), which can be easily pictured as a sliding scale. From no remote to [hybrid-remote](hybrid-remote/) to all-remote, and all points in between, a remote worker's experience in each setting will likely vary. Below, we're highlighting key topics to cover when seeking an understanding of how you'll be treated in a full-time remote role. Additional questions should be considered depending on your specific scenario and familiarity with the hiring company.

While there are a growing number of freelance gigs which can be completed remotely, this article is centered around [full-time remote careers](jobs/).

## Where can I find remote jobs?

We've curated a [list of companies and job boards](jobs/) to help in your search for remote jobs. We've also included a [list of qualities to look for](evaluate/) as you're evaluating potential employers.

## What factors should be considered when evaluating a remote job?

When considering employment, it's essential to evaluate the totality of the job. While things like compensation, safety/security, management style, day-to-day tasks, and benefits are paramount for some, others see flexibility, autonomy, and the ability to travel and regularly relocate as a higher priority.

It's wise to rank your personal priorities in order of importance as you consider a remote job. Depending on your preferences and work style, [all-remote may or may not suit you well](https://about.gitlab.com/blog/2015/06/17/highlights-to-my-first-remote-job/).

## How to research a company before accepting a job offer

Company [values](/handbook/values/) serve as the north star guiding every business decision by people you cannot physically see and shaping how colleagues treat one another, especially in a remote setting. Every company has a unique culture and values. Remote interviewees should research a company's values and ask questions about them during the interview process.

## How do remote companies evaluate prospective employees?

Remote [organizations](jobs/) search for people who place a high degree of value on [autonomy](https://about.gitlab.com/blog/2018/10/18/the-case-for-all-remote-companies/), [flexibility](https://about.gitlab.com/blog/2019/06/25/how-remote-work-at-gitlab-enables-location-independence/), [empathy](https://about.gitlab.com/blog/2019/07/09/tips-for-working-from-home-remote-work/), and [mobility]({{< ref "inclusion#fully-distributed-and-completely-connected" >}}).

Because of the self-directed nature of remote work, employers look for people capable of:

- being a [manager of one](/handbook/values/#managers-of-one)
- working [asynchronously](asynchronous/)
- [communicating through text](effective-communication/)
- setting up an ideal [workspace](workspace/)
- eliminating distractions for optimal [efficiency](/handbook/values/#efficiency)

![GitLab collaboration illustration](/images/all-remote/gitlab-collaboration-illustration.jpg)
{style="max-width: 50%;"}

## Other remote-work questions to consider

### Q: Where does leadership work?

When evaluating a remote role, it's critical to understand where leadership works on a day-to-day basis. In an all-remote company, each team member — including the executive team — is remote. This creates a culture of trust and [transparency](/handbook/values/#transparency), and it sends a clear message that no one will be treated as an outsider within the organization based on their geographic location.

In companies where the leadership team is colocated, but most (if not all) of the company is remote, consider asking how this impacts the dissemination of information. Remote [forces companies to do things they ought to be doing earlier and better](management/#how-do-you-manage-a-100-remote-team), including [documenting]({{< ref "documentation" >}}) culture and process. With a colocated leadership team, a company runs the risk of bypassing diligent documentation in favor of an in-person sync where discussion notes and outcomes are not documented and shared.

### Q: Are hybrid calls utilized or tolerated?

In [hybrid-remote](hybrid-remote/) companies, where certain team members are colocated and others are remote, consider asking how [meetings](meetings/) and calls are handled. [Hybrid calls](/handbook/communication/#hybrid-calls-are-horrible) are often allowed or encouraged, though they offer a suboptimal experience for remote attendees. Ideally, each call participant will have their own equipment (camera, headset, and screen), even if multiple members are colocated.

This ensures that each team member is treated equally, and removes typical boardroom issues such as difficulty seeing body language through a wide-angle camera and being interrupted or booted from a room.

### Q: Is there flexibility with working hours and days?

![GitLab collaboration illustration](/images/all-remote/gitlab-collaboration.jpg)
{style="max-width: 50%;"}

Flex-work and workplace flexibility have grown in popularity, but it's important to ask for specific examples of how this actually works within a company you are considering joining.

Do only senior leaders have complete flexibility to schedule their working hours and days around their lives? Is workplace flexibility truly embraced and supported throughout the organization? Does the company empower team members to be a [manager of one](/handbook/values/#managers-of-one), valuing [outputs](/handbook/values/#results) rather than inputs such as hours worked?

When life happens and you need to restructure your day on the fly, is this openly encouraged and supported or quietly frowned upon?

Answers to these questions are critical in understanding the [true level of autonomy](people/#those-who-value-flexibility-and-autonomy) you'll be given to add value in a given company.

### Q: Do teams default to asynchronous work, or adhere to select time zones?

It's important to understand how teams work within an all-remote company. In organizations where [asynchronous communication]({{< ref "communication" >}}) is the default, it's likely that team members are diligent about documentation, resist the urge to schedule [meetings](meetings/), and are sensitive to atypical working hours/arrangements.

Certain companies prefer to have everyone contributing between certain times, creating additional boundaries on those who live too far east/west from the proverbial company epicenter and for [nomads](people/#nomads) who regularly change locations and time zones.

### Q: How is information disseminated?

![GitLab code illustration](/images/all-remote/gitlab-code-review.jpg)
{style="max-width: 50%;"}

[Documentation]({{< ref "documentation" >}}) is important in all companies, and the answer to this question should shed light on how much a company values it. Ideally, a company will have a handbook or similar where processes and culture are documented first, and *then* shared out (via email, Slack, etc.).

### Q: Approximately how many times did you reference the company handbook last month, and propose changes to it?

Similar to the above, this question allows you to talk specifics on how processes and solutions are iterated upon, and who is empowered to contribute. (*Hat tip to [Wes Winham Winler](https://twitter.com/weswinham/status/1212044671091978240) for the question*.)

### Q: Are cloud collaboration tools the default?

![GitLab review illustration](/images/all-remote/gitlab-review-and-collaborate.jpg)
{style="max-width: 50%;"}

Consider asking if notes are captured using an online collaborative suite (Office 365, Google G Suite, etc.). This is a more transparent, efficient, and collaborative approach compared to emailing documents back and forth, which creates versioning headaches.

### Q: How is informal communication encouraged and enabled?

Remote companies must be intentional about [informal communication](informal-communication/). When some or all team members are not able to foster relationships in person, a company must take deliberate steps. Consider asking for specific [examples](/handbook/total-rewards/incentives/#visiting-grant) of how a company has created an atmosphere where team members are [encouraged to connect as humans](https://about.gitlab.com/blog/2017/06/30/there-and-back-again-in-one-release/), not just colleagues.

### Q: What percentage of your team was hired without an in-person meeting?

Breaking the habit of requiring an in-person touch point for situations of significance (e.g. hiring someone, bringing on a new agency partner, etc.) is tough. While there is nothing inherently wrong with having an in-person touch point along the hiring process if it's convenient, you'll learn a lot about an organization's faith in [virtual conversations](https://about.gitlab.com/blog/2019/08/05/tips-for-mastering-video-calls/) by asking this question.

### Q: What percentage of your team's social/team-building activities last quarter were remote (versus in-person)?

[In-person interactions](in-person/) are important in remote organizations. Asking this question provides valuable insight into a company's strategy for building bonds through planned in-person activities, as well as how equipped they are to facilitate team-building through remote interactions.

### Q: What percentage of your group meetings last week resulted in a written artifact?

This question dives into a couple of areas. It provides an opportunity to understand if a company truly embraces asynchronous communication, and it exposes their true view and use of [meetings](meetings/).

![GitLab commit illustration](/images/all-remote/gitlab-commit-illustration.jpg)
{style="max-width: 50%;"}

{{% include "includes/is_this_advice_any_good_remote.md" %}}

## Contribute your lessons

GitLab believes that all-remote is the [future of work](remote-vision/), and remote companies have a shared responsibility to show the way for other organizations who are embracing it. If you or your company has an experience that would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests/) and adding a contribution to this page.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
