---
title: "The complete guide to starting a remote job"
description: "This guide provides a full overview of what to expect and what to consider when beginning a new role as a remote worker in order to ensure success and well-being. Learn more here!"
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

On this page, we're detailing considerations and tips for getting started in a new remote role.

## What exactly is a remote job?

In an [all-remote](hybrid-remote/#all-remote-upgrade) organization, each individual is empowered to [work and live](people/) where they are most fulfilled. A remote job allows you to work from wherever you're most comfortable. That could be a coffee shop, your basement office, a coworking space, or even a different place every month!

## During the interview phase, get an understanding of how the company defines remote work

Different companies will have [different approaches to remote work](phases-of-remote-adaptation/). Make sure you understand what your work environment will be like, and whether it matches your own working style.

Remote work is not for everyone. To be a great remote worker, make sure you understand this GitLab operating principle on being a [manager of one](/handbook/values/#managers-of-one).

Another element to flesh out during an interview is remote communication. GitLab is an [asynchronous](asynchronous/) company. Much of what we do is [communicated through text](effective-communication/). For people used to working in-office and default to verbal communication, it may take some time to transition to communicating information via text.

## Prepare for a different type of onboarding

Being [stressed about learning a new job](https://www.classycareergirl.com/new-job-anxiety-conquer/) is a reality for many people. Remote onboarding for new GitLab team-members may be new as they join our all-remote culture. Prepare yourself to be flexible, open, and ready to listen, learn, research, try new things, and get comfortable with videos and video calls for your onboarding process.

## How do I prepare for the first day of remote work?

For those who have not worked in a remote organization before, you may want help thinking through an ideal [workspace](workspace/) and need a few tips and tricks for [informal communication](informal-communication/). Make sure your technology and internet are all working and connected and be ready to introduce yourself, take notes, and ask questions.

![GitLab customer illustration](/images/all-remote/gitlab-customer-path.jpg)
{style="max-width: 50%;"}

## Don't be afraid to ask for help

Whether you're new to working remotely or have been doing it for a long time, don't be afraid to ask co-workers for advice. It may be helpful to request a mentor to help you acclimate faster.

If you're interested in finding remote communities to learn from, try one of these:

1. [LinkedIn Digital Nomads and Remote Workers group](https://www.linkedin.com/groups/13657237/)
1. [Reddit Remote Work](https://www.reddit.com/r/remotework/)
1. [WeWorkRemotely community](https://weworkremotely.com/)

## Take time to internalize values

{{< youtube "7kMQj4O4ZGU" >}}

*In the [GitLab Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A) video above, Sid (co-founder and CEO) and Darren (Head of Remote) discuss the importance of values at GitLab.*

Absorbing a company culture in a colocated setting occurs over time, as one witnesses behaviors that are supported, praised, and discouraged. A benefit to working in an all-remote setting is that culture is (ideally) documented.

As you settle into a new role, ensure that you devote time to reading and internalizing [company values](/handbook/values/). While this may feel like a skippable activity, understanding the values early on enables you to have a strong foundation on which to build. Every decision you make in your role should be guided by values. If you have questions about how values are lived, take time during onboarding to consult with others.

At GitLab, one's [Onboarding Buddy]({{< ref "onboarding-buddies" >}}) is there to answer these questions and provide guidance. There is also a `#values` Slack channel for related discussions. Whenever you see a value being lived, we encourage the use of a [values emoji reaction](/handbook/communication/#say-thanks) to reinforce values being used day-to-day.

## Adjusting to a self-service mindset

![GitLab collaboration illustration](/images/all-remote/gitlab-collaboration-illustration.jpg)
{style="max-width: 50%;"}

GitLab's [100% remote culture]({{< ref "_index.md" >}}) and our workplace methodologies are highly unique. You should not expect to transfer the norms of colocated corporations into a work from anywhere scenario. Those who thrive at GitLab take the opportunity to drop prior workplace baggage at the door, embrace a liberating and empowering [set of values](/handbook/values/), and give themselves permission to truly operate differently.

So differently, in fact, that many of GitLab's most effective processes would be discouraged or forbidden in conventional corporations. It's not a trap. It's the future of work.

Explore the resources in our [all-remote handbook section](self-service/), as well as our collection of [relevant blog posts](https://about.gitlab.com/blog/categories/culture/), for a deeper understanding of [life at GitLab]({{< ref "_index.md#life-at-gitlab" >}}).

## Focus your workspace

If you've managed to be productive despite operating within a conventional [open office floor plan](https://royalsocietypublishing.org/doi/full/10.1098/rstb.2017.0239), you'll likely be thrilled with your productivity level [as a remote team member](https://about.gitlab.com/blog/2019/08/15/all-remote-is-for-everyone/).

However, engineering an [optimal workspace](workspace/) may not come naturally — particularly if you've worked in environments which were defined prior to you joining.

For new remote workers, it's important to think about [where you prefer to work on a daily basis](https://about.gitlab.com/blog/2019/09/12/not-everyone-has-a-home-office/). Optimize this for focus. Consider spaces in your home, coworking venue, etc. where you will be largely free from distraction. Given that most offices are riddled with distractions, the ability to design a space that dodges them [is a boon for remote workers](https://about.gitlab.com/blog/2018/05/17/eliminating-distractions-and-getting-things-done/).

The more focused you are due to your surroundings, the more quickly you can accomplish your duties and move on to important non-work activities.

Pay close attention to ambient sounds, visual distractions, and areas of high traffic. Aim to dedicate a space where only work occurs, enabling you to focus specifically on work while there and [healthily disconnect](https://about.gitlab.com/blog/2019/07/09/tips-for-working-from-home-remote-work/) when you exit.

## Establish routine with family and friends

{{< youtube "BC7Prkm3v3g" >}}

*In the [GitLab Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A) video above, two GitLab colleagues discuss the benefits of living in a lower cost-of-living environment near friends, family, and community.*

When you physically leave a home to go to work, it signals to friends and family that you are not easily reachable, and that you are focused on work-related tasks. In a [work from anywhere scenario](https://about.gitlab.com/blog/2018/05/11/day-in-life-of-remote-sdr/), you're able to remain at home all day should you so choose.

For families who are not used to this, boundaries can be difficult to establish and maintain. When an employee is visibly at home, it may signal to other family members that they are accessible.

Consider having an open, honest conversation with family members about your working hours. Explain that while you are indeed home, you should be considered unreachable unless there's a significant level of need that would roughly align with justifying an office interruption in a colocated setting.

This tends to be [particularly vital to discuss with children](https://about.gitlab.com/blog/2019/08/01/working-remotely-with-children-at-home/), who may struggle to understand why a working parent is in the home but are unable or unwilling to engage with them for certain parts of the day.

By explaining that [a working parent](https://about.gitlab.com/blog/2019/07/25/balancing-career-and-baby/) is able to spend more time engaging immediately prior to and after work due to dropping the commute, it helps frame the new scenario in a way that spotlights the benefits to a child. To take this a step further, consider [arranging your work schedule](https://about.gitlab.com/blog/2019/06/18/day-in-the-life-remote-worker/) to allow for a midday activity with a child. By engaging in this manner, and explaining that such a luxury would have been impossible in a colocated setting, it can help reinforce the benefits of remote work.

Consider [visual availability indicators](workspace/#busyavailable-indicators) that will allow friends and family to easily know whether or not you're willing to be contacted during working hours.

## Experiment with work environments

![GitLab transport illustration](/images/all-remote/gitlab-transport.jpg)
{style="max-width: 50%;"}

While working from home is an ideal scenario for many, you may find that you're happier, more fulfilled, and more productive elsewhere. If you feel burdened or socially drained while working from home, consider a coworking space or an [outdoor area](https://about.gitlab.com/blog/2019/09/23/how-to-push-code-from-a-hammock/).

Preferences vary from person to person, and even from season to season. For example, you may find that [working while road-tripping in an RV](https://about.gitlab.com/blog/2019/06/25/how-remote-work-at-gitlab-enables-location-independence/) is exactly the kind of environment to maximize your personal and professional happiness.

Or, you may find that [working with other nomads in a foreign location](https://about.gitlab.com/blog/2019/09/04/not-all-remote-is-created-equal/) provides added clarity and creativity.

People [adopt a remote lifestyle](people/) for many reasons. It's important to consider unique work environments if you're new to a remote role. If you've been forced into an office for your entire career, you may not instinctively know which work environment is best for you. By experimenting and asking for advice from others who have worked remotely before, you may discover a side of yourself that's finally able to flourish due to newfound flexibility.

At GitLab, team members are allowed to [expense costs](/handbook/finance/spending-company-money/) associated with coworking spaces or external offices, as we recognize that working out of one's home is not always ideal or desired. If you're new to a remote role, ask your manager if external office space is reimbursable.

## Prioritize ergonomics

Whether it's in your home office, at a coffee shop, a coworking space, or elsewhere, [consider ergonomics in every instance](workspace/#ergonomic-considerations).

Pay close attention to seating and posture, as well as repetitive stress on arms and wrists. It's worth investing in equipment designed to help you work healthier. Cutting corners in this area now can lead to chronic pains in the future.

At GitLab, team members are [allowed to spend company money as they would their own](/handbook/finance/spending-company-money/). If you're new to a remote role, ask your manager if ergonomic equipment is reimbursable.

## Procure the right equipment for working remotely

Working remotely enables you to work from all types of environments. Those new to remote working are unlikely to have [equipment](workspace/) optimized for that flexibility.

Items such as standing/treadmill desks, standing mats, external keyboard/mice, high-definition webcams, webcam lighting, noise-cancelling headphones, a dedicated microphone, a laptop riser, and ergonomic cases/backpacks should be considered depending on your work scenario.

## Do remote employers provide work equipment?

Not all remote employers provide work equipment. This is an important question to ask during your interview process. However, at GitLab, team members are [allowed to spend company money](/handbook/finance/spending-company-money/) as they would their own, with [guidance provided](/handbook/finance/expenses/#-setting-up-a-home-office-for-the-first-time) for various types of equipment.

## How to connect with people when starting a remote job

While you will naturally connect with people during your onboarding, you will also need to be intentional about relationship-building via informal communication with your co-workers.

Below are a number of intentional facets of [GitLab's culture](/handbook/company/culture#culture-at-gitlab), created to foster connections.

1. [Social call](/handbook/communication/#social-call): A series of optional calls once a month on a Tuesday, to which everyone in the organization is invited. We have no set agenda, but items can be added to the linked document. This is just a time set aside for everyone to openly talk where everyone is a moderator.
1. [Contribute Unconference](/handbook/company/culture/summit/): An in-person, week-long event where we bring the entire company together in one location to get to know each other better.
1. [Group conversations]({{< ref "group-conversations" >}}): Four times a week the company gets together virtually to discuss an area of the business. Slides are provided for context but not presented.
1. Social hours: Informal social calls organized within our immediate teams to get to know each other on a more personal level.
1. Local meetups: Co-located team members are encouraged to organize their own meetups, whether it's a co-working space or getting dinner together.
1. [Slack](/handbook/communication/#slack): We use Slack channels for informal communications throughout the company, whether it's a team-specific channel or a channel dedicated to sharing vacation photos with other team members.
1. [Zoom calls]({{< ref "tools-and-tips#zoom" >}}): Not only do we get to know our coworkers better by seeing them in real time during video calls, we also get to know their pets and families too. This visual engagement helps us relate to each other on a more personal level, so when we meet in person, we already know each other. In fact, when our team members meet face-to-face for the first time, the most surprising factor is usually each person's height.
1. Gaming: GitLab has a `#gaming` Slack channel where fans of video games and digital board games can connect. Coordinating shared gaming sessions is a great way to informally connect with team members and collaborate toward goals outside of work.
1. Music making: GitLab's `#music_making` Slack channel is a place where artists can come together and collaborate synchronously or asynchronously to make music together. Several GitLab team members came together to create [All I Want This Quarter Is You (GitLab)](https://youtu.be/9kTwqsW8I68), a musical masterpiece on the GitLab Unfiltered YouTube channel.

## How to be successful in your first week of remote working

### Familiarize yourself with the company's technology & tools

Spend time getting to know [GitLab's publicly viewable handbook](/handbook), which captures everything you need to know about the company.

Technology is ever-changing. Which is one reason why GitLab's [onboarding process](onboarding/) includes exercises in self-service via an [onboarding issue]({{< ref "general-onboarding" >}}) with multiple tasks broken down into small, digestible chunks. Each issue guides new hires to complete certain tasks on certain days, being a [manager of one](/handbook/values/#managers-of-one)  — an operating principle of [Efficiency](/handbook/values/#efficiency) — applies from the very beginning.

### Develop a schedule that you can initially follow

Create a routine, then tweak it to find what works best for you. Start with a [consistent workday routine](https://learn.g2.com/how-to-work-from-home), or determine when you have [waves of peak productivity](https://www.jonobacon.com/2019/01/14/remote-working-survival/) and design your work day and routine around them.

### Begin to create connections with co-workers

If you worked at an office before, you might miss interacting with your coworkers at lunch or in the office hallways. In a remote environment, you need to [be more intentional about connecting with coworkers](informal-communication/#formally-design-informal-communications). Make time for coffee chats, reach out to teammates, and share details of your life to help people get to know you.

### Set up work-life boundaries

Be intentional about planning your [time off]({{< ref "paid-time-off" >}}).
When you're not working, disconnect by turning off Slack and closing down your email client. At GitLab, this only works if all team members abide by the [communication guidelines](https://about.gitlab.com/blog/2016/03/23/remote-communication/#asynchronous-communication-so-everyone-can-focus). It also helps to enable the "working hours" feature on your calendar so that team members in other time zones know when to schedule meetings.

### Get accustomed to the communication preferences of your co-workers

GitLab encourages [non-work related communication](informal-communication/) (talking about private life on a team call) for [relationship building](https://medium.com/@markfrein70/the-distributed-workplace-15ef447fa926). Take advantage of group video calls for [bonding](https://about.gitlab.com/blog/2015/04/08/the-remote-manifesto/), one-on-one [video calls](https://about.gitlab.com/blog/2015/04/08/the-remote-manifesto/) between people (as part of onboarding), and be sure to attend [periodic summits](/handbook/company/culture/summit/) with the whole company to get to know each other in an informal setting.

Ask your co-workers what their preferred methods of communication are; write them down; and be sure to use their preferred method/s.

## Bolster your internet connection, and consider redundancy

![GitLab commit illustration](/images/all-remote/gitlab-commit-illustration.jpg)
{style="max-width: 50%;"}

It's important to remember that remote workers are responsible for their own connectivity. This may require you to invest in a more substantial home internet connection. It's worth consider redundancy in this department as well. For example, upgrading your smartphone plan to support tethering or investing in a dedicated mobile hotspot or MiFi. This ensures that you have a fallback connection in place should your primary connection fail.

Secondary connections are particularly important when multiple family members work from home. For example, if one member is uploading a large file, that may impact the audiovisual quality of another member's [video call](https://about.gitlab.com/blog/2019/08/05/tips-for-mastering-video-calls/). A secondary connection allows each working member to operate on their own without impacting the bandwidth of the other.

## Manage isolation and mental health

![GitLab values illustration](/images/all-remote/gitlab-values-tanukis.jpg)
{style="max-width: 50%;"}

For those accustomed to social interactions within a colocated work setting, it can be jarring to move into a remote environment where you primarily work alone.

It's important to pay close attention to your [mental health](mental-health/) and [emotional health](https://about.gitlab.com/blog/2018/03/08/preventing-burnout/) as you transition to a remote role. If you sense a void from missing out on face-to-face interaction, act deliberately and early.

Here are a few suggestions to avoid isolation.

1. Schedule breaks in your day to interact with friends or family in the home, or nearby in your community.
1. Experiment with working in a shared setting (e.g. a local coworking venue, [WiFi Tribe](https://about.gitlab.com/blog/2019/09/04/not-all-remote-is-created-equal/), etc.).
1. Leverage [video calls](https://about.gitlab.com/blog/2019/08/05/tips-for-mastering-video-calls/) whenever practical, both at work and outside of work.
1. Engage with colleagues on [non-work topics](/handbook/communication/chat#social-groups), via Slack, ad hoc video calls, or other communication tools.
1. Prioritize work events where travel and physical interaction is involved (e.g. [company summits](/handbook/company/culture/summit/), meetups, [events](events/), conferences, etc.).

For GitLab team members, be sure to join the `#mental_health_aware` Slack channel and read our [guide](mental-health/) on combating burnout, isolation, and anxiety in the remote workplace.

## Be intentional about informal communication

![Spreading aloha on a GitLab company call](/images/all-remote/GitLab-Aloha-Shirt-Team.jpg)
{style="max-width: 50%;"}

{{% alert title="Spreading aloha on a GitLab company call" color="success" %}}
{{% /alert %}}

Lean in when it comes to [informal communication](informal-communication/). While this requires the use of an unusual muscle — particularly for those who have not worked in a remote setting before — it's important to form and foster relationships.

Making social connections with coworkers is vital to building trust within your organization. One must be intentional about designing informal communication when it cannot happen organically in an office.

If your new remote role does not specify informal communication options available to you, consider [reading GitLab's list](informal-communication/) and implementing at your company.

## Imagine what's possible with no commute

{{< youtube "gyDGeibTfdk" >}}

*In the [GitLab Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A) video above, two GitLab colleagues discuss the benefits of all-remote. In particular, the ability to travel on a continual basis while working and visiting colleagues, friends, and family.*

Perhaps the most inspiring and thrilling aspect of embracing a remote role is [the sheer potential of it](https://about.gitlab.com/blog/2017/01/31/around-the-world-in-6-releases/). The possibilities are near limitless when you're [empowered](https://about.gitlab.com/blog/2017/06/30/there-and-back-again-in-one-release/) to live and work where you are most fulfilled.

While traveling the globe or working from a beachside cafe may not appeal to everyone, remote work enables a dramatically different lifestyle for all. By removing one's commute and ditching the requirement to be seen in a physical office, you're able to **structure your work around your life** as opposed to the other way around.

This is a [profound shift](people/), and it may not be entirely obvious how to maximize one's new reality.

Consider starting a document listing things that working within a colocated environment prevents you from doing. Items such as dropping children off for school, participating in midday community service functions, visiting friends and family outside of peak holiday seasons, learning a new language by living in a foreign locale, relocating to care for an ill relative, moving to a more satisfying environment, working in a more comfortable wardrobe, etc.

By taking a look at what you've been missing, you're able to more easily assemble a plan for embracing such things in a remote setting.

Consider asking yourself what you'll do with the time you save by losing the commute. Perhaps you'll be inspired to embrace a daily fitness routine, cook at home, or spend additional time with friends, family, and community. There's nothing wrong with reclaiming that time and using it to bolster your overall wellness, from improving your sleep habits to furthering your education.

## Resist the urge to operate the same as before

{{< youtube "cy6WGuzArgY" >}}

*Emna G., founder and CEO at Veamly, speaks with GitLab's [Darren M.](https://twitter.com/darrenmurph) on a number of remote work topics: reinforcing culture, encouraging work-life harmony, remote work processes, the importance of process optimization in team productivity, and asynchronous communication.*

*You'll find more videos such as these in the [Remote Work playlist on the GitLab Unfiltered YouTube channel](https://www.youtube.com/playlist?list=PL05JrBw4t0Kq7QUX-Ux5fOunQotqJbECc).*

As aptly stated in [Basecamp's Handbook](https://basecamp.com/handbook), **there's as much to unlearn as there is to learn** when it comes to thriving in a remote role.

Remote work enables a great deal of flexibility, freedom, and autonomy. It also requires adaptability when it comes to communication, and may require experimentation by the team member to reach peak enjoyment.

It can be tempting for new remote workers to simply implement tactics used in colocated spaces, but from their home or a co-working space. For example, learning to search for answers within [documentation](/handbook/product/ux/technical-writing/documentation/) rather than tapping someone on the shoulder and asking a question.

This also applies to more nuanced aspects of work, including employee perception. Whereas working from a unique place or doing things differently may be discouraged in a colocated space, consider celebrating such diversity in a remote space.

There is more benefit to working remotely than simply losing the commute. Those new to this paradigm should give themselves permission to explore, experiment, and learn from others both on their team and on remote-centric forums.

{{% include "includes/coursera_gitlab_remote_course.md" %}}

## What are the best resources for remote working?

We've created this [extensive list of resources for remote professionals, teams, and organizations](resources/).

[GitLab's library of guides to working remotely](guide/) is another great resource.

{{% include "includes/is_this_advice_any_good_remote.md" %}}

## Contribute your lessons

GitLab believes that all-remote is the [future of work]({{< ref "remote-vision" >}}), and remote companies have a shared responsibility to show the way for other organizations who are embracing it. If you or your company has an experience that would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests/) and adding a contribution to this page.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
