---
title: "Remote Guide for Design Teams"
description: Remote Guide for Design Teams
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

![GitLab collaboration](/images/all-remote/gitlab-collaboration-illustration.jpg)
{style="max-width: 50%;"}

With forethought and planning, active resiliency in the face of a sudden all-remote change can actually serve to enhance productivity. This guide outlines how design teams can optimally prepare for and navigate these sudden changes to an all-remote environment.

## Thinking strategically, acting creatively

Design teams must develop a strategy to operate suddenly in an all-remote environment. The main concepts to consider are the following:

1. **Communication Infrastructure:** In a remote environment it's important design teams implement purposeful communications. [Start with an agenda]({{< ref "../management#docs-instead-of-whiteboards" >}}), both to keep attendees focused and to keep non-attendees in the loop. Using Google Docs, for example, allows everyone to contribute ideas, comment on concepts, and document decisions. To compensate for the shift to all-remote, it's wise to establish broad and frequent communications.
1. **Collaboration Cadence:** In an office environment, design teams organically build and fall into a cadence of meetings, collaboration, and other team-based activities. When these in-person exchanges are not available, it's important design teams establish [asynchronous workflows]({{< ref "../asynchronous" >}}) and learn how to [collaborate through text]({{< ref "../collaboration-and-whiteboarding#collaborating-through-text" >}}).
1. **Leadership and Empathy:** The way design team leaders operate and exercise management oversight must change to reflect the sudden upheaval. This might entail more frequent but shorter one-on-one meetings to sustain a pulse on team members or more frequent check-ins to project work teams to provide support. Bottom line: how leaders managed in traditional environments will not translate directly or neatly into a suddenly all-remote one. Read our all-remote management guide on [effective all-remote leadership]({{< ref "../management" >}}) for more information.
1. **Metrics:** If "out of sight, out of mind" is allowed to become the design team all-remote mantra, morale will suffer. To celebrate accomplishments and enhance team cohesiveness, design teams should implement visual reminders of milestones, shortcomings, challenges, learnings, and expectations. If possible, they should track all-remote metrics and performance against previous traditional work environment metrics and performance. When metrics from both environments are juxtaposed, the team can see and thus manage productivity changes. Consider asking questions like: Is a team member distancing themselves from the team? Has a team member changed the way they communicate? Has anyone's work output significantly changed in recent times?
1. **Flexibility and Improvement Model:** Out of the gate, few design teams will operate at peak capacity in a newly remote environment. For this reason, it's important to remain flexible and allow systems to take hold. Whenever possible, team leaders should highlight individual and team successes, underscore positive metrics, and feature major project achievements to bolster morale and show what's possible. Design team leaders must be willing to ask penetrating questions about what's working and what isn't in order to effectively change models, adjust trajectories and improve performance.

## Prioritizing initiatives

Mature design teams will likely already leverage a series of communications tools so a sudden shift to an all-remote arena will not impact digital communications much. However, teams with an established collaborative cadence may find the shift to an all-remote environment challenging due to the absence of in-person brainstorms, iterative design sessions, visual feedback and mark-up meetings. Therefore, design teams should prioritize this element to ensure appropriate collaboration measures are put in place immediately so that no one on the team goes off on their own, unlinked from the greater team's efforts.

## Tools to make the change

![GitLab code review](/images/all-remote/gitlab-code-review.jpg)
{style="max-width: 50%;"}

Key tools and technologies needed to make the shift from in-person to all-remote collaboration among designers, product managers, engineers, and any other stakeholders include:

- Instant Messaging tools (e.g. Slack, MS Teams) to maintain the velocity of design and development
- Concepting/sketching tools (e.g. Mural, Miro, InVision's Freehand, Figma, Apple iPod/Pencil) for real-time brainstorming or sketching sessions
- Cloud-based planning and documentation platform (e.g. GitLab)
- Research and feedback platforms to validate designs (e.g. usertesting.com, Validately)

## Tips for getting started

Each team's transition to remote work will look different. Here are some tips and practical advice start with:

1. **Open edits on all platforms:** Lacking face-to-face interactions demands more transparency in digital feedback systems. Defer to "open for edits" in all platforms to allow team members opportunities to chime in on projects. Realize that time shifts for individual team members vary.
1. **More frequent accountability check ins:** Recognize that there are no longer any "water cooler" conversations and that "managing by walking around" requires a different route, different tool, and different set of expectations. Those short, quick but productive conversations will not exist any longer so it's important to replicate them through other means as much as possible. Set up open chat rooms or perhaps schedule several few minute breaks where invited team members can check in at particular times during the day.
1. **Embrace experimentation:** Innovation is borne of necessity and nothing creates more need for innovation than unexpected or even unimagined challenges. Request feedback from team members on new and better ways to communicate, collaborate and increase the velocity of project work. While feedback cycles may be slow initially when first going all remote, design team leaders should continue to implement and demand robust feedback loops.
1. **Block time:** In all-remote environments, team members will likely rely on email and chat more than before. As such, it's important to allow teams to block "work time" to avoid more frequent interruptions. Example: No emails or phone calls between 10:30 am and 2:30 pm.
1. **[Document everything]({{< ref "../handbook-first" >}}):** In a traditional environment, documentation becomes second nature. In a suddenly all-remote environment, the need to document and over-communicate everything becomes paramount.
1. **[Get together]({{< ref "../in-person" >}}):** An all-remote work environment does not mean an always-remote work environment. It's important for team members to interact with each other in person, even if only annually. Consider hosting an [in-person retreat]({{< ref "../in-person" >}}) for team members for this purpose.

## The upside of disruption

![GitLab collaboration](/images/all-remote/gitlab-collaboration.jpg)
{style="max-width: 50%;"}

Disruptions can cause consternation and unease, but there's a flip side as well. Below are three fundamental benefits from shifting to an all-remote environment, especially if that shift happens suddenly.

1. **Innovation:** As we have seen with the recent pandemic, when companies are forced to rethink their processes and deal with unforeseen circumstances, it leads to innovation. For design teams that are populated by creative individuals, the birth of innovation is especially true.
1. **Productivity:** In the short term, as individuals settle into their new work environments, it's possible productivity might take a dip. After all, having to deal with issues like setting up a remote office, adjusting for remote security policies, and finding ways to work in a busy home with family and pets around can cause some hiccups. The research, however, shows that individuals are far more productive when they are allowed the flexibility and the opportunity to do their jobs without unnecessary interruptions in traditional work environments. This is particularly true for design teams which often suffer from an interrupt-driven culture that can impinge upon the ability to effectively create and finish work product. With these distractions removed, design team members often report higher levels of employee satisfaction.
1. **Loyalty:** When trust is given to employees, loyalty is returned. Individuals appreciate it when their employers trust them to do their jobs and give them the tools to do so. It creates a different type of bond, separate and apart from the "check-in" culture that often accompanies typical work environments.

## Understanding impact

As design teams move to an all-remote environment, it's important to double down on effort to engage with other departments, e.g. finance, people operations, marketing, sales, etc. What once was taken for granted as every day interactions must now be purposely built into interdepartmental communications. To the extent possible, design team leaders should implement 360 degree feedback loops among key stakeholders in other departments to ensure smooth, efficient operations.

---

Return to the main [all-remote page]({{< ref "../_index.md" >}}).
