---
title: "Remote Guide for Finance Teams"
description: Remote Guide for Finance Teams
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

![GitLab navigation](/images/all-remote/gitlab-journey-and-navigation.jpg)
{style="max-width: 50%;"}

Check any online job board and you will find thousands of companies recruiting for finance professionals to work remotely. Like their counterparts in other parts of enterprises, CFOs and their direct managers understand the importance of recruiting the best and brightest finance professionals and then finding ways to integrate them into the company fully. On-premise finance work as the norm is today less important than a fully prepared, flexible and resilient finance team ready, willing and able to work in an all-remote way.

## Calculating sudden all-remote preparedness

Many organizations have already discovered their finance groups can function quite well remotely. According to an [Owl Labs survey](https://owllabs.ca/state-of-remote-work/2021), approximately 7% of finance/legal professionals work remotely. If your company had not previously dipped its toe into remote-work waters, COVID-19 "work from home" directives  likely required your company to  implement some or all of the following strategies:

1. **Move away from or fully off on-premise technology:** The  ability of a Finance team's members to access what is needed remotely minimally means accessing on-premise solutions via VPN, along with being well-equipped with the commensurate equipment to have a fully functioning workstation. A heavier lift is making the move to the cloud. In times of disruption, Finance can induce a sense of calm across an organization by operating with fewer (or without) hiccups.
1. **Go paperless:** Save time from having to shred. Make sure the Systems team backs everything up. Twice. You can do it. Thrust suddenly into an all-remote scenario, paper files will be your Achilles heel, as they will immediately become inaccessible if you didn't take them with you when the doors to the office shut behind you.
1. **Communication Tools:** Organizations that permit the use of a multitude of varying tools for collaboration to accomplish the same things—voice, video conferencing, chat, file sharing—permit confusion to creep in. All-remote productivity can be increased by using a finite set of company sanctioned tools. Further, a minimal set of tools ensures remote or asynchronous communication remains clear, focused and consistent, curbing loss of productivity. Minimize email for the sake of more immediate responses and feedback. Now that you've identified the right company communication tools, use them!  Especially early on in a sudden onset all-remote environment, frequent synchronous/real-time communication is key to gauging how your coworkers or those who report to you are doing. Simply put, people handle stressful events very differently.
1. **[Flexibility with Shifting Schedules]({{< ref "non-linear-workday" >}}):** With a company's new "everyone at home" dynamic, an adjustment period is necessary due to the simple fact that personal and business lives are far more acutely intermingled than before. Finance teams are not immune to this and a new paradigm of shifting schedules becomes the new norm. This forces teams to prioritize tasks and deliverables. Leaders need to keep a sense of routine, but, at the same time, be flexible as the dust settles into new patterns and the team finds its new rhythm.
1. **[Transparency]({{< ref "remote-values#transparency" >}}):** Transparency in a remote Finance team builds trust and confidence across the group.  Some highly remote companies share everything across the board to everyone, except salaries, and some even share that info as company-wide policy. The tendency is for the workforce to embrace their lane and know how they fit in the construct of the team and the business as a whole. Information and access flows much more freely within transparent organizations, democratizing access while maintaining control. It also allows team members to view each other as partners rather than pegs in a hierarchical structure. Team members need to be intentional about relationships with their  colleagues.
1. **Automate:** If transactions, invoicing, reporting, etc. can be automated, automate it. It frees up the team to work towards greater business goals, and encourages them to expand their vision into other areas that might otherwise suffer from inattention. It enables a Finance team to stay lean and nimble and keep the team's collective eyes on results.

## Tools to make the change

![GitLab code review](/images/all-remote/gitlab-code-review.jpg)
{style="max-width: 50%;"}

Key tools and technologies needed to make the shift from in-person to all-remote collaboration for Finance teams might include:

- Synchronous messaging tools (e.g. Slack, Microsoft Teams, IRC, etc.) to maintain velocity through real-time interaction and collaboration;
- Document sharing (Google Drive, Box, Dropbox, etc.)
- SaaS-based accounting software solutions (ADP, Quickbooks, etc.)
- Video conferencing (e.g. Zoom, Skype, Google Meet) for synchronous discussions with recording for later viewing by those who could not attend; and
- Cloud-based planning and documentation platform (e.g. [GitLab]({{< ref "gitlab-for-remote" >}})).

## Checks and balances

In order for a Finance team to run well after being suddenly dropped into working all-remote, it bears repeating that it's not for everyone. Human beings are social creatures after all. Be mindful of the following pitfalls your group may encounter when making the shift, forced or not:

1. Lack of face-to-face supervision means team members may not speak up as quickly when they encounter a challenge or block. Check in more regularly with your supervisor and those who report to you - at least until your team has its rhythm down. Managers who go "invisible" run the risk of having their employees feel that the manager is out of touch with employee needs.
1. Without routine communication, especially if coupled with a lack of access to information, team members lower their willingness to give others the benefit of the doubt. Taking extra time to listen rather than just talking at other team members is really important to keep the business culture buoyed and to ensure that top priorities are handled first.
1. On a more practical note, human and technical errors with the tools utilized for working remotely may be a real challenge resulting in unnecessary delays. This is especially a challenge if an employee is not technically inclined. Even the most well-intentioned shifts in the right direction to working productively while remote can backfire or may not have been fully analyzed. Some key automation may not exist yet or that paperwork you really need may not have been scanned into the system.
1. Experiment: Request daily feedback from Finance team members on new and better ways to communicate, collaborate and increase the velocity of project work. While feedback cycles may slow initially when going all remote, finance team leaders should implement and demand robust feedback loops.
1. Block time: In all-remote environments, finance team members will likely rely on email and chat more than before. As such, it's important to allow finance teams to block "work time" to avoid more frequent interruptions. Example: No emails or phone calls between 10:30 am and 2:30 pm.
1. **[Document everything]({{< ref "../handbook-first" >}}):** In a traditional environment, documentation becomes second nature. In a suddenly all-remote environment, the need to document and over-communicate everything becomes paramount.
1. **[Get together]({{< ref "../in-person" >}}):** An all-remote work environment does not mean an always-remote work environment. It's important for finance team members to interact with each other in person, even if only annually. Find ways to host a retreat for team members for this purpose.

## The upside of disruption

![GitLab code review](/images/all-remote/gitlab-collaboration.jpg)
{style="max-width: 50%;"}

As companies evolve to being able to shift to an all-remote setting on the fly, naturally their outlook about conducting business more routinely in a remote setting will also change. With that comes a number of great perks to their bottom line:

1. **Talent Acquisition and hiring:** Remote work environments open up greater access to talent because there are no longer any geographical restraints to hiring. Additionally, not only does the talent pool get expanded because of lack of geographical constraints, but also because today's workforce actively seeks more flexible work environments Consequently and especially if a company is based in a high-cost urban location, hires can be made for significantly less money than local talent would require.
1. **Workdays extend across time zones:** The company can gain better coverage/distribution so work happens more consistently throughout the day, rather than being focused into a tighter window of hours.
1. **Insulation against localized failures:** Furthermore, a company's ability to weather localized infrastructure failures like power outages, internet disruptions, natural disasters, etc. and business continuity plans improve if the workforce is dispersed geographically.
1. **Lower overhead:** More remote workers means less need to maintain commercial office space lowering overhead costs.

## Bottom line

This guide will help Finance teams discover a natural rhythm to operating in a suddenly remote way. This rhythm will allow teams to identify key priorities, manage them effectively, and learn from their implementation in an iterative fashion, further informing the next priority tier as appropriate. As in any professional environment, open communications about learning as you make your way is essential.

---

Return to the main [all-remote page]({{< ref "../_index.md" >}}).
