---
title: "Remote Guide for People Operations"
description: Remote Guide for People Operations
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

![GitLab all-remote team collaboration](/images/all-remote/gitlab-collaboration.jpg)
{style="max-width: 50%;"}

Perhaps more than any other functional department, people operations — referred to as "human resources," "HR," "people success," or simply "people" across various organizations —  is front and center in helping shape and optimize the changes required when a [sudden shift to an all-remote environment]({{< ref "remote-work-emergency-plan" >}}) becomes necessary. This guide outlines how people teams might navigate the sudden shift to an all-remote work environment, what challenges are most important to tackle, and how the new normal can unveil unforeseen benefits.

## Related resources

1. [Remote onboarding]({{< ref "../onboarding" >}})
1. [Building culture]({{< ref "../building-culture" >}})
1. [Hiring]({{< ref "../hiring" >}})
1. [Compensation and Total Rewards](/handbook/total-rewards)
1. [Remote internships]({{< ref "../internship" >}})

## Major strategic considerations

As with any new initiative, thinking and operating strategically is important for success. Maintaining company values, ensuring clear communication guidelines, and supporting managers and team members through the transition are essential to making the shift seamless.  Here are some strategic considerations to evaluate during your planning stage:

1. **[Cultural and Values Equivalence]({{< ref "../building-culture" >}}):** The sudden shift to an all-remote environment requires a smooth transition on the culture front. Whatever your organization's culture and values were before the immediate shift, they should remain so after. For example, if your organization operates in self-directed work teams, the suddenly all-remote standards should remain the same. Significant changes in how you operate may be inferred by team members as a lack of trust which can be difficult to reverse.
1. **Empathy and Understanding:** Sudden shifts also cause anxiety, concerns, and a level of unease for many people uncomfortable with change. Given this fact, it's important for people teams to inject into their everyday management systems ways to check on team members' progress, offer assistance, provide guidance and demonstrate empathy more frequently than they would have otherwise. In a colocated work environment, people professionals can visually inspect colleagues. When this no longer exists, it's critical to find flexible ways to enable the organisation to  check in and deal with the suddenly remote workforce. Empathy, grace, and understanding go a long way to helping maintain and reinforce bonds with team members.
1. **Manage to Milestones:** People departments should work with other leaders in the organization to ensure a clear definition of milestones and metrics. Be careful not to equate "time worked" with value-delivered. Instead, manage results and behaviors. If results suffer, then probe to uncover the reasons, recognizing that there might be a logical reason for a dip. Importantly, take special care to recognize and reward results or behaviors that spur better than expected results or performance. Highlighting success is just as important — if not more so — in a suddenly all-remote situation as it is in more traditional environments.
1. **Fundamentals:** It's easy to assume suddenly remote team members have all the pieces in place in their home to work productively. That would be a mistake. Survey team members immediately as to their [work-set up and urgent needs]({{< ref "../workspace" >}}), e.g. a good desk chair, secure Internet connection, headphones for video conferences, etc. To the extent possible, offer to reimburse them for reasonable home office equipment.
1. **Encourage Flexibility and Innovation:** A simple "copy/paste" of a traditional work environment into a suddenly all-remote one may sound good in theory but counterproductive in practice. Encourage team members to [adjust work schedules]({{< ref "non-linear-workday" >}}) and processes to reflect the newly all-remote arena, and recognize those with the most innovative applications. Again, do not set the productivity bar low; rather push for and call out those who are making a "good thing" better.
1. **Over-Communicate:** Communication is vital in any business. In a suddenly all-remote situation, diligent [documentation is a requirement]({{< ref "handbook-first" >}}). A handbook for documentation acts as a single source of truth for information making it possible for team members to get what they need the minute they need it. Weekly 1:1 meetings will keep you connected and checking in regularly, and team stand-ups and/or end-of-day sessions can provide structure to the team. The goal of adding these extra communication hooks is not to hover but to empower self-sufficiency as much as possible.
1. **[Emphasize the Human Element in HR]({{< ref "../being-a-great-remote-manager#traits-of-a-great-remote-manager" >}}):** Productivity spawns from people able to perform their jobs with minimal distractions. In a suddenly all-remote environment, this may be problematic. Leaders must understand that people's lives are complex, and team members may be juggling childcare, eldercare, community efforts, and beyond. parents if schools and daycares are closed. Recognize personal needs, and bend expectations accordingly. Consider implementing team breaks, e.g. a daily walkabout, or some other non-traditional activity that underscores your commitment to team members' well being.

## Embrace agility and remain flexible

![GitLab customer path](/images/all-remote/gitlab-customer-path.jpg)
{style="max-width: 50%;"}

As with any significant change, emphasize flexibility. When setting up an all-remote work environment, hiccups are natural and should be expected. The shift requires time to flush out what's working and what isn't. Remaining agile in the face of these evolving realities is essential to course-correcting trajectories. Let team members know that change is a constant, that adjustments will reflect reality on the ground and no set of initial rules are set in stone or sacrosanct. To accomplish this, find ways to leverage the following elements of a solid internal communications strategy:

1. Internal social networks, like Slack, which allow for more rapid communication across teams. Monthly email updates are fine, but business moves too quickly to rely on infrequent communications.
1. A culture of engagement that encourages everyone to participate in key initiatives. Research conducted by Aon Hewitt [found](https://aon.mediaroom.com/news-releases?item=137558) that a 5% increase in team member engagement led to a 3% increase in revenue the following year. What might be perceived as a soft skill is, in fact, a bottom line driver.
1. Engaging, visually-stimulating content that's easy to absorb, share, and retain. Forego the long, legalistic policy memos in favor or more compelling and memorable content. And don't worry if the videos are not professionally produced; we're used to various quality of content.
1. Customized communications based on departments, teams, and individuals. The more focused the communications, the better.
1. Frequent, visible recognition of success, especially in the face of challenging circumstances.
1. Even in fully asynchronous environments where people are not required to adhere to certain work hours, remember that time zones do exist and should be respected. Additionally, a global team may cross many time zones, and remote team members may move from one time zone to another as they travel.

## Tools to make the change

Key tools and technologies needed to make the shift from in-person to all-remote collaboration among team members include:

1. Instant messaging tools (e.g. Slack, Microsoft Teams) to maintain regular contact
1. Video conferencing (e.g. Zoom, Skype, Google Meet) for virtual touchpoints
1. Cloud-based planning and documentation platform (e.g. [GitLab]({{< ref "gitlab-for-remote" >}}))
1. Learning management system tool to enable remote training
1. Document management tool to allow remote signatures
1. Integration between your ATS, HRIS and payroll systems to create a fluid workflow experience

## Direct impact on people team members

The impact of any sudden change to people operations will fall unequally on team members. Given this, consider the following as you build, implement and tweak your road map:

1. **Building Culture:** An organization's culture should be built, nurtured, and amplified intentionally, not by accident. The same applies in a suddenly all-remote environment. Sure, the way work gets done will change, but that doesn't mean the culture should. Instead, it's critical to intentionally shift and project the company's culture in an all-remote arena, emphasizing it over and over. See [this review on building and sustaining an intentional remote culture]({{< ref "../building-culture" >}}).
1. **Self-learning and self-enabled environment:** Whenever a new hire brings up a valid process point that leads to a previously undocumented answer, the default mindset should be to answer and document right away. This requires a mindset of [self-service]({{< ref "../self-service" >}}), self-searching, and self-learning. It also requires diligence and empathy. This is a critical part of reinforcing a bias for [asynchronous](../asynchronous) and a culture where [every meeting is questioned]({{< ref "../asynchronous#question-every-meeting" >}}).
1. **Onboarding:**Time spent developing and honing your onboarding process in traditional work environments should be followed as much as possible in the suddenly all-remote environment to ensure that each new employee experiences the full impact of joining the organization. Avoid shortcuts if possible. See [this detailed review of onboarding](https://internal.gitlab.com/handbook/people-group/people-operations/people-connect/onboarding_process) in a remote environment.
1. **Hiring:** Being thrust into an all-remote environment doesn't mean hiring needs to stop. In fact, hiring remotely can be a huge benefit should you choose to stick with the remote model. With remote, companies can hire from anywhere and have access to the best talent, regardless of location. When moving candidates through the hiring process remotely, it's important to detail exactly how they will join the interview (i.e. phone call or video call), who they will be interviewing with, and how long they should expect the interview to take. Help candidates think through any logistics to consider. For example, if it's a video call, make sure to have a good internet and set up in a room with minimal distractions. Read [this overview on hiring in an all-remote arena]({{< ref "../hiring" >}}).
1. **Compensation:** Getting or keeping team members paid in a suddenly all-remote environment requires planning with your finance team, especially if foreign currencies come into play. Read [this overview on compensation]({{< ref "remote-compensation" >}}) for more information, which includes details on location and other factors.
**Internships:** Finding, recruiting and retaining interns when shifted to a suddenly all-remote environment can be challenging, but not impossible. Read [this guide on internships]({{< ref "../internship" >}}) for more information.

## The upside of disruption

![GitLab commit path](/images/all-remote/gitlab-commit-illustration.jpg)
{style="max-width: 50%;"}

Not all disruptions are bad. Often, they tend to spark new ways of thinking that spawn innovations.  Consider the following benefits from a people perspective:

1. **Focus on Results:** Without the minor issues as distractions, people professionals can focus on encouraging productive behaviors and helping team leaders drive results. This unleashing of people professionals to focus on business goals can have a [meaningful impact on job satisfaction](https://www.shrm.org/content/dam/en/shrm/topics-tools/news/hr-magazine/Employee-Job-Satisfaction-Engagement-Flyer.pdf).
1. **Leadership:** People teams can help advance leaders, edit succession plans, and prepare for the future away from the everyday noise that a traditional office might mask. Specifically, they can identify [leaders]({{< ref "being-a-great-remote-manager#traits-of-a-great-remote-manager" >}}) who are most likely to thrive in suddenly remote environments, including those who are particularly self-aware, demonstrate empathy, embrace a servant-leader mindset, and  possess a bias for documentation.
1. **Competitive Advantage:** Assuming competitors don't shift to an all-remote arena, there's a huge competitive advantage to finding and retaining talent in all-remote environments. Geographic limitations to talent acquisition disappear overnight as do retention fears of star performers getting poached for relocation. All-remote can be a big boost to your brand.

## The bottom line

People teams which embrace the suddenly all-remote shift for its upside potential rather than its downside possibilities are likely to provide greater support. By thinking creatively, embracing ambiguity, maintaining flexibility, and focusing on behaviors and results, people leaders will have a central role in managing the shift and optimizing it over time.

---

Return to the main [all-remote page]({{< ref "../_index.md" >}}).
