---
title: "Head of Remote: how to hire, job postings, job description, courses, and certifications"
description: Head of Remote
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

![GitLab collaboration illustration](/images/all-remote/gitlab-collaboration.jpg)
{style="max-width: 50%;"}

GitLab and Darren M. pioneered the "Head of Remote" role. In the wake of the COVID-19 pandemic, many organizations are transitioning to remote. Regardless of what [phase](phases-of-remote-adaptation/) they're in, or what [stage](https://app.hopin.com/events/gitlab-sales-kickoff-2021-peak-performance/stages) they intend to embrace, GitLab has triggered a global movement of appointing a dedicated lead to evolve a company's remote fluency.

## What is a Head of Remote?

A Head of Remote ensures operational agility and durability as a workforce decouples business results from physical geography. It serves as a cross-functional internal consultant to evolve key pillars (e.g. learning & development, knowledge management, tooling, onboarding, and culture/informal communication) such that each function becomes more effective in a distributed setting.

Initially, a Head of Remote sets the tone for behavioral and cultural shifts required to embrace new models of working. Longer-term, the role may evolve to lead or support overarching workplace experience.

## Why companies hire a Head of Remote

As more organizations embrace [remote-work variations](terminology/), they are realizing that remote and remote-hybrid workforces run the risk of [creating two opposing cultures and workflow defaults](https://www.wired.com/story/hybrid-remote-work-offers-the-worst-of-both-worlds). For the organization to thrive, charting a harmonious path forward *must be someone's job*. Not just a part of their job, but the *whole job*.

Distributed work unlocks talent and productivity, but not without intentional effort. The underlying infrastructure of how a team works will change without an office as a crutch, and it requires a leader to steer teams through the shift, coordinate upskilling, and enlist new tools where appropriate.

## Does your organization need a Head of Remote Work?

Senior leadership roles continue to grow as work expands, collaboration occurs across borders, and software continues to [eat the world](https://a16z.com/2011/08/20/why-software-is-eating-the-world). Just as UiPath articulates the need for a [Chief Automation Officer](https://www.uipath.com/blog/does-your-organization-need-chief-automation-officer), the COVID-19 pandemic has made clear that working with remote teams is too important to leave to chance.

Organizations should consider hiring a Head of Remote. This may be titled Director of Remote Work, VP of Remote Work, Chief Remote Officer, or a variety of alternatives. Longer-term, this role may evolve into a Head of Workplace Experience, Head of Culture, or similar.

Below is a series of fundamental questions that leaders must answer when transitioning to remote. It is unlikely that an existing team will be capable of directing adequate attention to these needs without backfilling for other responsibilities. You can also take a look at [Remote Work Trends](https://www.beautiful.ai/player/-MN2DyuYlmg6Bh5JA3sn/Remote-Work-Trends).

## Questions to ask a Head of Remote

Finding a leader with extensive remote experience and a history of successful business or culture transformations will be difficult. Suddenly-remote companies may consider hiring a Chief Documentarian to establish a regimented documentation strategy, and morph this role into a more encompassing one over time. Former editors and publishers may be suitable for such a role.

A sample of questions to be answered by a Head of Remote Work:

1. Who will direct training and upskilling of newly-remote managers, collect feedback on needed resources (and subsequently deploy said resources), coach them on unlearning old approaches, refine their mastery of asynchronous workflows, and motivate reports who may be oceans away?
1. Who will sit down and audit every single perk and benefit offered globally, and ensure that remote workers have equivalent benefits to those who choose to work onsite?
1. Who will lead an end-to-end [tools audit](collaboration-and-whiteboarding/), ensuring that tools which do not support asynchronous workflows are deprecated or replaced, and ensuring that existing tools are used in [remote-first ways](how-to-work-remote-first/)?
1. Who will create, establish, and champion your firm's [documentation strategy](handbook-first/), hiring the right team to ensure that communication voids are closed?
1. Who will coach your executives on the nuanced benefits of one or more being [remote by default](remote-work-emergency-plan/), sending clear signals that praise and promotion are not tied to a physical building?
1. Who will be the voice of the distributed worker, ensuring equality and belonging for those who may never step foot in a corporate office?
1. Who will be responsible for ensuring that newly-remote workers have healthy, ergonomic [workspaces](workspace/) at home?
1. Who will ensure that [learning and development](learning-and-development/) principles address the challenges of remote [hiring](hiring/), remote [interviewing](interviews/), remote [onboarding](onboarding/), remote [management](management/), remote promotions, and beyond?
1. Who will conduct an end-to-end process audit and provide structured replacements for remote-last workflows, such as a reliance on [synchronous meetings](meetings/) for consensus gathering and collaboration?
1. Who will lead the reevaluation of company [values]({{< ref "remote-values" >}}), and subsequent editing and bolstering such that everyone understands how to treat others without the need for routine in-person contact?
1. Who will put a travel strategy in place such that [in-person engagements](in-person/) become a core part of [building company culture](building-culture/)?
1. Who will revise your company's talent acquisition strategy, creating a clear and concise answer to "What's your stance on workplace flexibility?"
1. Who will build a visible [talent brand]({{< ref "culture#life-at-gitlab" >}}) demonstrating how remote workers are supported and included? (This will create significant sway in your Glassdoor reviews.)
1. Who will lead existing executives in [transforming](being-a-great-remote-manager/) their expectations and ways of working, coaching them to model the [unlearning of old habits]({{< ref "candidate-faq" >}}) and embracing new ones in transparent fashion?
1. Who will ensure that teams have the tools, direction, and coaching they need to [become documentarians](self-service/)?
1. Who will outline a multi-year remote transformation strategy with quarterly milestones and objectives, coaching a team through iterative change and celebrating small wins along the way?
1. Who will champion your culture and values, not only to galvanize teams through a pandemic, but excite them by building a more disciplined, cohesive, [asynchronous](asynchronous/), inclusive, and diverse future?
1. Who will understand the nuances of remote and the myriad business implications beyond just today?

**For an added deep dive on the topic, replete with a decision-making rubric, download the [Head of Remote white paper](https://web.archive.org/web/20240829121204/https://remote.com/resources/research/head-of-remote-whitepaper) from our friends at Remote.com and Distribute Consulting.**

### Remote transformation consultants

In lieu of hiring a full-time remote work leader, or as a bridge until you're able to recruit the ideal candidate, consider working with a specialty consulting firm. The below companies have extensive remote operational experience and carefully construct teams of subject matter experts to address the challenges specific to each client.

1. [Distribute Consulting](https://www.distributeconsulting.com)
1. [Global Workplace Analytics](https://globalworkplaceanalytics.com)
1. [Remote-how](https://remote-how.com)

No one remote transformation will be identical to another. Some companies need a documentarian to craft a [handbook](handbook-first/), while others need more assistance on messaging and tooling. These consultancies run end-to-end audits to meet companies where they are and move them forward.

Be especially wary of working with remote experts and consultancies which did not have extensive remote work experience *prior* to the COVID-19 pandemic.

### Companies hiring a Head of Remote

![GitLab transport illustration](/images/all-remote/gitlab-transport.jpg)
{style="max-width: 50%;"}

The below is an inexhaustive list of firms who are *publicly* hiring — or have hired/appointed — a dedicated remote work leader since the COVID-19 pandemic. To add to this list, please create a merge request or tag `@darrenmurph` on Twitter.

Multitudes of firms are hiring for this role without formally posting a job description.

1. Facebook (now Meta): [Director, Future of Work Movement](https://www.linkedin.com/in/simon-hill-815aa615) and [Director, Future of Work](https://www.linkedin.com/in/kelly-monahan-ph-d-18879413)
1. Dropbox: [Head of Virtual First](https://www.linkedin.com/in/terryotran) and [VP of Design](https://www.linkedin.com/in/alastairsimpson)
1. Twitter: [VP of Real Estate & Workplace and Remote Experience](https://www.linkedin.com/in/tracy-hawkins-5b303326)
1. Upwork: Director of Remote Organizational Effectiveness
1. Grammarly: [Head of Remote-First Hybrid](https://www.grammarly.com/jobs/corporate/head-of-remote-first-hybrid?gh_jid=4496226)
1. Okta: Head of Dynamic Work
1. LinkedIn: [Vice President, Flex Work](https://www.linkedin.com/in/shannonhickshardy)
1. VMWare: Senior Director, Collaboration and Productivity
1. Cloudflare: [Head of Distributed Work](https://www.linkedin.com/posts/seacue_head-of-distributed-work-activity-6798698073041313792-mDjb)
1. Quora: [Remote Work HR Specialist](https://www.linkedin.com/in/kara-ortbal-ab051b60)
1. Zapier: Remote Communications Manager
1. Vistaprint/Cimpress: Manager, Remote-First
1. Hopin: [Head of Remote](https://www.linkedin.com/in/jonathan-killeen-45a85b77)
1. Gong: Director of Remote Work
1. MainStreet: Title TBD
1. Cleveland Clinic: [Director of Remote Workforce Solutions](https://www.linkedin.com/in/ashley-rader-mha-64827b22)
1. The Partnership for Public Service
1. Oyster: [Head of Remote](https://www.linkedin.com/in/rhysmkblack)
1. Avalon Consulting Group: [SVP and Director of Remote Work](https://www.linkedin.com/in/margot-hostie-o-leary-82225056)
1. Strata Solar: [Director, Remote Operations](https://www.linkedin.com/in/keary-dosier)
1. Doist: [Head of Remote](https://twitter.com/dcwarrington/status/1444933106042122241)
1. Castor: Remote Lead
1. Atlassian: [VP, Team Anywhere](https://www.linkedin.com/feed/update/urn:li:activity:6883851660725161984)
1. NPR: [Director, Future of Work](https://www.linkedin.com/in/angie-hamilton-lowe-b0874b1)
1. Prudential Financial: [VP, Head of Capabilities for Future of Work](https://www.linkedin.com/in/wagnerdenuzzo)
1. Careem: [Director of Remote](https://www.linkedin.com/in/tariqvohra)
1. Microsoft: [Future of Work Communications](https://www.linkedin.com/in/hannahmcconnaughey)
1. HP: [Head of Future of Work, Collaboration, and Business Incubation](https://www.linkedin.com/in/loretta-li-sevilla-b29995)
1. Chevron: [Global Lead of Future of Work Strategies](https://www.linkedin.com/in/rashad-delph-5367283)
1. Evonik: [Head of Future of Work](https://www.linkedin.com/in/susanmcgoffmiller)
1. RBC: [Senior Director, Future of Work & Culture](https://www.linkedin.com/in/deenah)
1. Lockheed Martin: [Workforce Transformation, Future of Work](https://www.linkedin.com/in/peacey)
1. Nationwide: [Director, Future of Work](https://www.linkedin.com/in/aaronstout)
1. Procter & Gamble: [Senior Director, Digital Transformation and Future of Work](https://www.linkedin.com/in/craigahawkins)
1. Google: [Director, Future of Work & Workforce Planning at Google](https://www.linkedin.com/in/tazeenchaudhry)
1. Target: [Senior Vice President, Future of Work](https://www.linkedin.com/in/steve-brophy-1671a25)
1. Unilever: [VP, Future of Work](https://www.linkedin.com/in/patrick-hull-98602210)
1. Limeade: [Head of Remote](https://www.linkedin.com/in/arifmba)
1. Modern Health: [Workplace Experience Manager](https://www.linkedin.com/in/dominiccordon)
1. ADP: [Principal, Future of Work](https://www.linkedin.com/in/gmota)
1. SAP: [SVP & Chief Future of Work](https://twitter.com/Schmeichel_C)
1. Deloitte: [Global Future of Work Leader](https://twitter.com/sthatfield) and [Future of Well-being Lead](https://www.linkedin.com/in/ryanhopkinsuk)
1. The Recycling Partnership: [Director of Organizational Effectiveness](https://www.linkedin.com/in/tannenbaum)
1. Virgin Media O2: [Head of Future Work and Workplace](https://www.linkedin.com/posts/markus-urban_newjob-workplacestrategy-futureofwork-activity-7010268893533327361-MVUL?utm_source=share&utm_medium=member_desktop)

### What function or department does a Head of Remote sit in?

It depends. The general rule with a nascent role is to put it where the most help is needed. While People Operations may feel like the most suitable, a company's remote leader should be sat where they can exert the most cross-functional influence. The active roles above sit within People, Marketing, Communications, Finance, Real Estate, Operations, and Design — quite the eclectic mix.

- If change management linked to organizational design is the core concern, People Operations (or, more broadly, Operations) is likely a suitable location.
- If the key focus is on reducing or rearchitecting office space and changing both where and how people work, Real Estate and/or Finance is a logical option.
- If an organization has a solid level of remote fluency, a Head of Remote may thrive in Communications/Marketing, as the core responsibility will be to evangelize new ways of working both internally and externally.

## Using GitLab to prepare for a Head of Remote career path

Chief Diversity Officer, Chief Automation Officer, Chief Data Officer, and Chief Experience Officer are all relatively new C-suite titles. Yet, it's difficult to imagine progressive organizations scoffing at the validity of their existence. GitLab has pioneered a nascent role in Head of Remote — a senior leader dedicated to remote work and workplace experience.

While case studies through [Harvard Business School](https://www.hbs.edu/faculty/Pages/item.aspx?num=57917) and [INSEAD](https://publishing.insead.edu/case/gitlab) are percolating through the university system and equipping MBA students with information on running an all-remote company, there is no well-defined career path to becoming a Head of Remote.

Below are several recommended areas of study that will prepare you for a remote leadership career, paired with GitLab courses to share on your resume/CV and LinkedIn profile.

1. Master of Business Administration (MBA)
1. Industrial/Organizational Psychology
1. Organizational Design
1. Organizational Change
1. Organizational/Workplace Communication

### Courses and certifications in remote work leadership

![GitLab journey illustration](/images/all-remote/gitlab-journey-and-navigation.jpg)
{style="max-width: 50%;"}

At GitLab, we seek to open source our mastery of remote work in order to equip and empower the next generation of remote work leaders. We encourage those aspiring to fill remote work leadership roles to complete the coursework below and implement GitLab's proven practices into your current organization. In interviews, share completion of these courses and examples of implementing GitLab principles as a means to substantiate your mastery of remote work fundamentals.

1. [GitLab's Remote Work Foundations Certification]({{< ref "remote-certification" >}})
1. [Remote Team Management](https://www.coursera.org/learn/remote-team-management) (hosted on Coursera)

Prior to the COVID-19 pandemic, there was low supply and low demand for dedicated remote work leadership. In the midst of the pandemic, demand began to rise slowly, while supply remains low.

By 2022, most of the world's organizations will reckon with their new reality: at least a portion of their workforce will insist on more flexibility, and a refusal to adapt will lead to their best talent fleeing to organizations which are actively empowering people to work more flexibly.

<!-- TODO: Replace with screenshots. -->

> Sid Sijbrandij on [Twitter/X](https://twitter.com/sytses/status/1264341436138270720)
>
> Below is a thread about the future of remote work after the COVID-19 pandemic is over. I predict that remote will go through a trough of sorrow due to hybrid not working out, and most companies will return to being office based. But many all remote companies will see success.

As this occurs, many organizations will ignore our [warnings](https://www.wired.com/story/hybrid-remote-work-offers-the-worst-of-both-worlds) on the pitfalls and nuanced difficulties in creating a thriving [hybrid-remote organization](hybrid-remote/), triggering an acute spike in demand for senior leadership who understand the mind of a remote worker and the [organizational design principles](https://link.springer.com/article/10.1186/s41469-020-00087-8) to convert remote work from a challenge to a strategic advantage. **In a high demand/low supply environment, remote work mastery will become a highly marketable skill**.

Much like someone who is multilingual, an individual who has completed GitLab's [Remote Work Foundations certification](remote-certification/) and [Remote Team Management](https://www.coursera.org/learn/remote-team-management) course on Coursera will have an advantage when vying for new roles centered on remote work leadership. You will effectively speak a new and evolving business language which is critical to acquiring/retaining talent, creating workflows which are location agnostic, and building a culture which does not rely on a physical building to function.

### Skills and talents necessary to be a Head of Remote

While each organization will utilize a remote leader somewhat uniquely, below are skills worth honing and highlighting when pitching yourself as a Head of Remote to your existing organization, or putting yourself forward as a candidate for an open role.

Study the links below. They point to various educational sections within the GitLab handbook which will equip you with knowledge to pass the aforementioned certifications.

1. The ability to communicate with [low-context and high precision](effective-communication/#understanding-low-context-communication), particularly with the written word
1. Deep empathy and an ability to relate to challenges from team members across the globe ([Manager of One]({{< ref "leadership#managers-of-one" >}}))
1. A default to servant leadership, capable of triaging and defining solutions from inbound feedback
1. Expert storytelling skills to generate understanding and organizational buy-in for significant change management campaigns ([High Output Management]({{< ref "high-output-management" >}}))
1. Organizational savvy and the ability to garner influence to positively impact the working lives of team members
1. A native visionary and problem solver who seeks outside perspectives, tools, and workflows to continually evolve an organization's workplace design, culture, and strategy
1. Propensity to form and foster interdepartmental relationships
1. A default to working [transparently](/handbook/values/#transparency) and with a [low level of shame](/handbook/values/#low-level-of-shame) is vital given the extreme cross-functional nature of the role
1. A sound advisor to other executives, guiding decisions through a global and inclusive lens
1. Appreciation for [self-learning and self-service](self-service/)
1. Appreciation for [documentation](handbook-first/) and knowledge taxomony/codification
1. Proven ability to work [asynchronously](asynchronous/) and coach others to do so

## Head of Remote job description

We are collecting publicly available Head of Remote (or similarly titled) job descriptions in a [shared Google Doc](https://docs.google.com/document/d/19kqlWiCcOOsCuQOW2kUYEk3y-0P-9XuPODrPZp8fS24/edit?usp=sharing).

For companies who are attempting to articulate what they need in a remote leader, use the examples above as a starting point.

## Who created the Head of Remote role?

Sid Sijbrandij and Darren M. used GitLab to [create](https://gitlab.com/gitlab-com/www-gitlab-com/-/merge_requests/33460) the Head of Remote role on `2019-10-26`. There's a pretty good story behind it, too.

Following a "[Making Remote Work](https://medium.com/@gcvp/going-distributed-choosing-the-right-remote-friendly-team-model-6a04f833267c)" event in San Francisco, which was co-hosted by GitLab and General Catalyst, Darren M. ([`@darrenmurph`](https://twitter.com/darrenmurph)), Sid Sijbrandij ([`@sytses`](https://twitter.com/sytses)), and Andreas Klinger ([`@andreasklinger`](https://twitter.com/andreasklinger)) were discussing Darren's role at GitLab.

At the time, Andreas was the de facto Head of Remote Products at AngelList. After hearing Darren's duties, he informed Sid that Darren's title should be "Head of Remote" to be indicative of his responsibilities. He then [tweeted](https://twitter.com/andreasklinger/status/1187842851259867136) the same sentiment, which is embedded below.

Sid went back to his home and [created a merge request on GitLab](https://gitlab.com/gitlab-com/www-gitlab-com/-/merge_requests/33460) which proposed the title change, also [tweeting it](https://twitter.com/sytses/status/1188179157361950720) for the public to follow. Darren later merged the MR, ushering the proposal into reality.

## What does a Head of Remote do?

GitLab Head of Remote Darren M. details his role in an all-remote organization in his README, which serves as an operating manual to working with him.

More broadly, a Head of Remote exists to achieve the following.

1. Audit and pressure test all existing workflows, policies, and cultural underpinnings to ensure that they are adapted for [remote-first](how-to-work-remote-first/)
1. Serve as a trusted advisor and steerer to existing workstream leads, ensuring that their work is inclusive of geographies and time zones and accelerates the mission of all work being achievable regardless of one's physical location
1. Advise existing executives on proven remote work practices and lead a systematic unlearning process to replace old habits (e.g. defaulting to a meeting, forgoing documentation, working in silos vs. transparently, etc.) with more progressive ones
1. Evolve thinking and operations to suit the modern-day reality of workplace expectations
1. Deconstruct colocated office norms and rebuild workflows/culture to suit a vastly more opportunistic virtual work environment

If you are employed in an organization with leadership who assumes that they can manage all of the above on their own, without making investments or changes, send them the link to this section. Please tag me on Twitter ([`@darrenmurph`](https://twitter.com/darrenmurph)) if you'd like.

## Join the Head of Remote forum

We've created a space for remote leaders to share resources, challenges, and insight. Whether you're leading the remote transformation within your organization or you're seeking to pursue this as a career path, join the conversation (no longer available) in our Head of Remote forum.

## Is this a real movement backed by data?

### T3 Advisors

T3 Advisors [reports](https://twitter.com/darrenmurph/status/1335296679617179651) a sharp surge in companies creating remote work leadership roles, rising from just 2% in August 2020 to 12% in November 2020.

![T3 Advisors Head of Remote Study](/images/all-remote/T3_Advisors_Head_of_Remote_Report_2020-12-05_01.png)
{style="max-width: 50%;"}

### Initialized Capital

Survey data analyzed by [Kim-Mai Cutler](https://twitter.com/kimmaicutler), a partner at Initialized Capital, shows a staggering shift to remote-first in an article entitled *[Post-Pandemic Silicon Valley Isn't A Place](https://blog.initialized.com/2021/01/data-post-pandemic-silicon-valley-isnt-a-place)*.

![Initialized Capital 2020 location data](/images/all-remote/Initialized_2020_location_data.jpeg)
{style="max-width: 50%;"}

![Initialized Capital 2021 location data](/images/all-remote/Initialized_2021_location_data.jpeg)
{style="max-width: 50%;"}

> Pre-pandemic, the Bay Area was still the leading choice for our founders in terms of where to start a company. There were many other cities that were distant seconds or thirds including New York and Seattle.
>
> Post-pandemic is a different story. More than 40 percent of founders say that the best place to start a company will be in the cloud. We expect to see decentralized or remote companies displace venture-backed companies based in the Bay Area over time.
>
> Post-pandemic, the Bay Area will be the second leading technology hub after the cloud.

### Capgemini Research Institute

Capgemini Research Institute surveyed 500 organizations and 5,000 employees from a range of sectors globally and conducted interviews with academicians and executives to compile its [Future of Work report](https://www.capgemini.com/wp-content/uploads/2020/12/Report-The-Future-of-Work.pdf).

> Around three in ten organizations expect more than 70% of their employees working remotely in the next two to three years, up from just one in ten before COVID-19.

![Capgemini Research Institute](/images/all-remote/Capgemini_Research_Institute_Remote_Work_Survey_Data_2021.png)
{style="max-width: 50%;"}

## In the news

The below is an inexhaustive list of news articles covering the growing movement of firms hiring a dedicated leader for remote work. *Some of the articles may require a paid subscription to access*.

1. The Australian: [Why hybrid workplaces bring a whole new set of challenges (reproduction)](https://twitter.com/darrenmurph/status/1358117706323656707)
1. Forbes: [The Next In-Demand Job Title: Head Of The Future Of Work](https://www.forbes.com/sites/jenamcgregor/2022/01/18/the-next-in-demand-job-title-head-of-the-future-of-work/?sh=776b6d5160b8)
1. Protocol: [Do you need to hire a 'head of remote?'](https://web.archive.org/web/20230327033654/https://www.protocol.com/workplace/head-of-remote-darren-murph)
1. NPR Marketplace: [Why more companies are hiring heads of remote work](https://www.marketplace.org/2021/10/26/why-more-companies-are-hiring-heads-of-remote-work)
1. Quartz: [Five telltale signs you need a 'chief remote officer'](https://qz.com/work/2167719/five-signs-your-company-needs-a-head-of-remote)
1. The New York Times: ['Head of Team Anywhere,' and Other Job Titles for an Uncertain Time](https://www.nytimes.com/2022/08/04/business/job-titles-remote-work.html)
1. Fast Company: [More companies are hiring a 'director of remote work'](https://www.fastcompany.com/90573992/more-companies-are-hiring-a-director-of-remote-work)
1. San Francisco Chronicle: [Tech's hottest job title in 2021? 'Head of remote work'](https://www.sfchronicle.com/local/article/Meet-the-people-making-your-work-from-home-16044685.php#photo-20765212)
1. Digiday: ['Change without story is a mandate, change with story is purpose': Why marketing and comms execs are being tapped for chief-of-remote roles](https://digiday.com/marketing/change-without-story-is-a-mandate-change-with-story-is-purpose-why-marketing-and-comms-execs-are-being-tapped-for-chief-of-remote-roles)
1. Washington Post: [Why 'head of remote' is likely to be a job title of the future](https://www.washingtonpost.com/business/2020/09/09/head-of-remote-work-jobs)
1. The Chartered Institute of Marketing: [Is "head of remote" a marketer's next career choice?](https://www.cim.co.uk/content-hub/editorial/is-head-of-remote-a-marketer-s-next-career-choice)
1. Crowe Global: [Exclusive Q&A With GitLab's Head Of Remote](https://www.crowe.com/global/insights/art-of-smart/exclusive-q-a-with-gitlab-head-of-remote)
1. Ladders: [The dawn of the age of Chief Remote Work Officers](https://www.theladders.com/career-advice/the-dawn-of-the-age-of-chief-remote-work-officers)
1. Fortune: [Why GitLab hired a 'head of remote' before the Coronavirus pandemic](https://fortune.com/2020/05/28/coronavirus-head-of-remote-work-from-home-gitlab-github-jobs)
1. The Economist: [The three new executive roles that define 2020](https://applied.economist.com/articles/the-three-new-executive-roles-that-define-2020-fmoma)
1. The Globe and Mail: [Chief remote working officers are now navigating organizations into a post-pandemic world](https://www.theglobeandmail.com/business/article-chief-remote-working-officers-are-now-navigating-organizations-into-a)
1. SHRM: [Why You Need a Remote-Work Leader](https://www.shrm.org/hr-today/news/hr-news/pages/why-you-need-remote-work-leader.aspx)
1. VentureBeat: [After embracing remote work in 2020, companies face conflicts making it permanent](https://venturebeat.com/2021/01/01/after-embracing-remote-work-in-2020-companies-face-conflicts-making-it-permanent)
1. The Australian: [Why hybrid workplaces bring a whole new set of challenges](https://www.theaustralian.com.au/business/the-deal-magazine/will-the-hybrid-workplace-be-a-risky-option-for-employers-postcovid/news-story/7841d04614fe688fb366eb2eb3272d70) (subscription required)
1. LinkedIn Talent Blog: [Why You Need to Hire a Head of Remote Work — and What That Job Entails](https://business.linkedin.com/talent-solutions/blog/work-flexibility/2020/why-you-need-to-hire-a-head-of-remote-work)
1. Reworked: [Is Now the Time to Invest in a Head of Remote Work?](https://www.reworked.co/leadership/is-now-the-time-to-invest-in-a-head-of-remote-work)
1. Running Remote: [Is it time for your company to hire a Head of Remote?](https://runningremote.com/is-it-time-for-your-company-to-hire-a-head-of-remote)
1. Zenefits: [Why Companies Are Hiring a Head of Remote Work (and Why You Should, Too)](https://web.archive.org/web/20230602020646/https://www.zenefits.com/workest/why-companies-are-hiring-a-head-of-remote-work-and-why-you-should-too/)
1. Fast Company: [Why your business needs a Head of Remote](https://www.fastcompany.com/90715519/why-your-business-needs-a-head-of-remote)

## Contribute your lessons

Making remote work well, particularly in companies with colocated roots, is a shared challenge. If you or your company has an experience that would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests) and adding a contribution to this page.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
