---
title: "All-Remote Hiring"
description: How to hire and support a remote team
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

## Remote hiring, explained

The [pandemic](https://www.cdc.gov/coronavirus/2019-ncov/index.html) forced many organizations to transition to be [all-remote companies](guide/). Many realized the [benefits]({{< ref "remote-benefits#benefits-of-remote-work" >}}) and decided to keep the remote structure. This shift necessitates implementing a remote hiring process to grow a remote workforce.

As one of the world's largest [all-remote companies](guide/), GitLab has been hiring and onboarding remote workers, remotely for over a decade. We've detailed what we learned in the [Principles of Hiring section of our Handbook](/handbook/hiring). On this page, we're sharing best practices for a streamlined remote hiring process anyone can implement.

![GitLab customer illustration](/images/all-remote/gitlab-customer-path.jpg)
{style="max-width: 50%;"}

## What are the benefits of all-remote hiring?

One advantage of being an all-remote company is the ability to [hire talent from a global pool](/handbook/hiring), giving access to a tremendous amount of talent that many other companies overlook.

It can be a struggle for organizations to find, recruit, retain, and compensate employees in competitive markets, including most major cities. Imagine the influx of highly qualified applicants if the location requirement were removed from all job descriptions. For a glimpse at what this looks like, please visit [GitLab's Jobs page](https://about.gitlab.com/jobs).

In addition to giving your organization a competitive edge, here are some other advantages:

- ### Remote hiring supports a stronger and more diverse candidate pool

All-remote hiring widens the talent pool and allows you to hire from any countries where you have legal status. This can greatly improve your company's cultural diversity. [Diversity, Inclusion & Belonging (DIB)](/handbook/company/culture/inclusion/) has been fundamental to GitLab's success, and we strongly encourage prioritizing DIB in hiring practices.

GitLab strives to hire team members who are passionate, empathetic, kind, tenacious, and ambitious, regardless of their location. By opening the talent acquisition funnel to as broad a swath of the world as we can, we create a more inclusive hiring environment, lean on tight collaboration to drive progress [across time zones](asynchronous/), and focus our hiring decisions on results rather than location.

- ### Remote hiring is a quicker process

Because you don't have to organize travel or schedule around multiple calendars, remote testing and meeting speeds up the applicant search, narrowing, and interview process. You can asynchronously circulate recorded interviews and solicit feedback from team members unable to attend the interview.

- ### Remote hiring saves time and money

Cutting travel cuts considerable costs, making remote testing and interviewing highly cost-effective. I can also be less disruptive to end the process with candidates who are not a good fit at any point, without the guilt of wasting the candidate's or the company's time or money.

Hiring an all-remote team from across the globe allows GitLab to pay local rates, which you can learn more about [on the company blog](https://about.gitlab.com/blog/2019/02/28/why-we-pay-local-rates). By hiring brilliant minds in locations with lower costs of living, GitLab is able to save money to hire even more people as we scale our business.

- ### Remote hiring gives you an authentic virtual engagement experience

Remote interviews for remote jobs enable you to gauge a person's ability to communicate and interact onscreen, providing insight into how they will handle the virtual communication required in a remote role.

## What to do before starting the remote hiring process

### Commit to supporting remote work, not just allowing it

[**Supporting** remote work](phases-of-remote-adaptation/) is different than [**allowing** it](stages/#remote-allowed). Before hiring for a remote role, ensure that it is [set up to be successful](evaluate/). Prepare management with training on [how to be a great remote manager](being-a-great-remote-manager/).

Prepare a well-designed [remote interview process](/handbook/hiring/candidate-faq/) to ensure that you'll hire the right person and that they'll be prepared with accurate expectations.

### Advertise accurately and transparently

We've published our [hiring process](/handbook/hiring/interviewing), including example screening questions, in our handbook.

While this may be unique, we see it as simply staying true to our [transparency value](values#transparency). The process shouldn't be a mystery.

Letting candidates know what to expect allows them to focus on whether the role and the company are right for them, while we evaluate that too.

In this [GitLab Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A) video, GitLab's Head of Remote speaks with [Remotefit](https://remotefit.netlify.app/) co-founder Javier on building and sustaining culture while being open about processes in the talent acquisition and hiring process.

<!-- blank line -->
<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/3_bqUjz8Vd4?start=412" frameborder="0" allowfullscreen="true"> </iframe>
</figure>
<!-- blank line -->

> To be [transparent](/handbook/values/#transparency), we showcase our culture to prospective hires in advance. For example, there's a section of our Jobs FAQ called "[What's it like to work at GitLab?]({{< ref "candidate-faq" >}})"
>
> You cannot expect to hire people who are passionate about executing your strategy if you wait to share the plan *after* they are onboard. Some candidates may opt out of the interview funnel if they realize they aren't a good fit for the company's mission, vision, and values.
>
> It's silly to think that a company would withhold its strategy, culture, or workflows until *after* someone gets hired. These elements determine whether a team member will thrive. Why would you hold that back? — *Darren Murph, Head of Remote at GitLab*

In this [GitLab Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A) video, GitLab co-founder / CEO Sid Sijbrandij discusses hiring (amongst other topics) with researchers from [INSEAD](https://www.insead.edu).

{{< youtube "EuGsen3FxXc?start=2493" >}}

> "A company might claim, 'Our strategy is very important, and you need to be aligned to it! We'll only tell you after you join.'
>
> I think that's bananas. That's what every company in the world does. If your strategy is really important, make sure people buy in *before* they join. And make sure that people who don't buy in don't join the company.
>
> Execution depends on people; [being public about what we do](/handbook/company/strategy). allows us to attract the best people to best execute our strategy." — *GitLab co-founder and CEO Sid Sijbrandij*

### Make yourself attractive to top talent

Remote work is the last great competitive advantage for employers. Remote maximizes a person's freedom and autonomy to integrate work into their life instead of the other way around. If two employers offer a talented applicant the same title, salary, and benefits, the tipping point will be the employer that **supports remote work**.

We've gathered extra ways to attract top talent to your organization (Note: this list assumes a workplace supports remote and [permission to play](/handbook/values/#permission-to-play) behaviors.)

1. Benefits for families and caregivers (daycare stipend, cleaning/laundry stipend, meal stipend, enhanced health insurance options, continuing education, adoption/fertility support, etc.)
1. [No ask, must tell vacation policy]({{< ref "paid-time-off" >}}) which senior leaders visibly model
1. The ability to [expense](/handbook/finance/spending-company-money/#coworking-or-external-office--space) a "third space" for working — an external office, coworking space, or residential community space through the likes of [Codi](https://www.codi.com)
1. Caregiver leave (maternity, paternity, eldercare, etc.)
1. [De-location stipend](https://web.archive.org/web/20220202064653/https://zapier.com/blog/move-away-from-sf-get-remote-job/) (supporting relocation away from a high cost-of-market location)
1. 4-day workweek, Summer Fridays, no-meeting days, and other efforts that provide company-wide time off for employees to rest, recharge, and connect with community
1. Supporting the purchase of a complete and ergonomic [remote workspace](workspace/) uniquely tailored to each team member
1. Transparent policies for investing in and championing [diversity, inclusion & belonging](/handbook/values/#diversity-inclusion) (and published goals for improvement)
1. Restricted stock units (RSU) or stock options
1. Enhanced hiring bonuses and higher salaries
1. Large annual bonuses based on performance (*remote work [measures impact](/handbook/values/#measure-impact-not-activity), not activity, input, or time-in-seat*)
1. Well-trained remote managers that default to [asynchronous workflows](asynchronous/) (*Confidently assuring prospective talent that they will endure fewer meetings and micromanagement is a solid way to differentiate from other employers.*)
1. Publishing supportive policies which explicitly allow employees to create better [work/life harmony](people/#worklife-harmony) and put [family and friends before work](/handbook/values/#family-and-friends-first-work-second)
1. Supporting (via time and money) learning for self-development
1. Building and explicitly publishing a culture of trust, empowerment, and autonomy for employees to do great work regardless of location (*view [GitLab's guide on building culture](building-culture/) and its [Values page](/handbook/values/) for more*)
1. Engage and respect *existing* employees, empowering them to become [talent brand ambassadors]({{< ref "gitlab-ambassadors" >}}) on platforms such as Glassdoor, LinkedIn, Twitter, and Comparably
1. Permit open sourcing some of an employee's work and encourage building of their personal brands
1. Clear opportunities for [growth]({{< ref "career-development" >}}) and professional development

## What to do during the remote hiring process

### Source for remote-work qualities

Not everyone is suited for remote work. There can be many reasons why a remote job isn't right for an individual, based on their career stage, their working preferences, or what they hope to get out of their next role.

However, there are plenty of people who thrive in remote jobs (as GitLab's global team can attest). In our 10+ years of remote hiring, here are the qualities we've learned to seek out.

#### Self-management

There are nuances to loving remote work and being a great remote worker. An operating principle at GitLab calls it being a ["manager of one"](/handbook/values/#managers-of-one).

#### Communication skills

GitLab is an [asynchronous](asynchronous/) company. Much of what we do is [communicated through text](effective-communication/). People with lengthy in-office careers, who default to verbal communication, may be uncomfortable communicating via text at first.

How do you screen for text-communication skills? Whether they realize it or not, most people **have** worked remotely. If your company has multiple locations, there's a good chance you worked with people outside of your office.

#### Remote-work experience

If someone has not worked in a remote environment, chances are that they *have* worked outside of their office (e.g., working while traveling, advancing a university project while away from campus, etc.) Ask candidates for examples of how they managed those instances, looking specifically for how they embrace autonomy and [blameless problem solving](/handbook/values/#blameless-problem-solving).

Even if your company didn't define it this way, those offices [were remote to one another](stages/). You had to navigate Zoom calls, time zone differences, etc. For example, you may be based in Seattle with colleagues in Singapore and London. Asking applicants to dive into those situations will help uncover how they handle remote work.

#### Aligns with company values

Look for ways candidates align with company [values](/handbook/values/). Share them in advance and ask the candidates to explain which values resonate with them and why.

Having prior experience working remotely is appreciated, but even more are attributes like timeliness, dependability, respect, a heart for collaboration, perseverance, empathy, kindness, and ambition.

#### Self-awareness

Self-awareness and agile thinking are required to thrive in an all-remote setting. One way to screen for this is to test a candidate's ability to perform *thinking writing*, as described in [this Hacker News thread](https://news.ycombinator.com/item?id=24801098). Thinking writing is the ability to draft ideas, then read them, modify them, change their order, remove some, refine/add others, and share with everyone through a [low level of shame](values#low-level-of-shame).

Other qualities unique to a remote workplace are:

1. Inclination for [self-learning and self-service](self-service/)
1. Appreciation for [documentation](handbook-first/)
1. Proven ability to be a [manager of one](/handbook/values/#managers-of-one)
1. Capable of (and enjoys) working [asynchronously](asynchronous/)

When asked if anyone could learn to work well in an all-remote setting during an [INSEAD](https://www.insead.edu/) case study [interview](https://youtu.be/EuGsen3FxXc), GitLab co-founder and CEO Sid Sijbrandij replied:

> "What's essential in all-remote is that you are a [manager of one](/handbook/values/#managers-of-one).
>
> You're not going to have someone expecting you at the office and hold your hand, so you have to be able to manage yourself and work independently.
>
> It is critical that you can write well — be concise and precise in your written communication- to bridge time zones and leverage [asynchronous communication](asynchronous/)".— *GitLab co-founder & CEO Sid Sijbrandij*

### Tips for interviewing all-remote candidates

We've created a guide on [How to Conduct a Remote Interview](interviews/), and included some highlights below.

#### The top 10 questions to ask a remote candidate

The full list of [questions to ask a remote candidate](interviews/#interview-questions-to-assess-for-success-in-a-remote-environment) is here, but these are the most insightful:

1. What challenges have you faced working remotely, and how did you overcome them?
1. What methods do you use to ensure you are communicating with a remote team?
1. Have you ever worked independently without direct, daily supervision?
1. What strategies, tools, routines, or workflows do you use to meet daily goals?
1. What excites you about working remotely over working in a traditional office environment?
1. How do you switch off from work?
1. Tell me about a time you recognized an opportunity for process improvement and how you brought that up to leadership.
1. What would you do if you have a piece of work that requires help from someone in a different time zone and they are not available?
1. How do you schedule/prioritize/stay motivated?
1. What is your default when you don't know what to do next?

### Use video calls to interview and engage

Candidates need to be comfortable with video calls since they are a primary medium for communication in a remote role. At GitLab, we use [Zoom](/handbook/tools-and-tips#zoom) to connect with candidates via [video calls](/handbook/communication/#video-calls).

This [GitLab Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A) video demonstrates how to conduct a remote interview process.

{{< youtube "tHThOsneFOY" >}}

---

For more, watch Shane Bouchard, UX Manager, and Jeremy Watson, Senior Product Manager, [discuss interviewing and finding great designers](https://www.youtube.com/watch?v=d15_q_K5Yq8).

---

This approach reinforces several of GitLab's [values](/handbook/values/).

- [Efficiency](/handbook/values/#efficiency): We can provide a better candidate experience and hire faster since neither candidate nor interviewer must travel.
- [Diversity, Inclusion & Belonging](/handbook/values/#diversity-inclusion): We create a level playing field for all candidates by allowing them to interview from a space where they are comfortable.

## What to do after you hire a remote worker

### Invest in onboarding

When [hiring in an all-remote organization](hiring/), it is critical to onboard new team members well. You have to give new hires the information they need to do their jobs, and you have to empower them to think remotely. Remote onboarding relies heavily on [documentation](management/#scaling-by-documenting), anticipating the needs of new team members, and a dedication to continuously improving the process based on feedback.

Onboarding is a continuous process during a team member's first year. Investing upfront in your onboarding process will yield long-term benefits:

1. Sets clear expectations
1. Reduces new-hire anxiety
1. Increases productivity more quickly
1. Better team member retention

Companies that invest in onboarding report [54% more productivity](https://www.myshortlister.com/insights/employee-onboarding-statistics) from new hires. Studies show that [87% of team members are less likely to leave a company](https://totalteambuilding.com.au/the-positive-impact-of-team-building/) when they feel engaged.

1. Sets clear expectations
1. Reduces new-hire anxiety
1. Increases productivity more quickly
1. Better team member retention

Companies that invest in onboarding report [54% more productivity](https://www.myshortlister.com/insights/employee-onboarding-statistics) from new hires. Studies show that [87% of team members are less likely to leave a company](https://totalteambuilding.com.au/the-positive-impact-of-team-building/) when they feel engaged.

We are so convinced in the power of onboarding well that we've created a [Complete Guide to Remote Onboarding for New Hires](onboarding/). To help new hires focus on [three key onboarding dimensions](https://hbr.org/2018/12/to-retain-new-hires-spend-more-time-onboarding-them)--[organizational](onboarding/#organizational-onboarding), [technical](onboarding/#technical-requirements-for-all-remote-onboarding), and [social](onboarding/#social-requirements-for-all-remote-onboarding)--we assign a mentor or [onboarding buddy]({{< ref "onboarding-buddies" >}}).

#### Assign a mentor or onboarding buddy

To help prevent [New Job Anxiety](https://www.classycareergirl.com/new-job-anxiety-conquer/) and aid onboarding and the adjustment to an [all-remote]({{< ref "_index.md" >}}) culture, new team members are assigned an onboarding buddy.

A mentor or onboarding buddy is a friendly point of contact for a new team member. This individual sets the example for building relationships and models how to communicate in a variety of ways, such as video calls, check-ins on Slack, and [coffee chats](informal-communication/#coffee-chats).

### Practice informal communication

Knowing that remote workers can experience [loneliness](https://about.gitlab.com/blog/2018/04/27/remote-future-how-remote-companies-stay-connected) or [burnout](mental-health/), it's important to prioritize relationship-building through regular social interactions. Remote workers can socialize using [informal communication](informal-communication/).

### Perform regular check-ins

Model good informal communication practices with new hires by scheduling regular check-ins throughout their first few months. These can be a blend of formal and informal meetings used to gauge how they are progressing in their onboarding and to ensure they are acclimating to the work, team, company, and culture.

## Global hiring best practices

GitLab hires globally because we [envision]({{< ref "remote-vision" >}}) a world where talented, driven individuals seek employment and find roles based on **business needs** rather than **geographic location**. In our 10+ years of global hiring, we have significantly developed our best practices. Here are a few things to keep in mind; please see the [hiring section of our handbook](/handbook/hiring) for more in-depth coverage.

### Where do you *not* hire?

GitLab is often asked about which countries we hire in, and why. The simplest answer is that we continually strive to have the widest possible global hiring coverage, limited only by logistics and legality.

Each country has unique and complex rules, laws and regulations, which can affect how we conduct business, as well as the employability of the citizens in those countries. For companies that are just beginning to work remotely and seek to expand globally, the process of setting up entities in compliance with each country's requirements is a lengthy one.

We are growing rapidly and continuously expanding our hiring capabilities in other geographies. In countries listed in our [entity_mapper.yml file](https://gitlab.com/gitlab-com/www-gitlab-com/-/blob/master/data/entity_mapper.yml) that don't have `contractor: true`, we have a payroll and can employ people directly. In all other listed countries, we can hire people as a contractor.

Learn more at our [Country Hiring Guidelines](/handbook/people-group/employment-solutions#country-hiring-guidelines) section in the [Employment Solutions (International Expansion & Relocations)](/handbook/people-group/employment-solutions) handbook page.

### Handling local regulations, risks, entities, etc

Rather than attempting to incorporate in every country where an all-remote company has even a single employee, organizations must weigh the benefits of creating a legal entity with other options. There are four means of engagement with GitLab. These are commonly used arrangements that can be considered by other all-remote companies.

- **GitLab Entity**: Individuals can be employed directly with GitLab Inc, BV, LTD, GmbH, PTY, Federal.
- **Professional Employer Organization (PEO)**: In select countries where GitLab does not have an entity, we hire professional employment organizations to serve as the [employer of record (EOR)](/handbook/people-group/contracts-probation-periods#employer-of-record-providers) in order to facilitate payments.
- **C2C (Contractor)**: A corp to corp arrangement, whereby a corporation or LLC invoices GitLab BV for GitLab related work.
- **IND (Contractor)**: By far the most widely applicable. The individual contractor arrangement can be used in countries where GitLab is hiring, yet does not have an entity or PEO agreement in place. This allows an individual to invoice GitLab BV as an individual or via their own company with no partners.

Learn more about [employee types and hiring partners](/handbook/people-group/contracts-probation-periods#employee-types-at-gitlab) across countries in the [Contracts, Probation Periods & PIAA]({{< ref "contracts-probation-periods" >}}) handbook page.

It is not always practical to understand the nuances of local regulations in-house. Wherever GitLab has an entity or contractor, we have external counsel to advise and ensure that we are compliant.

In countries where GitLab utilizes a professional employer organization (PEO), counsel within the PEO advises us to ensure hiring compliance.

### Deciding between entity and PEO

![GitLab journey illustration](/images/all-remote/gitlab-journey-and-navigation.jpg)
{style="max-width: 50%;"}

Generally speaking, it becomes feasible to consider creating an entity within a country once a company reaches 20+ team members in that country. While total costs vary significantly from country to country, creating an entity within a country can cost as little as a few hundred dollars to tens of thousands of dollars.

A company must also hire skilled team members to oversee compliance with local taxes, laws, benefits, etc. in each country where there is an entity.

For countries where a company is not already incorporated or has a local entity, consider the below as a guide.

1. **Fewer than 5 team members**: Utilize a contractor arrangement
1. **Between 5 and 20 team members**: Leverage a Professional Employer Organization (PEO)
1. **20+ team members**: Consider establishing a local entity

### Impact of nonuniform hiring on employee experience

Beyond the administrative challenges associated with using various vehicles (entities, PEOs, contractors, etc.) to hire team members, companies should be proactive in recognizing how this will impact culture and morale.

While GitLab believes that there are far [more pros than cons to hiring globally]({{< ref "inclusion#fully-distributed-and-completely-connected" >}}) — creating a geographically diverse team, finding the world's best talent, hiring in underserved areas and connecting with people from diverse socioeconomic backgrounds — it's wise to evaluate how nonuniform hiring mechanisms may conflict with a company's values.

When leveraging a third-party to hire, it is difficult to ensure that they will treat your employees how you would ideally like to see them treated. Third-party companies are under no obligation to understand or implement your [values](/handbook/values/).

It is imperative that the hiring team communicate this in advance, ideally during the interview phase, to manage expectations of employees who are hired by a third-party firm that may not always act in accordance to your values.

Moreover, one should aim to leverage a single Professional Employer Organization (PEO) over the long term. Switching PEOs is disruptive to team members and creates mental and administrative burden. A growing company should pay particular attention to feedback from employees who rely on PEOs, and plan beyond current hiring needs.

### Is there a single PEO that covers the globe?

This is a common question from remote-first and all-remote companies who are understandably interested in streamlining the process of hiring talented team members from an array of countries. The short answer, for now, is "no."

Some PEOs serve an array of regions, but offer varying levels of service and disparate experiences from country to country. Seek out advice where possible to gather country-level feedback.

Remote is a new company that [intends to tackle this challenge over time](https://remote.com/blog/solving-global-employment-through-remote).

> Remote is working on solving global employment by allowing companies to employ people *locally* through Remote. That is, full employment local to each and every employee, but a single invoice for the employer. Remote manages payroll, benefits, and compliance, according to the standards of the employer.

Be intentional about due diligence when vetting PEOs. Some firms advertise global reach, but do not offer high-touch, reliable end-to-end service in every country. Instead, they leverage third-parties themselves in various countries, creating yet another layer in the process that may negatively impact employee experience.

### Local Sourcers: what they are and why you need them

Even when the world is your talent pool, there will be niche roles requiring a specialized applicant search. To that end, GitLab built a Sourcing team tasked with finding the best talent and nurturing the candidate pipeline — a strategy any company can implement.

While GitLab is location-agnostic, we ensure that we have local Sourcers based in every macro-region (e.g., Americas, APAC, and EMEA) poised to share their market expertise and leverage our presence in these territories.

Our sourcing effort is extremely important for bringing [diverse](/handbook/company/culture/inclusion/) talent onboard. Our Sourcers regularly network with recruiters and business verticals so they can quickly tap into real-time knowledge of specific markets when a niche position comes available.

Driven by our [Collaboration value](/handbook/values/#collaboration), we organize [source-a-thons](/handbook/hiring/sourcing#source-a-thons), which become a place for everyone to share market insights and contribute to hiring. These sessions are extremely productive as they help Sourcers better partner with their hiring managers and calibrate expectations. You can learn more about how GitLab's Sourcing team operates [here](/handbook/hiring/sourcing).

## Contribute your lessons

GitLab believes that all-remote is the [future of work]({{< ref "remote-vision" >}}), and remote companies have a shared responsibility to show the way for other organizations who are embracing it. If you or your company has an experience that would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests) and adding a contribution to this page.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
