---
title: "Hybrid-Remote: understanding nuances and pitfalls"
description: "This complete guide to remote-hybrid work teaches you all you need to know in order to establish a successful strategy for you and your company! Learn more here!"
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

On this page, we're detailing the primary differences between all-remote and other forms of remote working.

## What does hybrid-remote mean?

{{< youtube "_HhlqwJsNyM" >}}

*In the [GitLab Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A) video above, Darren (GitLab) and Anna-Karin (Because Mondays) discuss a number of challenges and solutions related to remote work, transitioning a company to remote, working asynchronously, and defaulting to documentation.*

Hybrid-remote (which can be referred to as part-remote), is [different than all-remote](https://about.gitlab.com/blog/2018/10/18/the-case-for-all-remote-companies). In an all-remote company, there is no single headquarters, and each team member is free to live and work in any place they choose. Everyone, including executives, is remote, as there are no offices to come to.

Hybrid-remote is currently more common than all-remote, as it is easier for large, established companies to implement. In a hybrid-remote scenario, there is one or more offices where a subset of the company commutes to each day — working physically in the same space — paired with a subset of the company that works remotely.

These institutions are primarily colocated, but allow remote work. The day-to-day workplace experience for remote-by-default individuals is vastly different (and [typically inferior]({{< ref "all-remote-vs-hybrid-remote-comparison" >}})) in a hybrid organization vs. an all-remote organization.

{{< youtube "QFbrPR0jAYs?start=3" >}}

*In the [GitLab Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A) video above, GitLab co-founder and CEO Sid Sijbrandij chats with Maren Kate, founder at AVRA Talent Partners.*

In discussing the decision to go all-remote at GitLab, Sid shares the following.

> For us, it was really important that people didn't have to come to the office to get information necessary for career opportunities.
>
> From very early on, we started writing things down. During Y Combinator, they told us "Look, remote work is for engineering, but not finance, marketing, or sales."
>
> So, we got an office. People got hired, they came there, **but after a few days they stopped showing up**.
>
> [Coming to the office] wasn't needed. They weren't getting any extra information. They were on Slack, on Zoom, in Google Docs, in GitLab pages, in GitLab Issues, in GitLab merge requests — they didn't need to be there.
>
> **It's not that people like their commute; it's just that people don't want to miss out.** If you make sure that people don't miss out, you can be remote, too. It takes a lot of effort and focus to make sure all conversations are captured appropriately and that everything is documented. - *GitLab co-founder and CEO Sid Sijbrandij*

## Why do employees want hybrid-remote work?

Employees who want a blend of in-person and working may be attracted to the hybrid-remote working option for many reasons:

- They may want to have regular "face time" with leadership, if senior leaders are based in the office.
- They may prefer to have in-person whiteboarding or collaboration sessions with creative teammates.
- It may be a pleasant way to maintain variety in their weekly routine.
- Or, in an office-first company, hybrid-remote may be the closest option available to working [all-remote](stages/#9-all-remote).

[Read more about the ten models of remote and hybrid teams.](stages/)

## Variations of the hybrid model

Remote and hybrid work come in a variety of forms, which are continually evolving and growing in popularity.

- **The office-centric hybrid approach**

An office-centric hybrid organization looks like a team that is not changing how it works. Synchronous, undocumented meetings and disconnected whiteboards are still hallmarks of collaboration. People are expected in the office for a predetermined number of days per week, though the reasoning is flimsy at best (e.g. "We like seeing people around.").

This approach roughly aligns with GitLab's definitions of [remote time / remote exceptions](stages/).

Leadership supports this model by continuing to do what it has always done.

- **The flexible hybrid approach**

This variation is marked by some initiative to introduce new tools and technologies into the workforce which are designed for distributed collaboration and contribution. Real estate exists for those who wish to work in the office, but there is not necessarily a set amount of forced days-in-office.

This approach roughly aligns with GitLab's definitions of [remote time / remote allowed / remote days](stages/).

Leadership supports this model by creating policies and approving new tools and technology to allow testing new flexibilities.

- **The remote-friendly hybrid**

Remote-friendly is marked by a wider acceptance of global distribution of people. Tools are in place that make it easy to work remotely, and processes are remote-friendly by design. Offices exist but serve more as complementary to remote work as opposed to being the first place people go to work.
This approach roughly aligns with GitLab's definitions of [remote allowed / remote first](stages/).

For leadership to support remote-friendly operation, remote work is supported at all levels of the company, with leaders modeling this behavior by working remotely on certain days themselves.

Being remote-friendly implies that the company also allows people to work [asynchronously](asynchronous/) without forcing set working hours.

This workplace approach has also been called ["fully flexible"](https://www.lyft.com/blog/posts/lyft-announces-fully-flexible-workplace) by Lyft.

- **The virtual first approach**

Virtual first is the same as [remote first](stages/), with digital-first and distributed-first also synonymous. This is marked by a deliberate, org-wide approach to pressure test culture, values, and workflows to guarantee that every element serves first the distributed workforce and not the vestiges of office-first workflows.

In the virtual-first workplace, everyone from top to bottom (and especially leadership) should ideally be out of the office.

In virtual-first, the company defaults to [asynchronous work](asynchronous/).

## What is the difference between remote and hybrid working?

In an [all-remote](terminology/) workplace, remote is the default, not the exception. Everything from how meetings are handled to onboarding new hires is [structured through a remote lens](https://stackoverflow.blog/2017/02/08/means-remote-first-company).

Hybrid-remote generally requires more effort to execute well than all-colocated or all-remote given the [two-tier work environment](what-not-to-do/).

Some hybrid-remote arrangements may involve *regular* commutes to the office, though not *daily* commutes. For example, a remote employee in a hybrid-remote organization may travel to an office one week each month for regularly scheduled in-person interactions, while working from a location of their choosing the rest of the month.

## What to consider when going hybrid-remote

For some firms, shifting to [all-remote](terminology/) may be impractical or impossible. Hybrid-remote is a popular alternative, but one that should be embraced with great deliberation, care, and intentionality. Hybrid-remote generally requires more effort to execute well than all-colocated or all-remote given the [two-tier work environment](what-not-to-do/). Below are specific areas to consider and plan for to ensure the smoothest operation.

### Only some days in the office

Companies which mandate or encourage 1 or more days per week in-office should be mindful of three important factors.

1. This inhibits team members from considering drastically different living locales, as they still need to be within a commutable distance to an office.
1. This prevents a company's sourcing and talent acquisition teams from operating differently compared to all-colocated. New hires will still need to relocate to the general office area, limiting your talent pool.
1. This will make the process of shifting to remote-first workflows more difficult, as the office will serve as a crutch to collaboration.

### Informal meetings

Informal (or unscheduled and unplanned) meetings in an office can be highly disruptive to hybrid-remote teams. While it may feel efficient to ask someone you see in a hallway for a few minutes of their time, this typically creates disruption in the day of the person you're hailing and leads to undocumented progress. Said progress is invisible to those outside of the office *as well as* others in the office who are not invited to the meeting, which works against the remote-first practice of documenting all work so that others in the organization can contribute.

Leaders should reinforce a particular rigor on documenting takeaways following informal meetings so that context is agreed-upon, it is visible to others regardless of their location, and miscommunication and gossip is minimized.

### Redesigned spaces for individual hybrid-remote meeting rooms

Hybrid calls are [suboptimal for remote attendees](meetings/#avoid-hybrid-calls). Leaders transitioning to hybrid-remote should consider redesigning existing office space to optimize for individual workspaces and individual meeting rooms. This reinforces that the office is simply [another venue to work remotely from]({{< ref "how-to-work-remote-first#offices-are-simply-venues-to-work-remotely-from" >}}).

Eliminating conference rooms serves as a forcing function to ensure collaboration is accessible to all and removes the temptation to have in-office team members gather around a single camera for a video call with remote attendees.

Leaders may consider keeping one or two large spaces to be reserved for team onsites, where entire teams or sub-teams will intentionally travel on specific dates to meet in person (e.g. fiscal year planning, team bonding, etc.). It's important to still document outcomes from these gatherings and ensure that 100% of the team is included.

Zoom is creating in-office videocall solutions which detect individual faces in a shared room and [pull them into panes for remote colleagues](https://youtu.be/WRUXvUYSmcM). As hybrid-remote becomes increasingly popular post-COVID, we anticipate solutions like these will better equalize the field of collaboration.

### Agendas upfront

The most functional hybrid organizations operate [remote-first]({{< ref "how-to-work-remote-first" >}}). This ensures that business continues even if 100% of the workforce opts to work remotely, outside of the office, on any given day. A key part of reinforcing this mindset is a mandate that all work meetings have an upfront agenda.

Practically speaking, this means that all in-office meeting invites have a shared agenda document attached, so that others can read, learn, and contribute regardless of their location (or even if they're awake and available during the meeting time). This process ensures that a [Live Doc Meeting]({{< ref "live-doc-meetings" >}}) procedure happens even for onsite meetings.

This is critical for process continuity regardless of where a team member is. In a hybrid organization, you will have team members who conduct onsite meetings some days, and remote meetings on other days. It's vital that the *process* of those meetings are the same; it's merely the physical position of a team member that changes.

### Coffee chats should be indiscriminate of location

[Coffee chats](informal-communication/#coffee-chats) are an excellent way to broaden one's perspective and meet new people from across the organization. Hybrid organizations should take care to not enable selective coffee chat pairing based on who is onsite and who is remote, as it signals a two-tier work environment.

### Record important conversations

The proximity of people in an office makes hallway, watercooler, and ad hoc conversations appealing. Leaders in hybrid-remote settings should reinforce the importance of using one's smartphone as a recording device to capture important, non-confidential work-related conversations, so that takeaways are more transparently shared with those outside of the office and misinterpretations are minimized.

### Leadership's place in the office

The best place for leaders and executives to be in a hybrid-remote environment is *[outside](transition/#make-the-executive-team-remote)* of the office.

1. This prevents remote team members from a perceived lack of "face time" with executives.
1. This prevents senior leadership from conducting their work in ways which are counter to remote-first principles.
1. This prevents cognitive dissonance from leadership on what tools, technologies, and training need to be prioritized to support remote-first workflows.
1. This prevents team members from coming to the office to rub shoulders with executives.
1. This reinforces that the office is no longer the [epicenter](stages/#7-remote-first) of power or decision making.

### Ad hoc social events

It's understandable for team members to long for social gatherings in and around office settings. Structuring [informal communication](informal-communication/) is vital in a remote setting, and some companies may choose to repurpose some of their office space to accommodate groups and gatherings. Libraries, fitness centers, game rooms, and music studios (among others) could be created to facilitate social gatherings for those who are onsite on any given day.

Leaders who enable this should be mindful of the following.

1. It's important to budget for travel to include remote team members in onsite social events.
1. Work should not happen in social rooms, as it hinders [transparency](/handbook/values/#transparency) and creates [dysfunction](/handbook/values/#five-dysfunctions) through the formation of communication silos.

### Equitable benefits and perks

Leaders should carefully evaluate spoken and unspoken perks of the office, and seek to extend equal benefits to those outside of the office. For example, access to an onsite daycare and fitness center would demand a childcare and fitness credit for those who are remote by default. This becomes particularly tricky for team members who are onsite some days of the week, and offsite others, unless the credits are extended to all.

### Authenticity in the interview process

When growing your team in a hybrid-remote setting, be sure to present an authentic picture of your culture to all candidates. If you interview a candidate in your office when they'll primarily be working remotely, they're unlikely to get a full understanding of what the employee experience will be like once they're on board. This can lead to engagement and retention issues. During the [interview process](hiring/), focus on the aspects of your culture that are universal to all team members, no matter where their work gets done.

### Expect rapid iteration

Hybrid-remote organizations may see high office utilization in the earliest days of a transition, as people flock to the familiar. However, as remote-first workflows are implemented and people relocate or optimize their life for something greater than a commutable distance to an office, it's possible that more space will go unused.

While this may seem jarring, it's a positive indicator that work and culture are progressing without the need of an office. This will create opportunities to capture greater real estate savings and/or repurpose office space for philanthropic efforts, such as opening up an internship center for the local community.

## Blueprints from companies openly sharing their transition to hybrid-remote

We believe it's useful for transitioning companies to see *how* others are embracing and making the shift to hybrid-remote structures. Below are examples of companies who are publicly and transparently sharing their journey, best practices, and lessons learned to guide others.

1. Dropbox - *[Virtual First Toolkit](https://experience.dropbox.com/virtual-first-toolkit)*
1. Slack - *[A new guide for adapting to a radically different workplace](https://slack.com/blog/transformation/navigating-the-disruption-of-work)*
1. Hubspot - *[How we're building a hybrid company](https://www.hubspot.com/careers-blog/future-of-work-hybrid)*
1. Coinbase - *[Building a remote-first company: our biggest lessons so far](https://www.coinbase.com/en-ca/blog/building-a-remote-first-company-our-biggest-lessons-so-far)*
1. Herman Miller - *[The Future of Work: Looking Forward](https://www.hermanmiller.com/solutions/future-of-work/)*

## Companies embracing hybrid-remote

COVID-19 created a wave of companies intentionally shifting to remote-first. For some organizations, unwinding all of their office space and [becoming an all-remote organization](transition/) is not practical. Many are announcing their plan to embrace some variation of hybrid-remote. This is not an exhaustive list, so we welcome additions and contributions.

1. HubSpot — *[The Future of Work at HubSpot: How We're Building a Hybrid Company](https://www.hubspot.com/careers-blog/future-of-work-hybrid)*
1. Dropbox — *[Dropbox goes Virtual First](https://blog.dropbox.com/topics/company/dropbox-goes-virtual-first)*
1. Robinhood — *[Robinhood is a Remote First Company](https://newsroom.aboutrobinhood.com/robinhood-is-a-remote-first-company/)*
1. Reddit — *[Evolving Reddit's Workforce](https://redditinc.com/blog/evolving-reddits-workforce)*
1. Figma — *[How work is changing at Figma](https://www.figma.com/blog/how-work-is-changing-at-figma)*
1. Coinbase — *[Post COVID-19, Coinbase will be a remote-first company](https://www.coinbase.com/en-ca/blog/post-covid-19-coinbase-will-be-a-remote-first-company)*
1. Shopify — *[Digital by default](https://www.shopify.com/careers/work-anywhere)*
1. Twitter — *[Where We Work](https://careers.twitter.com/en/locations.html)*
1. Slack — *[A new guide for adapting to a radically different workplace](https://slack.com/blog/transformation/navigating-the-disruption-of-work)*
1. Sike Insights — *[EQ & Remote Managers Report](https://bit.ly/3iX519B)*
1. Spotify — *[Distributed-First Is the Future of Work at Spotify](https://newsroom.spotify.com/2021-02-12/distributed-first-is-the-future-of-work-at-spotify)*
1. Grammarly — *[The Future of Work at Grammarly](https://en.ain.ua/2021/06/15/grammarly-permanently-switches-to-hybrid-remote-work-format/)*
1. Mailchimp — *[The Future of Work at Mailchimp](https://web.archive.org/web/20230207083313/https://mailchimp.com/future-of-work-at-mailchimp/)*
1. Adobe - *[The Future of Work at Adobe](https://blog.adobe.com/en/publish/2021/06/24/future-of-work-adobe)*
1. Asana - *[Reuniting and Thriving in a Distributed World With Asana](https://blog.asana.com/2021/04/reuniting-teams)*
1. LinkedIn - *[A Sneak Peek at LinkedIn's New Hybrid Workplace Plans](https://www.linkedin.com/business/talent/blog/talent-engagement/sneak-peek-at-linkedins-new-hybrid-workplace-plans)*
1. DoorDash - *[DoorDash's Hybrid Work Plan: Committing to Flexibility](https://doordash.news/company/doordashs-hybrid-work-plan-committing-to-flexibility)*
1. Uber - *[Our Return to the Office](https://www.uber.com/en-US/blog/our-return-to-the-office/)*
1. Cisco - *[Cisco Powers Hybrid Work](https://newsroom.cisco.com/feature-content?type=webcontent&articleId=2179907)*
1. Intel - *[Creating a "Hybrid-First" Company](https://www.intel.com/content/www/us/en/newsroom/opinion/creating-hybrid-first-company.html#gs.t85vm4)*
1. Lyft - *[We're Going Fully Flexible](https://www.lyft.com/blog/posts/lyft-announces-fully-flexible-workplace)*
1. Google - *[A Hybrid Approach to Work](https://blog.google/inside-google/life-at-google/hybrid-approach-work)*
1. Amazon - *[Amazon Updates Return-to-Office Guidance](https://www.aboutamazon.com/news/workplace/amazon-updates-return-to-office-guidance)*
1. Canva - *[Canva's Future of Work: Flexibility and Connection](https://medium.com/canva/canvas-future-of-work-flexibility-and-connection-b410d1793d83)*
1. Microsoft - *[The Philosophy and Practice of our Hybrid Workplace](https://blogs.microsoft.com/blog/2021/03/22/the-philosophy-and-practice-of-our-hybrid-workplace//)*
1. Unilever - *[Our Future Workplace](https://www.unilever.com/planet-and-society/future-of-work/future-workplace)*
1. Zoom - *[How Zoom is Approaching our Next Phase of Work](https://www.zoom.com/en/blog/how-zoom-is-approaching-our-next-phase-of-work/?cms_guid=false&lang=en-US)*
1. Deloitte - *[Transforming when, where, and how we work](https://www2.deloitte.com/us/en/pages/careers/articles/join-deloitte-hybrid-workplace.html)*

## Do hybrid-remote employees have a commute?

![GitLab transport illustration](/images/all-remote/gitlab-transport.jpg)
{style="max-width: 50%"}

Some hybrid-remote arrangements do involve *regular* commutes to the office, though not *daily* commutes. For example, a remote employee in a hybrid-remote organization may travel to an office one week each month for regularly scheduled in-person interactions, while working from a location of their choosing the rest of the month.

While this scenario may still be preferred over one where remote employees are *not* invited to visit in-person offices, it isn't quite as flexible as all-remote. There's still a commute involved, which can take the majority of a day in both directions for commutes involving flights.

## Are there advantages to hybrid-remote?

### Better work-life balance

Hybrid-remote employees can plan for more flexibility in their [daily life](people/#those-who-value-flexibility-and-autonomy) (for [kids](https://about.gitlab.com/blog/2019/07/25/balancing-career-and-baby), parents, friends, groceries, sports, deliveries).

### Optimize when and where you work

A hybrid-remote schedule is often asynchronous, allowing an individual to [choose their working hours](people/#worklife-harmony) based on when they are [most productive](asynchronous/).

They can also [set up and decorate an office or workspace](https://community.thriveglobal.com/how-remote-work-can-reduce-stress-and-revitalize-your-mindset/) in whatever way [works best for them](https://about.gitlab.com/blog/2019/08/01/working-remotely-with-children-at-home).

And of course, a hybrid schedule allows more flexibility for [traveling while working]({{< ref "working-while-traveling" >}}).

### Reduce exposure to illness

Especially after the global pandemic, people are concerned about decreasing their exposure to germs from coworkers. Hybrid-remote allows employees to choose whether to work onsite or remotely, and empowers them to choose their exposure boundaries and limits.

### Save on real estate expenses

Some hybrid-remote options allow employees to choose where they live. At any given time, they are free to [relocate](/handbook/people-group/relocation), be [location independent](https://about.gitlab.com/blog/2019/06/25/how-remote-work-at-gitlab-enables-location-independence), or even [travel with other remote professionals](resources/#organizations-for-traveling-remote-work).

### Hire talent across the globe

Not only does hybrid remote allow organizations to hire the best talent on the planet, it also gives your employees the opportunity to network as they [meet and work with people from many locations around the world](/handbook/total-rewards/incentives/#visiting-grant), widening one's view of the world and creating opportunities to learn about new cultures.

## Disadvantages to hybrid-remote

All things being equal, employees longing for additional freedom, autonomy, and workplace flexibility will likely view a hybrid-remote arrangement as superior to a colocated arrangement — one which *requires* a commute and an in-person presence on a daily basis.

Said another way, "some remote" is often viewed as superior to "no remote." Though far from ideal, it can be rationalized that fewer career opportunities, added judgement, and difficulties in bonding are prices worth paying to live and work where one wants.

There are considerations when accepting a role in a hybrid-remote company, and it's important to be mindful of these potential downsides.

1. **Hybrid-remote employees may have less access to information**. Unless you work for an employer that [documents everything](/handbook/values/#write-things-down), you may be asked to handle your day-to-day duties with less information — and incomplete information — compared to in-person colleagues. Over time, this can lead to more mistakes, confusion, frustration, and even [underperformance]({{< ref "underperformance" >}}).
1. **Fewer career and development opportunities**. Hybrid-remote employees who are out of sight may be [passed over](https://hbr.org/2017/11/a-study-of-1100-employees-found-that-remote-workers-feel-shunned-and-left-out) for promotions, advancement, and development [opportunities](https://news.ycombinator.com/item?id=15994294). They may also have fewer opportunities to more horizontally within the organization, and less influence to create a new role to serve evolving business needs.
1. **The feeling of being a satellite office**. Hybrid-remote employees must put effort towards not being treated as less-than within the organization. It is important to surface relevant inquiries during the interview process as to how remote colleagues are [onboarded](learning-and-development/), included, and perceived by others. Some employees may not be fazed by this treatment, but it can take a mental and emotional toll on others.
1. **Managing guilt**. It is not uncommon to hear remote workers [express guilt](https://www.glassdoor.com/blog/work-from-home-guilt) if they work in a company which is primarily colocated. Their socializing involves colleagues who may complain about commutes, or express sadness due to an inability to attend a certain family function. There are inherit inequalities in this arrangement, requiring the remote employee to empathize with in-person colleagues despite not being required to endure the same commutes and inflexibility.
1. **The burden of lobbying for remote**. If an employee is brought on in a remote capacity, but this arrangement is not supported equally across teams and managers, a situation may arise where the remote employee is constantly justifying the perceived privilege of not being forced to commute into a physical office.
1. **Determining whether remote is truly offered and supported**. Many large companies will tolerate remote employees, but they will not openly advertise roles as remote, nor will they publicly admit that they support remote work. This creates an exhausting game of hide-and-seek when searching for roles, in addition to searching for remote-friendly managers and teams *within* such an organization.
1. **Risk of being made an example of**. It is possible for remote employees in a primarily colocated company to be asked questions like "So, how did you finagle a remote arrangement?" This places remote employees in a difficult situation. Either they choose to champion the cause of empowering even more colleagues to work remotely, potentially harming their reputation in the process, or they appear unhelpful by keeping the perceived perk to themselves.
1. **Demands for overperformance**. When you're a remote employee working with colleagues who endure long commutes each day, you may encounter pressure — however subtle — to deliver results beyond those expected of in-person team members. This stems from a toxic culture of envy, where colocated employees deduce that if they must endure inflexibility and commutes, remote colleagues must produce additional results as to not get off easier.
1. **A culture built around the in-office experience**. Companies that rely heavily on physical perks and in-office experiences to define their culture have a difficult time translating those experiences to their remote employees in a hybrid-remote setting. You'll often see these perks highlighted for talent acquisition and retention purposes. In practice, remote employees will inherently miss out on the full employee experience unless the culture is more [intentionally and sustainably built](building-culture/).
1. **Physiological stress linked to open-plan offices**. Some hybrid-remote firms may require team members to work in open-plan office environments. [Research published in 2021 by Cambridge University](https://theconversation.com/open-plan-office-noise-increases-stress-and-worsens-mood-weve-measured-the-effects-162843) shows a "significant causal relationship between open-plan office noise and physiological stress." Working *anywhere* — home, office, etc. — can trigger stress if conditions are suboptimal, though all-remote generally provides greater flexibility to shift your [workspace](workspace/) from home, co-working venues, offices, and nature to optimize for [greater calm](https://youtu.be/bQMoF7oSh2o).

## Overcoming the hybrid-remote model's problems

Clear communication is one of the best ways to overcome hybrid-remote challenges.[GitLab's handbook](/handbook) captures everything an employee needs to know promoting autonomy and [efficiency](/handbook/values/#efficiency) for communication, processes, and procedures.

Each department and team should set, share, and track both monthly and quarterly goals, or ["objectives and key results" (OKRs)](/handbook/company/okrs). GitLab's OKRs are also clearly documented in our handbook for visibility across the company.

Our unique approach to [documentation](/handbook/product/ux/technical-writing/documentation/) also helps with [onboarding new team members](learning-and-development/) by putting everything they need to know in one place.

Finally, we recommend developing an extensive [onboarding template](https://gitlab.com/gitlab-com/people-group/employment-templates/-/blob/main/.gitlab/issue_templates/onboarding.md). Hosting a panel, like our [GitLab 101](/handbook/company/culture/gitlab-101), allows new hires to ask questions.

## What does a hybrid-remote work schedule look like?

A lot goes into building an effective hybrid-remote schedule:

- Are there days your team has set meetings?
- When and where are you personally most productive?
- Will your work get done better/faster working face-to-face?

Some people choose set days or times to be in-office or be remote, just be sure to communicate your choices clearly to your team so they know when and where they can find you if needed.

### Work how and when you are most productive

Some people work better with a [consistent workday routine](https://learn.g2.com/how-to-work-from-home), while others find it best to ride their [waves of peak productivity](https://www.jonobacon.com/2019/01/14/remote-working-survival). Either way, design your work day and routine around your strengths understanding that different seasons, holidays, and family schedules may change this routine.

> **"I think you need to throw the concept of 'nine to five' out the window and actively experiment to find what schedule lets you make the most of your time.
I often find the midday slump to be so real, so if I'm feeling this way I step away for a while and then come back for a few hours in the evening when I generally feel supercharged."**
[- Tanya Pazitny, Quality Engineering Manager](/handbook/company/team#tpazitny)

## All-Remote Upgrade

![GitLab values illustration](/images/all-remote/gitlab-values-tanukis.jpg)
{style="max-width: 50%"}

The [movement](stages/) from hybrid-remote to all-remote is defined at GitLab as an `All-Remote Upgrade`. For reference, in January 2020, 17% of new hires attending the [CEO 101 call](/handbook/company/culture/gitlab-101) moved from a hybrid-remote model to all-remote at GitLab.

This highlights another reality: [not all remote models are equal](https://about.gitlab.com/blog/2019/09/04/not-all-remote-is-created-equal), nor do they create [equality](https://about.gitlab.com/blog/2019/12/06/how-all-remote-supports-inclusion-and-bolsters-communities). All-remote is the [purest](https://about.gitlab.com/blog/2018/10/18/the-case-for-all-remote-companies) form of remote work, where every individual is treated as a [first-class team member](people/).

Through GitLab's [All-Remote Stories](stories/) and the [Remote Work GitLab Unfiltered playlist](https://www.youtube.com/playlist?list=PL05JrBw4t0Kq7QUX-Ux5fOunQotqJbECc), you can learn more from GitLab team members on what all-remote has meant to them and how it has shaped their lives and communities.

## Differences between all-remote and remote-first

In a remote-first organization, the *default* is remote. While there may be a company headquarters, or even an array of satellite offices, everything from how meetings are handled to onboarding new hires is [structured through a remote lens](https://stackoverflow.blog/2017/02/08/means-remote-first-company).

Said another way, there is a culture of assuming that remote is the norm, not the exception, and processes are established to reinforce that.

If you're considering working for a remote-first company, consider asking the following.

1. Do you have a headquarters?
1. Does the executive team work remotely, or do they all congregate in the same physical space day-to-day?
1. Where and how are all-hands calls handled?
1. Are interviews and onboarding handled on-premise or via video call?
1. Do team members have [hybrid calls](/handbook/communication/#hybrid-calls-are-horrible), or does each person have their own equipment?
1. What procedures are in place to ensure that remote employees are granted [learning and development](learning-and-development/) and promotion opportunities?

It is possible to find remote-first companies with a healthy, understanding culture that works to support both colocated and remote colleagues. Prospective employees should do their own due diligence to make sure the requisite values are established and lived out.

## GitLab Knowledge Assessment: Understanding a Hybrid-Remote Environment

Anyone can test their knowledge on Understanding a Hybrid-Remote Environment by completing the [knowledge assessment](https://docs.google.com/forms/d/e/1FAIpQLSc-aKsS7Yu1-wwlpHsfEtHt8CkKK5n5UhnnU6ixTlM00Dz9cw/viewform). Earn at least an 80% or higher on the assessment to receive a passing score. Once the quiz has been passed, you will receive an email acknowledging the completion from GitLab. We are in the process of designing a GitLab Remote Certification and completion of the assessment will be one requirement in obtaining the [certification](https://about.gitlab.com/learn/certifications/public). If you have questions, please reach out to our [Learning & Development](/handbook/people-group/learning-and-development) team at `learning@gitlab.com`.

{{% include "includes/is_this_advice_any_good_remote.md" %}}

## Contribute your lessons

GitLab believes that all-remote is the [future of work]({{< ref "remote-vision" >}}), and remote companies have a shared responsibility to show the way for other organizations who are embracing it. If you or your company has an experience that would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests) and adding a contribution to this page.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
