---
title: "Considerations for in-person interactions in a remote company"
description: Why in-person interaction matters in a remote company
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

![GitLab all-remote transport](/images/all-remote/gitlab-transport.jpg)
{style="max-width: 50%;"}

Humans are social creatures, and [research](https://papers.ssrn.com/sol3/papers.cfm?abstract_id=2443551) has shown that there is value in in-person interactions. While there are tremendous [advantages]({{< ref "remote-benefits" >}}) to operating a 100% remote company, leaders should consider being intentional about [planning in-person elements](https://www.fastcompany.com/3051518/the-science-of-when-you-need-in-person-communication), even if they're optional for team members.

## Bridging the gap during the pandemic

While the Covid-19 pandemic has impacted many teams' ability to gather in person, the guidance on this page can be used as a blueprint for your organization's future in-person interactions.

Small teams located in the same city or region may be able to still gather in person, but for an all-remote company where team members are distributed across many time zones, you'll need to lean on platforms like [Zoom](https://zoom.us), [Hopin](https://hopin.com), or [Virbela](https://www.virbela.com) to gather virtually in the meantime. It's important to maintain the purpose of these gatherings, and to be intentional and creative about continuing to bring the team together.

For example, at GitLab, we hosted our 2020 [Contribute](/handbook/company/culture/summit/) virtually. We used this time to take a break from our daily projects, celebrate the achievements of the team, and get to know one another better. By focusing this time on bonding rather than active work, we were able to boost engagement and invest in strengthening the relationships across the organization.

Between these larger gatherings, informal communication is another important element to maintain. We've curated a list of ways to approach this in our [informal communication guide](informal-communication/).

## Benefits of remote meetings

### Attendance is optional

GitLab has a meeting policy we like to call "[No agenda, no attenda](/handbook/communication/#external-communication)." Every work-related meeting has purpose, which is outlined a live doc agenda affixed to the calendar invite: here's a [templated example](https://docs.google.com/document/d/1WQe-0oiMCzB3MPBNdKluCEIfgTRpaIi-SJ8FmUJ2xHo/edit?usp=sharing) you can copy and use in your organization. As an all-remote company, we [do not look to a meeting by default](asynchronous/#question-every-meeting); when they are necessary, we strive to make in-person attendance optional by enabling asynchronous contribution.

### Meetings are recorded

Remote meetings can be recorded, especially when key individuals aren't able to join live. This allows team members to catch up on what transpired, adding context to notes that were taken during the meeting. Learn more about recording in Zoom in the [Tips and Tricks section of GitLab's Handbook]({{< ref "tools-and-tips#recording-in-zoom" >}}).

### Inclusive

Remote meetings that are accessible asynchronously encourage increased attendance because they remove time zone bias. Employees can view the meeting invite, agenda, and recording, and can contribute asynchronously as they are able.

## Benefits of in-person meetings

If a live meeting is recorded and made available to others, many of the same benefits of remote meetings apply to in-person meetings as well. However, it's hard for technology to capture the non-verbals and cameraderie that inevitably happens in an in-person meeting, which sometimes falls flat online.

### Synchronicity

Just as asynchronous participation is a benefit of remote meetings, there is a certain collaborative magic that can happen during an in-person meeting or retreat that is more difficult (though not impossible) to reproduce virtually. Often, the greatest value of being in a shared space is the ability to spin off ideas and smaller conversations and keep them going as new ideas arise.

### Networking

On a virtual call, you're limited to viewing a certain number of faces at a time. In person, you potentially have an opportunity to connect with everyone in the room.

## How to prepare for an in-person meeting

In-person meeting prep is similar to getting ready for a [video call](/handbook/communication/#video-calls). In these situations, you should plan to:

1. Start and end on time
1. Build in social interactions and plan to get to know the people in your group
1. Have the meeting space prepared to support visual thinking and collaboration
1. Plan to document the complex discussions that will happen as often an in-person meeting is required because of its need for immediate back and forth conversation
1. Take notes to help retain and recall any important details
1. Document by writing down notes and next steps into the proper directory (Google Drive, Salesforce, etc.)

## The importance of social interaction

We believe that [in-person interactions](in-person/) are extremely important, especially in an all-remote [culture]({{< ref "culture#culture-at-gitlab" >}}). Remote workers have increased risk of experiencing [loneliness](https://about.gitlab.com/blog/2018/04/27/remote-future-how-remote-companies-stay-connected) or [burnout](mental-health/).

One way to prevent loneliness and burnout are through relationship-building by prioritizing regular social interactions via informal communication throughout the workday, week, and month.

Informal communication enables friendships to form at work related to matters *other* than work. Those who feel they have genuine friends at work are [more likely to enjoy their job](https://onlinelibrary.wiley.com/doi/full/10.1111/peps.12109), perform at a high level, feel invested in the company, and serve others within the organization.

Here, we value informal communication as a complement to [in-person interactions](in-person/) and regularly offer [more than 20 different ways for team members to participate in social interactions](informal-communication/)!

## Meetups

{{< youtube "hi2D0Se_VnA" >}}

*GitLab Commit Brooklyn 2019 recap reel.*

Organizing customer and/or community [meetups](https://about.gitlab.com/community/meetups) around the globe is a great way to ensure team members meet each other in person, while also providing business and branding benefits. Meetups serve as incubators for [what could come next](https://about.gitlab.com/blog/2016/11/23/how-to-build-a-strong-dev-community), and provide a safe space for feedback to flow. Not only do they allow customers to put a face to a company they are engaging with, but it creates opportunity for team members to travel and meet each other while supporting a company initiative.

In an all-remote setting, meetups have psychological benefits as well. While colocated companies may struggle to garner deep support from team members who must plan, execute, and attend a meetup, all-remote team members tend to view meetups as special opportunities to do something they aren't able to do on a daily basis: interact with colleagues in the same physical space.

Perception plays a major role in quality of execution. In colocated settings, team members are required to commute and spend much of their waking hours with colleagues in a shared space. This could make the notion of spending added time, likely outside of their normal working hours, seem more like a burden and less like a bonding opportunity.

Conversely, team members in an all-remote setting have precious few opportunities to see one another face-to-face. In turn, may be easier to rally support for meetups given the underlying perk of in-person bonding and networking.

Learn more about how GitLab organizes community events in the [GitLab Meetup Guide](https://about.gitlab.com/community/meetups).

## Conferences

{{% cardpane %}}
{{% card footer="GitLab CEO Sid Sijbrandij and General Catalyst Managing Director Kyle Doherty kick off Making Remote Work. Photo by Slava Blazer Photography" %}}
![GitLab CEO Sid Sijbrandij and General Catalyst Managing Director Kyle Doherty kick off Making Remote Work. Photo by Slava Blazer Photography](/images/all-remote/making-remote-work-gitlab-gc-2019.jpg)
{{% /card %}}
{{% /cardpane %}}

It is common for colocated companies to send a lean contingent to [work-related conferences](events/), which is rational given the relative high costs involved. In colocated settings, work conferences add marginal bonding benefit given that attendees already spend a significant amount of time together in a shared physical office.

In remote-first and all-remote settings, the value proposition is drastically different. Conferences serve as an opportunity to send a team of colleagues to not only execute on business objectives, but also to spend time bonding with one another as humans.

{{% cardpane %}}
{{% card footer="Colleagues together at GitLab Commit London 2019" %}}
![Colleagues together at GitLab Commit London 2019](/images/all-remote/gitlab-commit-london-2019-colleagues.jpg)
{{% /card %}}
{{% /cardpane %}}

Consider supporting team members who wish to arrive early or stay late in order to spend time getting to know colleagues on a face-to-face basis, but be mindful not to judge or penalize those who opt out. Family commitments and personal preference should be honored. Choosing not to arrive early or stay late at a conference for bonding should not be viewed as indifference towards the company.

As an example, [GitLab Commit](https://about.gitlab.com/events/commit) — a series of user conferences — doubles as an excellent mechanism to bring colleagues together for a purpose, while also serving the greater community.

## Annual (or regular) summits

{{< youtube "xdtPNXtkBhE" >}}

*GitLab Contribute 2019 recap reel.*

While [virtual events](events/) and ongoing touch points through [informal communication](informal-communication/) mechanisms are vital for a team's growth, all-remote companies should consider a regularly scheduled gathering or summit for the entire company.

These gatherings should be optional, though encouraged, and should focus primarily on bonding. Hosting a summit only to inundate colleagues with presentations is not recommended. At [GitLab Contribute](/handbook/company/culture/summit/), for example, numerous excursions are planned throughout the week in order to bring people together in the same physical space for non-work activities.

With no central office, these are remarkably flexible. Your company may choose a different location for each occurrence, or perhaps support a voting system where colleagues can offer up suggestions for ideal locations.

In all-remote settings, these known touch points are critical for morale. Team members can plan their year around these seminal moments, with a period of in-person experiences giving them fresh perspective when engaging in the future through [Zoom](https://about.gitlab.com/blog/2019/08/05/tips-for-mastering-video-calls) or phone.

## Holidays, celebrations, and local coworking days

{{% cardpane %}}
{{% card footer="Celebrations at GitLab Commit London 2019" %}}
![Celebrations at GitLab Commit London 2019](/images/all-remote/gitlab-commit-london-2019-celebration.jpg)
{{% /card %}}
{{% /cardpane %}}

As an all-remote team [scales](scaling/), you may find that certain regions of the world are home to multiple team members. At GitLab, we encourage colleagues to join [Location Channels](/handbook/communication/chat#location-channels-loc_) in Slack, which allow them to easily connect with others who live relatively nearby.

This creates an easy path for gathering in a central location to bond. Common reasons for scheduling a get-together are holidays and milestone celebrations, though active local communities may consider coming together on a regular basis (monthly, quarterly, etc.) simply to maintain a physical connection.

Being a 100% remote company creates unique opportunities for these gatherings. A team may consider rotating who picks the venue or locale to meet at, creating a diverse calendar of events. Those who are comfortable doing so may even consider inviting local team members to their home or neighborhood.

GitLab recognizes that not everyone can or will prefer to work from their home. In turn, fees associated with co-working spaces are [reimbursable](/handbook/finance/expenses#coworking-or-external-office--space). Through location channels, team members who live close to one another can easily arrange dedicated co-working days and shared events, covering everything from dining together to supporting a local charity as a unit.

## Subsidized travel to visit team members

{{< youtube "KXHwEGlql-Y" >}}

*In the [GitLab Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A) video above, Darren (GitLab) and Elisa ([The Cowork Experience](https://thecoworkexperience.com)) discuss the merits of a company subsidizing and encouraging travel to visit other colleagues.*

Savings on real estate — and the litany of associated costs with operating one or more offices — is a key financial reason for a company to organize itself as completely remote. Consider returning some of those savings to employees by [subsidizing travel costs](https://about.gitlab.com/blog/2017/06/30/there-and-back-again-in-one-release) associated with [visiting colleagues around the globe](https://about.gitlab.com/blog/2017/01/31/around-the-world-in-6-releases).

GitLab's [Visiting Grant incentive]({{< ref "incentives#visiting-grant" >}}) is one such example. While some colleagues may prefer to stay put, there is value in transparently encouraging colleagues to [spend time](https://about.gitlab.com/blog/2019/09/12/not-everyone-has-a-home-office) with one another in a physical space. When a colleague travels to visit someone else, they are [immersed](people/#travelers) in a new place and new culture, which leads to greater empathy and understanding.

This also reinforces a company's ability to create a more [geographically diverse and inclusive work environment](/handbook/company/culture/inclusion/).

## Coworking excursions and retreats

{{< youtube "aJobgAOCW84" >}}

*The Cowork Experience assists remote companies with planning excursions that bring colleagues together in the same physical space.*

As an all-remote company [scales](scaling/), it becomes more challenging to get the entire company in one place during the same window of time. As the once-a-year company annual becomes a standard offering (and less a differentiator) for remote companies, there is opportunity to host smaller, more frequent excursions and retreats.

[The Cowork Experience](https://thecoworkexperience.com), for instance, develops bespoke programs with more intimate engagements at the team or regional level to foster deeper trust amongst colleagues. These usually include team-building activities as well as non-work excursions. They present an opportunity to bring colleagues together in a unique, refreshing locale, catalyzing things like planning while enabling personal bonds to be built.

Leadership should be mindful of personal strain placed on team members when they are asked to leave their home for extended periods of time, with covered childcare or similar assistance ensuring that undue burdens are not placed on caregivers.

## GitLab Knowledge Assessment: Considerations for in-person interactions in a remote company

Anyone can test their knowledge on considerations for in-person interactions in a remote company by completing the [knowledge assessment](https://docs.google.com/forms/d/e/1FAIpQLSdJF6Gdal_o6g4a3qAwwas9glPMOQAiPDvPNbz3GQI5E5cvaw/viewform). Earn at least an 80% or higher on the assessment to receive a passing score. Once the quiz has been passed, you will receive an email acknowledging the completion from GitLab. We are in the process of designing a GitLab Remote Certification and completion of the assessment will be one requirement in obtaining the [certification](https://about.gitlab.com/learn/certifications/public). If you have questions, please reach out to our [Learning & Development team](/handbook/people-group/learning-and-development) at `learning@gitlab.com`.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
