---
title: "Informal Communication in an all-remote environment"
description: How to foster informal communication in a remote company
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

On this page, we're detailing how informal communication occurs at GitLab, how it complements [in-person interactions](in-person/), and why it matters in an all-remote [culture]({{< ref "culture#culture-at-gitlab" >}}). There are over 20 different ways to foster informal communication below, and we are constantly discovering and adding new methods.

## What do we mean by **informal communication**?

Informal communication in the workplace is made up of interactions between co-workers that are unofficial in nature and focus on building social relationships outside of the normal hierarchy of a typical business structure.

In other words, it's what happens when we get to know each other and talk about anything *other* than work.

Talking about the weather; sharing photos of pets, favorite foods or holidays; sending a birthday greeting or encouraging message; banter, chit-chat, and having a laugh - it's all part of [bringing our full selves to work](/handbook/company/culture/inclusion/).

## What is the difference between formal and informal communication in the workplace?

Since GitLab is an all-remote organization that [works asynchronously](asynchronous/), nearly all work communication is [documented](/handbook/product/ux/technical-writing/documentation/), making all work-related communications "formal" communications. This helps support our value of [transparency](/handbook/values/#transparency).

We are big on relationship-buiding. We highly value intentionally creating time to build relationships via informal communications.

## Why is informal communication so important in a remote work setting?

Informal communication builds an [informal substructure of trust]({{< ref "building-trust" >}}). This trust helps people accept decisions. That acceptance makes successful execution of decision more likely.

All-remote workers who are all-work all the time risk [loneliness](https://about.gitlab.com/blog/2018/04/27/remote-future-how-remote-companies-stay-connected) or [burnout](mental-health/). One of the best ways to combat loneliness and burnout are through relationship-building by prioritizing regular social interactions via informal communication throughout the workday, week, and month.

## Informal communication advantages and disadvantages

While some people thrive on spending time to get to know others, others are annoyed by non-work-related texts and messages. Informal communication among diverse team members requires a high level of [empathy]({{< ref "being-a-great-remote-manager#empathy" >}}).

It's helpful to be transparent about your communication preferences so managers and teammates can know and respect your boundaries.

## Formally design informal communications

<!-- TODO: Replace with screenshots. -->

> Sid Sijbrandij on [Twitter/X](https://twitter.com/sytses/status/1270721630537277442)
>
> When working remote it is important to formalize informal communication. Explicitly plan time to create, build, and maintain social connections and trust. In our handbook we list 15 methods https://about.gitlab.com/company/culture/all-remote/informal-communication/ which I'll summarize in this thread.

### Organize informal communication

Informal team member communications, such as a chat about life outside of work, are necessary for building trust. Trust is essential for great business results and is a [foundational element of culture]({{< ref "culture#culture-at-gitlab" >}}). Many businesses invest heavily in offices and facilities, because they believe offices are necessary for informal communication.

> During the pandemic, many businesses that were forced to work remotely discovered that productivity [increased](https://bfi.uchicago.edu/working-paper/why-working-from-home-will-stick). Many of these same businesses are now making plans to return to the office. One reason given is that not everyone can work from home. GitLab solves this by allowing people to [rent and expense work space](/handbook/finance/expenses#-coworking-or-external-office--space). Another reason given is that people miss working from a central office with co-workers. I don't think that people miss the commute or the office furniture. They miss informal communication. Central offices are an expensive, inconvenient, and indirect way to facilitate informal communication. It is more efficient to directly organize informal communication.
>
> For example, every person who joins GitLab has to schedule at least 5 coffee chats during their onboarding. We also have Ask Me Anything meetings with senior leaders, Group calls organized by different groups/departments, and over 15 other explicit ways to encourage employee connections and relationship building. Intentionally organizing informal communication enables the trust-building conversations that are essential for collaboration. This can be more effective than relying on chance encounters in a physical office. You can connect with team members throughout the world and across departments through a coffee chat. You may not meet people outside of your own floor in an office setting. - *GitLab co-founder and CEO Sid Sijbrandij*

{{% cardpane %}}
{{% card footer="Group social calls are a great way for remote teams to connect and bond" %}}
![Group social calls are a great way for remote teams to connect and bond](/images/all-remote/gitlab-marketing-team-hotdog-meeting.jpg)
{{% /card %}}
{{% /cardpane %}}

### Valuing conversation on non-work topics

Informal communication is important, as it enables friendships to form at work related to matters *other* than work. Those who feel they have genuine friends at work are [more likely to enjoy their job](https://onlinelibrary.wiley.com/doi/full/10.1111/peps.12109), perform at a high level, feel invested in the company, and serve others within the organization. At GitLab, we desire those outcomes as well, reinforcing our [Results value](/handbook/values/#results).

For all-remote companies, leaders should not expect informal communication to happen naturally. There are no hallways for team members to cross paths in, no carpools to the office, etc.

> If you do all-remote, do it early, do it completely, and change your work methods to accommodate it. Be intentional about informal communication. All-remote forces you to do the things you should be doing anyway, earlier. - *GitLab co-founder and CEO Sid Sijbrandij*

In an all-remote environment, informal communication should be formally addressed. Leaders should organize informal communication, and to whatever degree possible, design an atmosphere where team members all over the globe feel comfortable reaching out to anyone to converse about topics unrelated to work.

## Community impact outings

Community impact outings are a meaningful alternative to Zoom happy hours. Instead of allocating a shared hour to chat in a video call with teammates, consider a formal outing where each team member redirects that hour to their local community. This approach is not only more inclusive of time zones and family commitments (as the hour can be spent at any point in a given week versus a set time on a calendar), but it celebrates the core of what makes us all unique: our chosen homes and surroundings.

Here's how to construct a Community Impact Outing.

1. Ask your team to block a given amount of time (e.g. one hour) on their calendar during a specific week. Entitle it `[TEAM] Community Impact Outing`. Empower team members to devote time to something meaningful to them, such as volunteering at a library or assisting the elderly.
1. Optionally, ask team members to wear company swag during their outing and capture a photo, video, selfie, or written story.
1. At the start of the following week, encourage team members to share those assets in a team Slack channel, all-hands, or stand-up meeting. Dedicate time to sharing what each team member did and how it impacted them.

Empowering people to fill their social quota *outside* of work, in local neighborhoods and communities, and then bring that culture *to* work, creates a refreshing medium for fostering informal communication.

## Create opportunity for chance meetings

> Sid Sijbrandij on [Twitter/X](https://twitter.com/sytses/status/1264341436138270720)
>
> Below is a thread about the future of remote work after the COVID-19 pandemic is over. I predict that remote will go through a trough of sorrow due to hybrid not working out, and most companies will return to being office based. But many all remote companies will see success.

In colocated settings, unplanned encounters can lead to interesting ideas or hypotheses, which can sprout innovation. In remote settings, leadership should create opportunities for these "chance meetings" to still occur.

### Remote retrospectives

Intentionally-organized [remote retrospectives](https://about.gitlab.com/blog/2019/12/19/how-gitlab-handles-retrospectives) create an atmosphere of chance discussions, as you're specifically there to riff on something. Zoom supports [Breakout Rooms](https://support.zoom.us/hc/en-us/articles/206476093-Enabling-breakout-rooms), which may be useful in catalyzing such conversation.

### Innovation communities

Encourage your workforce to join remote communities which exist to create chance meetings. [Open Assembly](https://open-assembly.com) is one such network, which "hosts the conversations, community and learning that help culture and business transition to the future of work." This creates a highly-focused session in which everyone arrives ready to engage with new people, find common ground, and share insights — all of which feed back into the culture and energy of one's workplace.

### Conferences and events

Remote teams have a tendency to savor and anticipate [in-person engagements](in-person/). As in-person interactions are less common in a remote role, this presents an opportunity for leadership to maximize the utility of conferences and events.

Leaders should consider sending teams to conferences as an efficient way to organize a dense series of chance meetings, with each person then returning to saner spaces to process, distill, and put effort into newly seeded ideas.

### The power of local communities

Global remote work creates tremendous opportunity for innovation to emerge from a more diverse array of locales. As remote teams are empowered to fill a part of their social quota by local interactions with neighbors and members of their home communities, they will experience a much richer set of inputs.

Consider a weekly [asynchronous](asynchronous/) debrief where remote team members share lessons learned and challenges faced in their home communities, which may spark spin-off conversations within the workplace linked to new products or solutions.

## Devote time to fostering relationships

{{% cardpane %}}
{{% card footer="GitLab marketing team Show & Tell social call" %}}
![GitLab marketing team Show & Tell social call](/images/all-remote/marketing-social-call-show-and-tell.jpg)
{{% /card %}}
{{% /cardpane %}}

In all-remote environments, there should be a greater emphasis placed on carving out time to get to know one another as humans. To connect and bond as empathetic beings with interests, emotions, fears, and hopes — people, not just colleagues.

If you've spent any length of time in a corporate setting, you've probably seen a company institute a weekly or monthly "happy hour," designed to gather employees in a shared space to converse about topics unrelated to work.

For colocated companies, the occasional team offsite — to take in a sporting event, to enjoy a shared lunch, etc. — may be enough to supplement naturally occurring informal communication in the office.

Below are a number of intentional facets of [GitLab's culture]({{< ref "culture#culture-at-gitlab" >}}), created to foster informal communication. We welcome other all-remote companies to iterate on these and implement as desired.

1. [Contribute Unconference](/handbook/company/culture/summit/): An in-person, week-long event where we bring the entire company together in one location to get to know each other better.
1. [Group conversations](/handbook/company/group-conversations/): Four times a week the company gets together virtually to discuss an area of the business. Slides are provided for context but not presented.
1. Coffee chats: More details below.
1. Coworking calls: More details below.
1. Social hours: Informal social calls organized within our immediate teams to get to know each other on a more personal level.
1. Local meetups: Co-located team members are encouraged to organize their own meetups, whether it's a coworking space or getting dinner together.
1. [Slack](/handbook/communication/#slack): We use Slack channels for informal communications throughout the company, whether it's a team-specific channel or a channel dedicated to sharing vacation photos with other team members.
1. [Zoom calls]({{< ref "tools-and-tips#zoom" >}}): Not only do we get to know our coworkers better by seeing them in real time during video calls, we also get to know their pets and families too. This visual engagement helps us relate to each other on a more personal level, so when we meet in person, we already know each other. In fact, when our team members meet face-to-face for the first time, the most surprising factor is usually each person's height.
1. Gaming: GitLab has a `#gaming` Slack channel where fans of video games and digital board games can connect. Coordinating shared gaming sessions is a great way to informally connect with team members and collaborate toward goals outside of work.
1. Music making: GitLab's `#music_making` Slack channel is a place where artists can come together and collaborate synchronously or asynchronously to make music together. Several GitLab team members came together to create [All I Want This Quarter Is You (GitLab)](https://youtu.be/9kTwqsW8I68), a musical masterpiece on the GitLab Unfiltered YouTube channel.

> **"I've been given a tour of team members' new houses, admired their Christmas decorations, squealed when their pets and kids make an appearance and watched them preparing dinner – glimpses into the personal lives of my colleagues that I've never had in any office job."** - [Rebecca](/handbook/company/team#rebecca), Managing Editor, GitLab

## How can informal communication be improved?

In addition to all the ideas above, we've curated best practices for how to improve informal communication both as an individual and as a team.

## Creating room for human connection on calls

{{% cardpane %}}
{{% card footer="Mixing it up with hats and backgrounds" %}}
![Mixing it up with hats and backgrounds](/images/all-remote/gitlab-marketing-social-hour.jpg)
{{% /card %}}
{{% /cardpane %}}

In a colocated setting, meetings tend to begin with personal conversation. Virtual calls may feel less amenable to that, so a team has to be intentional about creating space for empathy and human connection. A rolling calendar of calls that are purely about work can lead to [burnout](mental-health/). At GitLab, we accomplish this through the following methods.

### Speedy meetings

As part of our overall [Communications Handbook](/handbook/communication/#scheduling-meetings), we prefer to utilize the "speedy meetings" setting in Google Calendar, which encourages before-the-call banter and conversation. It also provides space between meetings to recharge and reset.

### Lead with empathy

Each work-related call should begin with an earnest, genuine "How are you?", or a similar and appropriate introduction. It's important to remember that everyone is facing a battle that you know nothing about, and in a remote setting you should actively listen.

### Welcome interruptions in calls

We should welcome pets, children, deliveries, neighbors, or partners interrupting a call. This is an opportunity to bond and to humanize the work experience. Take a few minutes to talk to the person if they are open to it, or ask the team member to share more about their pets/family.

## Using emoji to convey emotion

Though emoji have commonly been reserved for personal conversations that occur outside of the workplace, all-remote employees should feel comfortable using them in everyday discourse with team members.

[Perception has shifted on using emoji in professional settings](https://www.wsj.com/articles/yes-you-actually-should-be-using-emojis-at-work-11563595262). In Slack alone, more than 26 million custom emoji have been created since the feature was introduced. In all-remote settings, where you may never meet a colleague in person, leveraging visual tools to convey nuance in tone, emphasis, and emotion can lead to more empathy and a tighter human connection.

> Using emoticons, emoji, and stickers can supplement the lack of human nonverbal cues in computer-mediated environment. The [results](https://link.springer.com/chapter/10.1007/978-981-10-8896-4_16?mod=article_inline) show that proper use of emoticons, emoji, and stickers, especially positive emoticons, is conducive to both relationship formation and cognitive understanding. They not only help participants express emotions and manage interrelations but also function as words to aid message comprehension. - *Ying Tang and Khe Foon Hew, researchers at the University of Hong Kong*

Emoji can create a more [inclusive](/handbook/company/culture/inclusion/) communication environment. When you're working with colleagues where the de facto business language isn't someone's first language, more universal indicators (e.g. "eyes" for "I've seen this" or "smile" for positivity) can reduce the mental burden of deciphering a message.

Consider also using the [Giphy](https://slack.com/help/articles/204714258-Giphy-in-Slack) Slack app to communicate. The app lets you search a library of animated GIFs and send them in Slack.

## Talent shows

{{% cardpane %}}
{{% card footer="GitLab marketing talent show" %}}
![GitLab marketing talent show](/images/all-remote/gitlab-marketing-talent-show.jpg)
{{% /card %}}
{{% /cardpane %}}

Talent shows are great for building meaningful connections between colleagues, and are relatively easy to organize. Simply add a calendar invite, affix a Google Doc agenda to the invite for team members to sign up to showcase a talent, arrange a panel of 3-5 judges, and have a list of prizes ready to go.

If you organize these a week or two in advance, it enables team members to prepare. GitLab's Marketing team [hosted a talent show on Zoom](https://twitter.com/darrenmurph/status/1243194687453835265), with over 130 people on a video call. The moderator called on colleagues based on how they were arranged in the Google Doc, and the judges tallied up results at the end.

## Virtual tour

During a [coffee chat](informal-communication/#coffee-chats) or a [show and tell](informal-communication/#show-and-tell), take a moment to provide a virtual tour of where you live and work. This allows you to virtually "invite someone over" while enabling others to get to know you better. You can do this informally (while walking around with your laptop) or you can choose to make it a friendly competition within your team using recorded videos (à la [Architectural Design's Open Door](https://youtu.be/xlNC8Q62imU) style).

This was done during the Threat Management sub-department's team day. They included a "Virtual Home Tour" as one of the activities and they [recorded videos](https://drive.google.com/file/d/1go2xx8IoPUW7SiLSKU3vqWDBOYKx5dT8/view) to share with the team (*videos only available internally to GitLab*).

## Postcard swapping

Working in a truly global team means it's quite possible that nobody else works in your city. Sending postcards specific to your location to colleagues can be a great way to foster a sense of belonging and is usually very inexpensive. A group of GitLab team members set up a #postcrossing Slack channel to swap addresses and send each other postcards from our home cities, towns and villages from around the world.

It can be a great way to learn about a new place that you may not know about and is a great source of conversation topics for coffee chats.

Examples:

1. [Arty's postcards board](https://twitter.com/TheRealArty/status/1420903891764342786)
1. [Manoj sending 30+ postcards to 12 different countries](https://twitter.com/manoj_g33k/status/1379339796447784961)

## Coffee chats

{{< youtube "CH-NHoBOeho?start=496" >}}

In the Traction Conference [video](https://youtu.be/CH-NHoBOeho) above, GitLab co-founder and CEO Sid Sijbrandij shares how remote teams can stay connected with Frederic Lardinois of [TechCrunch](https://techcrunch.com).

We understand that working remotely leads to mostly work-related conversations with fellow team members, so everyone at GitLab is encouraged to dedicate **a few hours a week** to having social calls/coffee chats with anyone in the company.

It's a great chance to get to know who you work with, talk about everyday things and share a coffee, tea, or your favorite beverage. We want you to make friends and build relationships with the people you work with to create a more comfortable, well-rounded environment.

### Scheduling a Coffee Chat

GitLab Team Members can easily schedule a Coffee Chat in Google Calendar and link it to Zoom, with a 1-click link to the video call. When scheduling coffee chats with executive leadership, please reach out to their EBA to find a mutually available time. If they are not on the list in the [EBA Handbook](/handbook/eba/#executive-business-administrator-team), please follow the steps below:

Watch this [short video](https://youtu.be/zbbEn_PznK0) to see how it's done.

1. Search for the person in Google Calendar
1. Choose the time and duration (25 minutes is common for a coffee chat).
1. Name the meeting **Name / Name coffee-chat**
1. Click on *Make it a Zoom meeting*

Google Calendar will warn you if the time is outside the other person's working hours, and you can select from a list of suggested times.

### Diversifying your Coffee Chats

Coffee Chats are a fantastic opportunity to intentionally broaden your perspective at GitLab. Some suggestions on intentional Coffee Chats:

1. Pair with someone in a group/stage that have **some** overlap with yours, but with whom you don't interact regularly.
1. Pair with someone in a group/stage that your team has dependencies with, but that you don't know well (for example, Customer Success + Customer Support).
1. Pair with someone from a different region of the world (being respectful of working hours).
1. Pair with someone complementary to you — for example, if you're new, find someone who's been here a while; if you're in marketing, pair with a developer; and so on.

You can use the [GitLab org chart](https://comp-calculator.gitlab.net/org_chart), [Product stages page](/handbook/product/categories), or [Team page](/handbook/company/team) to find team members to pair with.

### Leadership Coffee Chat with URG Team Members

At the CEOs request, as of 2021-03-01 we are launching an effort `Leadership Coffee Chats with URG Team Members` aimed at driving more conversations and increasing understanding between leadership and Underrepresented Groups (URGs). Our goal is to leverage every opportunity to increase allyship and engage with all URGs at GitLab. The first iteration will start with our Black team members. Future iterations will include Coffee Chats with LatinX, Asian, LGBTQ, Women, etc. Anything discussed will remain confidential.

This format is similar to our regular Coffee Chats, and in this first iteration, the [E-Group]({{< ref "structure#e-group" >}}) and the [All-Directs]({{< ref "structure#all-directs" >}}) layer of leadership will connect with Black team members for coffee chats. To start, we will keep these within the same function as much as possible (i.e. Black team member in Marketing invited for a Coffee Chat with the CMO and an All-Direct Leader in Marketing)

The coffee chats are optional for our Black team members and participation is opt-in. Leaders and EBA's will drive this engagement by scheduling coffee chats with each of you who have opted in. You will opt-in via the spreadsheet titled Leadership Coffee Chat with URG (Black) which is searchable in Google Drive and clicking the checkbox in column C. URG team members should feel no pressure opt-in as this is optional. If you are unable to participate and you'd like to join a future coffee chat, please ping the Staff EBA to the CEO in slack in #eba-team to be added to the spreadsheet.

We recognize that coffee chats may place pressure on the URG team member to come up with questions or topics for the call to help alleviate that, we've started a list of conversation starters below that can be used during the coffee chat, these are purely suggestions that can be deviated from:

1. Tell me about yourself
1. What's the most exciting thing you're working on lately?
1. If you had to pick any character in a book, movie, or TV show who is most similar to you, who would you choose? Why?
1. When you were growing up, what was your dream job? Is any part of that still true?
1. What is your biggest regret? or fear?
1. What has been the best thing about working at GitLab?
1. If you had to pick one–skydiving, bungee jumping, or scuba diving–which would you do?
1. Which of your family members are you most like? Why?
1. If you had a reality TV show about your life, what would your theme song be?
1. What would an even more joyful workplace culture look like to you?
1. What are 5-10 qualities that you think are must-haves for new hires in terms of culture fit?
1. Which company value would you like to have a new high mark in? (as in, which do you feel you aren't living to its potential?)
1. If you could choose a colleague, team member, or exemplary professional to coach you on a particular topic, who would it be and why?
1. When do you have the most fun at work?
1. What or who inspired you this week? How?
1. How have you improved your remote working skills this month? Have you identified any challenges?
1. What are your primary goals this quarter?
1. What is the most meaningful part of your job?
1. What would you change about our product if you had a magic wand?
1. How do you describe our offering to family and friends?
1. What opportunities for learning and growth have you recently found or created for yourself? What such opportunities do you see for your colleagues?

If you have any questions please reach out to the [Staff EBA to the CEO](/handbook/eba/#executive-business-administrator-team) or the Manager, Diversity Inclusion and Belonging or your People Business Partner. If your question/feedback can be posted publicly, please post in the slack channel #urg-leadership-coffee-chat

### The Donut Bot

Team members can join the `#donut_be_strangers` Slack channel to be paired with a random team member for a coffee chat. The ["Donut" bot](https://www.donut.com) will automatically send a message to two people in the channel every other Monday.
Please schedule a chat together, and Donut will follow up for feedback.
You can also directly reach out to your fellow GitLab team members to schedule a coffee chat in the `#donut_be_strangers` Slack channel or via direct message.

*In the year 2020, Donut reported 537 people connected through 2042 coffee chats at GitLab, compared to 367 chats in similar-sized companies.*

*In the year 2021, Donut reported 846 people connected through 3210 coffee chats at GitLab, compared to 372 chats in similar-sized companies.*

*In the year 2022, Donut reported 1265 people connected through 4186 coffee chats at GitLab, compared to 356 chats in similar-sized companies.*

### GitLab Team Member Mixer Calls

Similar to a coffee chat, a "[GitLab Team Member]({{< ref "top-misused-terms" >}}) Mixer" call aims to help team members meet more folks from other groups or functions that they might not otherwise get to spend a lot of time working or interfacing with.

To set up a GitLab Team Member Mixer, two team members set up a single Zoom line.  Using the single Zoom line, each of those team members invites someone else to join - making a total of four team members on the call.  This way, you'll get to meet someone new - or find connections between team members you didn't know existed.  Each "host" brings a topic to discuss in case the conversation needs help getting started.

At the end - the host and their co-host's *guest* set up another GitLab Team Member Mixer call - with two new guests.  In this way, the participation gets spread throughout the organization and connects as many team members as possible.

### Juice Box Chats

Similar to a coffee chat, a "Juice Box Chat" is a chance for GitLab team members and their children, grandchildren, or other members of their family to get to know one another as well.  These chats can be informal or can focus on a specific topic: Legos, Super Heroes, camping, and video games all make for great subjects.

As we work in an all-remote environment, kids and other household members often show up to calls unannounced, which is just part of working remotely.  However, Juice Box Chats allow us to meet and socialize this way intentionally.  Think a "bring your kid to work day" except in an all-remote company.

You can take a look at the [internal time zones and interests document](https://docs.google.com/spreadsheets/d/1SSeFAMLKWuBZ9Ku32SzorKV_KHW5jTqTVAOovr3HeGM/edit#gid=0) to find a group that might work for you or join our `#kid-juicebox-chats` channel in Slack.

## Team Days and Social Calls

{{% cardpane %}}
{{% card footer="Spreading aloha on a GitLab company call" %}}
![Spreading aloha on a GitLab company call](/images/all-remote/GitLab-Aloha-Shirt-Team.jpg)
{{% /card %}}
{{% /cardpane %}}

Some teams at GitLab organize informal social calls on a regular basis in order to build camaraderie.
The [data team](/handbook/business-technology/data-team) has them every Tuesday.
Team members and managers are encouraged to create these calls as a medium for informal, agenda-free interaction between team members.

[Team days]({{< ref "building-trust#host-a-team-day" >}}) are another opportunity to intermix work and rapport building, and can be structured to work synchronously or asynchronously.

## Show and Tell

Consider creating a shared calendar for social events to more broadly allow people to join and be aware of social events that are in a more convenient time zone. For example, GitLab's [marketing](/handbook/marketing) team has a "Show and Tell" call where team members are encouraged to display something they've crafted and share the story behind it.

Arranging this is simple. Send a calendar invite to a team or department with a shared document attached. Those interested in showing can sign up in a numerical list with their names, so that it's simple to hop from one person to the next on the eventual video call.

Show and Tell sessions are excellent ways to humanize the work experience, and to learn about colleagues on a deeper, more personal level. It showcases what they're proud of, and what provides fulfillment outside of work.

## Team DJ Zoom Room

{{% cardpane %}}
{{% card footer="Time to get the virtual DJ room started in Zoom" %}}
![Time to get the virtual DJ room started in Zoom](/images/all-remote/zoom-share-computer-music-dj-room.jpg)
{{% /card %}}
{{% /cardpane %}}

[Zoom]({{< ref "tools-and-tips#zoom" >}}) added a unique feature within its `Share Screen` function, enabling a remote team to share audio from their computer with all who are in the Zoom meeting. This is useful for getting an entire team together in a shared virtual space without everyone feeling compelled to speak and socialize. A shared DJ Room is ideal for scenarios where team members need to be mostly heads-down on work, but appreciate the closeness of the team and the shared musical experience.

To create additional interaction, hand off the proverbial DJ duties every 2-3 songs, enabling an array of team members to share their favorite tunes. This can trigger fun conversation on preferred music genres and artists

To utilize this feature in Zoom, see below.

- Click the upward arrow beside the `Share Screen` icon
- Click the `Advanced` option tab at the top of the screen
- Click `Music or Computer Sound Only`
- Play music from any app or website, being mindful that you'll want to lower the volume so that your voice can also be heard

More instructions on this can be found at [this support page](https://support.bookwhen.com/en/articles/3942332-playing-music-on-a-zoom-live-stream-video-call).

## Create a company songbook

If the Team DJ Zoom Room strikes a proverbial chord with your team, consider creating a company songbook. Get inspired by visiting the [GitLab Songbook]({{< ref "songbook" >}}).

## AMA (Ask Me Anything)

![GitLab values illustration](/images/all-remote/gitlab-values-tanukis.jpg)
{style="max-width: 50%;"}

Hosting an [AMA](learning-and-development/#ask-me-anything-ama-group-conversations-and-key-meetings) is a great way for people to learn about others. While questions *can* be about work, these serve as an opportunity to ask funny and far-fetched questions that enable a more personal connection. It's particularly important to consider ongoing AMAs with executives. AMAs humanize leaders and remind teams that we are [all more alike than we are unalike](https://allpoetry.com/Human-Family).

## Celebrations and holidays

{{% cardpane %}}
{{% card footer="A bit of Airplane! fun on Halloween" %}}
![A bit of Airplane! fun on Halloween](/images/all-remote/GitLab-Halloween-2019-Costume-Zoom-Call.jpg)
{{% /card %}}
{{% /cardpane %}}

A team that is distributed across the globe creates opportunity for many celebrations. Different countries and cultures celebrate in their own way, enabling team members to gain an understanding of key dates and events that matter to colleagues. A culture that encourages a team to thoughtfully express their celebrations on company calls is a healthy, inclusive one.

### Global pizza parties/meals

Teams can also arrange shared meals around the world. [Global pizza parties](https://about.gitlab.com/blog/2019/10/02/support-virtual-pizza-party), for example, are possible to document and enjoy in a shared setting (Zoom or Slack), though one may wish to consider a breakfast pizza depending on time zone.

## Social games

![GitLab team in Luna Park live game show](/images/all-remote/luna_park_game_show_gitlab.jpg)
{style="max-width: 50%;"}

You can now bring peers or colleagues into online game shows through platforms like [Luna Park](https://golunapark.com). Some social games are built for synchronous experiences like [Collab](https://collab.getchinwag.com), while on-demand games are more amenable to asynchronous engagement across time zones.

## Virtual lunch table

{{% cardpane %}}
{{% card footer="Cheers to a fantastic team" %}}
![Cheers to a fantastic team](/images/all-remote/gitlab-zoom-happy-hour.jpg)
{{% /card %}}
{{% /cardpane %}}

An easy way to create an opportunity for team members to connect over a virtual meal is to maintain a videoconference room that serves as a rolling lunch table.

Adventurous team members could even cook on camera, and the host may consider utilizing Zoom's `Share Music` [feature](informal-communication/#team-dj-zoom-room) to pipe music into the virtual gathering spot.

Sharing a meal is a powerful way to connect as humans, particularly when you open it up globally. This creates a more casual atmosphere where team members can connect with colleagues on a more personal level, without work at the center of the video call.

## Virtual scavenger hunt

{{% cardpane %}}
{{% card footer="Virtual scavenger hunt at GitLab" %}}
![Virtual scavenger hunt](/images/blogimages/cs-scavenger-hunt/hugo.jpg)
{{% /card %}}
{{% /cardpane %}}

GitLab's Customer Success team ideated and executed a [worldwide scavenger hunt](https://gitlab.com/gitlab-com/customer-success/tam/issues/212) using GitLab (the product), which is [detailed on the GitLab Unfiltered blog](https://about.gitlab.com/blog/2020/04/06/cs-scavenger-hunt) and is easily replicated.

## Virtual trivia

GitLab's global [marketing team](/handbook/marketing) plays pub-style trivia every other week. You can compete as individuals or as teams, with a suggested time of 1 hour. For those within the GitLab organization, email `events@gitlab.com` if you want to arrange a game for your team.

GitLab utilizes MysteryTrip, which serves large teams well and doesn't place a heavy preparation load on the organizer. MysteryTrip handles the preparation work for questions, acts as trivia master, and has automatic scoring and a leadercard. This makes spinning up a game quick and easy, with pricing set at around $20 per player. For those outside of the GitLab organization, regularly-scheduled trivia sessions are an excellent way to take everyone's focus away from work and engage in a shared experience.

## Co-working calls

These video calls are scheduled working sessions on Zoom where team members can work through challenging tasks with a coworker, or simply hang out while each person works on their own tasks.
This recreates a productive working session you might have in person in a traditional office setting, but from the comfort of your own desk.
Want to try advanced mode? Screen share as you work together (keeping in mind any confidentiality issues).

## Collaborative virtual quizzes

A collaborative quiz tool like [Kahoot](https://kahoot.com) can be used for virtual team-building activities. Split into smaller breakout groups on Zoom to get to know each other and answer the questions. When you come back together in the central session, you can go over the questions and share stories about the answers. Incorporate some friendly competition by offering a prize for the winners.

## Humanizing the digital experience

In the wake of COVID-19, many suddenly-remote companies are seeking to humanize the digital experience. For companies which were not intentional about structuring informal communication in an office, this void becomes glaring in a remote environment.

In this section, we'll spotlight tips and advice from other experts and companies.

[Bretton Putter](https://twitter.com/BrettonPutter), founder at [CultureGene](https://twitter.com/culturegenehq), shares the below [examples](https://twitter.com/BrettonPutter/status/1263834004341563393/photo/1).

1. Book, TV, and movie clubs
1. Movie nights leveraging [Netflix Party](https://www.netflixparty.com)
1. Group game/dance/music nights via a streaming service like [Twitch](https://www.twitch.tv)
1. Lunch and Learn webinars (ideally learning about something not directly work related, such as playing an instrument)
1. Group fitness, yoga, and meditation sessions
1. Conference call bingo
1. Regular team coffee break rooms
1. Collaborative quizzes
1. Green/yellow/red personal status check-ins
1. [Geekbot](https://geekbot.com) "What I Did This Weekend" polls for teams on Slack
1. Dress-up/hat themes for team or all-hands video calls

### Tools for building empathy and connection

1. Build empathy, rapport, and cohesion on remote teams with [Kona by Sike Insights](https://www.heykona.com/)
1. Asynchronous voice messaging for teams via [Yac](https://www.yac.com)
1. Asynchronous video messaging for teams via [Loom](https://www.loom.com)

## GitLab Knowledge Assessment: Informal Communication in an All-Remote Environment

Complete all knowledge assessments in the [Remote Work Foundation certification](remote-certification/) to receive the [Remote Foundations Badge in GitLab Learn](https://gitlab.edcast.com/pathways/copy-of-remote-foundations-badge). If you have questions, please reach out to our [Learning & Development team](/handbook/people-group/learning-and-development) at `learning@gitlab.com`.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
