---
title: "The definitive guide to remote internships"
description: "How to have a successful internship remotely: key tips for employers and interns."
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

On this page, we're detailing considerations for both employee and employer as it relates to [remote internships](/handbook/engineering/internships) (also referred to as apprenticeships and co-ops).

## What are the benefits of remote internships?

![GitLab collaboration illustration](/images/all-remote/gitlab-collaboration-illustration.jpg)]
{style="max-width: 50%;"}

There are many reasons why remote internships are a value-add to any organization.

### Competitive hiring advantage

Remote is the [future of work]({{< ref "remote-vision" >}}). The ability to learn and work from wherever one is most fulfilled will soon become the norm. Companies which are built to support remote work (e.g. firms which create digital products), yet refuse to offer such flexibility, will be in low demand by top talent. This includes the most promising interns.

Offering remote internships provides a competitive advantage to attracting ambitious and capable interns, but it will soon [diminish]({{< ref "remote-vision#diminishing-competitive-advantage" >}}) into a practical requirement.

### Diversity

By hiring remote interns, organizations are able to broaden their usual scope and recruit talent from underserved areas of the globe. Cultural and geographic [diversity]({{< ref "inclusion#fully-distributed-and-completely-connected" >}}) is important to long-term success and vibrancy in a company.

### Fresh perspective

Interns are capable of offering valuable perspective. Given that many are only working for a few months, they're able to evaluate an organization with fresh eyes, and they have little to lose by offering [transparent](/handbook/values/#transparency) feedback along the way.

Particularly for interns who are in university, or recently graduated, they may also bring new tools and methodologies to the table.

## Finding a remote internship

Remote internships are more common than ever, though finding them can be challenging. Below, we're highlighting destinations that feature remote internships, where employers can post and job seekers can apply.

- [Covintern](https://covintern.com/jobs)
- [RemoteOK](https://remoteok.io/remote-internships)

## What makes a remote internship different?

![GitLab journey illustration](/images/all-remote/gitlab-journey-and-navigation.jpg)]
{style="max-width: 50%;"}

Remote internships  are unique in one primary way: there is no physical office involved. The rough timeline for an internship — 3 to 6 months — is typically the same in a remote internship as it is in most colocated internships. Internships are where working baselines are formed, and conducting one remotely requires special care and consideration from everyone involved.

This is of particular importance given that interns are usually inexperienced in the workplace. Internships have historically been used to introduce people to the working world. Foundational communication skills are learned in internships, as are conventions, norms, and expectations. They serve as an opportunity for an intern to ask a multitude of questions, given that practically everything about the experience is new.

## What are the drawbacks of remote internships?

Like any remote-working situation, remote internships have multiple [advantages]({{< ref "remote-benefits" >}}), but remote work doesn't suit everyone. Depending on their lifestyle, work preferences, and drive, [a remote internship can have disadvantages](drawbacks/#remote-work-challenges-and-solutions-for-employees) as well. We have outlined potential challenges and solutions for remote internships in our [all remote guide here](drawbacks/#remote-work-challenges-and-solutions-for-employees).

## Employer considerations

![GitLab values illustration](/images/all-remote/gitlab-values-tanukis.jpg)]
{style="max-width: 50%;"}

It is unlikely that an intern will be equipped to be a [manager of one](/handbook/values/#managers-of-one), and companies should expect interns to require a great deal of hand-holding.

Learn more about the importance of clear [communication]({{< ref "communication" >}}), intentional [onboarding](learning-and-development/#how-do-you-onboard-new-team-members), and utilizing [asynchronous workflows](asynchronous/) in a Harvard Business School article entitled "[Best practices for creating a successful virtual internship](https://www.hbs.edu/recruiting/blog/post/best-practices-for-creating-a-successful-virtual-internship)."

## What are the best practices for managing a remote internship?

Managing a remote internship is similar to managing one in-person. We've created an [in-depth guide to being a great remote manager](being-a-great-remote-manager/#traits-of-a-great-remote-manager) which includes focusing on:

- [Self-awareness](being-a-great-remote-manager/#self-awareness) for relationship building
- Employing [empathy and kindness](being-a-great-remote-manager/#empathy)
- Overcoming ego to be a [servant-leader](being-a-great-remote-manager/#servant-leader)
- Communicating in great [detail](being-a-great-remote-manager/#detailed)
- Modeling [trustworthiness](being-a-great-remote-manager/#detailed)

## What are the best tools for managing a remote internship?

Remote internships are fertile ground for communication breakdowns. Intentionally prioritizing strong communication lines, creating a psychologically safe space for interns to learn, and hiring the right interns will ensure a positive and successful experience.

### Creating good communication

There is much to glean from [GitLab's approach to meetings](meetings/), and a well-organized internships will also incorporate communication strategies such as [scheduled AMAs, group conversations, and Key Reviews](learning-and-development/#ask-me-anything-ama-group-conversations-and-key-meetings).

### Creating psychological safety

In colocated settings, interns can be physically sat beside a mentor, ready and able to answer a stream of questions throughout the internship period. The physical proximity typically creates psychological safety for the intern, enabling them to ask questions as they arise without an overarching fear that they are imposing.

To thrive, remote team members must appreciate and respect autonomy, though this requires a certain sophistication for [self-searching and self-learning](self-service/).

Interns who are inexperienced in the working world may be hesitant to ask questions in a remote setting. Some may feel that a constant stream of Slack pings or Zoom requests are a bother to their mentor. The virtual wall may create a friction point as they assume that everyone is busy and unreachable, and in turn, their blockers cannot be addressed.

Employers should act proactively to address this. **Consider the following**.

1. Have mentors and/or managers checking in with remote interns on a regular cadence, at least once per hour.
1. Reiterate daily that interns are free to inquire as often as necessary, as if their mentor were in the same physical room.
1. Host an "always-on" video room where the intern is able to see at least one other person working. (Note that this may require an overview of [all-remote meeting nuances](meetings/).)
1. Assign interns a second monitor where "always-on" video rooms can be present, overcoming the awkwardness of a standing video meeting.

### Hiring remote interns

There are certain [qualities](hiring/#what-qualities-do-you-look-for-in-remote-hires) that [hiring](A) teams look for in remote hires at any level. These include an appreciation for [self-learning and self-service](self-service/), a penchant for [documentation](management/#scaling-by-documenting), and a proven ability to work [asynchronously](management/#asynchronous).

Interns will naturally lack the work experience required to have a great grasp for any of the above; however, hiring teams can ask certain questions that provide insight into how they've operated in remote settings *outside* of the workplace.

**Consider the following questions.**

1. Tell me about a time when you moved a group project forward, at work or school, where you were in a different physical place than your other team members? (*Particularly for university students, chances are high that they have worked remotely on an important project. Dig for details on how they enjoyed it, what challenges they faced, and how they coped*.)
1. Have you ever taken an online course or training session? If so, describe your process for managing your own time, respecting deadlines, requesting assistance, and solving problems.
1. Are you an active member of an online community, or do you have experience managing logistics remotely for in-person events/gatherings?
1. Have you completed freelance work for remote clients, and would you be willing to provide references upon request?
1. Have you thought about where you would work remotely if offered this internship? (*Managers should not expect a precise answer to this, as even senior staff should experiment with [workspaces](workspace/), but it's useful to understand if the candidate has considered this element.*)

### Length of internship

While 3-month internships are common in colocated settings, consider offering 4-month remote internships. The added month creates space to acclimate to working remotely.

### In-person fast boots

While not necessarily required, organizations should consider a week-one in-person onboarding session — particularly if hiring several interns as part of a cohort.

A final week of in-person interaction may be useful for retrospectives and potential next steps.

## What are the challenges of managing a remote internship?

Because remote internships are learning-based and fast-paced, there are some [red flags to watch out for](being-a-great-remote-manager/#red-flags-to-watch-out-for):

- [Loneliness and isolation](being-a-great-remote-manager/#loneliness-and-isolation)--be sure to set up a regular communication schedule with your intern/s.
- [Feeling left out](being-a-great-remote-manager/#feeling-left-out)--be sure to create ways for your intern/s to connect with both you and the team.
- [Overworking](being-a-great-remote-manager/#overworking)--be sure to model and encourage work/life boundaries.

### Managing expectations

It's important for organizations to remember that remote interns are essentially learning **two** fundamental things: the job itself, and how to work well [with no office](getting-started/). In turn, it's important to calibrate expectations and what is measured.

This may be particularly challenging in fast-paced all-remote settings. All-remote companies tend to be highly [efficient](/handbook/values/#efficiency). In a firm where [impact, not activity](/handbook/values/#measure-impact-not-activity), are measured, there is a natural inclination to expect expediency. When a remote intern is learning two major lessons at once, progress may feel slower than usual.

For organizations with a strong desire to use their remote internship program as an intern-to-hire mechanism, be sure to screen for this during the interview process. Encourage prospective interns to be transparent about their intentions and readiness to start if successful.

### Mentorship training program

Firms hiring remote interns should first conduct training programs with managers. Touch on areas such as empathy for being junior, and enlist a trainer who can put the senior manager into the shoes of a new intern. This will prepare managers and mentors to think through questions and concerns from interns, and remind them of what it's like to be inexperienced and nervous when entering a new workplace.

### Offer remote mentors

Remote interns may be operating in their very first remote role. Organizations should not expect them to simply know how to work well in a remote setting. While GitLab's [guide to starting a remote role](getting-started/) may be of assistance, there are many assumptions made that require workplace experience.

Consider a secondary mentor for the length of the internship that has a great deal of experience in remote settings. Veteran remote workers are experts in sensing struggles and offering solutions by those who are struggling to thrive outside of an office.

Remember: struggling remote interns may have a sound understanding of their work tasks, but are unable to articulate blockers related to their work environment.

Consider also creating opportunities for interns to connect and network with senior leaders on the team. In his session at REMOTE by GitLab, Professor Raj Choudhury shared the results of a Harvard Business School study showing how brief virtual water cooler sessions with senior managers might have job and career benefits for newcomers in a remote setting. Watch the recording to learn more:

{{< youtube "RVMUworx2Vk" >}}

### Select projects intentionally

Certain projects and tasks are more easily completed by junior staff. Moreover, certain tasks are more easily accomplished asynchronously.

Leaders should be careful to not offload their own energy vampires on remote interns, but rather select complete projects that an intern can start and finish in a few months.

Too, it's important to select projects which are important or notable to a large group. This ensures that many people in the organization are invested in the intern's success, and it widens the scope of available mentors who are knowledgeable about the project and can step in and help across time zones.

If possible, avoid time critical work. Great intern projects tend to be items which are largely seen as "nice to haves" by full-time staff. These are projects that everyone recognizes would benefit the organization, but do not rise to the level of priority necessary to demand senior staff attention.

### Make your strategy and onboarding public

At GitLab, we make our [strategy](/handbook/company/strategy) and [OKRs](/handbook/company/okrs) (objectives and key results) public, and offer copious context on the question of "[What's it like to work at GitLab?]({{< ref "candidate-faq" >}})" This shows respect for job seekers, and it ensures that those who apply resonate with our [values](/handbook/values/).

Hiring remote interns is hard. An organization shouldn't make it harder by concealing their vision and values until *after* an intern is hired. Given the remarkably short duration of the internship experience, it's vital to act [transparently](/handbook/values/#transparency) in order to create as much pre-start alignment as possible.

## How can interns make the most of a remote internship?

Interns must recognize that expectations for self-managing your time will likely be higher in a remote internship, while resources *may* be fewer if a company lacks a mature internship infrastructure.

It's important to ask questions during the interview phase to understand the work environment. You'll want to make sure you have a remote mentor or [onboarding buddy]({{< ref "onboarding-buddies" >}}) who will be available to answer questions related to working remotely.

Too, consider reading GitLab's [guide to evaluating a remote job](evaluate/) and ask relevant questions as you interview.

All-remote forces you to do things that you [should do anyway](management/), but more quickly and more intentionally. That's a great backdrop for remote interns, who stand to gain not only work experience, but experience working in an environment where you're in control of your [space](workspace/), your [time](people/#those-who-value-flexibility-and-autonomy), and your [approach](/handbook/values/#give-agency).

## What are the best ways to stay connected with remote interns?

If you don't hire your remote intern/s at the end of their internship experience, be sure to sweeten their transition out by ending well.

1. [Say Thanks](/handbook/communication/#say-thanks) for the work they contributed during their internship. At GitLab, we even have a `#thanks` Slack channel!
1. Acknowledge intern contributions in team meetings, issues, company calls, 1-1 meetings.
1. Send a gift or a swag bag to commemorate their contributions.

Don't forget to gather information they are willing to share such as their email address, LinkedIn profile, or handles for other social channels so you can stay in touch. Who knows...maybe a [position at GitLab](https://about.gitlab.com/jobs) will come available that you can hire them for!

## Contribute your lessons

GitLab is currently piloting an [engineering internship program](/handbook/engineering/internships). We expect to learn a great deal from the experience, while documenting challenges and solutions. If you or your organization has experience offering remote internships which would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests) and adding a contribution to this page.

Return to the main [all-remote page]({{< ref "_index.md" >}}).
