---
title: "How do you conduct interviews remotely?"
description: How do you conduct interviews remotely?
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

On this page, we're addressing a popular question: "How do you interview remotely?" We're also curating a list of questions that we at GitLab appreciate hearing answers to from others in remote organizations.

## How do you interview remotely?

![GitLab collaboration illustration](/images/all-remote/gitlab-collaboration.jpg)
{style="max-width: 50%;"}

Whether you're wanting to learn how to hire remotely, or just wanting to know how to get hired for a remote position, it helps to know how you should prepare for a remote interview. You only get one chance to make a first impression, so keep these tips in mind.

## How do you prepare for a remote interview?

Remote interviews are similar to in-person interviews in many ways: You're still trying to make a good impression and communicate your strengths, you're just not doing it from the same room. One thing is certain: preparation is just as important in a remote interview as an in-person interview.

1. **Read instructions from your interviewer carefully (and ask questions if something is unclear).** Make sure that you understand the requirements for the interview and follow them carefully. The best way to make a good first impression is simply to be well-prepared!
1. **Prepare yourself with notes.** An advantage of having a remote interview is that you can make a "cheat sheet" for anything you want to mention, questions you'd like to ask, or other information that will help you get the most from the conversation.
1. **Have a distraction-free area for the interview, if possible.** Background noise or clutter can take attention away from you, which is not what you want.
1. **Make eye contact.** Look into the camera as much as possible, not the screen.
1. **Have a practice meeting.** If it will help you feel more comfortable, try to download any software for a video call far enough in advance to test your audio and video settings.
1. **Don't browse on your computer or phone during an interview.** Only have what you need for the interview, and don't get distracted.
1. **Use headphones with a microphone.** Not only will this make you sound better, it will reduce listening fatigue for the other person as well so that you can have a better conversation. One of the more common phrases you'll hear from GitLab CEO Sid Sijbrandij is, "[Can you put your headphones on?](https://about.gitlab.com/blog/2019/06/28/five-things-you-hear-from-gitlab-ceo)"

## What technology do you need to participate in and manage a remote interview?

### Camera

For a remote interview, being able to easily navigate a [video call](/handbook/communication/#video-calls) is vital. First, consider how you want to present yourself visually by choosing a camera quality:

1. Inbuilt webcam on a phone, laptop, or external display (baseline)
1. Dedicated USB webcam (mid-tier)
1. Mirrorless camera or DSLR with dedicated lens (high-end)

### Headphones

Wearing headphones can create a more positive video experience for all. If you're using a dedicated microphone, you may prefer comfortable studio-style headphones without an in-line mic. If you want to reduce the amount of hardware you're using, headphones with an in-line mic will be more appropriate.

Some prefer in-ear headphones rather than over-the-head headphones, and it's important to consider long-term comfortability for those who may find themselves in [video calls](https://about.gitlab.com/blog/2019/08/05/tips-for-mastering-video-calls) for multiple hours per day.

Bluetooth headphones can be problematic due to limitations of microphone quality, latency, and battery life. If you opt for Bluetooth headphones, it is recommended that you use a separate wired microphone. Bluetooth headsets can easily jump between devices, thus it is recommended to only pair one set per device to avoid unexpected disconnects during video calls.

### Microphones

"*When audio quality is high (vs low), people judge the content as better and more important. They also judge the speaker as more intelligent, competent, and likable. Messages that are difficult to process are less compelling.*" This [research](https://app.sciencesays.com/p/good-sound-quality-smarter), conducted by Norbert Schwarz at the University of Southern California, reinforces the importance of investing in equipment and atmosphere to generate the highest-fidelity audio in a remote setting.

When possible, avoid doing a job interview in a room with other people or in a place with heavy background noise. If you have a pair of Bluetooth or wired earbuds with an in-line microphone (like the ones commonly included with most smartphones), use those instead of the built-in microphone of a laptop, phone, or desktop monitor. These microphones tend to be of low quality, and do little to stop background noise.

### Reliable internet

You can have great technology, but if you fail to connect or stay connected during your interview, it can make it difficult to have a productive conversation. Be sure to reset, check, and test your internet connection especially prior to an interview.

If you have challenges with connectivity in your home office, consider asking your interviewer or recruiter whether the company offers [interview accommodations](/handbook/hiring/interviewing#adjustments-to-our-interview-process) such as reimbursing the cost to rent a private office or call booth for the interview.

## How do you conduct a remote interview?

Conducting a remote interview is all about preparation, and most importantly, setting expectations for the person being interviewed. You also have technical considerations to make since the person joining the video/conference call is using a different setup than you, or they may not have interviewed remotely before. Be clear about how to join the interview and the technical requirements. Make sure the process and/or email templates are documented internally so that others can communicate this process to future interviewees.

1. **Specify if it is a phone or video interview.** Nothing can derail the interview faster than being caught offguard. Communicate this ahead of time.
1. **Give instructions for how to connect to the video call.** Include download instructions for the software you're using or a step-by-step guide if connecting from the web.
1. **Give the candidate an outline.** The team at [FlexJobs](https://www.flexjobs.com/employer-blog/best-practices-conducting-remote-interviews) recommends an outline with an interview start time, the name of the interviewer and anyone else they will be meeting, and the general order of events so they know when to speak.
1. **Have a practice meeting.** Use this opportunity to make sure your audio and video is coming through clearly.
1. **Have questions prepared and in front of you ahead of time.** Owl Labs has prepared [this list of remote questions](https://resources.owllabs.com/blog/remote-job-interview-questions) if you need some inspiration.
1. **Share the process and documentation with others.** Make templates and processes available to other interviewers so that everyone communicates effectively.

## How can you make a remote interview feel more personal?

### Posture

Before a remote interview, check your front-facing camera or webcam to ensure you are well lit and can be seen. Maintain eye contact with your screen/camera and allow yourself to smile and react naturally--the same way you would for an in-person interview.

### Place

Pick a neutral location that is quiet and comfortable. That way, neither you nor the interviewer will be distracted by your environment. We encourage you to display your [quirkiness](/handbook/values/#diversity-inclusion) and personality, but for an interview, it's best to avoid chaos.

### Practice

To help make a great first impression, prepare by researching the company and reviewing their [handbook and values](/handbook). Practice answering some [sample interview questions](/handbook/hiring/interviewing#what-to-expect-during-an-interview-with-a-recruiter) live with a peer or by recording yourself or practicing in a mirror.

## What traits do remote interviewers look for?

In an [all-remote](hybrid-remote/#all-remote-upgrade) organization, each individual is empowered to [work and live](people/) where they are most fulfilled.

During the interview phase, it's vital to get an understanding of how a potential employee understands and plans to participate effectively in remote work. To be a great remote worker, potential hires should be:

- able to work [asynchronously](asynchronous/)
- self-disciplined and able to be a [manager of one](/handbook/values/#managers-of-one)
- comfortable with remote communication, much of which is [communicated through text](effective-communication/)
- ready to engineer an [optimal workspace](workspace/)
- able to focus and pinpoint both [when and where you prefer to work on a daily basis](https://about.gitlab.com/blog/2019/09/12/not-everyone-has-a-home-office)
- prepared to create work/life boundaries and balance in a [work from anywhere scenario](https://about.gitlab.com/blog/2018/05/11/day-in-life-of-remote-sdr)

## What are some tips for succeeding in a remote interview?

### Showcase your remote expertise

With many companies embracing remote work and hiring remotely, it's important to highlight your remote skills just like you would your other qualifications for the role. You can certainly incorporate this into the interview process, but you also may want to consider updating your resume.

The team at [We Work Remotely](https://weworkremotely.com/blog) addressed the question, "Should your resume change after the pandemic?" in [an Instagram post](https://www.instagram.com/p/CSFPMpaDJBr/?utm_medium=copy_link) with these five tips:

1. **Showcase remote work skills:** Don't only focus on tools, explain how you've been able to collaborate online, and how comfortable you are with asynchronous communication. If you transitioned to remote work, explain how you did it successfully!
1. **Focus on the results you've brought to your past jobs:** When your boss and coworkers can't see you, the only thing they can know about your work is the results you produce. Add what you've been able to accomplish in the past, numbers and processes are important to mention.
1. **Don't be afraid to explain more if you have work gaps:** The pandemic resulted in many jobs lost. If you lost your job or had to quit for personal reasons, it's important to explain it (as long as you're comfortable). Take this as an opportunity to explain if you learned something during this time, if you leveled up a skill, or if you worked on side projects.
1. **Show that you're more than just a worker:** Things have changed and companies are interested in knowing that you have a life outside of work. Add your interests or hobbies to your resume. Bonus points if you can explain how those help you be a better worker.
1. **Keep your location general, or tweak it depending on the job you're applying to:** Your complete address is irrelevant, get rid of it! If the job you're applying to requires a specific location or time zone, be sure to add it to your resume.

## What are the benefits of conducting a remote interview?

Remote interviews expand the possibilities for recruiting a more diverse and [inclusive](/handbook/company/culture/inclusion/) workforce. Remote gives your company a competitive advantage by opening the recruiting pipeline to unlimited geographic regions and sourcing employees from any location.

Not only does this create a more competitive hiring process by reaching a more diverse set of candidates, but it also allows your organization to hire great people not limited by the basis of [salary](https://pages.hired.email/rs/289-SIY-439/images/Hired_2023%20State%20of%20Software%20Engineers.pdf).

## What are the challenges of conducting a remote interview?

For hiring teams, one of the most common challenges associated with remote interviews is gaining insight into the candidate's personality.

### How do I assess culture fit remotely?

To answer this question, you first need to unlearn a bit, and change your frame of mind. A hiring manager should *not* aspire to assess culture fit. Rather, you should aspire to assess *values fit*.

For many, it is assumed that culture is simply the aura, energy, or vibe one gets when walking into an office. This is largely driven by decor and personas in the room. It is dangerous to allow company culture to be dictated by such factors, as this will create an oscillating culture that changes depending on mood or socioeconomic conditions.

A company culture is a company's list of values. Culture is an assurance that each employee respects, admires, and feels invested in a company's values, and that leadership works to ensure values are not violated. As GitLab, an operating principle within our Diversity, Inclusion & Belonging  value is "[culture fit is a bad excuse](/handbook/values/#culture-fit-is-a-bad-excuse)."

Remote interviewers should link a company's values during the interview and have a conversation to assess a candidate's alignment and understanding of those values. Particularly in a remote setting, [values](/handbook/values/) serve as the north star, guiding every business decision by people you cannot physically see and shaping how colleagues treat one another.

### Remote job seekers and candidates

When you're searching for a remote career opportunity, it can be daunting to know where to start. We've curated a [list of companies and job boards](jobs/) to help narrow your search, as well as a [list of qualities to look for](evaluate/) as you're evaluating a potential employer.

## Interview questions to assess for success in a remote environment

1. Have you ever worked remotely?
1. What were some of the challenges you faced with working remotely?
1. Why do you want to work from home or a third-space (e.g. co-working space, external office, [Codi](https://www.codi.com), etc.)?
1. Have you worked with a distributed team? How did it go? Even if it wasn't explicitly defined as remote work, you can include examples of moving a project forward while traveling, or doing so while your classmates, peers, or colleagues were in a different physical location.
1. What methods do you use to ensure you are communicating with a remote team?
1. How do you switch off from work?
1. Tell me about a time you recognized an opportunity for process improvement and how you brought that up to leadership.
1. Have you ever worked independently without direct supervision on a daily basis?
1. What strategies, tools, routines, or workflows do you use to ensure your day to day goals met?
1. What are some of the things that you have struggled with or you think you will struggle with working remotely and how do you intend to combat them?
1. What excites you about working remotely over working in a traditional office environment?
1. What would you do if you have a piece of work that requires someone in a different timezones help and they are not available?

## General remote-work questions

GitLab seeks to learn from others who are embracing remote work. This list of questions is directed at other peers working within a remote organization. Some are aimed at executives and hiring managers. In [this video](https://youtu.be/IFBj9KQSQXA) on the [GitLab Unfiltered YouTube channel](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A), Sid asks the below questions to InVision Chief People Office Mark Frein.

We are working on a submission process for remote companies who want to engage in interviews with GitLab to share their perspective on these questions and more — stay tuned!

1. What's driving society's appetite for workplace flexibility and remote opportunities?
1. What qualities are important to look for in new hires as you scale a remote organization?
1. How does all-remote contribute to people being themselves/vulnerable?
    What benefits have you seen manifest from this?
1. Do you need special leadership qualities to lead an all-remote team, or does what you learn leading traditional teams transfer over?
1. To what degree can remote comfortability be learned?
    - Is it easier to learn/adapt than learning to function in a co-located organization?
1. Do you feel that all-remote organizations contribute to solving cost-of-living, traffic and housing crises in cities like San Francisco and Los Angeles?
1. Do you feel that all-remote organizations are more inclusive by their nature?
    - Is all-remote a mechanism to tackle ageism in the workplace?
1. What's the impact of bringing skilled jobs to rural communities and underserved countries?
    - What kind of GDP-altering potential is there if all-remote itself is scaled?
1. Can existing co-located organizations transition to all-remote?
1. What encouragement would you give new startups today to structure their company as an all-remote entity?
1. What types of businesses are best suited for all-remote?
1. Why do employees apply to work in an all-remote culture?
1. What's the most important communication channel or practice that you use internally to keep your remote team connected and engaged?
1. What advantages do remote organizations have when it comes to building and sustaining their company culture?
1. What are some things you'd encourage newly remote employees to do?
    - Join a [WiFi Tribe](https://wifitribe.co) digital nomad chapter?
    - Consider relocating (temporarily or permanently)?
    - Working in new time zones?
1. How do you weave in-person touch points or communal interactions into your organization?

## Interview guests and answers

Below is an archive of past interview guests, answering the above questions and discussing remote work with GitLab team members.

### Pick Your Brain interviews

{{< youtube "WBf_DA0FF9k" >}}

An archive of Pick Your Brain interviews are below. We've also created a [Pick Your Brain Playlist](https://www.youtube.com/playlist?list=PLFGfElNsQthafBVmoPPVMvBc_Gg2nsyQb) on [GitLab's YouTube channel](https://www.youtube.com/channel/UCnMGQ8QHMAnVIsI3xJrihhg).

Learn more about scheduling a GitLab [Pick Your Brain series](/handbook/eba/#pick-your-brain-meetings).

1. [GitLab CEO Sid Sijbrandij and InVision Chief People Officer Mark Frein](https://about.gitlab.com/blog/2019/07/31/pyb-all-remote-mark-frein)
1. [GitLab CEO Sid Sijbrandij and FormAssembly CEO Cedric Savarese](https://about.gitlab.com/blog/2017/08/11/pick-your-brain-interview-cedric-savarese)
1. [GitLab CEO Sid Sijbrandij and Polymail Co-founder and CEO Brandon Foo](https://about.gitlab.com/blog/2017/06/02/pick-your-brain-interview-brandon-foo)
1. [GitLab CEO Sid Sijbrandij and Stitch Co-founder and CEO Jake Stein](https://about.gitlab.com/blog/2017/08/18/pick-your-brain-interview-jake-stein)
1. [GitLab CEO Sid Sijbrandij and SaaS.CEO Founder Vincent Jong](https://about.gitlab.com/blog/2018/01/26/pick-your-brain-interview-vincent-jong)
1. [GitLab CEO Sid Sijbrandij and Crazy Wisdom Podcast host Stewart Alsop III](https://www.youtube.com/watch?v=23XIx6n9SsQ)
1. [GitLab CEO Sid Sijbrandij and Outklip Founder Sunil Kowlgi](https://about.gitlab.com/blog/2019/04/18/lessons-on-building-a-distributed-company)
1. [GitLab CEO Sid Sijbrandij and Zapier's Mike Knoop and Noah Manger](https://about.gitlab.com/blog/2018/01/08/zapier-pick-your-brain-interview)
1. [GitLab CEO Sid Sijbrandij and FineTune CTO Kwan Lee](https://about.gitlab.com/blog/2017/09/15/pick-your-brain-interview-kwan-lee)
1. [GitLab CEO Sid Sijbrandij and Buffer CEO Joel Gascoigne](https://about.gitlab.com/blog/2017/03/14/buffer-and-gitlab-ceos-talk-transparency)
1. [GitLab CEO Sid Sijbrandij and leadership psychologist Banu Hantal](https://about.gitlab.com/blog/2019/06/21/cofounder-relations)
1. [GitLab CEO Sid Sijbrandij and Slab co-founder Jason Chen](https://about.gitlab.com/blog/2016/07/14/building-an-open-source-company-interview-with-gitlabs-ceo)

## GitLab All-Remote Snapshot interviews

GitLab's all-remote culture empowers team members to [live and work where they are most fulfilled](people/), and to structure their day in a manner that suits them.

If you have yet to work within an all-remote environment, it can be difficult to fully understand the potential. Each individual is [able to approach all-remote differently](people/), leveraging the autonomy it enables to improve one's life.

{{< youtube "QTPeyRW766Q" >}}

*In the [GitLab Unfiltered video](https://youtu.be/QTPeyRW766Q) above, two GitLab team members share their experiences on working in an all-remote setting, providing a glimpse at what's possible when embracing this style of work.*

To provide insight and [transparency](/handbook/values/#transparency) into the lives of GitLab team members — and give those considering remote work [ideas for structuring their own lives](resources/#blogs-from-gitlab-team-members) — we ask the below questions in a video interview. While GitLab's entire team is remote, there can be great diversity in answers.

1. Who are you, how long have you been at GitLab, and what do you do at GitLab?
1. What attracted you to GitLab?
1. Was all-remote a big contributor to why you chose to work at GitLab?
1. What notable elements of an all-remote culture have impacted how you structure your day and life?
1. Would you walk us through a typical day in your life?
1. If you were to give advice to someone considering working for an all-remote company, what would you tell them?

Explore answers from GitLab team members in the [Remote Work playlist](https://www.youtube.com/playlist?list=PL05JrBw4t0Kq7QUX-Ux5fOunQotqJbECc) at the GitLab Unfiltered YouTube channel.

GitLab team members interested in being interviewed should message [@dmurph](https://gitlab.com/dmurph).

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
