---
title: "All-Remote Learning and Development (L&D)"
description: How to build a L&D department in a remote company
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

On this page, we're detailing how [learning and development (L&D)](/handbook/people-group/learning-and-development) works in a global all-remote company.

## How does learning and development (L&D) work in an all-remote environment?

{{< youtube "trYrbPYOf_c" >}}

*A GitLab Live Learning session, embedded above and uploaded to [GitLab Unfiltered](https://youtu.be/QTPeyRW766Q), is an example of L&D iteration.*

Credit the conventional classroom environment for implying that learning is best achieved in a face-to-face, in-person setting. That mentality largely translates to the working world, where it is assumed that learning and development is best suited for boardrooms and lecture halls.

In an all-remote company, learning and development can still occur on a face-to-face basis, albeit through webcams and video chat software. Even in colocated organizations, a growing percentage of learning and development — particularly required training courses assigned by human resource departments — are delivered via webcast.

We believe that all-remote companies are at a competitive advantage when it comes to educating and developing team members. Across the [spectrum of learning styles](https://www.duq.edu/about/centers-and-institutes/center-for-teaching-excellence/teaching-and-learning/discover-your-learning-style), all-remote companies are able to easily scale training sessions, give team members greater agency over their development, and include historical cultural elements in [onboarding procedures](onboarding/).

Learn more about [learning and development at GitLab in our Handbook](/handbook/people-group/learning-and-development).

## Benefits to all-remote L&D

Learning and development teams within all-remote organizations enjoy unique benefits, a few of which are highlighted below.

- **Faster delivery of training courses**: When your company works [asynchronously](asynchronous/), you don't have to wait for a cohort to be in the same place at the same time to administer updated material.
- **Culture isn't lost**: Onboarding at most companies involves meet-and-greets and shallow briefs on whatever is pressing at the moment. Institutional knowledge and cultural underpinnings are largely lost due to a dearth of documentation as the company grows and experiences churn.
- **Learning is more [inclusive](values#diversity-inclusion)**: In all-remote settings, individuals can learn in [environments that are most comfortable for them](/handbook/company/culture/inclusion/) — home, a library, a coworking space, a lakeshore, while caring for a family member, etc. This allows those who struggle to focus in group settings, or who have mobility concerns, to embrace education that they may opt out of if the setting weren't ideal.

### What are some good resources for developing remote team skills?

Managing any team remotely is much like managing in-person. We've created an in-depth guide on the specific skills needed to [be a great remote manager]({{< ref "being-a-great-remote-manager" >}}). We have also created a guide rich with [tips on managing a remote team here]({{< ref "being-a-great-remote-manager#tips-for-being-a-great-remote-manager" >}}).

## Challenges with all-remote L&D

Most challenges associated with all-remote L&D can be addressed at the [hiring stage](hiring/). All-remote companies should seek team members who want to be a manager of one, thrive in environments of high autonomy, and who embrace virtual communication mediums. Learn more about [how to hire in an all-remote company](hiring/).

- **No guarantee of uptake**: In all-remote settings, educators and trainers must design courses that hold the attention of remote pupils, understanding that they may be engaged with the coursework in highly unconventional settings. In turn, it is difficult to guarantee that participants are truly internalizing what's being conveyed.
- **Live feedback/Q&A is hard**: At GitLab, we aim to operate [asynchronously](asynchronous/), staying true to our values of [Efficiency](/handbook/values/#efficiency) and [Results](/handbook/values/#results). Due to this, it's difficult to find time to hold a question and answer session with a large group of students. Utilizing [a Google Doc](/handbook/communication/#google-docs), where questions can be discussed and answered in real time, is a workaround.

### How can teams overcome remote L&D challenges?

Clear communication is one of the best ways to overcome remote challenges.[GitLab's handbook](/handbook) captures everything an employee needs to know promoting autonomy and [efficiency](/handbook/values/#efficiency) for communication, processes, and procedures by putting everything in one place.

Managers can set, share, and track team goals, or ["objectives and key results" (OKRs)](/handbook/company/okrs) for visibility across the team and company.

One potential downside for all-remote teams is having timely and adequate access to people and information. Managers can ensure everyone has the needed access to information by [documenting everything](/handbook/values/#write-things-down).

## The importance of documenting everything

{{< youtube "ejlb9tPzjZs?start=1510" >}}

*In the [GitLab Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A) video above, GitLab team members discuss the challenges and reasoning behind intentional documentation with Miki and Sandra from Job Portraits.*

Learning involves much more than comprehending what's necessary to complete a job. In fact, we hope candidates aspire to learn about GitLab's [history]({{< ref "history" >}}), [all-remote culture](/handbook/company/culture/), and [values](/handbook/values/) prior to joining the company.

The above would be difficult, if not impossible, to achieve without a commitment to [documentation](handbook-first/). Documentation is so important at GitLab that we have a [section of our Handbook devoted to it](/handbook/product/ux/technical-writing/documentation/).

Particularly in all-remote companies — where everything from [interviewing](interviews/) to [onboarding](onboarding/) to [career development]({{< ref "career-development" >}}) takes place outside of a central office — regimented [documentation](handbook-first/) is the only way to ensure future team members have access to the same information as past and current team members. Even if you've already started a company but have failed to document key learnings, it's never too late to start.

### Handbook first

GitLab's Handbook would [cover thousands of pages if printed](/handbook/about#count-handbook-pages). Each page is loaded with institutional knowledge on important topics like [hiring](/handbook/hiring), [values](/handbook/values/), and [benefits]({{< ref "benefits" >}}), Content is contributed, refreshed, and refined by hundreds of team members across the company.

We encourage other all-remote companies to adopt this [handbook first approach]({{< ref "handbook-usage#why-handbook-first" >}}). Simply, we default to adding knowledge to our handbook *before* disseminating elsewhere. Learn more about [GitLab's handbook-first approach to documentation](handbook-first/).

From a learning and development standpoint, this approach ensures that all team members have access to all learnings — past, present, and future — at all times. This is a highly [inclusive](/handbook/company/culture/inclusion/) way to manage knowledge, and it reflects our [mission]({{< ref "mission#mission" >}}) to change all creative work from read-only to read-write so that **everyone can contribute**.

## Learning and development as a mindset

![GitLab remote collaboration illustration](/images/all-remote/gitlab-collaboration-illustration.jpg)
{style="max-width: 50%;"}

We encourage companies to consider [GitLab (the product)]({{< ref "gitlab-for-remote" >}}) to manage L&D within their own handbook. With a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests), for instance, *any* team member can suggest new learnings to the appropriate places. Colleagues and those managing learning and development can comment, add feedback, and shape what is eventually added.

This is powerful in that it encourages team members to continually be mindful of new learnings, and to not keep those learnings to themselves. Said another way, all-remote teams are ideally positioned to *contribute* to learning and development, rather than simply waiting for the L&D team to generate new material to ingest.

This creates an atmosphere where all team members are hungry to learn from one another. Indeed, those in charge of learning and development in an all-remote company should look to colleagues across the organization to understand which areas are most misunderstood, and what modules would generate the most interest.

## Responsibilities from managers and leaders

GitLab's [100% remote culture](/handbook/company/culture/) and our workplace methodologies are highly unique. You should not expect to transfer the norms of colocated corporations into a work from anywhere scenario. Those who thrive at GitLab take the opportunity to drop prior workplace baggage at the door, embrace a liberating and empowering [set of values](/handbook/values/), and give themselves permission to truly operate differently.

So differently, in fact, that many of GitLab's most effective [processes](management/) would be discouraged or forbidden in conventional corporations.

Hence, GitLab managers are [expected]({{< ref "structure#management-group" >}}) to coach their reports to utilize [asyncronous communication](asynchronous/), be [handbook-first]({{< ref "handbook-usage#why-handbook-first" >}}), design an [optimal workspace](workspace/), and understand the importance of [self-learning/self-service](self-service/).

## What are some best practices for remote team management of L&D initiatives?

One of the best ways to keep a remote team aligned is to regularly review the [Learning and Development Team's Purpose, Vision, Mission, and Objectives](/handbook/people-group/learning-and-development#overview).

GitLab's L&D team has a [regular meeting schedule](/handbook/people-group/learning-and-development#learning--development-team-meetings) to brainstorm, strategize, discuss and collaborate, assign tasks, review feedback or data, and assess progress on the team's strategy and roadmap.

## What are some tips for building a successful remote team L&D program?

For a remote team to work well, managers should coach their team in healthy remote-work practices such as:

- [asynchronous communication](management/#asynchronous)
- working [handbook-first](/handbook/about/handbook-usage/#why-handbook-first)
- creating an [optimal workspace](workspace/)
- understanding the importance of [self-learning/self-service](self-service/).

To stay ahead in L&D, GitLab prioritizes personal [Growth & Development opportunities](/handbook/people-group/learning-and-development/growth-and-development/) by allowing team members to take advantage of training opportunities for professional development, certifications, workshops, coaching, language courses, and much more!

### Trust and communication

{{< youtube "RAp70i5s57Y?start=394" >}}

*In the [GitLab Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A) video above, senior backend engineer Charlie A. describes her experience working in an all-remote setting, from onboarding to fully embracing autonomy.*

> I've been challenged to be able to say, 'It's OK for me to not know this.' It's OK for me to ask somebody else and not feel bad about it. It's OK to not know everything. In this kind of setting, it's impossible for one person to know everything, so you have to rely on your coworkers to tell you.
>
> Impeccable communication and trust is the backbone of any relationship. When it comes to a working environment, [those elements] make it much easier to do what you need to do. - [*Charlie A. — Senior Backend Engineer*](https://gitlab.com/cablett)

Companywide trust and impeccable communication serve as the bedrock for learning and development in any company, all-remote organizations included. This relies on a [set of values](/handbook/values/) that encourages behaviors which are at odds with micromanagement.

Leaders should create a climate for employees where they are eager to learn new skills and improved processes rather than political tactics. For this to occur, each team member must be trusted and empowered to make decisions based on their professional experience and skill set. This is manifested through behaviors such as [reaching across departments](/handbook/values/#reach-across-company-departments), asking for help with [no fear of judgment or embarrassment](/handbook/values/#its-impossible-to-know-everything), and [speaking up](/handbook/values/#share) when values are not adhered to.

Proper learning and development requires more than a curriculum. It requires an atmosphere where people are unafraid and unashamed to learn, recognizing that those efforts will be encouraged and supported.

## How do you onboard new team members?

{{< youtube "CH-NHoBOeho?start=609" >}}

*In the Traction Conference [video](https://youtu.be/CH-NHoBOeho) above, GitLab co-founder and CEO Sid Sijbrandij shares how onboarding works within an all-remote setting with Frederic Lardinois of [TechCrunch](https://techcrunch.com).*

At a high level, this is how new team members are onboarded at GitLab.

1. On a new hire's first day, they are invited to create a GitLab account
1. Within their GitLab account is an [onboarding issue](https://gitlab.com/gitlab-com/people-group/employment-templates/-/blob/main/.gitlab/issue_templates/onboarding.md#all-gitlabbers) with over 200 tasks, including [GitLab's Guide to Starting a Remote Role](getting-started/)
    - Onboarding items are extremely prescriptive
    - Rather than bundling a complex series of asks into one "task," as is common elsewhere, GitLab strives to remove ambiguity
1. Each new hire is assigned an Onboarding Buddy as an added resource beyond the individual's manager
    - The Onboarding Buddy is a serious role, replete with [its own Handbook page]({{< ref "onboarding-buddies" >}})
    - The Onboarding Buddy provides assistance in any way, where no question is silly or too minute, to ensure the new hire has all questions addressed
    - If a concern or obstacle is surfaced to the Onboarding Buddy, and there is no solution in the Handbook, the Onboarding Buddy works with the new hire to create a merge request for the enlightenment of all future new hires
1. The onboarding process is self-directed and self-guided, with new hires encouraged to lean on [documentation](handbook-first/) in the [Handbook](/handbook) — as well as conversing with any GitLab team member — to get up to speed.

Read more in GitLab's [complete guide to remote onboarding](onboarding/).

### High-touch and low-touch flexibility

The beauty of an all-remote setting is that onboarding can be as high-touch or low-touch as a new hire wishes. Those who prefer visual learning can engage in a series of video calls and screen share sessions to walk through each element of their onboarding issue.

That flexibility is unique to the all-remote environment, as those who prefer a self-guided experience are typically forced into a very social onboarding at colocated companies.

### Empowerment from day one

GitLab's onboarding process is **empowering**. If a new hire gets stuck during onboarding, they are encouraged to update the Handbook, record a video to help others who may encounter the same obstacle, and contribute to learning and development from day one.

At GitLab, new hires are onboarded using [GitLab (the product)]({{< ref "gitlab-for-remote" >}}). We believe in using the tools we create. This allows new hires to become [familiar with GitLab](https://about.gitlab.com/features) in a way that feels meaningful (e.g. in learning GitLab, they are also accomplishing necessary onboarding tasks). This also provides a continual set of new users to test GitLab with fresh eyes. These individuals are ideally positioned to point out missing features or areas for improvement as we [iterate](/handbook/values/#iteration) on the product.

Learn more about [GitLab Onboarding in our Handbook]({{< ref "general-onboarding" >}}).

## What are some useful tools and resources for developing a remote (L&D) program?

### Clearly outline job families

![GitLab commit illustration](/images/all-remote/gitlab-commit-illustration.jpg)
{style="max-width: 50%;"}

All-remote companies should strive for a [single source of truth](https://docs.gitlab.com/ee/development/documentation/styleguide#documentation-is-the-single-source-of-truth-ssot) in all facets of running the business, including job families. Job families and their descriptions should be accessible to all from day one. GitLab makes these descriptions available even to prospective team members in the [Job Families section of our Handbook](/handbook/hiring/job-families), reinforcing our [Transparency value](/handbook/values/#transparency).

This removes ambiguity about how the company functions, [how it is organized](https://gitlab.com/gitlab-com/www-gitlab-com/tree/master/source/job-families), and what each position is responsible for.

From a learning and development standpoint, this transparency is vital in providing clarity in [career development](/handbook/people-group/learning-and-development#what-is-career-development). In role levels, requirements for each are clearly listed. This also allows team members to find colleagues in functions outside of their own that they are interested in learning more about.

### Recording meetings and trainings for asynchronous learning

{{< youtube "Cxs5EMHNf6g" >}}

*In the [video](https://www.youtube.com/watch?v=Cxs5EMHNf6g) above, published on the [GitLab Unfiltered YouTube channel](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A), [Chrissie B.](https://gitlab.com/cbuchanan) documents a question from a fellow GitLab team member — "How do you create a blog post as a non-technical user?" — by capturing the answer and walkthrough on video.*

This is a classic example of a GitLab team member answering once so that multitudes will benefit, reinforcing our [Efficiency value](/handbook/values/#efficiency). Notice that Chrissie's primary function is not within learning and development, yet her contribution leads to a more educated workforce.

{{< youtube "7RbVQwU69H0" >}}

*In the [video](https://www.youtube.com/watch?v=7RbVQwU69H0) above, published on the [GitLab YouTube channel](https://www.youtube.com/channel/UCnMGQ8QHMAnVIsI3xJrihhg), a member of the People Operations team conducts a training on decision making. Being unable to attend in person matters not, as the training is archived for later viewing.*

### Encourage team members to collect notes when attending conferences

Encourage team members to collect notes when attending conferences and distribute those notes to their team and other interested teams after the conference.

The attendees are encouraged to collect notes in a Google document and distribute the link via Slack channel(s) and other methods as appropriate.

Example:

- [Kubecon 2019 notes](https://docs.google.com/document/d/1CdcERqUJrSoyA6OU9D3CMz8SRYFbJwvcLJDtkgdSEsg/edit#heading=h.jki4vp3yq19q).  This document contains:
  - Pictures of interesting slides
  - Notes on those slides written by the conference attendees
  - Links to interesting presentations and documents from the conference
- Link to document distributed to Slack channels for the Protect team and Engineering overall
- Link to document added to [Engineering week in review](https://docs.google.com/document/d/1Oglq0-rLbPFRNbqCDfHT0-Y3NkVEiHj6UukfYijHyUs) document.

### Ask Me Anything (AMA), group conversations, and Key Reviews

All-remote companies should embrace learning and development not as something done during once during onboarding and then once or twice per year, but as a continual operation. GitLab encourages team members to also learn from *each other*, as the below methods demonstrate.

#### AMA

Reinforcing GitLab's [Transparency value](/handbook/values/#transparency), we routinely encourage the entire company to join for AMAs (Ask Me Anything), where individuals can pose questions to executives. This not only allows team members to learn from leaders, but it allows leaders to learn more about what matters to team members and those they serve.

{{< youtube "u1jv1HOc8fw" >}}

*In the [video](https://youtu.be/u1jv1HOc8fw)) above, published on the [GitLab Unfiltered YouTube channel](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A), GitLab CEO Sid Sijbrandij conducts an AMA.*

Here are a few other examples of AMAs:

1. [AMA with David Hornik (Board Member)](https://www.youtube.com/watch?v=LwZNbF6_PX0)
1. [AMA with VP of Engineering Eric Johnson](https://youtu.be/Wbq8HLWe0EE?t=25)
1. [AMA with GitLab Chief Revenue Officer Michael McBride](https://youtu.be/LElduuHH2EE?t=95)

### Group Conversations

All-remote companies are uniquely positioned to break down silos. Group Conversations allow members of any function to dive in and ask questions of a function outside of their own. Also, it gives members of one function the ability to ask questions of their own function.

Learn more about [Group Conversations in GitLab's Handbook](/handbook/company/group-conversations/).

{{< youtube "MN3mzvbgwuc" >}}

*In the [video](https://www.youtube.com/watch?v=MN3mzvbgwuc) above, published on the [GitLab YouTube channel](https://www.youtube.com/channel/UCnMGQ8QHMAnVIsI3xJrihhg), GitLab co-founder and CEO Sid Sijbrandij leads a Functional Group Update Training.*

More Group Conversations are listed below.

1. [Infrastructure Group Conversation](https://www.youtube.com/watch?v=CrHpG-dt9yk)
1. [Growth Group Conversation](https://youtu.be/Sd21OgztLws?t=104)
1. [Meltano Group Conversation](https://www.youtube.com/watch?v=O93MoxmmjZw)
1. [Plan Group Conversation](https://www.youtube.com/watch?v=k43fHWKmax0)

### Key Monthly Reviews

Learning and development occurs more naturally when team members are well-informed. If there are knowledge gaps in the company strategy, it's difficult to apply new learnings. Particularly in all-remote settings, it's important to make OKRs ([Objectives and Key Results](/handbook/company/okrs)) visible across the company.

This allows team members to educate themselves on what matters to each functional group, enabling new learnings to map to something tangible in their day-to-day work.

Learn more about [GitLab's OKRs](/handbook/company/okrs).

{{< youtube "FXpBol1TwiI" >}}

*In the [video](https://youtu.be/FXpBol1TwiI) above, published on the [GitLab Unfiltered YouTube channel](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A), members of GitLab's marketing team discuss a plan to operationalize marketing metrics for use in KPI and OKR presentations.*

For each GitLab executive, we hold a monthly call to discuss Key Performance Indicators (KPI) and Objectives and Key Results (OKR). This goes well beyond the usual scope of learning and development by providing on-the-job education on metrics that impact various parts of the company. Said another way, learning and development has greater impact when it's mapped to something tangible.

Learn more about [GitLab's Key Reviews](/handbook/company/key-review/).

{{% include "includes/is_this_advice_any_good_remote.md" %}}

## Contribute your lessons

GitLab believes that all-remote is the [future of work]({{< ref "remote-vision" >}}), and remote companies have a shared responsibility to show the way for other organizations who are embracing it. If you or your company has an experience that would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests) and adding a contribution to this page.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
