---
title: "GitLab Meeting Best Practices: Live Doc Meetings"
description: Overview of GitLab's meeting best practices, which create efficient, transparent, documentation-based meetings
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

![GitLab collaboration](/images/all-remote/gitlab-collaboration.jpg)
{style="width: 50%;"}

On this page, we're detailing how to create efficient, transparent, documentation-based meetings leveraging GitLab's proven principles. This style of meeting increases cohesion, discipline, and transparency regardless of the work environment.

## GitLab meeting best practices

![GitLab all-remote mentor](/images/all-remote/ceo-shadow-gitlab-awesomeness.jpg)
{style="width: 50%;"}

"[No agenda, no attenda](/handbook/communication/#external-communication)." Every work-related meeting should have a [live doc agenda](https://docs.google.com/document/d/1eH-adpjfyo_RnlfbPvJ3i0e1Qb-aVoNc4yajnkZgJcU/edit#heading=h.6upuyp25d0wm) affixed to the calendar invite. To better understand how GitLab utilizes agenda docs, here's a [templated example](https://docs.google.com/document/d/1eH-adpjfyo_RnlfbPvJ3i0e1Qb-aVoNc4yajnkZgJcU/edit#heading=h.6upuyp25d0wm) you can copy and use in your organization. [Coffee chats](informal-communication/#coffee-chats) are excluded from this given their function in informal communication.

If you determine that a meeting is needed to move a project forward, address a blocker, or resolve a miscommunication, follow the proven principles below.

### Agenda and sharing

1. Create the agenda in a Google Doc ahead of time using [GitLab's Agenda Template](https://docs.google.com/document/d/1eH-adpjfyo_RnlfbPvJ3i0e1Qb-aVoNc4yajnkZgJcU/edit#heading=h.6upuyp25d0wm) (this can be any shared document service, though GitLab uses [Google Workspace](https://workspace.google.com)). Please do not use [Google Calendar's automatic agenda/notes creation function](https://workspaceupdates.googleblog.com/2021/10/create-meeting-notes-in-google-calendar.html), as it does not adhere to GitLab's preferred agenda flow. If the automatic agenda doc has been created in error, edit the calendar invite and hover over the X to delete it from the agenda to avoid confusion.
1. Ensure that the appropriate sharing settings are in place to prevent a chorus of "I can't access the agenda" comments; agendas should be editable by all participants.
1. Link the agenda in the meeting invite.
1. Establish the agenda as far in advance of the meeting as possible.
1. Agendas should use [numbered lists](/handbook/communication/#writing-style-guidelines), not bulleted lists.
1. `Context` section includes: The goal(s) of the meeting; clear pre-work or pre-watch/read instructions; intent and expected outcomes using [low-context communication](effective-communication/).

### Pre-work and meeting kick-off

1. Pre-read/watch or pre-work materials should be emailed to attendees at least 24 hours in advance.
1. The meeting host ([DRI]({{< ref "directly-responsible-individuals" >}})) may summarize key points and context for the first 1 to 2 minutes of the meeting, but [few meetings should be presentations](/handbook/communication/#few-meetings-with-presentations).
1. Questions should be [written](/handbook/values/#write-things-down) and listed in advance of the scheduled meeting time; this tends to increase the quality of questions.

### Note taking and structure during the meeting

1. [Make a proposal](/handbook/values#make-a-proposal) whenever feasible. It should be possible to answer/comment with a simple "yes."
1. Link any relevant piece of text to associated resources to prevent people from spending time searching or asking.
1. Follow GitLab's [smart note taking guidance](/handbook/communication/#smart-note-taking-in-meetings) by taking notes inline with the agenda rather than using a separate "notes" section. Real-time note-taking by multiple participants is encouraged.
   - Another good reference is the CEO Shadow [handbook page tips section](/handbook/ceo/shadow/#taking-notes:~:text=in%20a%20meeting.-,Tips,-%3A), specifically `It's helpful if shadow one takes notes as the first speaker is talking, then shadow two starts when the next speaker continues the conversation. Shadow one can pick up note taking again when the next speaker contributes. By alternating this way, the shadows are better able to keep up with all the participants in the conversation.` This advice can be used in general meetings as well.
1. If you're not talking in the meeting, at any given time, help take notes. If there isn't a note taker listed in the document at the start of the meeting, people should self-note-take. Consider asking other people to write down the answers in real-time to allow the person who asked the question to focus on the answer. The person asking the question can touch up the answer when the conversation has moved on to something less relevant to them.
1. Notes should be properly indented and structured to follow the conversation's flow.
1. Notes do not have to be verbatim, but they should capture key points made and be clear on any decisions or next steps.
1. Preface questions and answers with the participant's name, giving context to the origin.

### Inclusion and transparency in meetings

1. Follow the order of the questions instead of jumping around in the agenda; this prevents the proverbial loudest voice in the room from dominating a conversation.
1. Always ask if the name preceding the question would like to verbalize; if they wish not to, or are otherwise unavailable, the meeting host should verbalize on their behalf.
1. Reenact questions in the list by verbalizing them even if they were already asked and answered in the shared document. Hearing the question and answer allows everyone to think about it and respond to it. It might also happen that when verbalizing the question or answer more context is given since most people can talk faster and with less effort than they can type. Another advantage if you're recording the meeting is that the recording contains everything.
1. Unless the meeting contains [Not Public]({{< ref "confidentiality-levels#not-public" >}}) information, record the meeting to share with those who cannot attend live and consider livestreaming for maximum transparency and feedback potential.
1. If a portion of a meeting does not pertain to you, [it's OK to look away](meetings/#9-its-ok-to-look-away). You are the [manager of your own time and attention](/handbook/leadership#managers-of-one).

## Q: What are the benefits of live doc meetings?

![GitLab collaboration illustration](/images/all-remote/gitlab-collaboration-illustration.jpg)
{style="max-width: 50%"}

Establishing a culture where team members are cognizant that they work with others who may be in a different location, or unable to attend a meeting live, is critical. Documentation is a vital part of avoiding team [dysfunction](/handbook/values/#five-dysfunctions).

Improving your meeting hygiene can start by shifting to live doc meetings. It is a relatively simple step, and tends to create an understanding of the value of documentation. If you're looking for a place to start in capturing team-wide buy-in on documentation, consider adding agendas to all work-related meetings and insist on live documentation during them.

1. It prevents [knowledge leaks](effective-communication/#why-text-communication-is-important-for-successful-remote-working). Meetings without agendas are only useful to those in it, and even then, it's likely that outcomes will be forgotten, or critical pieces of the puzzle will become less familiar over time.
1. It creates a more [inclusive]({{< ref "building-diversity-and-inclusion" >}}) meeting atmosphere. People can add questions and insights before (and even after) a synchronous meeting. Plus, those who are less comfortable verbalizing points in front of management can use the agenda doc to properly articulate their complete thoughts.
1. It creates a takeaway. The agenda doc lives longer after the meeting. If you want to share it further, perhaps sending to a person or team that you realize would have benefited from attending, you're able to do so.
1. It shifts the memorization burden away from humans. If there's an agenda doc affixed to each calendar invite, you can easily search your calendar for key words (marketing, CEO, engineering, etc.), find a given meeting, and immediately access a documented history of what was discussed.

## Q: When should I use a meeting over async?

Not all meetings are inherently bad. We encourage managers to establish [regular 1:1 meetings]({{< ref "1-1" >}}) with their team, for example. There are instances where a brief synchronous chat can replace multiple hours of asynchronous work. Strategically leveraging sync and async is an art, not a science.

Many meetings can be avoided by understanding how to [work well asynchronously](asynchronous/).

For a deeper dive on how GitLab implements meetings in a remote work environment, visit our [all-remote meetings guide](meetings/). To learn more about how GitLab communications, visit our [Communications page]({{< ref "communication" >}}).

## Q: What is a live doc meeting?

A live doc meeting is a GitLab specialty. It's a work-related meeting (e.g. not a [coffee chat](informal-communication/#coffee-chats)) where you document everything live (yes, everything)! Start documenting before the meetings begins by attaching a shared, editable agenda document to the calendar invite.

## Q: What is the agenda for a live doc meeting?

Here is a [sample template for a live doc meeting](https://docs.google.com/document/d/1eH-adpjfyo_RnlfbPvJ3i0e1Qb-aVoNc4yajnkZgJcU/edit?usp=sharing). Be sure to create a new Google Doc and attach a link to your live doc with every calendar invite. Please do not use [Google Calendar's automatic agenda/notes creation function](https://workspaceupdates.googleblog.com/2021/10/create-meeting-notes-in-google-calendar.html), as it does not adhere to GitLab's preferred agenda flow. Include the [agenda](https://docs.google.com/document/d/1eH-adpjfyo_RnlfbPvJ3i0e1Qb-aVoNc4yajnkZgJcU/edit#heading=h.6upuyp25d0wm) for the meeting, set the appropriate sharing permissions, and add instructions for expected engagement (in `Context` section) so team members understand how to contribute whether they attend synchronously or asynchronously.

## Q: What is meant by 'live document'?

A live document is a document that may continually be edited and updated. Examples could include a shared Google doc, whiteboard being used by a team for collaboration, or [GitLab's handbook](/handbook).

## Q: How can I participate in a live doc meeting?

There are two ways to participate in a live doc meeting: either synchronously, like when [joining a live Zoom call](/handbook/communication/#video-calls), or [asynchronously](asynchronous/), by reviewing the documented discussion along with any recorded video after the meeting is over.

## Q: When are live doc meetings held?

Live doc meetings are usually held in the host's time zone. However, leaders should [rotate meetings to accommodate a more diverse array of time zones](asynchronous/#remove-time-zone-bias) as well as record them so that others can watch at a later time.

## Q: Where are live doc meetings held?

Live doc meetings can happen fully in-person, fully online, or a on hybrid call — which is a blend of both. It's best to have everyone on a level playing field for communication and discussion, so [hybrid calls should be avoided](meetings/#avoid-hybrid-calls). If a hybrid call is necessary, have participants use their own equipment (camera, headset, screen) to avoid audio problems from delays and feedback.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
