---
title: "All-Remote Management"
description: How to manage a remote company
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

On this page, we're detailing what it takes to effectively and efficiently manage an all-remote company.

## What is all-remote management?

The pillars of [managing an all-remote company]({{< ref "being-a-great-remote-manager" >}}) are similar to managing any company, but there are certain areas where all-remote leaders need to pay particular attention.

## How do you manage a 100% remote team?

In [this video](https://youtu.be/IFBj9KQSQXA), GitLab co-founder and CEO Sid Sijbrandij and InVision Chief People Officer Mark Frein discuss the future of remote work, including managing all-remote teams at scale.

"How do you manage when everyone is remote?" is a common question for those leading or managing within an all-remote company.

In truth, managing an all-remote company is much like managing any other company. **It comes down to trust, communication, and company-wide support of shared goals**, all of which aid in [avoiding dysfunction](/handbook/values/#five-dysfunctions).

Remote forces you to do the things you should be doing [way earlier and better](https://nohq.co/blog/sid-sijbrandij-people-dont-want-to-commute-they-ju). It forces discipline that sustains culture and efficiency [at scale](scaling/), particularly in areas which are easily deprioritized in small colocated companies.

It's important to not assume that team members understand good remote work practices. GitLab managers are [expected]({{< ref "structure#management-group" >}}) to coach their reports to utilize [asynchronous communication](management/#asynchronous), be [handbook-first](/handbook/about/handbook-usage/#why-handbook-first), design an [optimal workspace](workspace/), and understand the importance of [self-learning/self-service](self-service/).

## Get certified in remote management

GitLab has partnered with Coursera to produce a ten-hour course, **[How to Manage a Remote Team](https://www.coursera.org/learn/remote-team-management)**. Join tens of thousands of enrollees and complete the course with a certificate in managing a remote team.

## What are the benefits of all-remote management?

### Work from anywhere

At GitLab, when we say our people can work from [anywhere](people/#travelers), we really mean it. We care about the [results](/handbook/values/#results) of their work, not where it's getting done.

This flexibility often means something different for [each person at GitLab](people/). We have team members who are completely [location independent](people/#nomads) and [travel full time](https://about.gitlab.com/blog/2019/06/25/how-remote-work-at-gitlab-enables-location-independence).

There are others who join and travel the world with remote co-working and co-living [organizations](resources/#organizations-for-traveling-remote-work).
Many of our team members appreciate the ability to still be able to work while visiting friends or family away from home.

Even for those who typically work in their home office, this [flexibility](people/#those-who-value-flexibility-and-autonomy) means they can do things like run errands on a weekday, take their child to school, spend more time with family, or walk their dog during the day.

We have a channel on Slack called `#office-today` where our team members can share photos of their work location or view on any given day.

### Time away from work

It's important to clarify that being able to work from anywhere does **not** replace the need to take time off of work.

We recognize how crucial it is to build in time where you can mentally take a break from your work, and as a company, we encourage our team members to do that. Learn more about [how time off works at GitLab.]({{< ref "paid-time-off" >}})

> **"I work closely with our executive team here, and they have been so supportive and encouraging when family-related conflicts arise. They are constantly reminding me that "family first" is our mantra, and give me ease of mind to take time away when needed. Sid, our co-founder and CEO, told me if it's a beautiful day out and I just want to go enjoy it, I should do that. Moments like these make me so proud to be a part of the GitLab team."**
> [*- Cheri, Chief of Staff*](/handbook/company/team#cheriholmes)

### Dedicate time for health and fitness

It's sometimes hard to remember to stay active when you work from home. If you're an employer, it's important to be intentional about modeling self-care and overall wellness habits. Here are some tips that might help:

1. Try to step away from your computer and stretch your body every hour.
1. If possible, choose a [workspace](workspace/) that's exposed to [natural light](https://www.makegreatlight.com/wp-content/uploads/Health_Benefits_Natural_Light.pdf).
1. Avoid "Digital Eye Strain" by following the [20-20-20 Rule](https://www.healthline.com/health/eye-health/20-20-20-rule#definition). Every 20 minutes look into the distance (at least 20 feet/6 meters) for 20 seconds.
1. Schedule physical time on your calendar

   - Go for a walk or do a short exercise for at least 15 minutes a day. Model this practice for your team by adding it to your calendar.

   > **"Getting out of the house before I start my day is very important for me.
   > Either walking the dog or going for a swim to clear my head and get the blood flowing."**
   > [- *Daniel G., Product Manager*](/handbook/company/team#danielgruesso)

## What are the challenges of all-remote management?

We've done a deep dive on the most common [drawbacks to all-remote working here](drawbacks/#remote-work-challenges-and-solutions-for-employees). The reality is that all-remote working isn't for everyone. Most challenges can be overcome with a little creativity and flexibility.

For example, all-remote companies that have colleagues spread out across time zones will encounter scenarios where one has to [compromise](drawbacks/) in order to be online at the same time for critical calls, meetings, or projects. However, there is great freedom in being able to disconnect from work at an appointed time with the understanding that your colleagues will communicate asynchronously rather than pressuring you to be available outside of your work hours.

As documented in the [Communication section of GitLab's Handbook]({{< ref "communication" >}}), there are limits to asynchronous communication. When we go **back and forth three times,** we jump on a [synchronous video call](/handbook/communication/#video-calls).

## Remote management tools

Similar to managing employees in-person, a remote manager must use their leadership skills to create communication, systems, and workflows that sets up their remote employees for success.

## Embracing total transparency

{{< youtube "-XBIIY2pFpc?start=33" >}}

*In the [video](https://youtu.be/-XBIIY2pFpc) above, published to [GitLab's YouTube channel](https://www.youtube.com/channel/UCnMGQ8QHMAnVIsI3xJrihhg), support engineering manager Lee M. explains how all-remote enables DevOps and how transparency plays a key role in a team's success.*

Transparency is a term that is often tossed around as a value within most companies. In all-remote environments, it is vital that transparency be more than a buzzword, but something that is embraced and allowed to guide every decision.

This will often feel unnatural and uncomfortable — a sign that your organization truly is living out the [value of transparency](/handbook/values/#transparency).

It helps to recognize all-remote organizations not as a collection of rigidly structured machines, but as a living, evolving organism. Leaders must trust their colleagues to operate with empathy, kindness, and concern for the well-being of one another, seeing the free flow of information as universally beneficial.

Learn more on how GitLab [defines and implements transparency in our Handbook](/handbook/values/#transparency).

## Managing time zones in a remote team

The ideal way to think about time zones in a remote team is to assume every team member is in a vastly different time zone, even if they aren't (yet). As you scale a team, it becomes increasingly possible that a manager and direct report, for example, could be on opposite sides of the world and will need to foster a functioning working relationship.

Remember that someone's home time zone will not necessarily represent their day-to-day time zone. Plus, someone working in a given time zone may prefer to work a [nonlinear workday](non-linear-workday/). Time zones are only one element which impacts when a team member works. Optimizing for nearness in time zones creates a business continuity risk; proactive communication about one's time zone and associated work expectations are critical.

Practically, the following should be considered.

1. Leaders should proactively optimize as many workflows as possible for [asynchronous](asynchronous/). This enables people to work when they are [most productive]({{< ref "leadership#managers-of-one" >}}), fosters a culture of [rich documentation](handbook-first/), and creates a more [inclusive work environment](/handbook/values/#bias-towards-asynchronous-communication).
1. Attempt to align on a time, or a rotation of times, where the manager and direct report can be online at the same time for a regular [1-1]({{< ref "1-1" >}}). If this pulls one person or the other into non-working hours, consider rotating times so the burden is equally shared.
1. Document what success looks like using [Objectives and Key Results (OKRs)](/handbook/company/okrs). This should be conveyed plainly and mutually agreed upon.
1. Foster community and mentorship with like time zones. E.g. If a manager gains a new direct report with a sizable time zone gap, ask others in the organization — even if they are not in the same department — who are more aligned with the time zone to include this person in their social activities.
1. Lean on documentation. Place importance on using [low-context communication](effective-communication/) in 1-1 documents, GitLab issues/merge requests, etc.
1. Consider using tools like [Yac](https://yac.com) and [Loom](https://www.loom.com) to convey thoughts and feedback with video and audio if the written word feels too impersonal. [Managers]({{< ref "being-a-great-remote-manager" >}}) should flex to the preferred medium and style of their direct report, and encourage open conversation to iterate on this as the relationship develops.
1. Meet in-person. When possible (e.g. at onsite [GitLab Contribute](/handbook/company/culture/summit/) gatherings), prioritize spending [in-person time](in-person/) with those who have little overlap in virtual working hours. These opportunities may arise at company retreats, events, and through serendipity in personal travel.
1. Celebrate [differences](/handbook/values/#quirkiness). For example, working with someone experiencing summer while you experience winter is remarkable. Lifestyle differences are an opportunity to learn and expand one's worldview, and this includes time zone differences.

You can also learn from the experiences of GitLab team members collected in [this survey from late 2021](https://gitlab.com/gitlab-com/www-gitlab-com/-/issues/12740).

## Handbook, goals, and documentation

{{< youtube "_HhlqwJsNyM" >}}

*In the [GitLab Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A) video above, Darren (GitLab) and Anna-Karin (Because Mondays) discuss a number of challenges and solutions related to remote work, transitioning a company to remote, working asynchronously, and defaulting to documentation.*

Remote work is what led to the development of our publicly viewable [handbook](/handbook), which captures everything you'd need to know about the company. If you can't tell, we like [efficiency](/handbook/values/#efficiency) and don't like having to explain things twice.

Each department and team's quarterly goals, or ["objectives and key results" (OKRs)](/handbook/company/okrs), are also clearly documented in our handbook for visibility across the company. We check in on these goals monthly, so there's as much transparency as possible around what each team is accomplishing.

Our approach to [documentation](/handbook/product/ux/technical-writing/documentation/) also helps with [onboarding new team members](learning-and-development/), because everything they need to know is in one place.

We also have an extensive [onboarding template](https://gitlab.com/gitlab-com/people-group/employment-templates/-/blob/main/.gitlab/issue_templates/onboarding.md) and we host a [GitLab 101](/handbook/company/culture/gitlab-101) for new hires to ask questions.

### Using GitLab for remote collaboration

GitLab relies on GitLab to build, sustain, and evolve its company handbook. GitLab is a collaboration tool designed to help people work better together whether they are in the same location or spread across multiple time zones. Originally, GitLab let software developers collaborate on writing code and packaging it up into software applications. Today, GitLab has a wide range of capabilities used by people around the globe in all kinds of companies and roles.

You can learn more at GitLab's [remote team solutions page]({{< ref "gitlab-for-remote" >}}).

### Docs instead of whiteboards

We're often asked, "But how do you whiteboard without everyone physically together?" We use Google Docs for collaboration. Every [meeting](meetings/) has a Google Doc agenda, which is used for documenting discussions, decisions, and actions. Everyone in the meeting can add notes at the same time, and we even finish each other's sentences sometimes.

By brainstorming in text instead of drawings, we're forced to clearly articulate proposals, designs, and ideas, with less variance in interpretations. A picture may be worth a thousand words, but it's also open to as many interpretations as there are people viewing it.  This breaks down silos by having information easily accessible and allows for team members to work together quickly to achieve our shared goals.

With Google Docs, we use indentations to go more in-depth on a given topic. This method retains context for comments, discussions, and ideas, even if someone wasn't present for the original conversation.

### Docs instead of water coolers

Documentation also helps with transparency, which is critical to remote work. While decisions made around office water coolers may be familiar in traditional workplaces, input is limited to those present.
Those who are not present feel left out, and you're missing an opportunity to hear different perspectives.

The GitLab way of working is more [inclusive]({{< ref "inclusion#fully-distributed-and-completely-connected" >}}). By documenting everything, no one is left out of the conversation and a diverse set of perspectives can be heard, not only from GitLab team members but also from customers and community contributors.

## Scaling by documenting

{{< youtube "2g-XmZeB2qk?start=853" >}}

*In the [interview](https://youtu.be/2g-XmZeB2qk) above between GitLab co-founder and CEO Sid Sijbrandij and [The New Stack](https://thenewstack.io)'s Alex Williams, Sid explains the importance of "handbook first" when it comes to maintaining velocity and [efficiency](/handbook/values/#efficiency) in scaling a team.*

> Because we're all-remote, we've been forced to adopt a lot of best practices early on. It scales a lot better. If you're colocated and on the same floor, that works well. If you're on multiple floors in the same building, that starts to deteriorate a bit. If you're in multiple buildings in the same city, that gets worse. If you're in multiple cities, it's harder, and if you're in multiple countries, it starts to break down. It's how most companies work, and that's one of the reasons why companies are really hard to scale.
>
> We never scaled by doing that. We always scaled by writing things down and recording things. As we grow bigger, it's paying off.
>
> At GitLab, we have a rule that says [handbook first]({{< ref "handbook-usage#why-handbook-first" >}}). If you're going to communicate a change to people, first put it in the handbook and then communicate that change to people.
>
> Our handbook has [grown to over 3,000 pages](/handbook/about#count-handbook-pages) — it's impossible to read all of it — but you're going to read the sections that are relevant to the job that you have to do. We encourage people to record things and share things. We're continuously trying to move conversations out of Slack and into [GitLab Issues](https://docs.gitlab.com/ee/user/project/issues) where everyone can see them. We encourage people to stream to YouTube on [GitLab Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A). - *GitLab co-founder and CEO Sid Sijbrandij*

This is one of the harder things to apply on a daily basis. Taking the time to document a solution isn't very satisfying in the moment, and is easy to deprioritize when other seemingly urgent tasks are vying for your attention.

To relieve tension, empower DRIs to make decisions, and create a more productive future for a team, it's vital to place a high degree of value on pausing to document. This requires leadership to praise and reward the act of documenting, measuring these contributions as diligently as one would measure sales or conversions.

This applies to all companies, though it can produce [outsized gains](scaling/) in all-remote organizations where there are fewer opportunities for information to be shared in a physical space.

This also requires humility, and a recognition that human memories aren't perfect. It's impossible to predict the future, but documenting a solution as soon as it is discovered guarantees that the answer will be available should it ever be needed later.

## Asynchronous

![GitLab customer illustration](/images/all-remote/gitlab-customer-path.jpg)
{style="max-width: 50%"}

When you [open your talent acquisition pipeline to the world](hiring/), you create an opportunity to hire people in an array of time zones. The ability to hand projects off across time zones is a [competitive advantage]({{< ref "remote-benefits" >}}), but minimizing disconnects, frustrations, and awkwardly-timed meetings requires an intentional approach.

### Active reinforcement

The first step in creating an atmosphere where colleagues are comfortable working [asynchronously](asynchronous/) is to avoid the default mentality as it applies to [meetings](meetings/). By making meetings [optional](meetings/#make-meetings-optional), recording and [documenting everything](meetings/#document-everything-live-yes-everything), being diligent to follow an [agenda](meetings/#have-an-agenda), and leveraging tools like [GitLab Issues](https://docs.gitlab.com/ee/user/project/issues) and Slack, all-remote companies are less reliant on colleagues being online at the same time.

This mentality must be actively reinforced. For example, in [team social calls](informal-communication/#team-social-calls) where dozens of people join a video chat to bond as a team, an agenda allows those who cannot make it to add [shout-outs](/handbook/values/#say-thanks) or discussion points that a fellow colleague can verbalize. This is an intentional approach to not only working asynchronously, but socializing asynchronously.

[Leonardo Federico](https://twitter.com/leonardofed), co-founder at [Sametab](https://www.sametab.com), offers an interesting perspective on asynchronous communication, noting that it [provides more optionality](https://www.sametab.com/blog/frameworks-for-remote-working).

> [Asynchronous] allows you to reorganize the company in a divisional organization more easily and embrace remote working even if you're colocated. Everything that works in an async fashion can also work sync but not vice-versa.

### Benefits for morale, well-being, and lowering stress

{{< youtube "cy6WGuzArgY?start=2018" >}}

*Emna G., founder and CEO at Veamly and GitLab's [Darren M.](https://twitter.com/darrenmurph) discuss why asynchronous is the future.*

>Asynchronous versus synchronous is traditionally seen as a process choice. What we've found at GitLab is that it's also a cultural element.
>
>Being fully committed to asynchronous communication can improve morale and well-being. If you operate with a mindset of having no other colleagues online at the same time, it forces you to encapsulate your work on a project in a way that can be ingested by others at a time convenient to them. This not only improves documentation, but it relieves everyone of the burdens associated with needing to be at work at the same time.
>
>When you approach your work in this manner, it's less chaotic. The sense of urgency is not on rushing something out, but on the thoroughness and thoughtfulness in documentation. — *[Darren M., GitLab](https://twitter.com/darrenmurph)*

There are considerations that go beyond productivity metrics. Companies should ask if demanding synchronous communication is impacting their team's ability to reason and process challenges in the most efficient and healthy way.

> With synchronous communication, the problem is that it creates a fake sense of emergency. It creates a heavy interruptive environment with a lot of context switching. You end up highly stressed all the time.
>
> We don't realize it because we, as a society, are so used to our stress. We live with it, and we don't even know what a life without bad stress is. By removing that interruptive effect [with asynchronous communication], that's how we go into the future.
>
> We cannot sustain, as a humanity, this way of life. We cannot keep up with it. — *Emna G., founder and CEO at Veamly*

Asynchronous communication alone will not solve [challenges associated with remote work](drawbacks/#for-employees), but it is a useful tool in a wider arsenal of tactics to avoid issues such as [burnout](https://about.gitlab.com/blog/2018/03/08/preventing-burnout).

### Time and productivity

When referencing time and productivity, Remote CTO Marcelo Lebre shares a potent thought on asynchronous communication in a [relevant blog post](https://remote.com/blog/why-you-should-be-doing-async-work).

> Async communication shines with great power here, as it shields everyone's time and focus while reducing meaningless time sinks. When you're communicating async, this types of interruptions happen much less. And the total time that you're able to do deep work is longer, the chance of achieving Flow much higher.

Learn more about GitLab's approach to asynchronous working by viewing our [Efficiency](/handbook/values/#efficiency) and [Collaboration](/handbook/values/#collaboration) values.

## Separating decision gathering from decision making

![GitLab collaboration illustration](/images/all-remote/gitlab-collaboration.jpg)
{style="max-width: 50%"}

Paralysis by analysis is something all companies should seek to avoid. In managing through this at an all-remote company, leaders should ensure that all colleagues understand that consensus doesn't scale.

Thus, there should be [no goal to achieve consensus](/handbook). This may feel awkward or unnatural to those coming from colocated corporate environments, but trusting decision makers and living out [the value of iteration](/handbook/values/#iteration) prevents unnecessary slowdowns in your organization.

By intentionally separating the process of decision *gathering* and decision *making*, you provide ample opportunity for everyone to add input, offering up fresh angles for consideration that may well sway the mind of the DRI ([directly responsible individual]({{< ref "directly-responsible-individuals" >}})).

It is vital for all-remote companies to foster an atmosphere of [trust and learning](/handbook/values/#five-dysfunctions), such that grudges are not held against decision makers after decision gathering has occurred. At GitLab, this is manifested in our [Collaboration](/handbook/values/#collaboration) value, which includes kindness, sharing, [short toes](/handbook/values/#short-toes), no ego, and assuming positive intent.

## Applying iteration to everything

{{< youtube "T4fQp9jtKWU" >}}

*In the [video](https://www.youtube.com/watch?v=T4fQp9jtKWU) above, published on the [GitLab Unfiltered YouTube channel](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A), Emilie Schario, Data Analyst, and Sid Sijbrandij, co-founder and CEO, discuss the best way to organize the Metrics pages in the company Handbook.*

Iteration is oft applied to engineering, but asking only part of the company to iterate can create [discord](/handbook/values/#five-dysfunctions). All-remote companies must empower every member of the team, across every function and job level, to approach their work with an [iterative mindset](/handbook/values/#iteration).

By applying [iteration](/handbook/values/#iteration) to everything, it removes the barrier of fear and judgement. It also enables faster cycles, and it makes miscues far less damaging.

For example, don't write a large plan, only write the first step. Trust that you'll know better how to proceed after something is released. Iteration can be uncomfortable, even painful. If you're doing iteration correctly, it should be.

Instilling this in an all-remote team is difficult. Most people are naturally inclined to only showcase polished work. In turn, managing this aspect of an all-remote team requires reminders that it's *preferred* to share unfinished work.

Leaders should work diligently to ensure that teams have a low level of shame and believe that everything is in draft and subject to change.

Learn more about [GitLab's value of iteration in our Handbook](/handbook/values/#iteration), and read how [one team used survey results to iterate on culture](https://about.gitlab.com/blog/2018/06/26/iterating-improving-frontend-culture).

## Company-wide organizational chart

There are no corner offices in an all-remote company. Although you should consider the organizational structure that makes the most sense for you (and [iterate](/handbook/values/#iteration) as the company evolves), one thing that should not change is the level of transparency.

To give each member of the company an equal view of how the organization is structured, how job levels/families are established, and what reporting structures look like, it's wise to consider an org chart accessible to all team members.

This removes ambiguity and enables clearer lines of communication.

We invite other all-remote companies to mirror GitLab's approach to publishing its [team structure](/handbook/company/structure/).

## Avoiding dotted lines and matrix organization

{{< youtube "tSp5se9BudA" >}}

*In the [video](https://www.youtube.com/watch?v=tSp5se9BudA) above, published on [GitLab's YouTube channel](https://www.youtube.com/channel/UCnMGQ8QHMAnVIsI3xJrihhg), GitLab co-founder and CEO Sid Sijbrandij and [Arch Systems](https://archsystemsinc.com) CEO Andrew Scheuermann discuss structure within distributed companies.*

In all-remote companies, it is easy to fall into a situation where you work with a day-to-day lead but report to someone else. There are no physical office structures to reinforce reporting structures.

Leaders in an all-remote company must work to avoid dotted lines and matrix organization. Everyone should report to exactly one person, and that person should understand your day-to-day tasks and be well-positioned to assist you in removing obstacles to thriving in your role.

Whenever there is need to work on a specific, high-level, cross functional business problem, a [working group](/handbook/company/working-groups) should be established for that need.

Learn more about GitLab's approach in the [Leadership section of our Handbook]({{< ref "leadership#no-matrix-organization" >}}).

## Focusing on results

{{< youtube "6QC1OwoddD8" >}}

*In the [video](https://www.youtube.com/watch?v=6QC1OwoddD8) above, published to [GitLab's YouTube channel](https://www.youtube.com/channel/UCnMGQ8QHMAnVIsI3xJrihhg), members of the engineering team demonstrate a focus on metrics.*

Perhaps the easiest way to avoid overanalyzing management in an all-remote company is to focus on [results](/handbook/values/#results). Focusing on results over hours worked creates an atmosphere where colleagues direct effort on the [right things](https://about.gitlab.com/blog/2018/09/07/mvcs-with-big-results) — shipping [great code](https://about.gitlab.com/blog/2019/03/20/enabling-global-search-elasticsearch-gitlab-com), making a client happy, solving a teammate's problem, etc.

This enables team members to complete their work and turn their attention to non-work activities (family, exercise, reading, caregiving, philanthropy, etc.) as quickly as possible.

By focusing on results, each team member has less of a mental burden to carry. They're aware that results are what matter as opposed to items like [personal success, status, and ego](/handbook/values/#five-dysfunctions).

Learn more on GitLab's [Results value in our Handbook](/handbook/values/#results).

### Objectives and Key Results (OKRs)

All-remote companies should go beyond striving for results. They should add as much detail and clarity as possible to what those results are, and what is measured along the way.

This can be achieved by implementing Objectives and Key Results (OKRs), a widely used framework for setting strategy and removing ambiguity over what matters.

Learn more about [GitLab's implementation of OKRs](/handbook/company/okrs).

### Key Performance Indicators (KPIs)

Managing results requires clear communication of what's being measured. KPIs strip away guesswork and allow global teams to look at uniform data for making decisions.

It's vital that all-remote companies make KPIs available to all. This not only helps each team member focus their efforts on driving results that move needles that matter, but it creates empathy.

Although KPIs are emotionless, allowing teams to understand what other teams are working towards creates an atmosphere of compassion, and enables team members to more easily offer help that is specific to an indicator.

Learn more about [KPIs at GitLab](/handbook/company/kpis/).

## Encourage flexibility and balance

![GitLab values illustration](/images/all-remote/gitlab-values-tanukis.jpg)
{style="max-width: 50%;}

In a conversation with GitLab's Head of Remote about company values, community contributor [JD Lewin](https://gitlab.com/jd_lewin) suggested that much of what leaders concern themselves with (surrounding management) can be addressed by creating a respectful work atmosphere.

When considering a new employer, he noticed that many conversations focused on *the work* rather than *the environment*. His articulation of this was powerful, and is transcribed with permission below.

> It's not about what the work is. I ask this: "**Does the organization support and complement what the rest of my life consists of? Does going to work each day snap into what the rest of my life is?**"
>
> For example: being a dad in the early 21st century means you need to show up in your child's life. I need to know that I can step away from my work in the middle of the afternoon if that's what my family requires of me. The culture must support that. In turn, I'll want to work the rest of my life for an employer who creates such an atmosphere.
>
> Waking up and wanting to work each day is a function of the relationship between the people at a company.

## Getting started: the early days of remote management

Leaders should ensure that new remote hires read a [getting started guide](getting-started/), and make themselves available to answer questions throughout one's journey with the company.

Tomasz Tunguz describes it as such in an article entitled "[The early discipline of remote startups](https://tomtunguz.com/the-early-discipline-of-remote-startups)."

> As teams scale, they need to develop infrastructure to successfully manage and coordinate large numbers of people. But in the early days, by virtue of being close to each other physically, it's easier to delay some of these investments.
>
> A quick hallway meeting of a few key stakeholders might be all it takes to commit to a strategic change. A last-minute all hands roused through word-of-mouth may be the prelude to a fundraising announcement.
>
> For a business that exists somewhere on the distributed-to-remote continuum these options don't exist, or at least they are significantly harder. These kind of communications are just as necessary within remote or distributed teams, but they require more planning, more foresight in order to be successful.
>
> Some very early stage companies are bringing in these disciplines from the outset, because of the demands of remote work. And this is a wonderful thing, because this investment will compound over the life of the business. - *Tomasz Tunguz, venture capitalist at Redpoint Ventures*

## GitLab Knowledge Assessment: All-remote management

Anyone can test their knowledge on all-remote management by completing the [knowledge assessment](https://docs.google.com/forms/d/e/1FAIpQLSfJEDRSuyVQxRU-vnpTXpRHjCzd_jtqNcGElJ2KHalJgy7jHQ/viewform). Earn at least an 80% or higher on the assessment to receive a passing score. Once the quiz has been passed, you will receive an email acknowledging the completion from GitLab. We are in the process of designing a GitLab Remote Certification and completion of the assessment will be one requirement in obtaining the [certification](https://about.gitlab.com/learn/certifications/public). If you have questions, please reach out to our [Learning & Development team](/handbook/people-group/learning-and-development) at `learning@gitlab.com`.

{{% include "includes/is_this_advice_any_good_remote.md" %}}

## Contribute your lessons

GitLab believes that all-remote is the [future of work]({{< ref "remote-vision" >}}), and remote companies have a shared responsibility to show the way for other organizations who are embracing it. If you or your company has an experience that would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests) and adding a contribution to this page.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
