---
title: "All-Remote Meetings"
description: How to conduct meetings at GitLab
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

## How to run an effective meeting at GitLab

We're thoughtful about how we run meetings, because, when done right, they are forums to increase efficiency, enhance collaboration, and drive results. The guidelines below are intended to help you run a great meeting at GitLab!

### What to do before the meeting

1. **Ask yourself if the meeting is necessary.** Though we have a [bias toward asynchronous communication](asynchronous/), a strategic balance between synchronous and asynchronous communication is required to achieve maximum efficiency. Moving a project or discussion forward asynchronously when feasible is preferred if it can be done efficiently and achieve desired results. Before scheduling a meeting, ask yourself if asynchronous methods could be effectively used to achieve the desired outcome.
1. **Review participants time zones.** Though we have a [bias toward asynchronous communication](asynchronous/), when a meeting is determined to be necessary review all participants' time zones. Consider creating meetings that overlap between EMEA/APAC + APAC/AMER + AMER/EMEA.
1. **Ensure meeting DRI.** When creating meeting across time zones, nominate volunteers to host and facilitate those meetings in their working hours that align better with their time zones.
1. **Send the meeting invite with proper advance notice.**  A meeting with team members will usually traverse multiple time zones. We recommend you send meeting invites 72 hours (minimum 24 hours) in advance of the meeting to give people time to respond to the invite. In addition, consider who is required in the meeting and mark non-essential participants as optional.
1. **Include a link to an agenda document in the invite.** Team members should be able to get context before the meeting through reviewing agendas, supporting materials, etc. [Meeting agendas](meetings/#4-all-meetings-must-have-an-agenda) should be shared 72 hours (minimum 24 hours) in advance of the meeting. Team members will need to know what is being discussed to decide if their participation is needed or [whether their meeting attendance is optional](meetings/#1-make-meeting-attendance-optional).
1. **Provide slides and supporting videos in advance.** We [embrace Neurodiversity](/handbook/values/#embracing-neurodiversity) by adopting a variety of different work styles and communication styles. Providing multiple ways to consume information (written / video / audio) allows everyone to contribute independent of their preferred comprehension style.
1. **Use "speedy meetings."** This [Google Calendar setting](https://calendar.google.com/calendar/r/settings) creates meetings of 25 / 50 minute duration, which leaves time to write notes, stretch, etc. in between meetings.
1. **Use the Zoom scheduler plug-in to add video conferencing to your Google Calendar event.** Leveraging the Zoom plug-in automatically adds Zoom links to your event, and reduces the probability of user error in copying and pasting an incorrect video conferencing link.
1. **Check your audio quality.** [Research shows](https://app.sciencesays.com/p/good-sound-quality-smarter) that when the audio quality is high, people judge the content as better and more important. We recommend you [invest in equipment](workspace/#what-technology-do-i-need-for-remote-working) to generate the highest-fidelity audio in your remote work setting, such as using a microphone.

### What to do during the meeting

1. **Start on time.** It's important to [begin and end meetings on time](meetings/#3-start-on-time-end-on-time) in order to minimize disruption.
1. **Recording.** For group meetings where there are multiple time zones, consider recording the meeting to allow for async participation.
1. **Give audio and video feedback.** If you are unable to see or hear someone, let them know so they can address and correct.
1. **Name pronunciation.** Inline with our [values](/handbook/values/#learn-how-to-pronounce-other-peoples-names), consider these tips to ensure name pronunciation during the meeting:
   1. Ask all participants what is your preferred name or do you have a nickname? Example: "My name is pronounced….you can call me…."
   1. Introduce yourself, and mention your pronouns and pronunciation, and ask participants if they want to introduce themselves. Reminder that pronouns can be set in [applications we use for collaborating](/handbook/people-group/pronouns/#setting-your-pronouns-in-applications)
   1. Adding team members name pronunciation in agenda.
   1. If you are unsure, it is always okay to ask for a reminder on how to pronounce a team member's name.
   1. If your name is mispronounced, one can always say: "Thank you for attempting to pronounce my name, it's actually pronounced #{name}".
   1. Ensure your [Slack profile name pronunciation has been completed](../../../tools-and-tips/slack.md#profile).
   1. Consider adding a link to the pronunciation of your name to the agenda doc in the attendee section.
   1. Ensure your [Google profile name pronunciation has been completed](../../../tools-and-tips/_index.md#add-name-pronunciation-in-google).
1. **Avoid presenting in most meetings.** Valuable synchronous time should not be used to present in [most cases](/handbook/communication/#few-meetings-with-presentations). Instead, recorded presentations make content accessible, prevent confusion, and increase participation for team members that prefer consuming content asynchronously. It is OK to present spontaneously to share unplanned material during a meeting, but stop sharing once the point is made. This ensures that the video stream is preserved for team members to engage and interact with each other.
1. **Be intentional about introductions (or not).** Some meetings may benefit from introductions, so be intentional about either doing introductions or not. If you are going to do introductions, make sure participants are aware beforehand so they are prepared. Create a [list of people](/handbook/communication/#meeting-introduction-guidelines) with their roles, and use that for guiding the introduction sequence. Let each individual introduce themselves so that Zoom emphasizes the speaker's video stream.
1. **Provide verbal cues.** If you're going through an agenda document, then add context: "bullet 3c, Sam, you added that point, can you verbalize it for us?" Similarly use slide numbers when going through a presentation to ensure that all attendees are tracking on the content.
1. **Adhere to the agenda order to ensure inclusiveness.** People may add agenda topics to the agenda asynchronously and synchronously during the meeting. In guiding discussions, ensure that agenda topics discussed are equitable and fair - don't let a single person or subset of the group monopolize the agenda at the expense of others.
1. **Document in real-time.** Since not all team members will be able to attend a meeting live, documentation is a vital part of avoiding team dysfunction. Follow [Live Doc meeting best practices]({{< ref "live-doc-meetings" >}}) to increase cohesion, discipline, and transparency.
1. **End on time.**

### What to do after the meeting

1. **Capture action items from notes.** For an ongoing meeting series, GitLab has established [nomenclature]({{< ref "1-1" >}}) such as adding tags like "TODO" and "DONE" to track action items. You can also file issues in GitLab.com to track action items.
1. **Consider important decisions.**  When the meeting takes place outside of some participants' time zones, consider confirming decisions and actions for 24-48 hours. This will allow participants to contribute asynchronously.
1. **Upload recording.** When the meeting is recorded, add the recording link and password in the agenda with in 12 hours after the meeting to allow for async consumption for people in different time zones. Also consider uploading to YouTube if it can be done so consistent with SAFE guidelines.
1. **Assess and Iterate.** Once the meeting concludes, reflect on what worked, what didn't work, and what you need to do differently to run a more effective meeting. This process touches three of our CREDIT values: Iteration, Efficiency, and Results for Customers. By taking a small amount of time after a meeting to focus on continuous improvement, we can apply those improvements in future meetings. This drive for continuous improvement drives Efficiency, which is the foundation for Results.

## What is a remote meeting?

A remote meeting, also known as a virtual meeting, happens when people use video and audio to connect online.

## 10 ways to do all-remote meetings right

"How do you do meetings right?" is a common question asked of all-remote companies like GitLab. The following guide assumes you've already questioned whether the meeting should happen in the first place; if you haven't, start with GitLab's [guide to asynchronous workflows and communication](asynchronous/#question-every-meeting).

Much of the same advice for running a good in-person meeting applies to remote meetings, with a few notable distinctions.

{{% cardpane %}}
{{% card footer="If you have to have a meeting, at least make it fun!" %}}
![GitLab marketing team Show & Tell social call](/images/all-remote/gitlab-zoom-meeting-hat-filter.jpg)
{{% /card %}}
{{% /cardpane %}}

### 1. Make meeting attendance optional

When you work in a global all-remote company, the usual assumptions about availability are opposite the norm. We have a growing team working in over 65 countries, with many time zones covered, which makes synchronous meetings impractical, burdensome, and inefficient. Anyone who has worked in a corporate environment has likely seen the sarcastic "I Survived Another Meeting That Should Have Been An Email" award. As an all-remote company, we [do not look to a meeting by default](asynchronous/#question-every-meeting); when they are necessary, we strive to make in-person attendance optional by enabling asynchronous contribution.

In many companies, synchronous meetings are used as a mechanism to create consensus. As you'll read in the [Leadership](/handbook/leadership) portion of GitLab's handbook, we are not a democratic or consensus driven company. People are encouraged to give their comments and opinions, but in the end one person decides the matter after they have listened to all the feedback.

This works because of our values, which leads GitLab to hire individuals who enjoy being a manager of one, a point detailed in our [Efficiency value](/handbook/values/#efficiency). Team members are empowered to decide whether a sync meeting is the best use of their time, and [set boundaries](mental-health/#be-transparent-about-boundaries) when needed.

#### Record meetings to encourage async participation

You should aim to record all meetings. This allows team members to catch up on what transpired and adds context to notes that were taken during the meeting. Learn more about recording in Zoom in the [Tips and Tricks section of GitLab's Handbook]({{< ref "tools-and-tips#recording-in-zoom" >}}).

#### Managing meeting attendance for team members

At the same time, even GitLab team members may find themselves on one of two extremes.

1. Some folks may find themselves with **too many meetings** on their calendars. Conference rooms have attendee caps. Virtual meeting rooms can hold more than a stadium worth of people, so there are no physical constraints around the number of folks who can be invited to a meeting. Help over scheduled folks by proactively marking them as optional if they are not required. This helps them in their prioritization and time management. Also revisit meetings for which you are the [DRI]({{< ref "directly-responsible-individuals" >}}) after each meeting. Can folks be removed from a meeting or meeting series? Or, can then be moved from required to optional? Avoid stale meeting invite lists.
1. Some folks may find themselves with **few meetings**, so they aren't particularly selective in their attendance. A topical meeting may be an opportunity to connect with team members or feel a sense of belonging, but a participant should choose not to attend a meeting if this is the primary reason for attendance. There are alternatives for [informal communication](informal-communication/) that can better address this need.

Managers can support their direct reports by reviewing the directs' calendars with them on a regular basis to align on which meetings should have in-person attendance.

### 2. Cancel unnecessary meetings

Meetings should not happen if there isn't a clear objective and adequate preparation. In most cases, meetings that should be postponed are cancelled before they begin. At GitLab, roughly 1% of meetings should end within the first minute as it becomes clear that the meeting doesn't have a known meeting outcome, key material required for a productive conversation, or adequate participant preparation. Cancelling a meeting quickly at the start of it is not a failure. It takes leadership to quickly read the situation and make an efficient and time saving call.

Recurring meetings are often established as meaningful points along a given journey. Don't hesitate to cancel them after their purpose has been served. Cancelling meetings isn't an insult to those on the invite list. In fact, ridding multiple calendars of an unneeded meeting is liberating to everyone involved. At the end of each meeting, the meeting [DRI]({{< ref "directly-responsible-individuals" >}}) should evaluate whether the meeting can be **cancelled** or the meeting cadence or duration can be **reduced**. If there are multiple folks who may have an opinion, this can be an agenda item for discussion at the end of the meeting.

### 3. Start on time, end on time

A nontrivial amount of time is required to regain focus after a distraction. While it is not always possible to schedule meetings such that they do not create distractions, it's important to begin and end meetings on time in order to minimize disruption.

When scheduling a meeting at GitLab, we value people's time and prefer the "speedy meetings" setting in our Google Calendar. This gives us meetings of, for example, 25 or 50 minutes - leaving some time to write notes, stretch, etc. before continuing to our next call. Learn more in the [Communication section of GitLab's Handbook](/handbook/communication/#scheduling-meetings).

### 4. All meetings must have an agenda

"[No agenda, no attenda](/handbook/communication/#external-communication)." Every work-related meeting should have a single live doc agenda affixed to the calendar invite at the time that the invite is added to calendars.

Meeting agendas should be include:

1. A relevant meeting title
1. Attendees with titles and organization names, if not in the same company
1. Background Information or context. This should answer:
    - What do folks need to know or review in order to meaningfully participate in the meeting or meeting sequence?
    - Why is this group gathering? The meeting's desired outcome should be clear.
1. The date (if multiple meetings on a topic, you can use the same agenda document, but put dates as H1s or H2s in Google Docs for easier navigation)
1. Questions or details. A place in the agenda where participants can add thoughts either synchronously or asynchronously.
1. If the meeting was recorded, after the meeting, update the agenda document with a link to the recording.

[Meeting DRIs]({{< ref "directly-responsible-individuals" >}}) should prep the agenda at least 72 hours before the meeting. This helps participants to:

1. Can make informed decisions around whether they should prioritize synchronous participation.
1. Have adequate time for any required review.
1. Have adequate time to contribute asynchronously within the agenda.

We've created a [templated example](https://docs.google.com/document/d/1WQe-0oiMCzB3MPBNdKluCEIfgTRpaIi-SJ8FmUJ2xHo/edit?usp=sharing) that you can copy and use in your organization. There is additional guidance and a separate template for [1:1 meetings]({{< ref "1-1#the-1-1-agenda" >}}). [Coffee chats](informal-communication/#coffee-chats) do not require agenda as their function is informal communication.

While it is problematic to have no agenda, it is also problematic to have more than one agenda. Meeting and meeting notes require a single source of truth. If you are in a meeting with more than one agenda, stop the meeting as soon as this is known. Clarify the agenda to use with other attendees and immediately deprecate the additional agenda. Add a link to the agenda being used from the deprecated agenda, so anyone who discovers it is aware of the source of truth agenda.

### 5. Document everything live (yes, everything)

**If you determine that a meeting is needed to move a project forward, address a blocker, or resolve a miscommunication, visit our detailed guide on conducting a [live doc meeting](live-doc-meetings/).**

It's not rude to focus on documentation in a meeting. A surefire way to waste time in a meeting is to avoid writing anything down. Meetings within an all-remote company require documentation to be worthwhile. Here are some additional ways you might document a meeting (in addition to the live doc agenda):

1. During the meeting, add input and feedback from attendees to existing agenda items.
1. When referencing a team member's name in the meeting agenda, ensure that both the first and last names are displayed. (e.g: When we write the name of the person who is speaking in the agenda, we should write the first and last name or use the tagging feature as a prefix)
1. For action items, we [go directly to a GitLab issue](https://about.gitlab.com/blog/2016/03/03/start-with-an-issue) or [merge request](https://docs.gitlab.com/ee/user/project/merge_requests). This creates a direct takeaway from the meeting, where ideas are summarized and action can begin immediately. Be sure to add a link the issue or MR in your meeting agenda for reference and completeness.
1. For optional attendees, or key team members who could not attend the meeting live, tagging them in the resulting GitLab issue(s) enables them to get themselves up to speed and contribute when it is suitable for their schedule.
1. Record the meeting. You can always delete an unwanted meeting, but you cannot turn back the clock and record a meeting retroactively. This is particularly important if you want to present or wish to have a written transcription of the meeting. Zoom's [Cloud Recording](https://support.zoom.us/hc/en-us/articles/115004794983-Automatically-Transcribe-Cloud-Recordings-) supports [transcription](/handbook/tools-and-tips/zoom#recording-video-transcripts) natively, and [Otter](https://otter.ai) is another popular transcription tool.

### 6. Use the right tools

All-remote meetings are made simpler given that there's no jockeying for space in a conference room, scrounging for huddle rooms, or wondering if a given group still needs the  room they've reserved — all very real conundrums in colocated environments.

1. GitLab uses Zoom for video calls and screen sharing. Its simple recording function makes it easy to capture meetings for others to watch at a later time. Learn more about how we optimize Zoom usage in our meetings in the [Tools and Tips](/handbook/tools-and-tips#zoom) portion of our Handbook.
1. We use [GitLab Issues](https://docs.gitlab.com/ee/user/project/issues) to document action items that come out of any given meeting, and loop anyone else in who opted out of real-time attendance.
1. Leverage tools such as Calendly, which can show you as busy in chat tools like Slack.

#### Use GitLab to replace meetings

A major enabler for reducing the quantity of meetings necessary at GitLab is our own product. GitLab is a collaboration tool designed to help people work better together whether they are in the same location or spread across multiple time zones. Originally, GitLab let software developers collaborate on writing code and packaging it up into software applications. Today, GitLab has a wide range of capabilities used by people around the globe in all kinds of companies and roles.

You can learn more at GitLab's [remote team solutions page](gitlab-for-remote/).

### 7. Avoid hybrid calls

A hybrid call is one that has a mix of participants in the same physical room, together with others who are remote. Hybrid calls should be avoided, as it's better to have everyone on a level playing field for communication and discussion.

If a hybrid call must happen, however, everyone should use their own equipment (camera, headset, screen) even if they are physically sitting in the same room. This ensures that everyone is on the same playing field in terms of call experience. If possible, it's best to separate briefly for the call and find your own workspace, creating a 100% remote call. This helps avoid audio problems from delays and feedback. Learn more about why hybrid (partially remote) calls are horrible in the [Communication section of GitLab's Handbook](communication#hybrid-calls-are-annoying).

### 8. Meetings are about the work, not the background

<!-- blank line -->

<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/EeUhxQn_ct4" frameborder="0" allowfullscreen="true"> </iframe>
</figure>

<!-- blank line -->
In the above [video interview](https://youtu.be/EeUhxQn_ct4) between GitLab co-founder and CEO [Sid Sijbrandij](https://twitter.com/sytses) and [NoHQ](https://nohq.co)'s [Dominic Monn](https://twitter.com/dqmonn), the two discuss common challenges and solutions to building, sustaining, and scaling a thriving remote workplace.

They speak at length about meetings within a remote environment. In particular, Sid shares that remote workers should embrace the benefit of being free to take meetings with loved ones nearby.

> **Enjoy the benefits of your kids barging in on a meeting. That's the best distraction in the world.** - *GitLab co-founder and CEO [Sid Sijbrandij](https://twitter.com/sytses)*

Your appearance, surroundings, and background can be the source of great stress and anxiety when preparing for a video call. At GitLab, we encourage team members to bring their whole selves to work.

1. Don't waste time trying to find the perfect backdrop for your video call.
1. Celebrate [unique surroundings](https://about.gitlab.com/blog/2019/06/25/how-remote-work-at-gitlab-enables-location-independence). It's not uncommon to see GitLab team members participate in a video call from the shores of a lake, coffee shops, RVs, or even while walking.
1. Focus on your internet connection and your audio quality ([use headphones](https://about.gitlab.com/blog/2019/06/28/five-things-you-hear-from-gitlab-ceo)), reducing listening fatigue for others.
1. Encourage family and housemates to say hello! All-remote employees invite others into their homes via video call, creating a unique opportunity to share their lives with colleagues.
1. Consider *not* using a video call. Visit GitLab's [Communication](/handbook/communication/#video-calls) section of the Handbook to learn more.

### 9. It's OK to look away

Many organizations have attempted to improve the utility of meetings — usually as a workaround to actually doing less of them — by implementing a "screen-free" meeting mandate. At GitLab, we empower team members to be the manager of their attention.

1. It's completely acceptable to work on other tasks if (a particular portion of) a meeting doesn't apply to you. If your meeting is with only GitLab team members please leave your camera on to allow people to see the overall interest level and adjust the time spent on certain topics. If your meeting includes non-GitLab team members consider turning off your camera because people outside GitLab might not know that it is acceptable for us to work on other tasks during a meeting.
1. It's not embarrassing to ask occasionally for something to be repeated. Because you manage your own attention, you are free to engage with other work and then be pulled back into a relevant part of the meeting conversation.
1. It feels rude in video calls to interrupt people. This is because the latency causes you to talk over the speaker for longer than during an in-person meeting. We should not be discouraged by this, the questions and context provided by interruptions are valuable. This is a situation where we have to do something counter-intuitive to make all-remote meetings work. In GitLab, everyone is encouraged to interrupt the speaker in a video call to ask a question or offer context. We want everyone to contribute instead of a monologue. Just like in-person meetings be cognizant of when, who, and how you interrupt. For example, this can help avoid the issue of men too often interrupting women.

Learn more in the [Communication section of GitLab's Handbook](/handbook/communication/#video-calls)

### 10. Say thanks and be creative

At GitLab, we have a dedicated Slack channel [devoted to saying thanks](/handbook/communication/#say-thanks). Kindness is embedded in our [Collaboration](/handbook/values/#collaboration) value, and gratitude is an essential part of our culture. This reinforces what connects us as a [geographically diverse](/handbook/company/culture/inclusion#fully-distributed-and-completely-connected) team.

A great example of several GitLab's [values](/handbook/values/) being used to generate a creative outcome from a regularly scheduled meeting is detailed on the company blog: ["How we turned a dull weekly all-hands into a podcast"](https://about.gitlab.com/blog/2019/06/03/how-we-turned-40-person-meeting-into-a-podcast)

While we can thanks team members within meetings, we do not thank each other for meeting participation as this is not part of our values and could reward folks attending meetings that they are not required in. This would not support [efficiency](/handbook/values/#efficiency), a GitLab value.

## Remote meeting FAQ's

### What are the benefits of a remote meeting?

Scheduling a virtual meeting allows you to set the meeting length and invite a limited number of people. You can participate in a remote meeting from [almost anywhere in the world](/handbook/people-group/employment-solutions#country-hiring-guidelines)! If you are working in your garage or basement, be sure to use a green screen behind you and put up a professional background image to present well on screen.

### What are the challenges of a remote meeting?

You are not expected to be available all the time, but there may be times you will need to flex your schedule to schedule or attend a meeting with someone from another time zone outside of your typical working hours. Most remote-meeting challenges fall under two categories:

1. trouble with technology
1. communication complications

Both can be overcome by [checking your internet connection](getting-started/#bolster-your-internet-connection-and-consider-redundancy) regularly and growing aware of the [communication preferences](getting-started/#get-accustomed-to-the-communication-preferences-of-your-co-workers) of others.

### How can I prepare for a remote meeting?

1. Review your calendar at least a day in advance of the meeting, so that you are aware of the meeting and what is being discussed. Meetings should not be surprises. When people know what is on their calendars and are aware of related materials, they can make smart decisions around how much time to spend reviewing materials in advance.
1. Prepare for your meeting by carefully reading the live doc agenda attached to the calendar invite **before** the meeting. Here's an [example](https://docs.google.com/document/d/1WQe-0oiMCzB3MPBNdKluCEIfgTRpaIi-SJ8FmUJ2xHo/edit?usp=sharing) of what one might look like.
1. Check and [make sure your technology, Internet](getting-started/#bolster-your-internet-connection-and-consider-redundancy), and environment are good.
1. Don't be afraid to [ask for help](getting-started/#dont-be-afraid-to-ask-for-help) if you need it in order to be fully prepared.

### What should I do after a remote meeting?

1. Write everything down so you can retain and recall important details.
1. Schedule action items, next steps, or a future meeting. Input into the proper directory (Google Drive, Salesforce, etc.) to help ensure there are no balls dropped.
1. If you missed something, re-watch the video recording.

![GitLab all-remote mentor](/images/all-remote/ceo-shadow-gitlab-awesomeness.jpg)
{style="max-width: 50%;"}

### How can I improve my remote meeting skills?

[Lorraine Lee](https://www.linkedin.com/in/lorraineklee) has created [training on how to better your video and presentation skills](https://youtu.be/A5KtmrgVqr8) for an all-remote workspace.

Key points include:

1. How to effectively use lighting, visuals, and curate your environment
1. Using movement, power words, and the think/do/feel matrix to keep your audience engaged
1. Smiling, making eye contact, and framing yourself in video
1. Elevating energy by standing up, projecting, and using hand gestures

### What are "All-remote Virtual 'Offsites'"?

![GitLab values illustration](/images/all-remote/gitlab-values-tanukis.jpg)
{style="max-width: 50%;"}

When working in an all-remote company, there is a strong tendency to avoid traditional "offsites" that require travel from all participants. GitLab has [experimented](https://gitlab.com/gitlab-com/Product/issues/601) with all-remote "offsites" as a method to provide some of the deeper shared understanding that results from such meetings without the heavy financial, personal, and environmental toll of travel. These longer, structured meetings have had mixed results. Here's what we've learned so far:

1. Block off everyone's calendar just as if they'd traveled for an offsite. Remove all other distractions (Slack, email, etc.) and enable Do Not Disturb modes on phones and computers.
1. Ensure you have a strong desired outcome before planning a virtual offsite. This will ideally be discussed before the date and time are set, and written into the agenda.
1. Coordinate pre-reading and work that can be done [asynchronously](/handbook/communication/#internal-communication) ahead of the remote offsite.
1. For newly formed groups, include initial ice-breakers and activities to develop shared trust. For example, begin with a show & tell that allows team members to showcase something they've assembled or have contributed to.
1. Schedule breaks during calls longer than 1 hour.
1. Keep in mind the downsides of time-zone shifting to attend these synchronous meetings. Team members in shifted time-zones may arrive with lower energy.
1. Combine asynchronous activities between synchronous meetings.
1. Take more time than you normally would to explain activities and intent, framing your position with [additional context](effective-communication/). In traditional offsites, understanding comes from observing others in the room, and this can be more difficult remotely. If you are leading the offsite, encourage people to have [short toes](/handbook/values/#short-toes) and [assume positive intent](/handbook/values/#assume-positive-intent) when it comes to being interrupted, as a higher-than-expected amount of back-and-forth may be necessary to achieve understanding.
1. If possible, spend a full day working together with breaks, and share a remote meal together [coffee-chat](informal-communication/#coffee-chats) style.
1. Check your [tools](/handbook/tools-and-tips) to make sure they can support the synchronous setup you are proposing.

All-remote virtual offsites are cost-effective and enable team members to pivot back to [life outside of work](people/#worklife-harmony) as soon as the meeting concludes. However, there is still great value in [in-person interactions](in-person/), and leaders should aim to include those opportunities when possible rather than shifting entirely to remote offsites.

### How do I run a remote board meeting?

In April 2019, GitLab transitioned our board meetings to all-remote. This means that none of the attendees are colocated. By doing so, we've made it as easy as possible for the right people to attend our board meetings, including board members, observers, executives, and anyone doing a [deep dive](/handbook/board-meetings#deep-dives), which can include directors, managers, and, in some cases, individual contributors.

Learn more on [how to run an all-remote board meeting](https://about.gitlab.com/blog/2020/04/15/remote-board-meeting).

### What is the difference between remote and in-person meetings?

{{< youtube "EuGsen3FxXc?start=788" >}}

When asked during an [INSEAD](https://www.insead.edu/) case study interview (shown above) about an all-remote company's ability to bring people together in the same physical space for a meeting, GitLab co-founder and CEO Sid Sijbrandij provided the following reply.

For context, Sid joined the Zoom call from San Francisco, while the researchers joined from Singapore.

> We can [bring people together in the same physical space], but we don't do it because it's very inefficient. Imagine the cost of this meeting if I had to fly to your location, or you to mine.
>
> [Colocated companies] fall back on extremely inefficient things, like flying people halfway around the world for a four-hour meeting. GitLab doesn't fall into that trap.
>
> We have meetings that are more efficient. I bet our meetings, via Zoom, are more efficient than meetings in a conference room. With [live note-taking]({{< ref "communication" >}}), up-front [agendas]({{< ref "suggested-agenda-format" >}}), and our follow-up, GitLab meetings are more efficient.
>
> Not only do we have more efficient meetings, we also do not have the time waste of flying people across the world.
>
> I see multinational organizations where you're supposed to be in the office even if you're the only person in that location, just so they can check that you're working. That is a ridiculous waste of time.
>
> So, no, colocated companies do not have an advantage. They don't have the benefit of knowing how to do remote right because it's not in their DNA.
>
> Of course there are benefits to colocated meetings — it's easier to interrupt each other, it's easier to see what everyone around the room is thinking, you don't have wireless issues, it's easier to look each other in the eyes, it's easier to break bread before/after the meeting, it's easier to talk a walk or do something fun together.
>
> We try to take advantage of them, though. We have [GitLab Contribute](/handbook/company/culture/summit/) where we all come together to go on excursions and have informal chats. As an executive group, we [come together every quarter for 2.5 days for high-velocity meetings](/handbook/company/offsite). Those are augmented with Google Docs, and we allow people to attend remotely if they cannot join in person.
>
> There are benefits, but they aren't as big as people make them out to be.
>
> The biggest thing is [taking the initiative to interrupt each other](https://about.gitlab.com/blog/2019/08/05/tips-for-mastering-video-calls), as that's harder in a remote setting. At GitLab, we solve that by making sure that questions are in a Google Doc in advance so it's clear who has a question and who to hand the conversation off to. — *GitLab co-founder and CEO Sid Sijbrandij*

### Who should be invited to meetings?

We can use our [DRI framework]({{< ref "directly-responsible-individuals#dri-consulted-informed-dci" >}}) to inform who should participate in a meeting. The **DRIs and consulted folks will play key roles within meetings**. A meeting DRI or facilitator owns the meeting. Other DRIs may own specific activities in support of an initiative. Consulted people are those whose opinions are sought, typically subject-matter experts; and with whom there is two-way communication. **Most informed people should not be invited** if there is a more efficient way to engage or cascade information. When informed folks are invited due to needs for immediate alignment or limitations around effectively cascading asynchronously, they should not be added as a recurring participant in a sequence of meetings.

### How do you enable folks who don't attend meetings in-person to effectively participate?

When agendas are shared at least 72 hours in advance, you can have efficient asynchronous participation. If sticking to the agenda becomes the norm, folks who have thoughts or questions, but choose to prioritize other things above meeting attendance, can have confidence that their thoughts will be considered and their questions will be addressed. Team members can later review recordings and notes. This helps to minimize team members' fear of missing out on key details.

### How do you create a low meeting culture?

In addition to making it effective and efficient for participants to contribute asynchronously, don't thank people for showing up in meetings. At GitLab [results](/handbook/values/#results) and [efficiency](/handbook/values/#efficiency) are values, participation is not.

### How do you keep participants engaged in a remote meeting?

1. Have your video on at all times because it's much more engaging for participants.
1. Use team members' names to make everyone feel welcome and recognized.
1. Advise participants to mute their mics to minimize background noise and ensure all attendees hear the speaker.
1. Don't be discouraged by interruptions. Sometimes, there is a lag on a remote call.
1. Speak up as soon as you notice something is not working.
1. Start and end your calls on time.
1. Give attendees the option to ask someone else to `please verbalize` for them if they aren't comfortable speaking up.

For more tips, visit the [GitLab video call communication guide](/handbook/communication/#video-calls).

### What are the best alternatives to Zoom for remote meetings?

While GitLab uses Zoom as the primary video platform for communications,  others may prefer different tools. Some popular Zoom alternatives are:

- WebEx
- MS Teams
- Skype

## A Conversation with Sid on Meeting preparation and efficiency

{{< youtube "nn1Mjh7j-1I" >}}

In the above [video interview](https://www.youtube.com/watch?v=nn1Mjh7j-1I) between GitLab co-founder and CEO [Sid Sijbrandij](https://twitter.com/sytses) and [CEO Shadow Nikki Silverberg](https://gitlab.com/nikkiroth), the two talk through how Sid prepares for and operates in a full day of meetings. Sid also talks through how he uses the points above to make meetings at GitLab and his day efficient.

## GitLab Knowledge Assessment: All-Remote Meetings

Complete all knowledge assessments in the [Remote Work Foundation certification](remote-certification/) to receive the [Remote Foundations Badge in GitLab Learn](https://gitlab.edcast.com/pathways/copy-of-remote-foundations-badge). If you have questions, please reach out to our [Learning & Development team](/handbook/people-group/learning-and-development) at `learning@gitlab.com`.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
