---
title: "The complete guide to asynchronous and non-linear working"
canonical_path: "./non-linear-workday/"
description: How to reinvent your routine and create a non-linear workday in an all-remote environment
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

![GitLab customer path](/images/all-remote/gitlab-customer-path.jpg)

On this page, we're detailing what life can look and feel like when embracing a non-linear workday, paired with suggestions on catalyzing your imagination to consider possibilities that simply are not possible in a colocated, synchronous workplace.

## Q: What is a non-linear workday routine?

A non-linear workday means that you can move between work and non-work time on an  [asynchronous](asynchronous/) schedule - without needing to account for PTO (paid-time-off). For example, a remote worker may start their day at 6:00 am and work till 9:00 am local time. To spend time with family, this person will not check work email or resume working again until 3:00 pm local time and continues to work until 8:00 pm local time. And tomorrow may be a totally different schedule depending on work/life circumstances.

## Breaking preconceived notions about routine

{{< youtube "ZlUpDkoq_v0" >}}

*In the [GitLab Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A) video above, Darren M. (GitLab's Head of Remote) and Elisa R. (Founder of The Cowork Experience) discuss the impact and purpose of routines when looking at satisfaction and productivity.*

A common recommendation for those new to remote work is to find a routine early on, and stick to it. While this may be sound advice for *some*, it ignores the reality that remote enables a complete deconstruction of the perceived need for routine.

Routine is a common suggestion not necessarily because it is *good*, but because it is *tradition*. Routine is mandated in a colocated environment, where team members are required to commute and work between fixed hours. We have been conditioned to believe that routine keeps us disciplined, when in reality, routine simply makes it easier for colocated companies to keep workers in line.

Many people adhere to routines simply because they know no other way. Remote allows another option, thanks to the tremendous benefits of [asynchronous workflows](asynchronous/), [handbook-first documentation](handbook-first/), and company wide [transparency](/handbook/values/#transparency).

## What is a non-linear workday?

{{< youtube "SeTTehyZsFc" >}}

*In the [video](https://youtu.be/SeTTehyZsFc) above, GitLab's Head of Remote talks with Megan Dilley (Director, Remote Work Association) about remote work's democritizating power, the importance of community, and projections for what life will look like after the great remote work migration of 2020. Discover more in GitLab's [Remote Work playlist](https://www.youtube.com/playlist?list=PL05JrBw4t0Kq7QUX-Ux5fOunQotqJbECc).*

Perhaps the most useful approach to describing a non-linear workday is to share an example. In transparency, this is an actual example from a GitLab team member.

- Darren wakes up at 6:00 AM on a Tuesday in Montana. After a shockingly brief 30 second commute from one room to another, he's ready to start his workday, coffee in hand.

- Darren begins work at 6:30 AM, and works until 8:30 AM. He changes his Slack status to a skiier emoji, noting to colleagues that he'll be out through 4:30 PM local time. (This distinction is important, as his company works asynchronously with colleagues across an ever-changing array of time zones. Said another way, time is relative.)

- He then cooks breakfast, eats with his family, and packs his ski gear into the car. By 10:00 AM, the family is skiing. There is almost no one on the mountain, as the vast majority of the world is following a typical routine that pulls them into a colocated office by 10:00 AM on any given Tuesday. Lift lines are nonexistent. Lift tickets were heavily discounted — it's Tuesday, after all — and there was no traffic to contend with. All of these are [spoils of an off-peak life](people/#the-spoils-of-an-off-peak-life).

- By 3:00 PM, Darren and his family ski back to the car, refreshed after an exhilarating day. Given that they're departing the mountain before rush hour has any impact on traffic, they're back to their rental apartment by 3:30 PM.

- After a shower and an early dinner, Darren logs back on to work at 4:30 PM, enthused to tackle ongoing projects and help move issues forward. But first, he shares a few photos he grabbed while skiing — something that is encouraged when you operate in a [non-judgemental culture](mental-health/#create-a-non-judgemental-culture) and measure people on [impact, not activity]({{< ref "remote-values#results" >}}). Though working remotely with hundreds of colleagues across six continents, this deliberate approach to [informal communication](informal-communication/) creates personal bonds that are, in many ways, deeper than those formed in-office.

- Because it's winter in Montana, it's fairly dark outside by 5:00 PM. Darren has maximized his daylight hours, and has time-shifted his working day to primarily occur during darkness. Given that he would likely be indoors during this time anyway, it's more conducive to work. There is no pull to leave and explore the outdoors when it is dark. Instead, it is an ideal time to work, despite the fact that resuming your work day while most others are ending theirs is incongruent with the conventional definition of routine.

![GitLab all-remote team](/images/all-remote/all-remote-skiing-montana.jpg)
{style="max-width: 50%;"}

We should pause at this point and recognize that time is still relative. When Darren resumes his workday at 4:30 PM, he has six more hours to contribute if working a standard eight-hour day. It is important to not get caught up in local times. 4:30 PM may sound like an absurd time to resume working, but that's morning, afternoon, and night for various other members on his team.

- Darren resumes his work from 4:30 PM to 10:30 PM, relying on [low-context documentation](effective-communication/#understanding-low-context-communication) created by his colleagues while he was skiing to understand the current state of work that he is involved in. He contributes asynchronously, as to minimize required [meetings](meetings/) and be considerate of colleagues who may also be working in non-linear fashion.

### Examples of a non-linear workday

You can experience non-linear workdays on a spectrum. While the above example is purposefully extreme to articulate benefits, there are practical, everyday ways to break up your day. This enables you to refresh in a way that is uniquely beneficial to you, and can adapt based on the demands of your day.

- Parents and caregivers may take time during their morning and afternoon to take children to school and spend time bonding during a commute that they'd be forced to outsource if working a more rigid schedule.
- A runner who schedules training sessions around meetings.
- Scheduling fitness as a midday break, which is ideal for those who are not keen on exercising first thing in the morning or after their workday.
- Scheduling meeting blocks based on the evolving nap schedule of a toddler.
- Segmenting your day to create availability to volunteer during certain daylight hours at a food bank, library, community center, etc.
- Structuring your day to handle everyday tasks (e.g. an oil change for your vehicle, meeting with a contractor repairing your home, etc.). A bonus could be tending to these tasks during non-peak hours, which creates efficiency by avoiding transit during rush hours.

## Q: What are the benefits of a non-linear workday routine?

### Flexibility

A non-linear workday empowers team members to live and work both when and where they're most productive.

### Autonomy

Team members are given [agency](/handbook/values/#give-agency) to move projects forward on a schedule that suits them. Because GitLab [measures impact, not activity](/handbook/values/#measure-impact-not-activity), people are free to achieve results when it best suits them.

### Efficiency

Remote decouples routine from responsibility. Employees who enjoy being a [manager of one](/handbook/values/#managers-of-one) thrive in a remote setting, and often exhibit *more* discipline to work well when no one is looking.

## Q: What are the challenges of a non-linear workday routine?

### Juggling time zones

Depending on where you and your teammates are primarily based, it may be a struggle to communicate well with others in a [different time zone](asynchronous/#asynchronous-work-is-more-inclusive).

### Staying organized

One challenging aspect of remote work is delineating where one working session ends and another begins. There is often no reason or excuse to stop or shift tasks other than "the clock tells me it's time to stop."

### Distractions

For novice remote workers, it's important to think about [when and where you prefer to work on a daily basis](https://about.gitlab.com/blog/2019/09/12/not-everyone-has-a-home-office). Optimize your physical and mental space for focus and design a space that prevents distractions [as a boon for your remote work](https://about.gitlab.com/blog/2018/05/17/eliminating-distractions-and-getting-things-done).

## Q: What are some common distractions when working remotely?

The most common distractions to remote workers are ambient sounds, visual distractions, and working in areas with high traffic. Attempt to dedicate both physical and mental space where only work occurs. This enables you to focus specifically on work and be sure to [healthily disconnect](https://about.gitlab.com/blog/2019/07/09/tips-for-working-from-home-remote-work) when you exit the space.

## Q: What are the best ways to stay productive when working remotely?

It can be tempting to default to old ways, whereas working a non-linear schedule or from a unique location requires doing things differently. [Basecamp's Handbook](https://basecamp.com/handbook) tells us that **there's as much to unlearn as there is to learn** when it comes to thriving in a remote role.

While remote work provides flexibility, freedom, and autonomy, it also requires adaptibility and experimentation when it comes to learning remote communication. A few pro tips include:

- Learn and adapt to the [communication preferences of your co-workers](getting-started/#get-accustomed-to-the-communication-preferences-of-your-co-workers)
- [Bolster your internet connection](getting-started/#bolster-your-internet-connection-and-consider-redundancy), and have a back up plan
- Monitor your [mental health](mental-health/) and [emotional health](https://about.gitlab.com/blog/2018/03/08/preventing-burnout)
- Be intentional about [informal communication](informal-communication/) to foster co-working relationships

There is more benefit to working remotely than simply getting rid of the commute! To celebrate, we've curated an [extensive list of resources for remote professionals, teams, and organizations](resources/).

[GitLab's library of guides to working remotely](guide/) is another great resource.

## Q: What are some tips for staying organized when working remotely?

You can explore our [complete guide for remote workers](getting-started/), which contains great tips for staying organized such as:

- Invest time [learning the company's technology & tools](getting-started/#familiarize-yourself-with-the-companys-technology--tools) to maximize [efficiency](/handbook/values/#efficiency)
- Develop a [schedule](getting-started/#develop-a-schedule-that-you-can-initially-follow) that you can test and tweak
- Create strategic [connections with co-workers](getting-started/#how-to-connect-with-people-when-starting-a-remote-job)
- Set up [work-life boundaries](getting-started/#set-up-work-life-boundaries)

The non-linear workday decouples time from work and acts as a forcing function to embrace [asynchronous workflows](asynchronous/). Local times are only as important as your company relies on synchronicity to get things done.

The more this bothers you, the further you need to distance your organization from synchronous defaults.

## Fostering your imagination

![GitLab all-remote team](/images/all-remote/remote_work_02.jpg)
{style="max-width: 50%;"}

- What could your life be if no two days were ever the same?
- What do you long to do that you think a work routine is holding you back from?
- How would you integrate work into your life if you were given permission to scrap everything you thought you knew about the importance of routines?

Answering the above will allow you to truly evaluate what elements of routine are beneficial to you, and which are holding you back.

The above skiing example is a maximally [efficient](/handbook/values/#efficiency) day. It was a full working day, and a full day of exploring and spending meaningful time with family. The above team member could've opted to take PTO ([paid time off]({{< ref "paid-time-off" >}})), or opted for a shorter ski session. He could've taken a half-day, thereby extending the ski session or simply providing more buffer time between work and play.

You could swap anything in for skiing and envision how it could apply to you. From participating in midday school activities with your children, to helping with a midday community service event, to being available to serve as support during an important medical appointment for a loved one — the examples are endless.

The point is, a non-linear mindset gives you options to [break free from routine](people/) and structure each day differently.

{{< youtube "csS3iTjIHNo?start=1193" >}}

*In a [GitLab Unfiltered](https://www.youtube.com/playlist?list=PL05JrBw4t0Kq7QUX-Ux5fOunQotqJbECc) conversation, Dani from Ceridian asked GitLab's Head of Remote the following question: "What's a question that people don't ask, but you feel they should, about remote work?"*

*His answer is verbalized in the video above, and partially transcribed below.*

> What could life look like if I never had to commute again? If I did not have to be in this particular city for work?
>
> What you're seeing en masse (due to COVID-19) is people being thrust into remote, and they're trying to replicate virtually the in-office experience.
>
> I want people to give themselves permission to realize that remote is an entirely new universe. You don't have the commute. You don't have the stigma and office expectations. You can potentially shift your day to work during your peak productivity hours, which opens up hours that have never been accessible to you before.
>
> It's the ultimate blank slate, the ultimate life cheat code. There tends to be remoter's guilt, where you feel like you need to over-produce as a remote employee to compensate for the removal of a commute. The commute was never the employer's to begin with; that was always your time.
>
> You can do something with that. You can be innovative with it. — *Darren M., Head of Remote, GitLab*

## What is required to enable non-linear workdays?

![GitLab values illustration](/images/all-remote/gitlab-values-tanukis.jpg)
{style="max-width: 50%;"}

The example detailed here would not have been possible without a few realities already in place.

- The company must work [handbook-first](/handbook/about/handbook-usage/#why-handbook-first), such that all meaningful takeaways from conversations are documented in their proper place, around the clock.
- The company must embrace [asynchronous workflows](asynchronous/) (including [tools like GitLab](https://about.gitlab.com/stages-devops-lifecycle) as well as processes) in a deliberate, intentional, and thorough way.
- The company must support a [non-judgemental culture](mental-health/#create-a-non-judgemental-culture), which measures team members on [impact rather than activity]({{< ref "remote-values#results" >}}). This enables people to enter and exit work as they so choose, with no fear of retribution for doing something as unorthodox as skiing while everyone else works, and working while everyone else wishes they would've gone skiing.
- A personal dedication to being a [manager of one](/handbook/values/#managers-of-one), able to focus on the right tasks while working from a foreign environment.
- An understanding that not every single day will look like this. Even masters of non-linear workdays recognize that some days are less amenable to midday excursions than others. Rather than being sour about that, embrace the thrill of it being possible at all, and put effort into structuring your upcoming schedule in a way that allows for such days. As a manager of one, you have to take control over (and be accountable for) your schedule. Otherwise, other forces of the world and work will control it for you.

In December of 2021, the Learning and Development team hosted [Dr. Krystal Wilkinson](https://www.mmu.ac.uk/staff/profile/dr-krystal-wilkinson), senior lecturer at Manchester Metropolitain University, to speak about her research on the impact, challenges, and realities of working structures similar to the non-linear workday. Watch the recording on the [GitLab Unfiltered YouTube channel](https://www.youtube.com/watch?v=m-GBiLbfTVk).

### What about meetings?

 The obvious question when discussing such examples is this: "How do you leave work during a time when [meetings](meetings/) are most likely to be scheduled?"

The not-so-obvious answer is: Create a workplace culture where meetings are a last resort, and ensure that unavoidable meetings can be [contributed to asynchronously](meetings/#have-an-agenda).

It bears repeating that not every single day will present itself as a natural, meeting-free day. However, the more intentional your company is about ruthlessly minimizing meetings, [separating decision gathering from decision making](management/#separating-decision-gathering-from-decision-making), and insisting that all work begin where it eventually needs to end up (e.g. in a [GitLab issue](https://docs.gitlab.com/ee/user/project/issues) or [merge request](https://about.gitlab.com/blog/2019/12/19/future-merge-requests-realtime-collab)), the more feasible it will be. You'll also realize benefits on the [mental health](mental-health/) front.

GitLab's [approach to meetings](meetings/), as with all of our processes, is public in our [handbook](/handbook). We encourage leaders to study, implement, and make suggestions for improvement.

### Find what works for you

While embracing non-linear workdays can be incredibly freeing, it's also important to recognize that breaking daily routines might not be productive for everyone. In a conversation in GitLab's [#neurodiversity]({{< ref "erg-gitlab-diversability" >}}) Slack channel, team members shared a range of experiences with non-linear workdays.

Ultimately, it's up to each person to experiment and determine their optimal work preferences and schedule (or lack thereof). Whether your schedule looks different each day, or you stick to a strict routine, or you incorporate elements of both, the key is knowing that you have the freedom and [autonomy](/handbook/values/#managers-of-one) to decide what's best for you.

### Set clear priorities: 3 tasks

Non-linear workdays are focused on results. Building systems to focus on results helps avoid overwhelm and burnout. The video below reviews the **3 Tasks System** as a method for setting and achieving key priorities.

{{< youtube "H5Sg3Gw8E0Y" >}}

**3 Tasks System Summary**

- The goal is to achieve 3 meaningful outcomes every day, week, month, and year. Small outcomes add up to meaningful and long-term results
- Productivity is about doing the right things at the right time. Choosing 3 tasks forces prioritization and helps avoid context switching
- Key benefits of this system include:
    1. reduction in time spent on unimportant work
    1. improved personal efficiency and effectiveness
    1. increased sense of accomplishment
    1. increased results over time
- Choose a recording system that works for you: notepad, sticky notes, Mac reminders, GitLab issues, etc.
- Each day, choose what needs to get done today and decide what can be punted to future days/months
- Other things will come up outside of your 3 tasks. When they do, write them down on a `next` or `future` card. Write them down so you can take remove the pressure of having to remember these tasks.
- Adapt this system to meet your own needs

## GitLab Knowledge Assessment: Non-Linear Workday

Complete all knowledge assessments in the [Remote Work Foundation certification](remote-certification/) to receive the [Remote Foundations Badge in GitLab Learn](https://gitlab.edcast.com/pathways/copy-of-remote-foundations-badge). If you have questions, please reach out to our [Learning & Development team](/handbook/people-group/learning-and-development) at `learning@gitlab.com`.

{{% include "includes/is_this_advice_any_good_remote.md" %}}

## Contribute your lessons

GitLab believes that all-remote is the [future of work]({{< ref "remote-vision" >}}), and remote companies have a shared responsibility to show the way for other organizations who are embracing it. If you or your company has an experience that would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests) and adding a contribution to this page.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
