---
title: "The complete guide to remote onboarding for new-hires"
description: "A complete guide to onboarding new remote work employees and establishing processes that ensure success from day one. Learn more here!"
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

![GitLab customer path](/images/all-remote/gitlab-customer-path.jpg)
{style="max-width: 50%;"}

On this page, we're detailing how to successfully onboard new hires in a remote environment.

## What is remote onboarding?

Onboarding is the official process of integrating new team members into an organization. Remote onboarding is done via technology without any face-to-face interactions.

## How long should remote onboarding take?

GitLab believes the onboarding process is incredibly important. We don't expect anyone to hit the ground running from day one.

We anticipate the remote onboarding process to take at least two full weeks, with the third week designated for team-specific onboarding and training. We encourage new team members to participate in their teams' work in the first two weeks, but without pressure to contribute heavily.

## What is an onboarding session?

At GitLab, we like to do what we call ["dogfooding"](/handbook/values/#dogfooding) our own product. Hence onboarding tasks are completed in a [GitLab issue](https://docs.gitlab.com/ee/user/project/issues).

All onboarding steps are found in an [onboarding issue template](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/blob/main/.gitlab/issue_templates/onboarding.md), which contains a standardized set of tasks and steps that each new team member will complete. The onboarding process for the new team member is [self-driven and self-learning](/handbook/values/#self-service-and-self-learning)and as [asynchronous](/handbook/values/#bias-towards-asynchronous-communication) as possible. This is intentional, in order to aid acclimation into the remote life at GitLab.

Read more about GitLab's all-remote [onboarding process]({{< ref "general-onboarding" >}}) in our handbook.

## How to manage onboarding new hires remotely

Onboarding remotely should focus on [three key dimensions](https://hbr.org/2018/12/to-retain-new-hires-spend-more-time-onboarding-them): the organizational, the technical, and the social. By using this integrated approach, top companies enable their team members to stay and thrive in their roles. We'll show how you can focus on these three key dimensions of onboarding through an all-remote onboarding process.

### How to prepare for remote onboarding

One way to begin creating social connections for new remote team members is to have them [added to a chat channel]({{< ref "general-onboarding#slack-channel-support-for-new-team-members" >}}). GitLab's `#new_team_members` Slack channel is a place for people to introduce themselves with photos and information about themselves and their interests.

### Organizational onboarding

A large part of onboarding is providing answers to logistical questions:

1. How do I sign up for benefits?
1. What tools should I use?
1. Where do I go to find answers?
1. Who can help me with ____?

Traditional in-person companies usually rely on trainers or more hands-on approaches to help new hires navigate their surroundings. All-remote companies have to be more efficient and make information easily accessible, so documentation will be essential for a smooth onboarding process. At GitLab, we provide a detailed [handbook](/handbook) that is always evolving.

The GitLab team handbook is the central repository for how we run the company. It consists of over [2,000 web pages of text](/handbook/about#count-handbook-pages), all searchable of course. Our handbook serves as a [single source of truth](https://docs.gitlab.com/ee/development/documentation/styleguide#documentation-is-the-single-source-of-truth-ssot) that all team members can reference and depend on for answers about GitLab.

For onboarding, we're able to direct new hires to a huge repository of information and also teaching them to be self-sufficient and proactive when looking for answers. Because we've implemented a [handbook-first approach](handbook-first/#make-handbook-first-a-value), the GitLab handbook is always changing and growing as we learn new things.

In an all-remote setting where team members are possibly working from a variety of timezones, mastering [asynchronous workflows](asynchronous/#how-to-implement-asynchronous-workflows) is vital to avoiding dysfunction. Onboarding through documentation is more efficient because it's scalable, repeatable, and instills the basics of asynchronous work.

**Additional resources:**

1. [GitLab onboarding]({{< ref "general-onboarding" >}})
1. [Guide for starting a remote job](getting-started/)
1. [Adopting a self-service and self-learning mentality](self-service/)

### Technical requirements for all-remote onboarding

While tools are an important part of any role, new hires need to feel empowered to use them. Organizations can help build technical confidence by setting up early wins with action items the new hire can complete as they move through their training. Organizational onboarding provides the access to information through handbooks/documentation, and technical onboarding is about using that knowledge to work through the tools.

At GitLab, we practice [dogfooding](/handbook/values/#dogfooding). Our entire company uses GitLab to collaborate on the handbook and we also create issues and merge requests in our product. For all new GitLab hires, we have created an [onboarding issue template](https://gitlab.com/gitlab-com/people-group/employment-templates/-/blob/main/.gitlab/issue_templates/onboarding.md) that has tasks to complete each day. We believe in using the tools we create. This allows new hires to become familiar with GitLab in a way that feels meaningful (e.g. in learning GitLab, they are also accomplishing necessary onboarding tasks). This also provides a continual set of new users to test GitLab with fresh eyes. These individuals are ideally positioned to point out missing features or areas for improvement as we iterate on the product.

For technical onboarding, give new hires access to the tools they'll be using in their roles and, most importantly, encourage them to use the tools as early as possible. Using tools, even for very small tasks, builds confidence and helps new employees to feel productive and empowered.

## Common remote onboarding challenges

One of the biggest challenges that new team members may encounter when onboarding remotely is not knowing who to ask for help with technical issues or "newbie questions." Assigning an [onboarding buddy](onboarding/#social-requirements-for-all-remote-onboarding) is an essential step so that team members always have a friendly face they can talk to.

Onboarding remotely can also bring technical issues: everything from delayed equipment delivery, to trouble with account creation, to the need to rapidly acquire new technical skills. It's very important to ensure that your IT team has adequate resources to be able to support new team members during their first days and weeks on the job.

Crucially, when there are issues with onboarding, new team members may not feel comfortable raising them. Close the loop by asking for regular feedback on the onboarding experience, and be sure to act on that feedback.

**Additional resources:**

1. [All-remote management](management/)
1. [Tools that enable remote teams](resources/#tools-that-enable-remote-teams)
1. [3 things I learned in my first month at GitLab](https://about.gitlab.com/blog/2016/11/02/three-things-i-learned-in-my-first-month-at-gitlab)

### Social requirements for all-remote onboarding

Starting a new job can be overwhelming. If a new hire is used to working in a traditional office, adjusting to the remote work lifestyle might be a challenge. Having socialization as part of the onboarding process can help team members feel more connected to their new teams, even though they don't share an office.

In an all-remote company, it's important to encourage [informal communication]({{< ref "informal-communication" >}}) so that team members can build relationships. This can be incorporated into the onboarding process in a couple of key ways:

1. **Assign an onboarding buddy.** This individual can be a friendly point of contact for a new team member and also introduce them to others. Onboarding buddies often set the expectation for how to build relationships with other team members, so new hires and onboarding buddies should communicate in a variety of ways, such as video calls, check-ins on Slack, and coffee chats. At GitLab, we take this kind of role seriously and have an entire handbook page dedicated to [onboarding buddies]({{< ref "onboarding-buddies" >}}).

1. **Formally design informal communication.** In an all-remote environment, informal communication should be formally addressed. Leaders should organize informal communication and provide structured opportunities for new hires to get to know their coworkers. We incorporate socializing tasks into our onboarding template such as [scheduling coffee chats](informal-communication/#scheduling-a-coffee-chat), introducing yourself in the `#new_team_members` slack channel, or participating in a video call.

1. **Creating personal connections.** We are social creatures, and [research](https://papers.ssrn.com/sol3/papers.cfm?abstract_id=2443551) shows the value of personal connections. While there are tremendous [advantages]({{< ref "remote-benefits" >}}) to operating a 100% remote company, be open to [participating with in-person elements](https://www.fastcompany.com/3051518/the-science-of-when-you-need-in-person-communication), even if they're optional.

**Additional resources:**

1. [Building and reinforcing a sustainable culture](building-culture/)
1. [Considerations for in-person interactions in a remote company](in-person/)
1. [Social slack channel ideas](/handbook/communication/chat#social-groups)

## The importance of the onboarding process

![GitLab collaboration light bulb](/images/all-remote/gitlab-collaboration-illustration.jpg)
{style="max-width: 50%;"}

Onboarding is the official process of integrating new team members into an organization. The difference between onboarding and orientation is that orientation is typically a singular event, whereas onboarding is a continuous process during an team member's first year. Having an efficient onboarding process can have long-term benefits:

1. Better team member retention
1. More productive, more quickly
1. Reduces anxiety
1. Sets expectations

Onboarding is an investment in the long term success of new hires and in the company as well. Studies show that [87% of team members are less likely to leave a company](https://totalteambuilding.com.au/the-positive-impact-of-team-building/) when they feel engaged. Companies that invest in onboarding report [54% more productivity](https://www.myshortlister.com/insights/employee-onboarding-statistics) from new hires.

When [hiring in an all-remote organization](hiring/), a cohesive onboarding process is especially important because not only do you have to give new hires the information they need to do their jobs, you have to empower them to think remotely as well. Remote onboarding relies heavily on [documentation](management/#scaling-by-documenting), anticipating the needs of new team members, and a dedication to continuously improving the process based on feedback.

## Remote onboarding best practices

- **Outline work logistics and expectations.**
At GitLab, we believe the best way to operate is by [documenting](management/#scaling-by-documenting) processes, guides, solutions, how-tos, and policies. Be sure to empower remote workers to  adopt [remote-first communication and workflow practices](how-to-work-remote-first/).

- **Identify employee concerns and answer questions.**
GitLab is committed to [transparency](/handbook/values/#transparency). This value gives team members access to a great deal of visibility to what is going on throughout the organization. However, it does not negate the need to invite employees to ask questions.

- **Add some excitement.**
In addition to the [incredible benefits of all-remote work]({{< ref "remote-benefits" >}}), getting to network and interact with their team, whether remote or [in-person](in-person/) is part of what makes work fun and exciting - especially in an all-remote [culture](/handbook/company/culture/).

Here's our list of more than 20 ways to participate in a happy, healthy [informal work culture](informal-communication/).

- **Schedule check-ins with new employees.**
It's a good idea to schedule weekly [1-1 meetings]({{< ref "1-1" >}}) to field questions, ask about any challenges, or focus on areas to grow and build trust. Managers can supplement formal meetings with [coffee chats](informal-communication/#coffee-chats) where no work is discussed: the goal is to simply listen, share, and have open conversations and nurture the social component of remote working.

## What are onboarding activities?

At GitLab, [the first thirty days](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/blob/main/.gitlab/issue_templates/onboarding.md#the-first-thirty-days) consist of a series of tasks to be completed sequentially. A sample GitLab onboarding sequence might look like:

- Day 1: [Getting Started: Accounts and Paperwork](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/blob/main/.gitlab/issue_templates/onboarding.md#day-1-getting-started-accounts-and-paperwork)
- Day 2: [Remote Working and our Values](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/blob/main/.gitlab/issue_templates/onboarding.md#day-2-remote-working-and-our-values)
- Day 3: [Security & Compliance](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/blob/main/.gitlab/issue_templates/onboarding.md#day-3-security-compliance)
- Day 4: [Social & Benefits](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/blob/main/.gitlab/issue_templates/onboarding.md#day-4-social-benefits)
- Day 5: [Git](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/blob/main/.gitlab/issue_templates/onboarding.md#day-5-git)
- [Weeks 2 - 4: Explore](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/blob/main/.gitlab/issue_templates/onboarding.md#weeks-2-4-explore)
- [Week 3: Job Specific Tasks](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/blob/main/.gitlab/issue_templates/onboarding.md#job-specific-tasks)

## What do new hires want from an onboarding program?

Onboarding is the first impression a new hire gets of your organization. It's critical to invest the time to do it well so that your new team members get to know you, understand what is expected of them, introduces them to co-workers and teammates, and sets them up to succeed.

At GitLab, we document to create a [single source of truth](/handbook/values/#single-source-of-truth) so we can operate [handbook-first](/handbook/about/handbook-usage/#why-handbook-first) and value [transparency](/handbook/values/#transparency) by making the handbook [publicly accessible to all](/handbook).

## Remote onboarding tips

### How is onboarding a remote employee different from an office employee?

Because remote onboarding is mostly self-guided, the real-time face-to-face ability for new employees to ask questions does not exist. Knowing this, we've created some important reminders for onboarding remote employees such as:

1. **Check in immediately.** Receiving and retaining a wealth of new information can be overwhelming, particularly on the first day of work.
1. **Suggest helpful hints.** Chances are that you've discovered some tips, tricks, and hacks--share them proactively!
1. **Remind them to introduce themselves.** Remind the new team member to introduce themselves in the Slack channel `#new_team_members` or relevant team channel. Encourage them to share some personal info and include a photo or two!
1. **Encourage them to socialize with other new hires.** For example, new employees might organize a group call with other new hires in order to walk through onboarding together, while learning about new personalities and [departments of the company](/handbook/company/structure/).
1. **Introduce them to any tools for connecting with colleagues.** Chat tools such as Slack may seem ubiquitous, but not everyone has used them before - and even if they have, they may not know how your network is organized.
1. **Ask where they need help and connect them with the experts**. Connect new team members with subject matter experts if your assigned team member requests additional help in a given area.
1. **Keep checking in regularly.** Checking in regularly will help them feel welcome and supported.
1. **Provide backup if needed**. If you plan to be out (e.g. [vacation]({{< ref "paid-time-off" >}}), [company business](/handbook/travel), [events](https://about.gitlab.com/events), etc.) during a new team member's first few weeks, make sure that a backup person is available to offer support.

### What are some tips to plan an effective employee onboarding training?

Best practices for effective onboarding include clear **communication**. A few ways to do this are:

- Encourage people to write everything down
- Allow open access to view all important documents
- Use screenshots so everyone at any time can follow the thought process
- Encourage non-work related communication for relationship building
- Encourage group video calls for bonding
- Encourage one-on-one video calls between people (as part of onboarding)

### Remote first company culture

For many, building a [remote first culture](how-to-work-remote-first/) is challenging, but worthwhile. **Culture is the barometer of how well an organization is communicating and reinforcing its values**.

Culture is created when a company's values are prescriptively articulated and visibly [reinforced](values#how-do-we-reinforce-our-values) through elements such as [discretionary bonuses]({{< ref "incentives#discretionary-bonuses" >}}) and linking promotions to values.

For new team members, this is even more crucial: if your culture is not self-reinforcing in a remote environment, it may not translate during the onboarding period.

## Remote first company values

GitLab's six core values are
[**🤝 Collaboration**](/handbook/values/#collaboration),
[**📈 Results**](/handbook/values/#results),
[**⏱️ Efficiency**](/handbook/values/#efficiency),
[**🌐 Diversity, Inclusion & Belonging**](/handbook/values/#diversity-inclusion),
[**👣 Iteration**](/handbook/values/#iteration), and
[**👁️ Transparency**](/handbook/values/#transparency),
and together they spell the **CREDIT** we give each other by assuming good intent.

Feel free to adopt or remix our values for your remote-first team.

## How to evaluate your existing onboarding process

In the spirit of [transparency](/handbook/values/#transparency), GitLab's People Connect Team will evaluate the onboarding process by having new employees fill out an [Onboarding Survey](https://docs.google.com/forms/d/1sigbOqWKuEtGyLROghvivgWErRnfbUI1_-57XhAwu_8/edit).

## High-touch and low-touch flexibility

The beauty of an all-remote setting is that onboarding can be as high-touch or low-touch as a new hire wishes. Those who prefer visual learning can engage in a series of video calls and screen share sessions to walk through each element of their onboarding issue. Those who prefer more self-learning can benefit from thorough documentation and readily-available resources for self-guided learning.

That flexibility is unique to the all-remote environment, as those who prefer a self-guided experience are typically forced into a very social onboarding at colocated companies.

## Empowerment from day one

![GitLab values](/images/all-remote/gitlab-values-tanukis.jpg)
{style="max-width: 50%;"}

The onboarding process should be empowering. At GitLab, if a new hire gets stuck during onboarding, they are encouraged to update the handbook, record a video to help others who may encounter the same obstacle, and contribute to learning and development from day one.

Learn more about our approach to [All-Remote Learning and Development](learning-and-development/#how-do-you-onboard-new-team-members).

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
