---
title: "All-Remote Compensation"
description: How does compensation work in a remote company
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

On this page, we're detailing how compensation works in a global all-remote company.

## How do you pay people?

When you open your hiring pipeline to practically every nation on the planet, you get questions like "How do you pay people?"

While there are certain complexities to paying team members who are spread across the globe, we believe that it's worthwhile. Being an all-remote company enables us to [hire the world's best talent](hiring/), not just the best talent from a few cities.

{{< youtube "Yr2do8A38r0" >}}

In the above [GitLab Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A) video, GitLab co-founder and CEO Sid Sijbrandij discusses the logistics of hiring remote team members with [Proof](https://prooftrading.com/) CEO [Daniel Aisen](https://twitter.com/dcaisen).

Compensating people in a variety of countries isn't easy, and there's no blanket solution. However, as GitLab grows, it's able to incorporate in more countries. This allows us to be a traditional employer, paying local team members directly.

For countries where that's not yet possible, we oftentimes hire professional employment organizations to serve as the employer of record (EOR) in order to facilitate payments. In other cases, we hire new team members as [contractors]({{< ref "contracts-probation-periods" >}}).

We continually look at where our team is growing, which guides us in prioritizing where to incorporate next.

## What currency do you use?

The preference is for team members and future team members to be paid in their local currency. However, there may be instances where this is not possible and another currency may be chosen by the team member. For the full list of countries where GitLab can pay using local currency, visit the [Contracts section of our Handbook]({{< ref "contracts-probation-periods#available-currencies" >}}).

## Why do you pay local rates?

GitLab endeavors to [pay local rates]({{< ref "compensation#paying-local-rates" >}}) as opposed to paying a San Francisco wage to everyone in the company, regardless of their location.

Our co-founder and CEO Sid Sijbrandij discusses this in a blog post entitled "[Why GitLab pays local rates](https://about.gitlab.com/blog/2019/02/28/why-we-pay-local-rates/)."

> If we pay everyone the San Francisco wage for their respective roles, our compensation costs would increase greatly, and we would be forced to hire a lot fewer people. Then we wouldn't be able to produce as much as we would like. If we started paying everyone the lowest rate possible, we would not be able to retain the people we want to keep.

Particularly in comparison to companies in cities with high costs of living, such as London, San Francisco, Singapore, Sydney, etc., an all-remote company realizes [a notable set of advantages]({{< ref "compensation#why-we-pay-local-rates" >}}) by hiring brilliant minds in locales with lower costs of living.

Funds that would be reserved for salaries — necessary to compete in hot labor markets — can be redirected to areas such as [research and development](https://about.gitlab.com/blog/2018/06/12/how-ux-research-impacts-product-decisions/) (R&D), [acquisitions](/handbook/acquisitions/), and [hiring more people](https://about.gitlab.com/jobs/).

These additional investments can be made simply by lowering a company's overall spend on compensation, but only if a company is willing to hire in locales where a dollar goes farther than the [SF Benchmark](/handbook/total-rewards/compensation/compensation-calculator#sf-benchmark).

## How can other companies move to a remote compensation model?

To talk through Best Practices for Remote Compensation, GitLab partnered with [Compaas](https://web.archive.org/web/20230327015045/https://www2.compa.as/gitlab) to outline how to get started recommendations, and pitfalls when transitioning to a remote friendly or remote only compensation model.

## How do you decide how much to pay people?

Plainly, we want our compensation to be at a level were we can recruit and retain people who meet our requirements. A far more elaborate explanation can be found in the [Compensation Principles section of GitLab's Handbook]({{< ref "compensation#compensation-principles" >}}).

Deciding how much we pay people who live and work in a multitude of regions across the globe is a continual process. [Iteration](/handbook/values/#iteration) and [Transparency](/handbook/values/#transparency) are values at GitLab, and both apply to compensation calculations.

{{< youtube "CgQNFffuHrc?start=34" >}}

In the above video, which was [streamed live](https://www.youtube.com/watch?v=CgQNFffuHrc) on [GitLab's YouTube channel](https://www.youtube.com/channel/UCnMGQ8QHMAnVIsI3xJrihhg), GitLab Compensation & Benefits Manager Brittany Rohde discusses a variety of all-remote compensation topics with [Microverse](https://www.microverse.org/) COO [Juan José Mata](https://www.linkedin.com/in/jjmata).

### Understanding GitLab's Compensation Calculator

All-remote companies should consider a public compensation calculator to remove guesswork. When you open roles to a global talent pool, this allows candidates to get familiar with compensation expectations prior to applying, which creates efficiencies in the hiring process.

Colocated companies are generally relieved of this burden, as anyone applying to a role requiring them to reside in a given city can do their own research on market rates for that locale.

### Iterating on compensation

During the fourth quarter of each year, GitLab conducts a compensation review to ensure all team members are paid based on market data in the [compensation calculator]({{< ref "compensation-calculator" >}}). This is not a Cost of Living Adjustment, but instead a review of the market changes.

For all-remote companies looking to enact a similar process, please study our [Annual Compensation Review]({{< ref "compensation-review-cycle#annual-compensation-review" >}}).

### Factoring the factors

For GitLab team members — with the exception of [Executive Compensation]({{< ref "compensation#executive-compensation" >}}) and anyone on a quota — the following factors are factored into their salary. We invite other all-remote companies to study this formula if considering how to pay a truly global team.

Your salary = [SF benchmark]({{< ref "compensation-calculator#sf-benchmark" >}}) x [Location Factor]({{< ref "compensation-calculator#location-factor" >}}) x [Level Factor]({{< ref "compensation-calculator#level-factor" >}}) x [Compa Ratio]({{< ref "compensation-calculator#compa-ratio" >}}) x [Contract Factor]({{< ref "compensation-calculator#contract-factor" >}}) x [Exchange Rate]({{< ref "compensation#exchange-rate" >}})

## What role does experience play?

![GitLab bulb illustration](/images/all-remote/gitlab-collaboration-illustration.jpg)
{style="max-width: 50%;"}

A person's background and experience influences their value to a company, regardless of how the company is organized. In an all-remote setting where a company pays local rates, experience can play an outsized role in a team member's cash compensation.

It's important to evaluate experience *not* based on years in the workforce, but rather, demonstrated ability to drive projects and deliverables from the position description to completion. In an all-remote setting, this can include experience operating and managing in a work environment where you do not regularly meet direct reports, clients, and peers on an in-person basis.

While compa ratios at colocated companies typically focus on experience in the role, all-remote compa ratios must consider more nuance — elements such as an ability to [communicate well virtually](https://about.gitlab.com/blog/2019/08/05/tips-for-mastering-video-calls/) and operate effectively in an [asynchronous]({{< ref "communication" >}}) setting.

Learn more about [GitLab's Compa Ratios]({{< ref "compensation-calculator#compa-ratio" >}}).

## How do stock options factor in?

As many other organizations do, GitLab provides equity grants in the form of Incentive Stock Options (ISOs) and Non-Qualified Stock Options (NSOs).

The difference in these two types of grants are, generally, as follows: ISOs are issued to US employees and carry a special form of tax treatment recognized by the US Internal Revenue Service (IRS). NSOs are granted to contractors and non-US employees.

You can learn more in the [Stock Options section of the Handbook](/handbook/total-rewards/stock-options/).

{{% include "includes/is_this_advice_any_good_remote.md" %}}

## Contribute your lessons

GitLab believes that all-remote is the [future of work]({{< ref "remote-vision" >}}), and remote companies have a shared responsibility to show the way for other organizations who are embracing it. If you or your company has an experience that would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests/) and adding a contribution to this page.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
