---
title: "Remote/work-from-home starter guide"
description: Remote work starter guide for employees
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

## What is remote work / working from home?

![GitLab all-remote laptop illustration](/images/all-remote/gitlab-all-remote-laptop-map-illustration.jpg)
{style="max-width: 50%"}

In an [all-remote](stages/#9-all-remote) organization, each individual is empowered to [work and live](people/) where they are most fulfilled.

For many people, the preferred workplace is a home office. Of course, not all remote workers make their offices at home - but the majority do.

"Remote work from home" is any work that is performed in an individual's home, on behalf of an organization that may or may not have physical offices.

## How do I set myself up to work from home?

Ultimately, the best way to work remotely depends on your personal preferences. However, many aspects of home working are more or less universal. Here are five approaches that are likely to boost your remote work-from-home proficiency.

### 1. Create a dedicated workspace (achieve focus)

*Where* you work is as important as what you work on and who you work with. Having a [defined space](https://about.gitlab.com/blog/2018/05/17/eliminating-distractions-and-getting-things-done#8-dedicate-a-room-to-work) helps usher you into an area of focus. While it is ideal to dedicate a room for work, if that is not possible, you can do something simple like hanging a curtain to block off a place of work.

Once you have created your workspace, focus on [ergonomics for a healthy setup](https://www.webmd.com/pain-management/ss/slideshow-ergonomic-tips-for-a-home-office#:~:text=Choose%20a%20work%20surface%20that,your%20desk%20or%20table%20legs.). Ask your employer if they will reimburse you for items such as chairs, noise-canceling headphones, monitors, external keyboards, etc. that promote a healthy and focused workspace. Try not to compromise on comfort. You may be able to work uncomfortably temporarily, but your productivity, health, and mood will likely decline over time.

For a full list of home office optimizations, visit GitLab's [guide to a productive home office](workspace/).

*In this [video](https://youtu.be/uP0aiei0JKA), GitLab's Head of Remote Darren Murph talks to Sprinklr's [Andrew Kasier](https://www.linkedin.com/in/andrewrkaiser) about creating an office that allows for deep focus and work.* Discover more in GitLab's [Remote Work playlist](https://www.youtube.com/playlist?list=PL05JrBw4t0Kq7QUX-Ux5fOunQotqJbECc).*

{{< youtube "uP0aiei0JKA" >}}

*Discover more in GitLab's [Remote Work playlist](https://www.youtube.com/playlist?list=PL05JrBw4t0Kq7QUX-Ux5fOunQotqJbECc).*

### 2. Separate work from life (prevent burnout)

When you're working remotely from home, it can be difficult to set boundaries between work time and ... everything else.

This is likely to be the most difficult hurdle to clear, particularly for new work-from-home employees who have family in your home during your work hours. You should have a dedicated conversation with family, helping them understand that just because you're home, doesn't mean you're available.

On the other hand, when there's [no physical office to leave](how-to-work-remote-first/#offices-are-simply-venues-to-work-remotely-from), it's tempting to work longer than is expected (or healthy). Proactively planning what you'll do with your commute time is key to ramping into a workday as well as ramping off. You can set reminders to begin and end work or pre-plan activities during the void previously filled by a commute. A [daily schedule](getting-started/#develop-a-schedule-that-you-can-initially-follow) will look different for each individual, but leaving your home for a walk or a planned activity with friends/community may be a great way to create clear work/life separation.

GitLab has created this extensive [guide to combating burnout, isolation, and anxiety in the remote workplace](mental-health/).

### 3. Regularly engage with others (avoid loneliness)

When there is no office to spark spontaneous [informal communication](informal-communication/), you must be intentional about weaving it into your day.

- Schedule regular [coffee chats](informal-communication/#coffee-chats) with people using a video call.
- Experiment with audio-based chat tools like [Yac](https://www.yac.com) and video-based tools like [Loom](https://www.loom.com).
- Create an always-on video conferencing room that your team can work from. (In a remote setting, [it's OK to look away](meetings/#its-ok-to-look-away)!)
- Talk about what you normally would. If sports, vacation plans, and hilarious tales of insubordination by children are common water-cooler material, work with your team to establish a chat channel to discuss things outside of work. The medium may be different, but the connection is the same.
- Drop any shame or embarrassment. Don't [worry about your background](meetings/#meetings-are-about-the-work-not-the-background), and feel welcome to let your pets and family find their way into calls on occasion. It humanizes the experience and reminds everyone that we're people first, and colleagues second.
- Connect with family and community. Working from home allows you to spend time with a different set of people than just your coworkers. Look for opportunities to build bonds with family and [community](people/), which may have been impossible or limited when you had a commute.

### 4. Respect the routine, but try new things (find structure)

One of the [benefits of remote]({{< ref "remote-benefits" >}}) is the ability to experiment with unconventional working days. Not everyone shares the same [peak hours of energy and focus](https://www.jonobacon.com/2019/01/14/remote-working-survival). For example, if you work best in late evenings, let your team know you are going to try some [non-linear workdays](non-linear-workday/#q-what-is-a-non-linear-workday-routine).

You can maximize the benefits of [asynchronous workflows](asynchronous/) in an [all-remote](terminology/) situation if you fill your former commute space with things that make you [healthier](mental-health/) like exercising, resting, bonding with family, cooking, reading, studying, etc.

### 5. Embrace change (allow iteration)

Relax: you aren't born knowing how to work from home. You cannot [copy](what-not-to-do/) an in-office environment and paste it into a remote one and expect everyone to function as usual. Transitioning to remote is a [*process*](remote-work-emergency-plan/). When done well, a transition to remote avoids [serious harm](/handbook/values/#five-dysfunctions) operationally as well as culturally.

It's important to [overcommunicate with your team](getting-started/#begin-to-create-connections-with-co-workers) as you adjust.

- [Ask questions](getting-started/#dont-be-afraid-to-ask-for-help)
- Offer solutions for communication gaps
- Seek advice on how others have set up their workplace
- Crowdsource advice from within your organization
- Look for opportunity in the midst of the chaos.

{{< youtube "R0AB8ZvnEIU" >}}

*In this [video](https://youtu.be/IU2nTj6NSlQ), GitLab's Head of Remote shares his top work-from-home tips with [Jack Altman](https://twitter.com/jaltma), CEO of [Lattice](https://lattice.com).*

## Additional resources

For a deep dive, consider studying and implementing suggestions from GitLab's [comprehensive guide to remote work](https://allremote.info).

- [How to live your best remote life](https://about.gitlab.com/blog/2019/07/09/tips-for-working-from-home-remote-work)
- [GitLab's guide for starting a remote job](getting-started/)
- [Pitfalls to watch out for when embracing remote](what-not-to-do/)
- [Mastering the all-remote environment: My top 5 challenges and solutions](https://about.gitlab.com/blog/2019/12/30/mastering-the-all-remote-environment)
- [5 Tips for mastering video calls](https://about.gitlab.com/blog/2019/08/05/tips-for-mastering-video-calls)
- [Mastering the at-home office environment](https://about.gitlab.com/blog/2019/09/12/not-everyone-has-a-home-office)
- [How to make your home a space that works with kids](https://about.gitlab.com/blog/2019/08/01/working-remotely-with-children-at-home)
- [5 Things to keep in mind while working remotely with kids](https://about.gitlab.com/blog/2019/08/08/remote-kids-part-four)
- [Combating burnout, isolation, and anxiety](mental-health/)
- [Adopting a self-service mindset](self-service/)
- [Remote Without Warning Webinar: How to adapt and thrive as a suddenly-remote company](https://youtu.be/n4ZZaE-XCVs?t=5)
- [Preparing Your Team for Remote Work Webinar](https://youtu.be/9tYEKAFgQQw?t=5)

{{% include "includes/coursera_gitlab_remote_course.md" %}}

{{% include "includes/is_this_advice_any_good_remote.md" %}}

## Contribute your lessons

GitLab believes that all-remote is the [future of work]({{< ref "remote-vision" >}}), and remote companies have a shared responsibility to show the way for other organizations who are embracing it. If you or your company has an experience that would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests) and adding a contribution to this page.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
