---
title: "How to repurpose office space in a remote world"
description: "Here is a complete guide to repurposing your existing office space to make the most of remote work. Learn more!"
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

## What's the role of office spaces in a remote world?

![Remote journey illustration](/images/all-remote/gitlab-remote-journey-color-illustration.png)
{style="max-width: 50%"}

As organizations around the globe have embraced [various models of remote or hybrid work](stages/), a new question has emerged: What do we do with our office space? Business leaders and facilities teams must decide what their top priority will be for these physical spaces.

This question is also relevant for owners and investors in commercial real estate spaces that have traditionally been used as corporate office space. How do we optimize these spaces in this new world of remote and distributed work?

We'll explore a number of options on this page, as well as highlight examples from organizations and property owners that have already repurposed their physical offices.

## Closing the office

If you're a business leader whose team is transitioning to an all-remote model, the first option to examine is whether you can (or want to) close some or all of your office spaces. This sends the clearest signal that you're [fully embracing](transition/#close-the-office) remote work. It's likely to be the most cost-effective approach, and will eliminate the potential for the office to remain a crutch to collaboration.

This may not be a feasible option for some organizations in the short term due to leasing terms and other binding factors. That's why we'll explore other ways to repurpose this space, both for organizations and the owners of the spaces.

## Repurposing office space

For organizations that plan to retain some or all existing office space, there are a number of ways to redesign and use these spaces more effectively to enable better remote-first collaboration, social and team building, and even community connection.

**Ask for input from your team**

Gathering input from your employees is an important first step in the decision-making process to determine the future use of your office space. This is especially key data if you're embracing a [hybrid](hybrid-remote/) work model. There's no "one size fits all" for [workspaces](workspace/), remote or colocated. Knowing your team's current needs and preferences for this space can help prioritize what features you invest in and ensure it's a productive space that serves your organization into the future.

![Remote work environment](/images/all-remote/gitlab_all_remote_work_environment_scale.jpg)
{style="max-width: 50%"}

### Make office space more remote-friendly

Companies that were mostly colocated prior to the COVID-19 pandemic likely prioritized desks, hoteling workstations, and meeting spaces with the assumption that most work would happen within the walls of the office. Those spaces are in need of an upgrade in order to truly embrace your new remote-first or hybrid organizational design.

The goal should be to ensure the office is treated as simply [another space to work remotely](how-to-work-remote-first/#offices-are-simply-venues-to-work-remotely-from).

Here are some changes to consider to make your space more inclusive of remote team members:

1. Eliminate and/or redesign meeting rooms for [individual hybrid-remote meeting spaces](hybrid-remote/#redesigned-spaces-for-individual-hybrid-remote-meeting-rooms)
1. Install an LCD wall (or similar) with images and photos from remote team members to serve as a reminder of your team beyond the office
1. Ensure that hoteling or co-working areas are prioritized within the office over dedicated desks or large cubicles
1. Upgrade video conferencing technology in all meeting spaces to avoid the downsides of [hybrid calls](how-to-work-remote-first/#everyone-must-use-their-own-webcam-no-hybrid-calls)
1. Include reminders in meeting spaces about your documented, [remote-first meeting norms](meetings/)
1. Incorporate digital signage for internal communications campaigns and promotions so that remote team members have access outside of the office

### Turn the office into a social gathering space

For remote or hybrid teams, [time spent together in-person](in-person/) is most valuable when used for social connection and team building.

Most traditional office spaces have some kind of gathering space for employees, but it typically doubles as a cafeteria, break room, gaming area, or large conference room. These spaces often have capacity limits that prevent them from being able to accommodate the entire team for company celebrations and social events. Take your unused cubicle or "work only" space and convert this part of your office footprint to serve the emerging needs of your organization for social spaces of all sizes. Examples of these new spaces include:

1. Assembly theaters
1. Event ballrooms
1. Music studios
1. Libraries
1. Fitness studios
1. [Walking paths or ramps](https://hbr.org/2022/01/design-an-office-that-people-want-to-come-back-to) for active "walk-and-talk" meetings

These changes will enable your team to shift your collective mindset around the purpose of the office and establish the remote-first practices that allow work to happen from anywhere.

### Convert the office to a community hub, co-working, or innovation space

![GitLab collaboration lightbulb](/images/all-remote/gitlab-collaboration-illustration.jpg)
{style="max-width: 50%"}

If you're an organization that invests in local entrepreneurs, innovation projects, or service-focused initiatives, you can use your existing office space to support those investments.

This is also a community-focused option for real estate owners who no longer have corporate tenants occupying spaces that were previously outfitted for offices.

Co-working and networking spaces can become hubs for entrepreneurs and startups looking to connect with their community without an expensive investment in office space. Some co-working spaces even specialize in supporting specific audiences. For example, [these co-working spaces](https://www.nexudus.com/blog/1414921425/10-co-working-spaces-around-the-world-offering-childcare) around the world provide on-site childcare for working parents.

## Examples of companies repurposing office space

These companies have already taken innovative approaches to how they've reduced or reinvented their office space to support their team's needs for the future. This is not an exhaustive list, and we encourage contributions to it.

- [Cimpress/Vista](https://cimpress.com/accelerating-with-remote-first): Shifted to a remote-first model and reduced their overall office footprint. They're turning remaining offices into collaboration centers for team members to gather.
- [Atlassian](https://thinkremote.com/atlassian-office-redesign): Transitioned a ["TEAM Anywhere"](https://www.atlassian.com/practices/use-cases/team-anywhere) distributed model. The company redesigned its Austin office to be more equipped to support both remote and in-office employees.
- [Hubspot](https://www.hubspot.com/hybrid): Shifted to a hybrid model that allows team members to choose from three primary work environments: home, flex, or office. They redesigned their offices to better serve "flex" and "office" employees, while working to make their perks and benefits location agnostic.
- [Amazon](https://deadline.com/2020/05/amazon-turns-office-building-homeless-shelter-seattle-1202942304): Partnered with a non-profit organization to turn one of its headquarters buildings in Seattle into a homeless shelter and community support center.

## Alternative uses for office space

Here are other examples that owners of commercial office space could consider in lieu of corporate tenants in their spaces outfitted as offices. This is not an exhaustive list, and we encourage contributions to it.

- [Residential space](https://www.npr.org/2022/03/23/1088272830/how-an-empty-office-becomes-a-home)
- [Affordable housing](https://www.nytimes.com/2021/03/29/nyregion/remote-work-coronavirus-pandemic.html)
- [Gyms](https://news.crunchbase.com/news/vacant-office-space-proptech-startups-repurpose)
- Classrooms and learning centers
- [Vertical and container farms](https://gardenculturemagazine.com/repurposing-empty-skyscrapers-into-urban-farms)
- Warehouses and distribution centers
- [Mixed-use buildings that meet both living and working needs](https://www.workdesign.com/2020/10/how-do-cre-organizations-think-workspace-will-be-repurposed-post-covid-19)
- Co-working spaces

## Invest in your team's **remote** workspaces

![Remote workspace](/images/all-remote/gitlab-all-remote-laptop-map-illustration.jpg)
{style="max-width: 50%"}

Reducing or eliminating corporate office space is likely to bring cost savings to your organization. Keep in mind that just because you no longer have to invest in physical real estate does not mean you have no need for a workspace-related budget. The onus is on business leaders to provide the space and equipment their employees need to create healthy and productive remote workspaces. As this continues to become the norm for remote and hybrid workers, top talent will expect this as a requisite part of any total rewards package and employee experience.

You can find more guidance on how to invest in your team's workspace in [this guide](work-from-home-field-guide/).

{{% include "includes/is_this_advice_any_good_remote.md" %}}

## Contribute your lessons

GitLab believes that all-remote is the [future of work]({{< ref "remote-vision" >}}), and remote companies have a shared responsibility to show the way for other organizations who are embracing it. If you or your company has an experience that would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests) and adding a contribution to this page.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
