---
title: "Scaling an all-remote team"
description: Scaling an all-remote team
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

On this page, we're detailing how scaling an organization works better with all-remote.

## Does all-remote work at scale?

![GitLab journey illustration](/images/all-remote/gitlab-journey-and-navigation.jpg)
{style="max-width: 50%;"}

Given the relative newness of all-remote, many people immediately wonder if a 100% remote company works well at scale. This is largely due to their unfamiliarity with the concept, and it overlooks a different question — does *colocation* work well at scale?

Many individuals have experienced success when working short-term with a small group of people who are not in the same place at the same time. This could be a group project in school, arranging a trip for friends or family, or planning a wedding.

There are fewer examples of large remote teams working successfully, though that is changing due to a variety of factors (e.g. advancements in internet infrastructure, rising costs of living in major metropolitan areas, etc.).

GitLab believes that all-remote is the future of work, and that it not only works well at scale, but works *better* at scale than antiquated colocated models.

In [this GitLab Unfiltered video](https://youtu.be/Rt57pb8KElI), GitLab co-founder and CEO Sid Sijbrandij chats with Prof. Raj Choudhury of Harvard Business School on the topic of remote work.

In response to a question on whether or not all-remote is infinitely scalable, or whether there is an inflection point beyond a certain organization size, Sijbrandij offers the following.

> It scales **better** than the other model. It's not that we [as an all-remote company] have to defend against the question of 'Does this scale?'
>
> A team in one room works really well. A team on one floor probably works OK. A team on multiple floors, you start having some problems. A team across multiple offices, it gets even harder. A team in multiple cities, it gets even harder. A team on multiple continents, that gets super hard. That model breaks down.
>
> There's very little benefit to colocation if you're such a big company. While the benefits of remote — [writing down your processes](/handbook/product/ux/technical-writing/documentation/), stimulating cross-company [informal communication](informal-communication/) — those get much more pronounced at scale.
>
> It's not just that [all-remote] scales. It scales way better. - *GitLab co-founder and CEO Sid Sijbrandij*

## Colocation challenges at scale

![GitLab values illustration](/images/all-remote/gitlab-values-tanukis.jpg)
include

What is often lost in pondering the feasibility of all-remote at scale is the inherent difficulty of creating efficiency across colocated companies with multiple offices.

### Time zones

For a multinational corporation with even two offices, those two offices are remote to each other. While time zones are the bane of our existence at GitLab, they're no less thorny, for example, to an organization with one office in Singapore and another in Dallas.

Reducing headaches related to collaboration across time zones is not a problem which is unique or exclusive to remote. Because all-remote forces a company to lean heavily on [documentation](management/#handbook-goals-and-documentation) of culture and process from the start, a fully remote organization can adapt to the addition of new team members in new time zones with greater poise.

Too, colocated corporations which do not default to [asynchronous communication](management/#asynchronous) in one office will likely struggle to operate in this manner when collaborating with colleagues in a difference office.

### Real estate costs

As colocated companies scale in size, their spend related to real estate will swell. This not only encompasses office space, but related activities such as security, cleaning, remodeling, etc.

Conversely, the relative savings *from* a dearth of real estate grows larger as an all-remote team scales.

### Moving or changing offices

As a colocated team grows in size, it may become necessary to move or change offices. This not only requires a great deal of attention from a planning and execution standpoint, but it's costly in other areas. Moving creates disruption, which negatively impacts efficiency. Too, it can have a very real impact on employees who base their living arrangements on the proximity to work.

There's also the risk of a city becoming unaffordable or unattractive for talent, forcing a move to a new region altogether.

With an all-remote workforce, these risks are fully mitigated.

### Second-class satellite offices

In any colocated enterprise where there is at least two physical offices, it becomes difficult to treat them as equals. While labeling offices as headquarters may indicate importance, employees and investors will likely look to the physical location of the executive team to make a determination on which has higher importance.

This creates unnecessary friction within the organization, particularly impacting those who do not work at the de facto HQ.

## All-remote benefits at scale

With no company offices to maintain, all-remote organizations are able to recognize outsized agility and efficiency at scale.

{{< youtube "EuGsen3FxXc?start=640" >}}

In the [GitLab Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A) video above, GitLab co-founder and CEO Sid Sijbrandij discusses all-remote scalability (amongst other topics) with researchers from [INSEAD](https://www.insead.edu/).

> The more widespread an organization is, the less it benefits from being colocated. An all-remote organization will have to adopt the processes you'd use to control an organization at scale.
>
> [Writing things down](/handbook/values/#write-things-down), [recording things](/handbook/marketing/marketing-operations/youtube/), and [working asynchronously](management/#asynchronous) — we have to master those things early, so they become more prevalent in the organization. Hence, they are easier to scale.
>
> For example, we have the best [onboarding process](learning-and-development/#how-do-you-onboard-new-team-members) of any company in the world. It's not perfect — I can see lots of room for improvement — but no other company has [250+ tasks](https://gitlab.com/gitlab-com/people-group/employment-templates/-/blob/main/.gitlab/issue_templates/onboarding.md#all-gitlabbers) you need to complete when onboarding.
>
> That's more useful at scale. We just hired 600 people in 2019, and they were all able to benefit from that. — *GitLab co-founder and CEO Sid Sijbrandij*

### Team growth

A rapidly growing firm is able to grow even more quickly as an all-remote team, as leadership can focus solely on attracting the right talent and onboarding them appropriately. There are no meetings to plan for office expansion, no requests for families to relocate, and no budget allocations devoted to real estate.

### Hiring

By opening one's [hiring pipeline to the world](hiring/), you're able to capture a more diverse array of applicants. You're also able to recruit individuals who may otherwise opt out of the workforce completely, such as stay-at-home parents, caregivers, and military spouses.

By paying [local rates](https://about.gitlab.com/blog/2019/02/28/why-we-pay-local-rates/), an all-remote company can save money on hiring costs overall and hire more people. By removing the "Are you willing to relocate?" question from the interview process, hiring teams are able to focus on what actually matters: aptitude, drive, passion, empathy, and one's ability to add value to the company.

### Reduced ambiguity

All-remote teams need to be diligent about documenting culture and process from inception. This allows everyone, regardless of location or time zone, to have access to critical information without the burden of tapping someone on their shoulder and inquiring.

At scale, this has a pronounced impact on an organization's ability to reduce confusion and ambiguity. As a team grows, there are ever more people able to contribute, which allows documentation to work even better.

Conversely, small colocated teams are apt to eschew documentation with the assumption that they'll remain in close enough proximity to always share information face-to-face. This becomes increasingly problematic as the company scales, and increasingly difficult to remedy.

### Knowledge dissemination

As any team scales, greater depths of organizational knowledge are acquired. Each additional hire brings in added expertise and experience. In a colocated setting, this influx of knowledge takes place, but it is unequally disseminated. Those physically close to the next new person are most likely to reap the benefits, while those in a different office — or even a different floor — will be disadvantaged in gleaning the same insights.

In an all-remote setting, everyone is equidistant in practical terms. When your "office" is a Slack room, there is less friction in reaching out to a new employee to seek advice. This has a profound impact at scale, and contributes to a more [transparent](/handbook/values/#transparency) work climate.

{{% include "includes/is_this_advice_any_good_remote.md" %}}

## Contribute your lessons

GitLab believes that all-remote is the [future of work]({{< ref "remote-vision" >}}), and remote companies have a shared responsibility to show the way for other organizations who are embracing it. If you or your company has an experience that would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests/) and adding a contribution to this page.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
