---
title: "The 10 models of remote and hybrid work"
description: "The complete guide to 10 models of remote and hybrid work can help you decide what's best for your workplace."
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

## About the types of remote work models

![Remote journey illustration](/images/all-remote/gitlab-remote-journey-color-illustration.png)
{style="max-width: 50%;"}

There are many types of remote arrangements, each with its unique benefits and challenges. GitLab is a fully remote company, and we work with organizations that fall into many different models - from fully co-located, to hybrid, to all-remote.

This guide is a strategic resource for any company looking to solidify your remote or hybrid workplace design. If your workplace is transitioning to remote or hybrid, use this alongside our guide to the [phases of remote adaptation](phases-of-remote-adaptation/) to create your transition plan.

If you'd like more comprehensive remote-work guidance, download [The Remote Playbook](https://learn.gitlab.com/allremote/remote-playbook).

## How to choose a remote team model

The ten models described here should actually be viewed on a spectrum or a sliding scale. You can borrow ideas from any of them to suit your team. Carefully weigh the benefits and disadvantages of each, and consider collecting feedback from your team before making a decision.

Once you've identified a model that should work for you, commit to the transition fully - but be open to iterating as feedback comes in.

For more, see GitLab's [guide to transitioning a company to remote work](transition/).

{{< youtube "_HhlqwJsNyM" >}}

*In the [GitLab Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A) video above, Darren (GitLab) and Anna-Karin (Because Mondays) discuss a number of challenges and solutions related to remote work, transitioning a company to remote, working asynchronously, and defaulting to documentation.*

## 1. No remote

Some companies do not allow for any remote work. This could be due to a leadership mandate, or could be attributed to the nature of the business. For example, medical care, broadcasting from live events, and certain forms of manufacturing require team members to be onsite in a shared location.

It is worth noting, however, that even businesses which have historically been impossible to complete remotely are seeing new opportunity arise thanks to technological advancements.

The da Vinci Surgical System, for instance, has been [used in telesurgery](https://www.bbc.com/future/article/20140516-i-operate-on-people-400km-away), and communications infrastructure is robust enough in some locales to support [remote broadcasting](https://ftw.usatoday.com/2015/06/espn-broadcasts-remote-integration-save-millions).

### Benefits and challenges of a non-remote team arrangement

In addition to the types of work that must be performed onsite, there are teams that can thrive in person and struggle in a distributed environment. Often, this is related to management style, but it's also common in local business where employees are members of the same community.

The major challenge of not allowing remote work is employee engagement and retention. Many people want more flexibility in their work, and co-located companies can struggle to allow team members enough freedom. If your people aren't able to integrate their work with their lives, they may choose to move to a workplace that offers better flexibility.

Multinational corporations with multiple offices across the globe are inherently distributed, even if they do not allow remote work. An employee in one office is inherently remote to another employee in another office, and a refusal to recognize this reality can create dysfunction when attempting to collaborate across offices.

## 2. Remote time

You can also think of "remote time" as "remote tolerated," meaning that it's allowed while not being the norm. This model allows all approved employees in a company to work *some* (but not *all*) days from home, or a place of their choosing.

This is commonly seen in agency and corporate environments where "remote Fridays" are sold as a perk to employment. In such scenarios, it is clear that leadership is not piloting remote work as a means to judge the feasibility of all-remote, but rather compromising with employee demands for greater flexibility.

Such employers are tolerant of some amount of working outside of the office, but still expect an individual to spend the bulk of their time in the office.

Some employers allow specific remote time, such as allowing an individual or team to work remotely a certain amount of days or hours per week. This can vary greatly amongst companies, with some being very rigid (e.g. the entire company may work remotely on Fridays, but there are no exceptions to the day) to very loose (e.g. a proven individual may work remotely up to three days per week of their choosing).

### Benefits and challenges of allowing remote time

This model can be seen as a progression from the previous model, which increases flexibility to help improve the employee experience. The major benefit is an increase in satisfaction as your people are given more autonomy over their time.

Nonetheless, there is still significant ambiguity, and the looseness is generally left up to individual managers to decide. This also hampers mobility. Employees which must commute into the office a certain amount of days per week cannot reasonably explore relocation to areas which may be more amenable, and will likely not invest heavily in creating a focused, ergonomic [workspace](workspace/) at home given the in-office requirement.

## 3. Remote exceptions

In this model, the great majority of a company works in the office (or multiple offices), while some employees may work remotely indefinitely due to their role or location. This is a common model, and is sometimes thought of as a hybrid-remote arrangement. However, it isn't truly hybrid, as the culture of this type of organization will still revolve around the office.

### Benefits and challenges of remote exceptions

The major benefit of this model is that it allows office-based companies to hire outside their office locations - e.g. to provide 24-hour customer support, or to acquire top talent for a hard-to-source skill.

However, the challenges here are many. For office employees, this may be a "no remote" work arrangement, and they may wish for more flexibility. Meanwhile, remote team members are likely to feel disconnected and potentially overlooked. Because the remote experience is defined as an "exception," team members may be considered as an afterthought. This can result in high turnover.

Plus, exceptions who choose to relocate to an area far away from the company's headquarters are always at risk of being called back into the office. In such a scenario, they would be forced to either relocate back to a commutable distance from the headquarters, or resign and look for other employment.

## 4. Remote allowed

In this model, remote work is allowed for anyone at the company (with very few edge cases, such as those who are employed to physically service a building or must work with equipment that cannot be transported).

A variety of limitations can be applied on this model, depending on the organizational design. Some companies offer "hot desking" and/or require team members to come in a certain number of days per month. Others call employees into the office for events and meetings.

What distinguishes this model from hybrid-remote or remote-first is that the office is still considered to be the center of the company. Leadership often works in the office.

### Benefits and challenges of allowing remote work

The biggest benefit to this model is flexibility for team members. Individuals can theoretically choose where and how they work, keeping access to the office for networking and collaboration while also having focus time away from its distractions.

However, job seekers should [inquire](evaluate/) to what degree remote workers are supported in such environments. There is a marked difference between *allowing* remote and *supporting* remote. Some employers believe that remote employees are bypassing a commute, therefore no additional support is warranted.

Other employers make concerted efforts to ensure that remote workers feel included, valued, and welcomed.

Firms such as [Twitter](https://blog.twitter.com/en_us/topics/company/2020/keeping-our-employees-and-partners-safe-during-coronavirus.html) and [Shopify](https://www.shopify.com/blog/working-remotely-for-the-planet) are embracing this approach following the COVID-19 pandemic.

## 5. Hybrid-remote

There are many flavors of [hybrid-remote](hybrid-remote/). The key attribute of a hybrid-remote arrangement is that *some* employees — but not all — are allowed to work remotely 100% of the time. These organizations have at least one physical office, and on any given day, a significant portion of the team physically commutes to that location.

Who works remotely, and who is in the office? This is where hybrid models vary the most. For some teams, certain people are in the office all or most of the time, and others are remote all or most of the time. Other companies are experimenting with assigned remote days and in-office days for everyone. At some workplaces, the employee can choose where they work and how. At many others, it's up to management.

### Benefits and challenges of hybrid-remote work arrangements

Hybrid-remote is one of the most popular models currently being explored by organizations worldwide. The potential benefits are many: workplace flexibility; lower overhead from reduced attendance; increased productivity; and the potential for around-the-clock work.

However, hybrid-remote is a [tempting compromise that masks many downsides](hybrid-remote/). In a hybrid-remote organization, leaders are forced to manage two fundamentally distinct ways of working. There is administrative burden to manage a default-onsite experience and a default-offsite experience, and some employees may choose to oscillate between the two.

While such organizations work well for some employees, it's important to note that many hybrid-remote companies are not comfortable being publicly labeled as such. Their job vacancies may not be listed as remote-friendly. Should you apply for such a role, be prepared to lobby for assuming the role in a remote environment every step of the way.

<!-- TODO: Replace with screenshots. -->

> Sid Sijbrandij on [Twitter/X](https://twitter.com/sytses/status/1264341436138270720)
>
> Below is a thread about the future of remote work after the COVID-19 pandemic is over. I predict that remote will go through a trough of sorrow due to hybrid not working out, and most companies will return to being office based. But many all remote companies will see success.

Want to know more? Read GitLab CEO Sid Sijbrandij's WIRED article: [Hybrid Remote Work Offers the Worst of Both Worlds](https://www.wired.com/story/hybrid-remote-work-offers-the-worst-of-both-worlds)

## 6. Remote days

In an effort to ensure that there is only ever one playing field to manage, some companies may allow remote days where the entire company (executives included) works remotely at the same time. This is a less commonly seen model which may be most attractive to organizations that have invested heavily in real estate, yet where most or all jobs can be done remotely and where most people experience a long, disruptive commute.

### Benefits and challenges of remote days

This approach may lead to stronger remote muscle being built, and [remote-first workflows](how-to-work-remote-first/) used on remote days could become the default even on colocated days. The entire team is subject to a [forcing function](how-to-work-remote-first/): on some workdays, office equipment and workflows just aren't an option.

Remote days can be very beneficial to teams seeking a reduction in commute time, but who also want to keep equitable "face time" and in-person interaction without excluding any members of the team. Meetings can be scheduled on office days, while remote days can effectively become focus days. This also provides some flexibility for team members to reduce work/life conflict.

However, this can be challenging because of the significant context switch that happens between one work environment and the other. Teams need to be prepared with strong workflows so they're able to be effective in a constantly shifting workplace. This model may also reduce flexibility for ad-hoc needs such as appointments, since office time can easily start to be thought of as obligatory.

## 7. Remote first

Remote-first organizations optimize their workplaces for remote. They create documentation, policies, and [workflows](how-to-work-remote-first/) that work when assuming that 100% of the organization is remote, even if some continue to occasionally visit a company-owned office.

These companies work to ensure that offices are simply [venues to work remotely from](how-to-work-remote-first/#offices-are-simply-venues-to-work-remotely-from), and are not the epicenter of power or culture.

[Quora shifting to remote-first](https://news.ycombinator.com/item?id=23646164) in June 2020 is an example of this, as is [Upwork's move](https://twitter.com/hydnbrwn/status/1263840533144727552) in May 2020.

### Benefits and challenges of working remote-first

Remote-first is a model with many benefits, and few challenges. The benefits are the flexibility, productivity and employee satisfaction that come with remote work. Because workflows are designed to function wherever team members are located, this model offers as much flexibility as all-remote. In addition, team members have access to an office where they can connect with colleagues and have in-person meetings as desired.

The biggest challenge with a remote-first team is engagement: different team members will engage differently with remote and on-site work options, and it's possible for some people to "fall through the cracks." These organizations should use data to monitor engagement and satisfaction, and implement programs to make sure employees stay connected to the company.

## 8. Remote only

A remote-only organization has no physical office, and all work is done remotely. This is very similar to being all-remote, with one major distinction: most people are located in the same geographic region, so work hours are biased towards one time zone.

Many companies allow employees to work remotely, but maintain "core team hours." [InVision](https://www.invisionapp.com/inside-design/remote-design-best-practices/), for example, has members spread across multiple countries and time zones, but aims to achieve "at least a 4-hour overlap with InVision's core team hours, 10am–6pm Eastern Standard Time."

This tends to attract employees who are in relative close proximity to one another, or at the very least, in a nearby time zone even if located in a different hemisphere.

### Benefits and challenges of timezone-biased remote work

For smaller remote organizations, this is a very common model. It offers all the benefits of remote work: lower overhead without real estate to maintain; greater flexibility for team members; and higher engagement and retention.

There are two main challenges: first, teams that mostly share a timezone can default to synchronous work, including a heavy meeting load, because they lack a forcing function encouraging them to develop better async practices.

Second, a timezone-biased company that wants to scale its team can run into sourcing challenges if the best people for the job are outside its preferred timezones. Ultimately, organizations using this model may shift to all-remote.

## 9. All-remote

"All-remote" describes organizations that do not maintain offices and work globally across many time zones. [GitLab is an all-remote company](terminology/), with [team members](/handbook/company/team) in 65+ countries.

In all-remote companies, there is no effort placed on trying to coordinate team members to a given time zone. Rather, a bias towards [asynchronous communication](asynchronous/) encourages documentation, discourages synchronous meetings as a default for collaboration, and provides greater flexibility for each member to determine the working hours that best suites their [lifestyle](people/).

This goes beyond enabling a work from home arrangement; all-remote creates a work from *anywhere* arrangement.

{{< youtube "jdN5mj5ieLk?start=2115" >}}

As part of a Harvard Business School case study [interview](https://youtu.be/jdN5mj5ieLk) (shown above), GitLab co-founder and CEO Sid Sijbrandij spoke with Professor Prithwiraj Choudhury on the various stages of remote work.

> We think it's time for clear differentiation between companies which *allow* remote, and companies that will not allow you to come into an office.
>
> People will start understanding the difference. If there is no headquarters, you're not at a satellite office. — *GitLab co-founder and CEO Sid Sijbrandij*

### Benefits and challenges of all-remote work arrangements

GitLab believes that the benefits of remote work outshine its challenges. Benefits include the ability to hire top-tier talent anywhere in the world; happier and more engaged team members; and societal impacts such as distribution of opportunity, increased diversity, and reduced traffic. There's plenty more: read our [guide to the benefits of remote work]({{< ref "remote-benefits" >}}).

However, this does come with disadvantages. These may include loneliness, challenges with onboarding, difficulty building and maintaining culture, and breakdown of boundaries between work and life. Read our complete [guide to the drawbacks of remote work](drawbacks/) for more detail.

## 10. Strictly remote

Taken to its extreme, a strictly remote company would never meet in person and never permit synchronous meetings. This seems impractical, and we are not yet aware of a company that adheres to this. If you are aware of any such company, please [create a merge request](https://docs.gitlab.com/ee/user/project/merge_requests/creating_merge_requests.html) and assign to `@dmurph` to evaluate.

## GitLab Remote Foundations Badge

To test your knowledge about remote work, consider taking the [GitLab Remote Foundations](https://gitlab.edcast.com/pathways/ECL-4d9840ae-0c56-4645-ad7b-452029b1e5bc) course in our learning experience platform to earn the **Remote Foundations** badge. This badge can be earned by *anyone* who wants to learn about GitLab's approach to remote work.

{{% include "includes/is_this_advice_any_good_remote.md" %}}

## Contribute your lessons

GitLab believes that all-remote is the [future of work]({{< ref "remote-vision" >}}), and remote companies have a shared responsibility to show the way for other organizations who are embracing it. If you or your company has an experience that would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests) and adding a contribution to this page.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
