---
title: "Why GitLab uses the term all-remote to describe its 100% remote workforce"
description: Remote work terminology
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

![GitLab all-remote team](/images/all-remote/gitlab-com-all-remote-1280x270.png)
{style="max-width: 50%;"}

GitLab is the world's largest all-remote company. We are 100% remote, with no company-owned offices *anywhere* on the planet. We have {{< team-size >}} team members in more than 65 countries. On this page, we're detailing why we refer to this structure as **all-remote**, and why we prefer this term over others.

## What does "all-remote" mean?

[All-remote](hybrid-remote/#all-remote-upgrade) means that each individual in an organization is empowered to [work and live](people/) where they are most fulfilled. By including the word "all" in "all-remote," it makes clear that every team member is equal. No one, not even the executive team, meets in-person on a daily basis.

{{< youtube "IU2nTj6NSlQ?start=181" >}}

*In the [video](https://youtu.be/IU2nTj6NSlQ) above, GitLab Head of Remote Darren M. discusses the topic of all-remote during an interview with [Stuart Miniman](https://twitter.com/stu), host of [theCUBE](https://www.thecube.net) and GM of Content at [SiliconANGLE Media](https://siliconangle.com). A portion is transcribed below.*

> We don't say you have to work from home — you can work from anywhere.
>
> That's wherever you're most comfortable. Maybe that's a co-working space, maybe that's at a friend's house, maybe that's a different place every month.
>
> We have people [at GitLab] who travel all around the world, and every month they're in a different time zone. We have over 1,100 employees, but none of them operate their days quite the same as anyone else.
>
> The beautiful thing about all-remote is it truly makes everyone a first-class team member. A lot of people will say in a hybrid-remote setting, 'If I don't go to the office frequently enough, I miss out on some things, or maybe I miss out on praise or promotion opportunities.' You feel inferior or deprioritized, as if you don't fully belong.
>
> In an environment like that, you have to take certain approaches to include people. You have to be intentional to include those remote individuals, whereas if it's all-remote, you're all on a level playing field.
>
> All-remote enables a workforce that may have been rejected at other stages — caregivers, working parents, or military spouses, where their spouse has to move at each new deployment. A lot of these people might say 'It's too complicated to continue to reinvent my career with every move along the way.'
>
> In an all-remote setting, your job goes with you as those changes in life happen. That's going to become the norm, where the notion of moving for a career will seem silly. The career should follow you no matter where life takes you.

### Contrasting with remote-first

All-remote is different than [remote-first](hybrid-remote/#differences-between-all-remote-and-remote-first). A remote-first organization embodies many of the principles that create a [thriving all-remote culture](building-culture/) — [handbook-first documentation](handbook-first/), [asynchronous workflows](asynchronous/), no [hybrid calls](/handbook/communication/#hybrid-calls-are-horrible), etc. — but these entities reserve the right to establish a physical company headquarters.

It *is* possible to [find remote-first companies](jobs/#remote-first-companies) with a healthy, understanding culture that works to support both colocated and remote colleagues. Prospective employees should do their own due diligence to make sure the requisite values are established and lived out.

### No company-owned offices

The company [does not have an office occupied by their employees]({{< ref "remote-benefits#for-your-organization" >}}) in an all-remote setting. By extension, this ensures that [every member of leadership is remote](transition/#make-the-executive-team-remote), creating a level playing field that is not possible when even one or two executives congregate daily in the same physical space.

### A more inclusive work environment

Such a structure ensures that each team member is given autonomy to create the [workspace](workspace/) that works best for them, in a place that suits them, creating an environment that is naturally more [inclusive](https://about.gitlab.com/blog/2019/12/06/how-all-remote-supports-inclusion-and-bolsters-communities).

### No location hierarchy

In an all-remote company, there is no single location or region that is more important than another. Team members work [asynchronously](asynchronous/), ensuring that no time zone is seen as [more significant](stages/#remote-biased-towards-one-time-zone) than another.

### Freedom to change locations

All-remote is not partial to where you work, nor how frequently you relocate. All-remote does not mandate that you work from *home*; it simply affirms that there is no company office to commute to. This empowers team members to work from co-working spaces, dedicated rental offices, their home, planes/trains, hotels, parks, or anywhere else where there is a strong, reliable internet connection.

Because there is no central office, all-remote enables team members to live and work in underserved and rural locales. This [bolsters economies in small communities](people/#reversing-rural-depopulation) and simultaneously reduces infrastructure strain on dense cities.

All-remote doesn't mandate that you ask permission before [changing locations](https://youtu.be/tTQAU78QSt8). You are free to work in a different place each day should you choose. This enables [digital nomads](people/#nomads) to coexist with those who must remain in one place due to mobility challenges or family [commitments](people/#caretakers), treating each person as equals regardless of their lifestyle.

## What "all-remote" does not mean

Let's address some of the common misconceptions about all-remote work.

First things first: An all-remote company means there is *no* office where multiple people are based. The only way to not have people in a satellite office is not to have a main office. It's not that we don't have a headquarters, it is that we have 1,000+ (and growing) headquarters!

The terms "remote" and "distributed" are often used interchangeably, but they're not quite the same. We prefer the term "remote" because "distributed" suggests multiple physical offices. "Remote" is also the [most common term](https://www.google.com/search?q=distributed+companies) to refer to the absence of a physical workspace, and being able to do your job from anywhere.

For employees, being part of an all-remote company does not mean working independently or being [isolated](mental-health/#working-to-prevent-burnout-isolation-and-anxiety), because it's not a substitute for human interaction.

Technology allows us to [stay closely in touch](informal-communication/) with our teams, whether asynchronously in text or in real time with high-fidelity conversations through video. Teams should collaborate closely, [communicate](informal-communication/) often, [build relationships virtually](https://about.gitlab.com/blog/2019/07/31/pyb-all-remote-mark-frein), and feel like valuable members of a larger team.

Working remotely also doesn't mean you're physically constrained to home. You're free to work [wherever you want](people/#travelers). That could be at home with family, a coffee shop, a co-working space, or your local library while your little one is enjoying story-time. It could mean that you're [location independent](people/#nomads), traveling around and working in a new place each week. You can have frequent video chats or virtual pairing sessions with coworkers throughout the day, and you can even meet up with other coworkers to work together in person if you're located near each other.

At the organizational level, "all-remote" does not mean simply offshoring work. Instead, it means you're able to [hire the best talent from all around the world](hiring/). It's also not a management paradigm. You still have a hierarchical organization, but with a [focus on output instead of input](management/).

All in all, remote is fundamentally about *freedom* and *individual choice*. At GitLab, we [value your results](/handbook/values/#results), regardless of where you get your work done.

### Careers, not outsourcing or offshoring

It's important to recognize that all-remote is *not* a synonym for outsourcing or offshoring. Outsourcing typically has a central authority who farms work out to low-cost regions for the primary purpose of saving money. This is not the same as spreading career-building opportunity to underserved regions. All-remote seeks to [hire the world's *best* talent](hiring/), regardless of location.

## In-person considerations

![GitLab in-person interactions at Commit SF 2020](/images/all-remote/gitlab-commit-sf-2020-in-person.jpg)
{style="max-width: 50%;"}

GitLab believes that [in-person interactions](in-person/) are valuable. We are intentional about gathering the entire team every 9 to 12 months for a shared experience ([GitLab Contribute](/handbook/company/culture/summit/)), and we encourage team members to gather in-person for [reimbursed holiday gatherings](/handbook/finance/spending-company-money/#year-end-holiday-party-budget), [GitLab Commit](https://about.gitlab.com/events/commit) events, and other opportunities such as conferences and trade shows.

GitLab also gathers its [e-group]({{< ref "structure#e-group" >}}) for a [quarterly four-day offsite]({{< ref "offsite" >}}). These offsites are planned and highly structured as to create exceptional efficiencies. The agenda, takeaways, and changes are all documented for the rest of the company to see, with broader company discussion in a dedicated `#e-group` Slack channel. This is intentionally designed to be [transparent](/handbook/values/#transparency).

There is a marked difference between being intentional and selective about in-person interactions, and forcing a team to endure a daily commute.

## Why does the term "all-remote" matter?

![GitLab all-remote workspace](/images/all-remote/gitlab-all-remote-laptop-map-illustration.jpg)
{style="max-width: 50%;"}

We feel that terminology is important when detailing the future of work. Brushing this off as merely semantics allows each person to interpret terms differently. This could lead to problematic conflation. A shared understanding of what all-remote is, and how it differs from other terms related to remote work, is vital to productive conversation.

## Alternative terms that miss the mark

Remote is fundamentally about *freedom* and *individual choice*. At GitLab, we [value your results](/handbook/values/#results), regardless of where you get your work done.

{{< youtube "jdN5mj5ieLk?start=2115" >}}

As part of a Harvard Business School case study [interview](https://youtu.be/jdN5mj5ieLk) (shown above), GitLab co-founder and CEO Sid Sijbrandij spoke with Professor Prithwiraj Choudhury on the various [stages of remote work](stages/).

> We think this model will be called all-remote.
>
> We think it's time for clear differentiation between companies which *allow* remote, and companies that will not allow you to come into an office.
>
> People will start understanding the difference. If there is no headquarters, you're not at a satellite office. You're not a second-class team member. — *GitLab co-founder and CEO Sid Sijbrandij*

### Distributed

All all-remote teams are distributed by nature, but not all distributed teams are inherently all-remote.

In an all-remote environment, there is no central authority dictating where teams must be built. The term "distributed" does not absolutely imply remote. Many companies refer to themselves as distributed, noting that they have several colocated teams strategically placed in various locales around the globe. While these offices are remote to each other, individuals hired into said offices are still forced to commute.

There are distributed environments where certain individuals are fully remote, and are never required to commute to a company-owned office. This is not the same as all-remote, as there exists a location hierarchy where remote team members are disadvantaged by missing out on colocated conversation. A more appropriate term for this type of environment is [hybrid-remote](hybrid-remote/).

### Fully-distributed

Even the term "fully distributed" falls short, as it does not ensure that there are no company-owned offices in the mix. Taken a step further, a company with no offices that bills itself as fully-distributed *could* plant an office in the future and still maintain its fully-distributed branding. In doing so, it would create an unequal playing field for team members.

Conversely, an all-remote company is bound to never plant an office, removing that worry from the minds of team members.

### Remote-only

While the term "remote-only" does preclude a company-owned office from entering the equation, it is unnecessarily limiting. The word "only" is particularly problematic. This implies that under no circumstance can team members be in the same physical space, while all-remote provides more options on this front. As mentioned earlier, GitLab values in-person interactions and plans them intentionally. All-remote affords this flexibility.

## Evaluating a remote company

If you encounter a company that uses any of the above terms interchangeably, consider reading our guide on [evaluating remote jobs](evaluate/). In it, you'll find a number of probing questions that will uncover the true identity of the work environment.

For added context, consider reading GitLab's guide on the [various stages of remote work](stages/), as well as a comprehensive look at [hybrid-remote](hybrid-remote/).

{{% include "includes/is_this_advice_any_good_remote.md" %}}

## Contribute your lessons

GitLab believes that all-remote is the [future of work]({{< ref "remote-vision" >}}), and remote companies have a shared responsibility to show the way for other organizations who are embracing it. If you or your company has an experience that would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests) and adding a contribution to this page.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
