---
title: "The GitLab Test — 12 Steps to Better Remote"
description: The GitLab Test — 12 Steps to Better Remote
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

![GitLab remote work spectrum illustration](/images/all-remote/spectrum_of_remote_work_gitlab.jpg)
{style="max-width: 50%;"}

GitLab is one of the world's largest all-remote organizations. As we've scaled remote, we've documented over 40 individual guides that comprehensively cover the proven principles of remote-first work, culture, process, and optimization. The foundational elements are distilled in [The Remote Playbook](https://allremote.info).

For some, there's still a looming question: *How do I know if we're running a great remote operation?*

## The GitLab Test: 12 Steps to Better Remote

![GitLab remote work checklist illustration](/images/all-remote/remote_checklist_illustration.jpg)
{style="max-width: 50%;"}

Enter **The GitLab Test: 12 Steps to Better Remote**. Kudos to [The Joel Test](https://www.joelonsoftware.com/2000/08/09/the-joel-test-12-steps-to-better-code) for the nomenclature inspiration.

The great part about this test is it takes around 10 minutes (or less, if you read quickly). Each question is a quick yes or no. A score of 12 is perfect and 11 is tolerable. 10 or lower indicates that there are significant [office-first strongholds](what-not-to-do/) which are preventing your organization from reaching the goal of Phase 4 of Remote Adaption— **[Intentionality](phases-of-remote-adaptation/#phase-4-intentionality)**.

![GitLab remote work environments illustration](/images/all-remote/remote_report_house_gitlab.jpg)
{style="max-width: 50%;"}

### 1. Are senior leaders remote by default?

The *quickest* way to send the *clearest* signal that remote is the future is to start at the top of the organizational chart. Remove execs from the physical office, and you'll quickly figure out what gaps you need to fill with tools and process.

If you force the executive team to work remotely for a meaningful amount of time (over one month, in most cases), you'll discover communication gaps, as well as voids in tooling and process.

If senior leaders default to gathering in the same physical office, decisions are apt to be made less transparently and office-first norms will thwart progress in shifting consensus gathering, brainstorming, collaboration, and decision making to [remote-first](how-to-work-remote-first/).

### 2. Are team members empowered to define their working hours?

Excellent remote teams are able to move work forward in relative concert without stiffly defined working hours. Broadly speaking, defined working hours create comfort in collaborating synchronously, even when it's more efficient to work [asynchronously](asynchronous/). The bigger issue is the implied *reliance* on synchronicity. This creates a foundational risk that collaboration, coordination, and iterative decision making grinds to a halt when someone cannot work their defined shift.

In areas where defined working hours are required by the role or client, great remote organizations will add redundancy or bolstered documentation to enable team members to enjoy the spoils of a [non-linear workday](non-linear-workday/) to whatever degree possible.

### 3. Is most communication about work done asynchronously?

There are [valid reasons](asynchronous/#best-practices-guidelines-and-async-feature-set) to work synchronously. Communicating *about work* is best done asynchronously. This includes status updates, FYIs, process documentation (e.g. how to [alert your security team about a suspected phishing attempt](/handbook/security#what-to-do-if-you-suspect-an-email-is-a-phishing-attack)). It also includes *meeting about a meeting*.

Prerequisites for this to work well are below.

1. Leveraging a single tool to funnel communication about work (e.g. [GitLab](/handbook/product/gitlab-the-product), [Friday](https://friday.app), [Dropbox Spaces](https://blog.dropbox.com/topics/product-tips/make-remote-work-easier-with-dropbox-spaces), [Qatalog](https://qatalog.com))
1. Documented [communication guidelines]({{< ref "communication" >}}) on how and where to communicate about work
1. Executive commitment to [transparency](/handbook/values/#transparency)

### 4. Are your values, and how to live them, explicitly defined and documented?

Great remote organizations undergo an audit which seeks to convert tacit knowledge (e.g. implied knowledge) to explicit knowledge (e.g. documented knowledge). This begins with a values audit.

It's not enough to have core values documented on a company website. Each core value needs [operating principles](/handbook/values/#operating-principles), such that a globally distributed team can reference tangible examples of how common terms like collaboration, iteration, and results are lived out. This also creates shared understanding of what values mean to your specific organization. Ideally, all team members are empowered to contribute proposals to bolster values and share newly-discovered methods of living them out.

### 5. Does every functional department surface work in a single tool with company-wide visibility?

Different company functions may require different tools to drive results. For example, a Design team may use MURAL, Figma, and Photoshop, while a Marketing Operations team leverages tools like Salesforce and Marketo. Great remote organizations leverage a single tool (e.g. [GitLab](/handbook/product/gitlab-the-product), [Friday](https://friday.app), [Dropbox Spaces](https://blog.dropbox.com/topics/product-tips/make-remote-work-easier-with-dropbox-spaces), [Qatalog](https://qatalog.com)) to surface work that is happening in department-specific tools. By surfacing ongoing work, via links or other documentation, this central tool acts as organizational glue. It enables a distributed team to discover what other teams are working toward with clicks instead of meetings. This intentional transparency fosters alignment, purpose, and enables feedback to occur earlier.

### 6. Does your organization work handbook-first?

Great remote organizations are careful not to use the word "documentation" when they really mean "handbook-first." Documentation without taxonomy is a recipe for textual chaos, which is no better than verbal chaos caused by a perpetual loop of unstructured synchronous meetings. [Handbook-first](handbook-first/) is an intentional approach to seek answers *first* before interrupting someone's flow, and to document changes *first* in the appropriate place before making announcements in a chat tool or email.

### 7. Is informal communication formalized?

Great remote organizations do not leave camaraderie (mutual trust and friendship) to chance or serendipity. Camaraderie is created and maintained by [informal communication](informal-communication/), and is a key pillar of [culture]({{< ref "culture#culture-at-gitlab" >}}).

Remote culture is largely built by empowering people to fill their social quota *outside* of work, in local neighborhoods and communities, and then bring that culture *to* work. Too many leaders are looking to replace onsite lunches with virtual lunches and happy hours, instead of empowering workers to look to their communities to further define who they are as people.

### 8. Are communication expectations documented in a single source of truth?

Absent [communication guidelines]({{< ref "communication" >}}), colocated organizations generally default to meetings as the catch-all for communicating about work. Great remote organizations create and document expectations and suggestions around communication, both formal and informal. For transitioning organizations, don't wait until you have implemented a central workspace tool to start articulating communication expectations. Even a [boring solution](/handbook/values/#boring-solutions) such as requiring all work-related meetings to [have an agenda attached](live-doc-meetings/) to the calendar invite can usher in new ways of thinking.

### 9. Does each team member call/collaborate with their own equipment?

A [hybrid call](meetings/#avoid-hybrid-calls) is one that has a mix of participants in the same physical room, together with others who are remote. Hybrid calls should be avoided, as it's better to have everyone on a level playing field for communication and discussion. If a hybrid call must happen, however, everyone should use their own equipment (camera, headset, screen) even if they are physically sitting in the same room.

### 10. Do you have a documented and defined in-person strategy?

Humans are social creatures, and [research](https://papers.ssrn.com/sol3/papers.cfm?abstract_id=2443551) has shown that there is value in in-person interactions. While there are tremendous [advantages]({{< ref "remote-benefits" >}}) to operating a 100% remote company, leaders should consider being intentional about [planning in-person elements](in-person/), even if they're optional for team members.

Quarterly or bi-annual retreats, annual company-wide gatherings, in-person onboarding cohorts, and budgets for ad hoc in-person moments are just a few examples. Great remote organizations recognize that people do not need to spend hours each day commuting to see one another every 24 hours, but budgeting for *strategic* in-person gatherings are useful for bolstering culture and building rapport.

### 11. Do you hire, praise, and promote on values alignment and results?

Great remote organizations actively work against [proximity bias](https://web.archive.org/web/20230603111443/https://www.protocol.com/workplace/proximity-bias-hybrid-work) by utilizing praise and promotion tactics rooted in [values alignment](/handbook/values/#culture-fit-is-a-bad-excuse). A boring solution to encourage this is the use of a [promotion document](/handbook/people-group/promotions-transfers#general-promotion-document-template) which requires a manager detail how an individual has exemplified company values.

### 12. Do you fund individual workspaces and reimburse for out-of-home office use?

Great remote organizations recognize that there are more than two places to work. While "the office" and "home" are two options, the third space is vast. Platforms such as [Codi](https://www.codi.com), [Gable](https://www.gable.to), and [Switchyards](https://switchyards.com) exist to support these arrangements. Enabling team members to [submit for reimbursement](/handbook/finance/expenses#-coworking-or-external-office--space) for coworking or external office space indicates that an organization is so sure of its remote-first workflows that it is comfortable empowering people to work from a variety of spaces.

{{% include "includes/is_this_advice_any_good_remote.md" %}}

{{% include "includes/coursera_gitlab_remote_course.md" %}}

## Contribute your lessons

GitLab believes that all-remote is the [future of work]({{< ref "remote-vision" >}}), and remote companies have a shared responsibility to show the way for other organizations who are embracing it. If you or your company has an experience that would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests) and adding a contribution to this page.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
