---
title: "Considerations for transitioning a company to remote"
description: Considerations for transitioning a company to remote
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

On this page, we're detailing considerations for transitioning a colocated or hybrid-remote company to 100% remote, as well as tips for introducing remote team members to a historically in-office organization.

We maintain a separate guide with blueprints and examples on [transitioning from a *primarily colocated environment* to a *hybrid-remote environment*](hybrid-remote/).

For more, visit GitLab's guide to understanding the [phases of remote adaptation](phases-of-remote-adaptation/).

## How do you transition a hybrid team to a fully remote team?

{{< youtube "MSj6-wC4f9w" >}}

*In the [GitLab Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A) video above, Darren (GitLab) and Janice (Groupdesk) discuss the potential of transitioning a hybrid-remote company to all-remote.*

In general, a company seeking to transition to fully remote should actively avoid or remove [common hybrid-remote pitfalls](hybrid-remote/#disadvantages-to-hybrid-remote) by whatever means necessary. Moreover, it's important for leaders to put themselves in the shoes of a prospective job seeker who will ask [very specific questions](evaluate/) to determine how prepared a company is to thrive in a 100% remote setting.

Much of it boils down to changing whatever elements you need in order to become the remote company that you would want to work for. This requires old habits to be left behind, and intentional effort to be made on areas such as [documentation](handbook-first/), [informal communication](informal-communication/), and working well [asynchronously](asynchronous/).

If existing leadership is not equipped to understand these nuances or lead such a transformation, consider recruiting a Head of Remote with deep experience working in remote settings and leading globally distributed teams. [Andreas Klinger](https://twitter.com/andreasklinger/status/1187841403381878785) aptly articulates this role as being "at the intersection of optimizing internal tooling, processes, transparency, collaboration, efficiency, inclusivity, onboarding, hiring, employer-branding, culture and communication overall."

The specific answer to this question will vary from company to company, and will be impacted by the following attributes.

1. Company size
1. Quantity of offices
1. Percentage of employees who already work remotely
1. Existing tools and technology infrastructure for operating remotely
1. Existing culture surrounding communication and career mapping

### Make the executive team remote

The *quickest* way to send the *clearest* signal that remote is the future is to start at the top of the organizational chart. [Julien Dollen](https://twitter.com/juliendollon), Director of Engineering at Oracle, explains below.

> If you want remote to work, start by cutting off the head. When the chief is remote, all of a sudden everybody is remote and everybody starts writing down everything. What used to be ephemeral and on a whiteboard became written down and stored. — *Julien Dollon, Director of Engineering at Oracle*

Cédric Fabianski, co-founder and CTO at Bearer, [reiterated](https://www.bearer.sh/blog/how-to-make-remote-a-success) that he saw this work well at FreeAgent, too. He notes that by moving the executive suite out of the office, it removes any doubt about leadership's intentions to complete the transition.

### Establish a remote infrastructure

{{< youtube "_HhlqwJsNyM" >}}

*In the [GitLab Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A) video above, Darren (GitLab) and Anna-Karin (Because Mondays) discuss a number of challenges and solutions related to remote work, transitioning a company to remote, working asynchronously, and defaulting to documentation.*

Companies considering a transition to fully remote should ask themselves if they could function if every team member chose to work from their home tomorrow. To get an idea of what needs to be in place from a [tools and technology](/handbook/tools-and-tips) standpoint, consider the following questions in light of the aforesaid scenario.

1. What voids would become apparent?
1. What areas of communication would falter?
1. What confusion would emerge?
1. What tools do we use today that we would continue to use as a fully remote team?
1. What tools that empower fully remote teams should we consider?

Companies that rely on in-office meetings will likely need to embrace a new paradigm, leveraging Zoom and Google Calendar. Too, they should resist the urge to default to [meetings](meetings/), relying instead on [asynchronous communication](asynchronous/) wherever possible.

Enabling access to systems and files across a fully remote company can be very different, and may require a new approach to security.

### Document the culture

![GitLab commit illustration](/images/all-remote/gitlab-commit-illustration.jpg)
{style="max-width: 50%;"}

If you do not have a living, evolving [company handbook](handbook-first/), start one now. Embracing the notion of "if it's not documented, it isn't actionable," is key to detaching from colocated norms and positioning for success with all-remote. Manage expectations that this handbook will never be complete, and it may take months or years to even feel comprehensive.

Ideally, updating the handbook with policies and processes is something that the entire company is empowered and encouraged to do. For existing companies who do not have the luxury of starting their handbook as they start their business, consider hiring an arbiter to kickstart its creation and development. Former journalists and documentarians are great candidates for such a role.

Consider each aspect of your company culture that is unwritten or implied, and [document](handbook-first/) each one. In a fully remote setting, there are no daily in-person interactions where cues are absorbed. Hence, it is vital to over-communicate not just in daily work, but in explaining and detailing values that company culture is built upon.

[GitLab uses GitLab](gitlab-for-remote/) to build, sustain, and evolve its company handbook. GitLab is a collaboration tool designed to help people work better together whether they are in the same location or spread across multiple time zones. Originally, GitLab let software developers collaborate on writing code and packaging it up into software applications. Today, GitLab has a wide range of capabilities used by people around the globe in all kinds of companies and roles.

You can learn more at GitLab's [remote team solutions page](gitlab-for-remote/).

### Close the office

If at all possible, close the office. Shuttering an office (or multiple offices) offers the clearest signal that you're all-in with remote, and leaders are serious about ensuring that no one is treated — consciously or otherwise — as an outsider.

### Equip and educate team members

While remote work is liberating and empowering, it can be [jarring and isolating](drawbacks/) for those who are not equipped to manage the change. In an all-remote or remote-first company, team members are well aware of [what to expect]({{< ref "culture#life-at-gitlab" >}}) even before they apply for a role. In fact, many remote companies receive outsized interest in roles specifically *because* of their remote nature.

It's vital for leadership to understand that there may be resistance to a remote transition from employees who would prefer not to work remotely, or are anxious about the [lifestyle change](people/).

Clear and proactive internal communication is essential to removing fear and instilling excitement about the increased autonomy.

1. Consider building an applicable guide to starting (or moving into) a remote role, akin to [GitLab's guide on the topic](getting-started/).
1. Host AMA (Ask Me Anything) sessions to get a better understanding of team member concerns and perspectives, and use that feedback to shape strategy.
1. Retain workspace consultants to ensure that team members are equipped to work [comfortably and ergonomically in their home](workspace/).
1. Consider a policy that [reimburses fees associated with co-working spaces](/handbook/finance/spending-company-money/), understanding that some employees will thrive in settings that mimic the office.
1. Invest in education, including [conferences](events/), courses, meetups, etc.
1. Formalize and document an [in-person strategy](in-person/), embracing retreats, [company summits](/handbook/company/culture/summit/), etc. to show that bonding in a physical space is still valued.
1. Prepare for micro-groups to form as people relocate. Leverage [geographic Slack channels](/handbook/communication/chat#location-channels-loc_) to retain community even as people use newfound remote freedoms to move to a locale that is more personally fulfilling.
1. Get intentional about [informal communication](informal-communication/). With the removal of daily in-person interactions, you'll need to formalize mechanisms such as coffee chats, team social calls, and co-working calls to form and foster relationships.

### Embrace iteration and transparency in transition

{{< youtube "3HHyjAV3hYE?start=581" >}}

*In the [GitLab Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A) video above, Darren (Head of Remote, GitLab) and Gabe (Senior Product Manager, GitLab) talk on the topic of going slow to go fast, as well as the importance of a "[handbook-first](/handbook/about/handbook-usage/#why-handbook-first)" approach to companywide documentation.*

> I think [documentation](handbook-first/) has to be [instilled as a value](/handbook/values/#write-things-down). It has to start there, and the whole leadership team in an organization has to be onboard.
>
> All of [leadership](/handbook/leadership) needs to understand the importance of documentation — not just with lip service. A true, genuine understanding of its value. If they *truly* understand the value of it, they'll emanate that to their direct reports.
>
> For companies looking to transition to fully remote, a helpful step for leadership is to say: "OK, we're going to be remote-first as a start." This means that a company in transition would optimize everything in its physical office space to be remote-first. Instead of optimizing conference rooms with lots of tables, for instance, you have each employee sit in their own office and wear headsets all day. This is how you prevent remote employees from feeling [disconnected and isolated](hybrid-remote/#disadvantages-to-hybrid-remote).
>
> This is going slow to go fast. Lots of energy up front — you go slow — but that accelerates things dramatically a year or so down the road. — *[Gabe W.](https://gitlab.com/gweaver), Senior Product Manager, GitLab*

Expect bumps along the road. As with any significant business transformation, it's wise to communicate proactively to team members, customers, and investors that obstacles will emerge. Transitioning a company to fully remote, while still running the business, is not easy. It's a long-term bet that the short-term pain will be [worthwhile]({{< ref "remote-benefits" >}}).

Leadership should be completely [transparent](/handbook/values/#transparency) with team members as the transition unfolds. Share headaches and roadblocks as well as successes. This should occur in an agreed channel so that discussion and feedback is centralized, and action items can be clearly disseminated.

[Iteration](/handbook/values/#iteration) is a core value at GitLab, and we strive to [apply iteration to everything](management/#applying-iteration-to-everything) — from [building a product](https://about.gitlab.com/blog/2019/04/26/agile-iteration-unique-onboarding-experience) to shaping our [workspaces](workspace/). This applies to business transformation as well. Implement the [smallest valuable change](/handbook/values/#minimal-valuable-change-mvc), solicit feedback, and tweak or revert if needed. By taking this approach to transforming your business, you're setting the example for how day-to-day tasks should be managed in a fully remote setting.

### Iteration requires empowered teams and workers

The cost of cross-team coordination is difficult to track; in many enterprises, this leads to delays and cost overruns. A [sudden remote transition](remote-work-emergency-plan/) is an opportunity to address always-evolving policies for new applications, procurements, projects, and/or vendors.

The ability to charge forward and deliver capabilities is a combination of a few key activities:

- Open source software to reduce code written
- Dynamically provisioned environments
- Freedom to experiment without consensus
- Monitoring and clean-up to manage resources and costs

Attempting to transition to a remote working environment while maintaining the gatekeeping effects of the system administrators and security teams may hinder aspirational values such as [bias for action](/handbook/values/#bias-for-action). Do not provide access to sensitive data sets or applications to unverified vendors or take any unnecessarily risky approaches, but try to shrink guard rails and take inventory of what is *truly* sensitive and/or confidential.

Leadership must foster creativity and intentionally seek progressive, [two-way door](/handbook/values/#make-two-way-door-decisions) approaches. Once a technique or application is proving itself out in the experimental phase, mature it with security evaluations and reliability. Importantly, any experiments that don't pan out won't have wasted months or years.

## Hiring a Head of Remote Work

Organizations should consider hiring a Head of Remote Work. This may be titled Director of Remote Work, VP of Remote Work, Chief Remote Officer, or a variety of alternatives. Longer-term, this role may evolve into a Head of Workplace Experience, Head of Culture, or similar. Below is a series of fundamental questions that leaders must answer when transitioning to remote. It is unlikely that an existing team will be capable of directing adequate attention to these needs without backfilling for other responsibilities.

Finding a leader with extensive remote experience and a history of successful business or culture transformations will be difficult. Suddenly-remote companies may consider hiring a Chief Documentarian to establish a regimented documentation strategy, and morph this role into a more encompassing one over time. Former editors and publishers may be suitable for such a role.

A sample of questions to be answered by a Head of Remote Work:

1. Who will be responsible for ensuring that newly-remote workers have healthy, ergonomic [workspaces](workspace/) at home?
1. Who will sit down and audit every single perk and benefit offered globally, and ensure that remote workers have equivalent benefits to those who choose to work onsite?
1. Who will lead an end-to-end [tools audit](collaboration-and-whiteboarding/), ensuring that tools which do not support asynchronous workflows are deprecated or replaced, and ensuring that existing tools are used in [remote-first ways](how-to-work-remote-first/)?
1. Who will create, establish, and champion your firm's [documentation strategy](handbook-first/), hiring the right team to ensure that communication voids are closed?
1. Who will coach your executives on the nuanced benefits of one or more being [remote by default](remote-work-emergency-plan/), sending clear signals that praise and promotion are not tied to a physical building?
1. Who will be the voice of the distributed worker, ensuring equality and belonging for those who may never step foot in a corporate office?
1. Who will ensure that [learning and development](learning-and-development/) principles address the challenges of remote [hiring](hiring/), remote [interviewing](interviews/), remote [onboarding](onboarding/), remote [management](management/), remote promotions, and beyond?
1. Who will conduct an end-to-end process audit and provide structured replacements for remote-last workflows, such as a reliance on [synchronous meetings](meetings/) for consensus gathering and collaboration?
1. Who will lead the reevaluation of company [values]({{< ref "remote-values" >}}), and subsequent editing and bolstering such that everyone understands how to treat others without the need for routine in-person contact?
1. Who will put a travel strategy in place such that [in-person engagements](in-person/) become a core part of [building company culture](building-culture/)?
1. Who will revise your company's talent acquisition strategy, creating a clear and concise answer to "What's your stance on workplace flexibility?"
1. Who will build a visible [talent brand]({{< ref "culture#life-at-gitlab" >}}) demonstrating how remote workers are supported and included? (This will create significant sway in your Glassdoor reviews.)
1. Who will lead existing executives in [transforming](being-a-great-remote-manager/) their expectations and ways of working, coaching them to model the [unlearning of old habits]({{< ref "candidate-faq" >}}) and embracing new ones in transparent fashion?
1. Who will ensure that teams have the tools, direction, and coaching they need to [become documentarians](self-service/)?
1. Who will outline a multi-year remote transformation strategy with quarterly milestones and objectives, coaching a team through iterative change and celebrating small wins along the way?
1. Who will champion your culture and values, not only to galvanize teams through a pandemic, but excite them by building a more disciplined, cohesive, [asynchronous](asynchronous/), inclusive, and diverse future?
1. Who will understand the nuances of remote and the myriad business implications beyond just today?

Transitioning to remote work [is not a binary switch](phases-of-remote-adaptation/) that is flipped. While many organizations were thrust into their homes overnight, that is only the first of many steps. Remote is a journey of iteration — a tireless, evolving trek that demands a leader, or else your firm risks falling back into [conventional habits](what-not-to-do/) or creating a fractured culture where no one is clear on what is expected.

The larger your organization is, or the more deeply it is entrenched in colocated tradition, the more significant the challenge and compensation expectations. This role will be far more complex in a [hybrid-remote](hybrid-remote/) setting compared to an [all-remote](terminology/) setting, as you're answering every question twice.

## Adding remote employees to a primarily in-office culture

![GitLab values illustration](/images/all-remote/gitlab-values-tanukis.jpg)
{style="max-width: 50%;"}

While GitLab believes that all-remote is the best structure to ensure that [our values are lived]({{< ref "remote-values" >}}) and no one is treated as a second-class team member, the reality is that most companies formed to date have at least one physical office.

In many instances, it is not feasible to transition entirely to all-remote, though leaders and recruiters are starting to realize that remote work is the future. Stripe, for example, has stated that its "[fifth engineering hub is remote](https://stripe.com/blog/remote-hub)."

> Stripe has engineering hubs in San Francisco, Seattle, Dublin, and Singapore. We are establishing a fifth hub that is less traditional but no less important: Remote. We are doing this to situate product development closer to our customers, improve our ability to tap the 99.74% of talented engineers living outside the metro areas of our first four hubs, and further our mission of increasing the GDP of the internet. — *David S., CTO at Stripe*

Jack Dorsey, CEO at Twitter, has shared that remote is the company's future.

<blockquote class="twitter-tweet tw-align-center"><p lang="en" dir="ltr">The <a href="https://twitter.com/hashtag/TweepTour?src=hash&amp;ref_src=twsrc%5Etfw">#TweepTour</a> is over! 27 offices visited around the world, our last visit being our future: remote. So many stories, so many amazing folks. Thank you all! <a href="https://twitter.com/hashtag/oneteam?src=hash&amp;ref_src=twsrc%5Etfw">#oneteam</a> ❤️</p>&mdash; jack 🌍🌏🌎 (@jack) <a href="https://twitter.com/jack/status/1189340061206306816?ref_src=twsrc%5Etfw">October 30, 2019</a></blockquote> <script async src="https://platform.twitter.com/widgets.js" charset="utf-8"></script>

In instances where a company intends to maintain at least one physical office, but will allow remote hires for certain roles, added care must be taken. There is effectively nothing that can be done to completely remove bias that comes from seeing someone in the same physical space day after day, so leadership must be intentional about considering remote employees for input, feedback, promotion, and mentorship.

Added care must be taken to ensure that the usual [downsides of hybrid-remote](hybrid-remote/#disadvantages-to-hybrid-remote) are not tolerated. Conversely, employees considering a hybrid-remote role must be prepared to gracefully manage said challenges should they arise.

Above all, a company which intends to begin hiring remotely (or allowing existing employees to optionally transition from colocated to remote) **must structure the company as if every single team member were remote**.

This means that any hallway conversations must be documented and disseminated for all who were not present to hear, and it means that in-office workers must each use a single webcam and microphone to join a group call (as opposed to in-office colleagues [gathering in a conference room with a sole camera](/handbook/communication/#hybrid-calls-are-horrible)).

It means, for example, that colleagues who are sitting side-by-side must use a public Slack channel to communicate, as vocalizing a conversation would be unfair to team members who are remote.

This requires tremendous effort, day after day, from every member of the company.

## GitLab Knowledge Assessment: Transitioning a Company to Remote

Anyone can test their knowledge on Transitioning a Company to Remote by completing the [knowledge assessment](https://docs.google.com/forms/d/e/1FAIpQLSc4bQbcRMBtcj_ZFCZ2VIr6tUyasr9N6L2vQnwnpDd4yHQ4Xg/viewform). Earn at least an 80% or higher on the assessment to receive a passing score. Once the quiz has been passed, you will receive an email acknowledging the completion from GitLab. We are in the process of designing a GitLab Remote Certification and completion of the assessment will be one requirement in obtaining the [certification](https://about.gitlab.com/learn/certifications/public). If you have questions, please reach out to our [Learning & Development](/handbook/people-group/learning-and-development) team at `learning@gitlab.com`.

{{% include "includes/is_this_advice_any_good_remote.md" %}}

## Contribute your lessons

Making remote work well, particularly in companies with colocated roots, is a shared challenge. If you or your company has an experience that would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests) and adding a contribution to this page.

Return to the main [all-remote page]({{< ref "_index.md" >}}).
