---
title: "What not to do when implementing remote: don't replicate the in-office experience remotely"
description: What not to do when implementing remote
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

Due to global issues concerning [Coronavirus (COVID-19)](https://www.cdc.gov/coronavirus/2019-ncov/index.html), rising rents in concentrated urban areas, and the ongoing battle amongst organizations for recruiting and retaining top talent, there has been a noted shift in appetite for working remotely. Companies which were previously against remote work are suddenly considering remote, or implementing remote, with varying degrees of intentionality.

The reality is that almost every company is [already a remote company](scaling/#does-all-remote-work-at-scale). If you have more than one office, operate a company across more than one floor in a building, or [conduct work while traveling](working-while-traveling/), you are a remote company. It behooves all of these firms to adopt remote-first practices, even if some interactions occur in a shared physical space.

On this page, we're detailing what not to do when transitioning to remote, or moving towards remote.

## Do not assume that there are no resources available yet

![GitLab all-remote team](/images/all-remote/gitlab-com-all-remote-1280x270.png)
{style="max-width: 50%;"}

GitLab has created a **[comprehensive guide to working well remotely]({{< ref "guide" >}})**, covering popular topics such as:

1. [Transitioning to remote]({{< ref "transition" >}})
1. [Forcing functions to work remote-first]({{< ref "how-to-work-remote-first" >}})
1. [Hybrid-remote pitfalls to avoid]({{< ref "hybrid-remote" >}})
1. [Phases of remote adaptation]({{< ref "phases-of-remote-adaptation" >}})
1. [Meetings]({{< ref "meetings" >}})
1. [Management]({{< ref "management" >}})
1. [Scaling]({{< ref "scaling" >}})
1. [Informal communication]({{< ref "informal-communication" >}})
1. [Building culture]({{< ref "building-culture" >}})
1. [Combating burnout, isolation, and anxiety]({{< ref "mental-health" >}})
1. [Embracing asynchronous workflows]({{< ref "asynchronous" >}})
1. [Remote workspaces]({{< ref "guide#workspac" >}})
1. [Getting started in a remote role]({{< ref "getting-started" >}})

The pages within, just like the entire GitLab [handbook](/handbook), are [publicly accessible](hiring/#make-your-strategy-public). Please consider studying these guides, implementing them, and contributing your learnings to make them better.

## Do not replicate the in-office/colocated experience, remotely

It is vital to recognize and appreciate this point: **an organization should not attempt to merely replicate the in-office/colocated experience, remotely**.

Remote work is not traditional work which is simply conducted in a home office instead of a company office. There is a natural inclination for those who have not personally experienced remote work to assume that the core (or only) difference between in-office work and remote work is location (in-office vs. out-of-office). This is inaccurate, and if not recognized, can be damaging to the entire practice of working remotely.

The principles of remote work are different. The approach to conducting work is different. Just as multi-level office buildings required elevators and phones to be functional as workplaces, teams working remotely should embrace [tools](handbook-first/#tools-for-building-a-handbook) (GitLab, Figma, etc.) that enable [asynchronous communication](asynchronous/) and should reconsider traditional thoughts on items such as [meetings](meetings/) and [informal communication](informal-communication/).

## Do not transfer all in-person meetings to virtual

![GitLab customer path](/images/all-remote/gitlab-customer-path.jpg)
{style="max-width: 50%;"}

Remote work isn't something you do as a reaction to an event — it is an *intentional* approach to work that creates greater [efficiency](/handbook/values/#efficiency), more [geographically and culturally diverse teams](https://about.gitlab.com/blog/2019/12/06/how-all-remote-supports-inclusion-and-bolsters-communities), and heightened [transparency](/handbook/values/#transparency).

What is happening en masse related to Coronavirus (COVID-19) is largely a temporary work-from-home phenomenon, where organizations are not putting remote work ideals into place, as they expect to eventually require their team members to resume commuting into an office.

Merely [transferring planned office meetings to virtual meetings](https://www.abacusnews.com/culture/worlds-biggest-online-population-staying-home-and-chinas-internet-cant-cope/article/3050947) misses an opportunity to answer a fundamental question: is there a better way to work than to have a meeting in the first place?

## Do not assume that everyone has access to an optimal workspace

![GitLab all-remote team](/images/all-remote/gitlab-com-all-remote-v3-dark-1280x270.png)
{style="max-width: 50%;"}

While long-term remote workers have had years to tweak and iterate on their [home office](workspace/), those who are thrust into working from anywhere may be ill-prepared. Organizations should not expect team members to be masters in office design and ergonomics. Too, what works best for one person [will look different](https://about.gitlab.com/blog/2019/09/12/not-everyone-has-a-home-office) than another person.

If [transitioning to remote](transition/), organizations should empower team members to [spend company money as if it is their own](/handbook/finance/spending-company-money/) when constructing a home office. Consider [reimbursing](/handbook/finance/spending-company-money/#coworking-or-external-office--space) expenses related to coworking spaces and external offices, as some team members will prefer to work outside of their homes.

## Do this, not that

Some may find it useful to see examples of comparisons between colocated norms, and the most closely correlated remote recommendation. You will notice that many suggestions link back to [asynchronous](asynchronous/) workflows, [transparency](/handbook/values/#transparency), and working [handbook-first](handbook-first/), which are cornerstones to doing remote well.

Note that all of these suggestions are not exclusive to remote. Even for companies which intend to maintain offices or transition to a [hybrid-remote company](hybrid-remote/), implementing [remote-first techniques](hybrid-remote/#differences-between-all-remote-and-remote-first) ensure that all employees are viewed as first-class citizens and companies avoid the [five dysfunctions](/handbook/values/#five-dysfunctions) of a team.

- Sending an email or Slack message <> Leverage a [transparent, asynchronous communications tool](handbook-first/#tools-for-building-a-handbook)
- Scheduling a meeting <> Communicate [asynchronously](asynchronous/)
- Gathering executives in a shared physical space <> Model commitment to remote by [getting the executive team out of the office](transition/#make-the-executive-team-remote)
- Grappling with a large project <> Breaking discussions down into their [smallest, most minimally viable parts](/handbook/values/#iteration)
- Gathering consensus for a one-way door decision <> Break decisions down into a series of smaller, [two-way door decisions](/handbook/values/#make-two-way-door-decisions) which can be iterated upon and reverted
- Sharing updates verbally <> Write things down with detail and precision, in a [low-context manner](effective-communication/)
- Expecting an immediate response <> Approach your work as if [everyone else is asleep](asynchronous/#mental-health), and work to create a [non-judgmental culture](mental-health/#creating-a-non-judgemental-culture)

## Do not assume that remote happens overnight

![GitLab all-remote team](/images/all-remote/gitlab-com-all-remote-v4-dark-1280x270.png)
{style="max-width: 50%;"}

For companies who move into an office building, it's unlikely that everything works perfectly on the first day. Signage may be missing, security gates may be erratic, elevators may be stuck, etc. Adapting to a workplace takes time, and polish comes with [iteration](/handbook/values/#iteration).

The same is true when embracing remote work. Particularly for companies which were established with colocated norms, it is vital for leadership to recognize that the remote transition is a *process*, not a binary switch to be flipped. Leaders are responsible for embracing iteration, being open about [what is and is not working](transition/), and messaging this to all employees.

Remote isn't a structure that merely works or doesn't work. Remote is a way of working that requires intentional and perpetual care and evaluation — just as you'd expect in an office environment. Working well remotely (or in-office, for that matter) is not something that is ever *done* or *accomplished*. There are always new tools to consider, new workflows to integrate, and new expertise to ingest.

Too, what works for a small remote team may not work for a remote team consisting of thousands of team members. All of this is equally true for colocated companies, though it tends to be less amenable to Band-aid (temporary) solutions in a remote environment.

## Do not assume that remote management is drastically different

![GitLab journey illustration](/images/all-remote/gitlab-journey-and-navigation.jpg)
{style="max-width: 50%;"}

In truth, [managing a remote company](management/) is much like managing any company. **It comes down to trust, communication, and company-wide support of shared goals**, all of which aid in [avoiding dysfunction](/handbook/values/#five-dysfunctions).

Remote forces you to do the things you should be doing [way earlier and better](https://nohq.co/blog/sid-sijbrandij-people-dont-want-to-commute-they-ju). It forces discipline that sustains culture and efficiency [at scale](scaling/), particularly in areas which are easily deprioritized in small colocated companies.

It's important to not assume that team members understand good remote work practices. GitLab managers are [expected]({{< ref "structure#management-group" >}}) to coach their reports to utilize [asynchronous communication](management/#asynchronous), be [handbook-first](/handbook/about/handbook-usage/#why-handbook-first), design an [optimal workspace](workspace/), and understand the importance of [self-learning/self-service](self-service/).

Leaders should ensure that new remote hires read a [getting started guide](getting-started/), and make themselves available to answer questions throughout one's journey with the company.

## Do not assume your existing values can remain static

![GitLab values illustration](/images/all-remote/gitlab-values-tanukis.jpg)
{style="max-width: 50%;"}

To operate well as a remote enterprise, your values [must be in support of this way of working]({{< ref "remote-values" >}}). GitLab's collection of [values](/handbook/values/) and [operating principles](/handbook/values/#operating-principles) contribute to a thriving all-remote environment. Consider studying the nuances of these values and adjusting or adding to your company's existing values. Values that were established to support colocated norms may not apply to remote, particularly those which obstruct transparency.

Don't be quick to brush values off as understood, either. For example, collaboration in a colocated space  is routinely demonstrated by gathering people in a shared physical space in search of [consensus](management/#separating-decision-gathering-from-decision-making). [Collaboration](/handbook/values/#collaboration) in a remote setting is demonstrated by empowering the greatest amount of people to contribute insights asynchronously while enabling the DRI (directly responsible individual) to [make decisions without explanation]({{< ref "directly-responsible-individuals#empowering-dris-no-explanation-needed" >}}).

{{% include "includes/is_this_advice_any_good_remote.md" %}}

## Contribute your lessons

GitLab believes that all-remote is the [future of work]({{< ref "remote-vision" >}}), and remote companies have a shared responsibility to show the way for other organizations who are embracing it. If you or your company has an experience that would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests) and adding a contribution to this page.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
