---
title: "Considerations for working while traveling"
description: Considerations for working while traveling
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

![GitLab transport illustration](/images/all-remote/gitlab-transport.jpg)
{style="max-width: 50%;"}

On this page, we're detailing considerations for optimizing comfort and efficiency when taking your office with you while traveling.

## Connect to the Internet securely

When possible, do not connect to public WiFi networks. If a public WiFi network is your only option, it's crucial to employ robust security measures such as using a [personal VPN](/handbook/tools-and-tips/personal-vpn/#what-is-a-personal-vpn).

Additionally, GitLab team members should be wary of connecting to unsecured networks or accessing sensitive information over public connections, even when using a VPN. When Ethernet connections are available, they generally offer a more secure option than WiFi due to their physical nature, but it's still essential to verify the network's authenticity and utilize encryption protocols whenever possible.

## Internet redundancy

{{% cardpane %}}
{{% card footer="A smartphone with tethering enabled is vital for digital nomads. Photo by Darren Murph" %}}
![A smartphone with tethering enabled is vital for digital nomads. Photo by Darren Murph](/images/all-remote/smartphone-tethering-laptop-dm.jpg)
{{% /card %}}
{{% /cardpane %}}

For remote workers, a robust connection to the internet is [vital](https://about.gitlab.com/blog/2016/03/23/remote-communication). This is easier to control at [home](https://about.gitlab.com/blog/2019/09/12/not-everyone-has-a-home-office) or in a [coworking venue](https://about.gitlab.com/blog/2019/09/04/not-all-remote-is-created-equal), and it requires special consideration when on the road. [Avid travelers](https://about.gitlab.com/blog/2019/06/25/how-remote-work-at-gitlab-enables-location-independence) and dedicated [nomads](people/#nomads) should maintain at least two connectivity sources — ideally, two sources that connect to different mobile networks.

A simple way to achieve this redundancy is to lean on one mobile network operator for your smartphone (and enable tethering if it is not on by default with your current plan), while procuring a mobile hotspot through a different operator.

Another way to improve your chances of a strong internet connection while traveling is to bring an Ethernet cord and adapter that allows you to connect an ethernet cord to your laptop. Not all hotels or coworking spaces will provide an ethernet connection option, but if it is available Ethernet is your best bet for a fast, secure internet connection.

If you plan to travel through [various countries and continents](https://about.gitlab.com/blog/2017/06/30/there-and-back-again-in-one-release), plan ahead. Services such as [KnowRoaming](https://www.knowroaming.com/) and [Skyroam](https://soliswifi.co/) enable connections across borders. While it's possible to acquire a local SIM card in most countries, you'll need an unlocked smartphone or hotspot. Plus, you may need a basic understanding of the local language, local currency, and to shop during regular business hours.

### Buy local data with an eSIM, without changing your SIM card

If your phone supports [eSIMs](https://www.digitaltrends.com/mobile/esim-explainer) you may also be able to use services like
[GigSky](https://www.gigsky.com) or [Airalo](https://www.airalo.com/) which allow you to purchase affordable local data plans
on demand without needing to change SIM cards. Even if you don't purchase the plan
you can use such a service as a redundant option if your local or roaming SIM
is not getting reliable service.

Some tips for using Airalo:

- Purchase your eSIM before you travel and be sure to activate it while connected to WiFi.
- Have another phone handy so that you can take a picture of the QR code needed to activate your eSIM. This way you can scan it with the phone you're using with the eSIM.
- On the screen where your QR code appears, open the link to the activation instructions. There may be an additional step required to activate the eSIM which involves updating your APN information. This might not appear in the general activation instructions in Airalo's FAQs because it is specific to the eSIM you purchased.

## Equipment and ergonomics

![GitLab code illustration](/images/all-remote/gitlab-code-review.jpg)
{style="max-width: 50%;"}

Working while traveling requires a delicate balance. It's wise to have a minimalist mindset when it comes to equipment, as each additional item creates additional burden in transit.

However, long-term travelers should consider health, ergonomics, and comfort, and invest in the appropriate equipment. Examples include laptop risers, global power adapters, external peripherals (keyboard, mouse, etc.), a backup battery, comfortable headphones, and a rugged backpack with support straps. [Secondary displays](https://support.apple.com/en-us/HT210380) add weight but may be worthwhile for the productivity gains.

Consider where you plan to work on the road, and what elements of your [home workspace](workspace/) you may miss. This will help you plan your purchases, should any be necessary.

Learn more about [traveling workspaces from the GitLab blog](https://about.gitlab.com/blog/2019/10/10/whats-in-your-backpack).

## RV/camping, long-term rentals, and couch-surfing

{{% cardpane %}}
{{% card footer="Working from the ends of the earth is a major perk of all-remote. Photo by Darren Murph" %}}
![Working from the ends of the earth is a major perk of all-remote. Photo by Darren Murph](/images/all-remote/gitlab-working-easter-island-dm.jpg)
{{% /card %}}
{{% /cardpane %}}

Being able to work from anywhere enables new lifestyle possibilities, including [extended road trips in an RV/camper](https://about.gitlab.com/blog/2019/06/25/how-remote-work-at-gitlab-enables-location-independence). Those considering such a lifestyle should peruse online forums to understand the day-to-day demands, and take care to plot out your journey in way that doesn't leave you scrambling for a connection.

Call campgrounds in advance and ask for speed test details on their WiFi, and use online coverage maps to determine what will be available from a mobile operator. Consider weather and facilities as well.

For those looking for a somewhat more stable version of the continual road trip, consider long-term rentals or [couchsurfing](https://www.couchsurfing.com). Many rental properties on [VRBO](https://www.vrbo.com), [Airbnb](https://www.airbnb.com), etc. offer significant discounts for those willing to rent for one or more months. If you suspect you'll need a vehicle to properly explore the area, inquire with the host. It's possible that they have a personal vehicle to include for the length of your stay for a nominal fee. Be sure to ask for a speed test before booking to ensure that you will have a satisfactory internet connection upon arrival, and take at least one additional internet source (smartphone or mobile hotspot) as a backup.

## Communicate your status and location

{{% cardpane %}}
{{% card footer="Working at GitLab Commit London 2019" %}}
![Working at GitLab Commit London 2019](/images/all-remote/gitlab-commit-london-coworking-2019.jpg)
{{% /card %}}
{{% /cardpane %}}

The beauty of [asynchronous communication]({{< ref "communication" >}}) is that you're able to travel more freely without the burden of needing to be online at a specific time. When you take your office on the road (or to the skies), keep your Slack status updated with your location, time zone, and expected working hours. This enables team members around the globe to easily recognize where you're at, and respect shifting work hours.

At GitLab, and other companies using Google Apps, your coworkers, trying to
schedule meetings or interviews with you, will rely on Google calendar as the
source of truth for your availability. As such it is important that your
working hours are set and your timezone is updated as soon as possible. It's
best to do this before boarding a flight as it gives people scheduling more
notice. Unfortunately, there is no way to schedule a timezone change ahead of
time in Google calendar. There may be times when you need to reject a
calendar invite ahead of time due to your working hours changing. An option to
alleviate this issue is to add a blocking calendar event during times when you
won't be working while traveling and this can signal clearly to the coworkers
when you will be working by looking at the unblocked times.

## Connect with locals

At GitLab, our [Visiting Grant]({{< ref "incentives#visiting-grant" >}}) partially reimburses travel when one team member travels to visit another. In an all-remote setting, this encouragement is important. It sends a message that we should seek out opportunities to spend face-to-face time with colleagues when we travel.

For those in other remote companies, consider asking if there are colleagues located in areas where you intend to travel. If not, engage with local coworking spaces in order to build community and seek advice on the areas where you're traveling.

{{% include "includes/is_this_advice_any_good_remote.md" %}}

## Contribute your lessons

GitLab believes that all-remote is the [future of work]({{< ref "remote-vision" >}}), and remote companies have a shared responsibility to show the way for other organizations who are embracing it. If you or your company has an experience that would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests) and adding a contribution to this page.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
