---
title: "How to create the perfect home office setup for remote working"
description: Considerations for a Productive Home Office or Remote Workspace
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

## Why is your home office setup so important?

![GitLab all-remote laptop illustration](/images/all-remote/gitlab-all-remote-laptop-map-illustration.jpg)
{style="max-width: 50%;"}

[Remote work](getting-started/#what-exactly-is-a-remote-job) provides the flexibility to work from anywhere. For many people, that means you can customize your home workspace to your unique needs. It's important to configure a remote setup that works best for you. If you're just getting started in a remote role, [check out this guide](getting-started/#experiment-with-work-environments) for more tips.

## What is the best way to design a work from home setup?

[Setting up a home office](https://about.gitlab.com/blog/2019/09/12/not-everyone-has-a-home-office) can be difficult. Many office spaces hire design professionals to create the workspace, but that burden shifts to employees in a remote environment.

While there are [benefits]({{< ref "remote-benefits" >}}) to ditching the cubicle, it can feel overwhelming to design a new workspace. It's not as hard as you think to create a space where you can be comfortable, focused, and productive.

Workspace expert Ryan Anderson from [MillerKnoll](https://www.millerknoll.com) shares how to set up a personal workspace using best practices for ergonomics, productivity, and environment.

{{< youtube "l9jmb8TE7sw" >}}

Like Ryan says, it's important to view your home office as an evolving project. [Iteration](/handbook/values/#iteration) applies to workspaces, too. As you begin working in your office, you may realize that you need to shift your monitors, add lighting, or find that you get more done in silence or ambient noise than wearing headphones playing music.
GitLab teamed up with the workplace design experts at Herman Miller to create the **[Work-From-Home Field Guide](work-from-home-field-guide/)**. This resource is a blueprint for leaders and remote teams to build healthier workspaces, no matter where work gets done. On this page, we're sharing lessons from that guide, with a lot of added detail.

## The importance of choosing the right workspace equipment

Setting up a home office requires two types of equipment: technology and furniture. Budget, physical space, accessibility, or any number of other factors may limit your ability to find the gear that will serve you best. Plus, you'll probably look for equipment that suits your taste.

While we can't answer every equipment question for you, here's an in-depth guide to what some of our workplace experts are using in their own home offices.

![GitLab commit illustration](/images/all-remote/gitlab-commit-illustration.jpg)
{style="max-width: 50%;"}

## What technology do I need for remote working?

### Internet connection

Since remote workers are responsible for internet connectivity, invest in a substantial home internet connection. You may also want to have a backup in case your connection fails - for example, you could upgrade your smartphone/plan to support tethering or invest in a dedicated mobile hotspot or MiFi.

Assuming you're lucky enough to have excellent access, you may also want to set up a secondary connection so there's enough bandwidth for everyone working from your location. One person uploading a large file could impact the audio or visual quality of another person's [video call](https://about.gitlab.com/blog/2019/08/05/tips-for-mastering-video-calls) if they are trying to share a single connection.

### PC

Refer to your company's policy for specifics on [purchasing a computer or laptop](/handbook/it/end-user-services/onboarding-access-requests#laptops). Since this will your main mode of working and communicating, be sure the specs and speed fit your optimal way of working.

### Camera with video capability

In an all-remote setting, [video calls](/handbook/communication/#video-calls) are vital to maintaining close relationships with clients, partners, and colleagues. While voice calls are flexible and allow for uniquely efficient lifestyles (e.g. listening to a conference call while running in a park), it's important to integrate video into [workplace communication](meetings/).

There are generally three tiers of camera quality for at-home workspaces (professional studio rigs notwithstanding).

1. Mirrorless camera or DSLR with dedicated lens (high-end)
1. Dedicated USB webcam (mid-tier)
1. Built-in webcam on a phone, laptop, or external display (baseline)

#### Mirrorless or DSLR camera

For optimal image quality in video calls, a dedicated mirrorless camera or DSLR is the ideal. *The Verge* maintains a [basic setup guide](https://www.theverge.com/21244380/webcam-camera-how-to-dslr-mirrorless-capture-card-usb-hdmi) if you're new to the concept. Sony's Alpha line of mirrorless cameras are excellent for webcam use. However, these types of cameras and their accessories can be very expensive, and may not be right for everyone's needs. Before committing, read the following considerations.

1. Make sure your camera supports constant AC power (typically via micro-USB). If not, order a dummy adapter which slots in your battery compartment.
1. Determine if you need a USB capture card, which converts a camera's HDMI video output stream into a Zoom-friendly webcam stream. Many manufacturers, like Sony and Nikon, are [releasing software](https://imagingedge.sony.net/en-us/ie-desktop.html) that negates the need for this added piece of hardware.
1. Toggle the right settings. Put your camera in movie mode, enable clean HDMI output (so you don't have menu icons in your webcam feed), disable Auto Power Off, enable servo tracking (if applicable), enable continuous face tracking (if available), and tweak the exposure and white balance to create a normalized image based on your room's lighting conditions.
1. Don't skimp on a mounting solution. You'll need a heavy duty desk clamp, such as the [Manfrotto 035RL](https://www.bhphotovideo.com/c/product/546356-REG/Manfrotto_035RL_035RL_Super_Clamp_with.html), and articulating arm like the [Impact 3 Section](https://www.bhphotovideo.com/c/product/1015864-REG/impact_3_section_double_articulated.html) to manage the heft of a mirrorless camera or DSLR with lens attached.

#### Optimized webcam or manufacturer camera setup

Most phones and laptops come with passable webcams direct from the manufacturer. If you're on a budget or travel often, this may be the best option for you. However, built-in cameras do not offer optimal quality.

If you take frequent video calls in your home workspace, a dedicated webcam like the [Logitech Brio Ultra HD Pro](https://www.logitech.com/en-us/products/webcams/brio-4k-hdr-webcam.960-001105.html) offers a higher resolution camera compared to built-in cameras, and is better able to handle low-light scenarios. Many dedicated webcams also include a software suite for touching up one's appearance, tweaking white balance, and applying background themes when paired with a green screen. These are also less complicated to install and maintain compared with mirrorless/DSLR rigs.

Consider [selecting a webcam](https://www.nytimes.com/wirecutter/reviews/the-best-webcams/) with a versatile mount, enabling it to be set atop a desktop monitor as well as a laptop. You can greatly improve the output from a dedicated webcam by focusing on [good lighting](https://www.nytimes.com/wirecutter/blog/video-call-lighting-tips).

Whether you're working with a webcam or the built-in device camera, you can optimize your space for better results. By utilizing a ring light or [Elgato Key Light](https://www.elgato.com/ww/en/p/key-light), and ensuring that there are no windows to your side or rear, you'll create a more even picture with fewer shadows. For more, read [5 tips for mastering video calls](https://about.gitlab.com/blog/2019/08/05/tips-for-mastering-video-calls) on the GitLab blog.

### Headphones

Wearing headphones, particularly in noisy environments, creates [a more positive audio experience for all](https://about.gitlab.com/blog/2019/06/28/five-things-you-hear-from-gitlab-ceo). Your choice of headphone will vary depending on your workspace. For example, if you're using a dedicated microphone, you may prefer comfortable studio-style headphones without an in-line mic. If you want to reduce the amount of hardware you're using, headphones with an in-line mic will be more appropriate.

GitLab recommends trying out various headphone styles in advance if possible. Open-ear vs. closed-ear, for example, provides a very different listening experience. Noise-cancelling headphones are great for crowded coworking spaces, but may blot out too much sound for [work-from-home caregivers](people/#parents) who need to be aware of what's happening inside the home.

It's important to consider long-term comfort for those who may find themselves in [video calls](https://about.gitlab.com/blog/2019/08/05/tips-for-mastering-video-calls) for multiple hours per day. For example, some people prefer in-ear headphones rather than over-the-head headphones.

Bluetooth headphones can be problematic for roles requiring a significant amount of calls, due to limitations of microphone quality, latency, and battery life. If you opt for Bluetooth headphones, you may want to also use a separate wired microphone. Bluetooth headphones, if  paired with multiple devices (e.g. one pair of headphones with a pairing history involving a laptop as well as a phone), may jump between devices.  We recommend pairing one set of Bluetooth headphones per device to avoid unexpected disconnects during video calls.

What constitutes "good headphones" varies significantly depending on preference. We recommend digging into [Wirecutter's various headphone guides](https://www.nytimes.com/wirecutter/electronics/headphones/) for researched suggestions.

### Microphone

Almost any phone or laptop comes with a built-in microphone that should be adequate for your needs. A pair of Bluetooth or wired earbuds with an in-line microphone can help reduce background noise, if you work in a noisy space. These are commonly included with most smartphones.

However, if you frequently speak in front of audiences, record talks or podcasts, or simply wish to have excellent audio quality, invest in a [dedicated USB microphone](https://www.nytimes.com/wirecutter/reviews/the-best-usb-microphone) (and, if desired, a desk mount for added ergonomic positioning). For example, [Blue Microphones](https://www.logitechg.com/en-us/products/microphones.html) offers a variety of options that are crafted with creators, streamers, and podcasters in mind, and all provide exceptional clarity and noise reduction on [video calls](/handbook/communication/#video-calls).

Several GitLab team members have positive experiences with the [M-Audio UberMic](https://www.amazon.com/M-Audio-Uber-Mic-Professional-Microphone/dp/B0767N58ZY).

"*When audio quality is high (vs low), people judge the content as better and more important. They also judge the speaker as more intelligent, competent, and likable. Messages that are difficult to process are less compelling.*" This [research](https://app.sciencesays.com/p/good-sound-quality-smarter), conducted by Norbert Schwarz at the University of Southern California, reinforces the importance of investing in equipment and atmosphere to generate the highest-fidelity audio in a remote work setting. If you have the funds available, this is an often-overlooked but very worthy way to use them.

### Monitor

If you feel that your digital workspace is too cramped when relying solely on a laptop, consider using at least one [external monitor](https://www.nytimes.com/wirecutter/reviews/best-monitors). External monitors offer flexible positioning, which allows your neck to be situated in a more natural and ergonomically correct position.

If you do video calls often, an external display will enable you to use one screen for video chatting and another for documentation, referencing pages, etc.

If you feel overwhelmed by too much information spread across multiple monitors, consider [window management software solutions](https://thesweetsetup.com/window-management-macos-2018) such as [Rectangle](https://github.com/rxhanson/Rectangle) and [Magnet](https://apps.apple.com/us/app/magnet/id441258766?ign-mpt=uo%3D4&mt=12).

If you'd like a portable monitor and you primarily use a MacBook laptop, consider expanding your visual workspace with [Sidecar](https://www.apple.com/newsroom/2019/06/apple-previews-macos-catalina) (available in macOS Catalina). This allows an iPad to double as a secondary display for your Mac.

### Teleprompter

If you present content regularly, consider adding a teleprompter that enables you to read a pre-written script while looking directly into a lens. This straight-on profile creates a more authentic connection with the audience, akin to a newscaster on television, especially when creating training modules or asynchronous video overviews.

For a basic solution, consider the [Padcaster Parrot Smartphone Teleprompter](https://padcaster.com/pages/parrot). If you have a smartphone and mirrorless/DSLR camera already, this $99 kit provides everything else you need.

Matt Mullenweg (CEO, Automattic) published an exhaustive overview of his [streaming setup at home](https://ma.tt/2020/05/ceo-video-streaming), including an [Ikan Elite](https://www.amazon.com/dp/B019H3B2DE) teleprompter rig.

Sid Sijbrandij (CEO and co-founder, GitLab) shared a video overview of his [streaming and teleprompter setup on GitLab Unfiltered](https://youtu.be/or86AXuXgYI).

{{< youtube "or86AXuXgYI" >}}

*GitLab CEO Teleprompter Setup; captured during [GitLab Commit Virtual 2020](https://about.gitlab.com/events/commit)*

#### Why teleprompters aren't ideal for everyday video calls

Teleprompters enable eye contact similar to meeting someone in-person and can make meetings more engaging. However, there are currently challenges with using a teleprompter setup as your everyday video conferencing setup. Once these are overcome, we may recommend it.

1. **Problem (Major):** When Zoom is on the teleprompter, the chat, controls, and screen sharing are extremely small and unusable. They have a "dual monitor" mode that is meant for screen sharing and it behaves as expected for n=3+ calls. But for 1:1 calls it unexpectedly puts yourself on the video window in the teleprompter.
    - *Mitigation:* We may need to wait for Zoom to roll out a new mode that is teleprompter-specific
1. **Problem (Major):** The mouse, Zoom controls, and screen shared content are horizontally flipped on the teleprompter making it very difficult to work
    - *Mitigation:* Buy [a device](https://telepromptermirror.com/hdmi-mirrorbox) that horizontally flips the HDMI output to the monitor mounted in the teleprompter
1. **Problem (Minor):** It's disconcerting that the audio of the person you're looking at is coming from your computer which is sitting to the side. This is especially true when you have a video monitor window on that computer that pulls your attention away from the teleprompter because it's brighter, larger, and syncs to the audio
    - *Mitigation:* External stereo speakers that mount to teleprompter
1. **Problem (Minor):** It's harder to know when your camera is off when it's mounted in a teleprompter. And that's a problem if your office is a guest bedroom (or something)
    - *Mitigations*
        - Get some sort of "on air" light
        - Get a black silk hood to flip over the camera
        - Remember to turn the camera off every single time
1. **Problem (Minor):** The video quality is slightly degraded by the physics of light passing through an additional pane of glass
    - *Mitigations*
        - Adjust lighting
        - Just live with the difference (not that bad)

### External keyboard and mouse

Laptop keyboards are engineered to *fit the laptop*, not to be ergonomic. Whenever possible, consider working in a space where there's room to utilize an external keyboard. This allows you to adjust the keyboard so that you're typing in a natural way, reducing strain on your wrists and fingers.

There are a wide variety of ergonomic keyboards, and it's worth trying out a few in a retail location if possible. If this is not practical, Wirecutter has assembled [a well-researched guide on the best ergonomic keyboards](https://www.nytimes.com/wirecutter/reviews/comfortable-ergo-keyboard).

A traditional mouse can put strain on the wrist by creating movements in an unnatural position. Fortunately there are plenty of other options available such as vertical mice, trackpads, trackballs and pen tablets. Each has their own advantages. Find one that is comfortable for you and minimizes wrist movement as much as possible (vertical mice, for example, engage your shoulder and arm more than your wrist and trackballs rely on moving your fingers). You can also consider a left-handed mouse. Wirecutter and CNN Underscored both recommend the [Logitech MX Master 3](https://www.nytimes.com/wirecutter/reviews/logitech-mx-master-3-mouse-review/) mouse. See CNN Underscored for a list of other recomended ergonomic mice [here](https://www.cnn.com/cnn-underscored/reviews/best-ergonomic-mouse).

It's important for remote workers to be cognizant of repetitive motion. While it may seem extreme to some, consider installing two mice and switching hands to move one's cursor.

## What furniture should I use in my home office?

Keep in mind that work often happens [in multiple spaces](https://youtu.be/l9jmb8TE7sw?t=454) throughout the workweek. You'll want to consider a range of spaces for different types of work:

1. **Primary spaces:** Ideal for deep, focused work where you need secondary screens, specialized tools, or controlled conditions for important video calls.
1. **Secondary spaces:** Try these for re-energizing your mind with [coffee chats](informal-communication/#coffee-chats), 1:1s, [learning and development](/handbook/people-group/learning-and-development), etc.
1. **On-the-go spaces:** Great for cognitively light work and fitting in bursts of productivity between meetings or appointments.

### Chair

Seating should be not viewed as an expense, but as an *investment* in your health, comfort, and productivity.

Unless you plan to utilize a standing desk, which is covered below, your chair is likely to be the single most important element of your home office. Not all ergonomic chairs are created equal, and a chair that works well for one person may not be ideal for another. It's important to [consider your posture](https://my.clevelandclinic.org/health/articles/4485-back-health-and-posture), and make adjustments to habits if needed, to make the most of an ergonomic chair.

**Many remote workers spend a significant portion of their day seated.** While [resources exist](https://www.steelcase.com/research/articles/topics/learning/an-arizona-state-study-movement-in-the-workplace/) to explain how frequently you should take a break, stand up, stretch, and engage in activity during the workday, you should be careful not to skimp on seating.

If possible, visit a physical store to try out a variety of ergonomic seating options, or purchase online from a retailer that offers a generous return policy.

[Steelcase](https://www.steelcase.com/products/office-chairs) and [MillerKnoll](https://www.hermanmiller.com/products/seating) both offer solid options. While retail pricing on chairs from these firms is very high, you can often find them used for less. To assist in your research, consider [Wirecutter's exhaustive (and continually updated) guide to office chairs](https://www.nytimes.com/wirecutter/reviews/best-office-chair/).

**Employers:** Consider offering an [allowance](/handbook/finance/spending-company-money/) for employees to invest in a high-quality ergonomic chair.

### Desk

While some remote workers prefer to [bounce around](https://about.gitlab.com/blog/2019/09/23/how-to-push-code-from-a-hammock) during the day, those looking to [invest in a desk](https://www.nationalbusinessfurniture.com/blog/complete-guide-to-office-desks) for a dedicated workspace should consider a few elements.

- Plan your desk purchase to fit your equipment, rather than the other way around.
- If you plan to use one or more desktop monitors (which is recommended), measure the physical dimensions and ensure that your desk has room to hold them.
- Factor in other items such as external speakers, scanners, printers, microphone mounts, webcams, external webcam lighting, etc.

Generally, a larger desk is preferred, as it reduces crowding. A clean, uncrowded desk is a happier place to work from.

#### Standing desks

An adjustable standing desk is a great, ergonomic option. You can find standing desks at a variety of price points, heights, adjustability levels, and more. An adjustable desk allows you to easily move your desk higher in order to stand while working, and then adjust it back down to sit for a time. This is a good article on [The Best Standing Desks](https://www.nytimes.com/wirecutter/reviews/best-standing-desk) in higher price ranges.

GitLab team members have been satisfied with the value and quality of standing desks from [Autonomous](https://www.autonomous.ai), [IKEA](https://www.ikea.com/us/en/p/trotten-desk-sit-stand-white-s99429578/), [Fully](https://www.fully.com/standing-desks.html) and [WorkTrainer for small spaces](https://www.worktrainer.de/Kleiner-Wand-Sitz-Steh-Tisch-Walldesk-elektrisch).

Research is ongoing as to the [ideal ratio of sitting to standing](https://uwaterloo.ca/kinesiology-health-sciences/news/innovation-measuring-fatty-acids-saves-labs-time-and-money) during a workday.

> Using advanced ergonomic and health risk calculations, [Jack Callaghan](https://uwaterloo.ca/kinesiology/people-profiles/jack-callaghan), a professor in Waterloo's Department of Kinesiology, has found that the ideal sit-stand ratio lies somewhere between 1:1 and 1:3  – a vast departure from traditional wisdom.

#### Standing mats

If you plan to stand for an extended portion of your working day, consider investing in a [standing desk mat](https://www.nytimes.com/wirecutter/reviews/best-standing-desk-mat). Also called anti-fatigue mats, these cushion one's feet and allow natural weight shifting while working.

### Office supplies

If you're transitioning from an office environment where supplies magically appeared or were stocked in a closet for your use, now you are responsible for acquiring them. Check out our [complete list of office supplies](/handbook/finance/expenses/#equipment).

## Creating the right environment

### Lighting

When [communicating](informal-communication/) via webcam, you need to be aware of your lighting scheme.

Meetings are about the work, [not the background](meetings/#meetings-are-about-the-work-not-the-background), but those who are [designing their home office](https://about.gitlab.com/blog/2019/09/12/not-everyone-has-a-home-office) may want to consider lighting before too many absolutes are put in place. Here are a few lighting tips to be mindful of.

1. Avoid backlighting or sidelighting when possible (e.g. design your office so that outside light shines onto your face, not your back or side).
1. Consider smart bulbs (e.g. [Philips Hue](https://www.philips-hue.com/en-us/products/smart-light-bulbs)) to light your office, which can be tweaked to create a soft, pleasing light regardless of your wall color.
1. While [enclosed rooms](https://about.gitlab.com/blog/2019/09/12/not-everyone-has-a-home-office) are ideal for controlling light, they may feel inhibiting to work from.
1. Try to avoid shadows and changing light conditions.

While studio lighting is ideal, not everyone will be inclined to install large, heat-generating light boxes in their home office. As remote work and live-streaming become more popular, companies are devising smaller solutions. Elgato's [Key Light](https://www.youtube.com/watch?v=d2qR-wMPoTE) is a great example. By placing one Key Light at the edge of a desk and facing its LEDs directly into the wall, a soft, refreshing light is [bounced back onto the participant](https://www.youtube.com/watch?v=RckLFNRKPfU).

[DIY solutions](https://www.diyphotography.net/look-good-webcam-vlog) are relatively easy to create with a mount and a light ring.

Aside from your video setup, lighting is also an important factor in your overall comfort and productivity in your office space. Natural light is best, particularly when your desk is facing the light source to help avoid glare. If you don't have access to natural light, consider using adjustable bulbs to mimic natural lighting.

### Atmosphere

If you've learned to be productive in a conventional [open office floor plan](https://royalsocietypublishing.org/doi/full/10.1098/rstb.2017.0239), you'll likely be able to increase your productivity level [as a remote team member](https://about.gitlab.com/blog/2019/08/15/all-remote-is-for-everyone).

Consider [where you prefer to work on a daily basis](https://about.gitlab.com/blog/2019/09/12/not-everyone-has-a-home-office) and optimize this space for focus. Try to remove visual, sound, and motion distractions to maximize your focus on work while in the space and [healthily disconnect](https://about.gitlab.com/blog/2019/07/09/tips-for-working-from-home-remote-work) when you exit.

### Busy/available indicators

While remote workers should relish the benefits of being close to friends and family while working, some may prefer a more formal approach to signaling their availability.

For example, the [Luxafor Flag](https://luxafor.com/product/flag/) light indicator utilizes a color system to alert those around you (or outside of your home office) whether or not they are free to interrupt without requesting permission.

Alternatively, if you have access to a nearby light fixture, install a color-changing smart bulb connected to your phone or computer to change the color to indicate availability.

### Ergonomics

Remote employees may want to consider hiring a trained ergonomic consultant to provide professional input and recommendations on how your home office should be constructed. While this is an investment, it's the type of cost that can be significantly offset over time by improving your health and well-being.

### Finding the ideal temperature

Research has [found](https://www.bbc.com/worklife/article/20160617-the-never-ending-battle-over-the-best-office-temperature) that there is no single temperature in which all people are more productive. Consider testing several temperatures to see which suits you, or adjust temperature based on your work activity.

## Examples of work-from-home setups

- GitLab Head of Remote, Darren M., shares details on his work-from-home arrangement, which includes a mirrorless camera as a webcam for optimal video quality.
- Job van der Voort, CEO at Remote, provides [a breakdown of his top-notch home office setup](https://remote.com/blog/maximum-productivity-home-office).
- GitLab Developer Advocate Michael F. [details his current setup](https://dnsmichi.at/all-remote-workspace) with helpful tips on lighting, apps and settings, and how to personalize your workspace.
- Emma Bostian, Software Engineer at Spotify, [writes about her home-office tech setup for recording courses and podcasts](https://dev.to/emmabostian/lights-camera-action-my-tech-setup-for-recording-courses-podcasts-2p6j)
- Andreas Klinger, founder at [Remote First Capital](https://www.remotefirstcapital.com), maintains an [ongoing Twitter thread](https://twitter.com/andreasklinger/status/1238325463300202497) of exceptional at-home workspaces.

## What are some tips for creating a productive home office?

### Set up work-life boundaries

Plan your work time and [time off]({{< ref "paid-time-off" >}}) in advance. When you're not working, turn off Slack and close your email client. At GitLab, this only works if all team members abide by the [communication guidelines](https://about.gitlab.com/blog/2016/03/23/remote-communication#asynchronous-communication-so-everyone-can-focus). It also helps to enable the "working hours" feature on your calendar so that team members in other time zones know when to schedule meetings.

Have an open, honest conversation with co-dwellers about your working hours. Explain that while you are home, you should be considered unreachable unless there's a significant level of need.

Be sure to have the ["I'm home but working" conversation with children](https://about.gitlab.com/blog/2019/08/01/working-remotely-with-children-at-home), who may struggle to understand why [a working parent](https://about.gitlab.com/blog/2019/07/25/balancing-career-and-baby) is in the home but unable or unwilling to engage with them for certain parts of the day.

### How can I decorate my home office?

When you work from home, you create a space that fuels your work. According to this [Thrive Global article on remote space setup](https://community.thriveglobal.com/how-remote-work-can-reduce-stress-and-revitalize-your-mindset/), "Maybe that is art, pictures, having a couch close by, or maybe it's just having music playing...at home you can really do whatever you want. It feels less like a corporate job and more of your own thing."

Try not to [worry about your background](meetings/#meetings-are-about-the-work-not-the-background) too much. Sometimes pets or family wander into a room while you're on a call and reminds us that we are people first and colleagues second.

### Not sure what is reimbursable?

Items you want for your home office may or may not be reimbursable.  Please refer to the [Home Office Equipment and Supplies](/handbook/finance/procurement/office-equipment-supplies) to see what is allowed to be reimbursed.

### What should I do if I don't have enough space for a home office?

Get creative if you cannot dedicate space for a permanent home office. You can assemble movable pieces for a "mobile office" that you set up and tear down daily, utilize a co-working space, work from a public business or building, or tether to work anywhere. Our team members have entertaining stories of getting creative to connect, everything from working in parked vehicles to access public wi-fi to SIM cards and tethering devices allowing connection from an exotic mountaintop.

## Leadership's role in supporting healthy workspaces

Whether an organization is [fully remote, remote-first, or hybrid](stages/), it's up to company leaders to enable an equitable and inclusive employee experience. Just as you'd invest in a team's workspace in a physical office, enabling team members to create healthy and productive spaces is a core part of building remote infrastructure. An optimized workspace leads to [team member happiness, wellness, and engagement](stories/), and it also leads to better overall results for your organization.

Keep in mind that there's no "one size fits all" for a home office setup, because each member of your team has different needs, work preferences, and home environments. Consider providing budget for your team to spend on their home workspace, a coworking space, or equipment needed to be productive on the go. For example, at GitLab, team members are [allowed to spend company money](/handbook/finance/spending-company-money/) as they would their own, with [guidance provided](/handbook/finance/expenses#-setting-up-a-home-office-for-the-first-time) for various types of equipment. Keep in mind that team members' needs may change as they [experiment to find their ideal work environment](getting-started/#experiment-with-work-environments).

## GitLab Knowledge Assessment: Considerations for a productive home office or remote workspace

Anyone can test their knowledge on how to set up a productive home office or remote workspace by completing the [knowledge assessment](https://docs.google.com/forms/d/e/1FAIpQLSeuswfs_t1Dl2vbmapTLNRHa2rfi5zwUg2IQ7ZQI7hxc1gB5g/viewform). Earn at least an 80% or higher on the assessment to receive a passing score. Once the quiz has been passed, you will receive an email acknowledging the completion from GitLab. We are in the process of designing a GitLab Remote Certification and completion of the assessment will be one requirement in obtaining the [certification](https://about.gitlab.com/learn/certifications/public). If you have questions, reach out to our [Learning & Development team](/handbook/people-group/learning-and-development) at `learning@gitlab.com`.

{{% include "includes/is_this_advice_any_good_remote.md" %}}

## Contribute your lessons

GitLab believes that all-remote is the [future of work]({{< ref "remote-vision" >}}), and remote companies have a shared responsibility to show the way for other organizations who are embracing it. If you or your company has an experience that would benefit the greater world, consider creating a [merge request](https://docs.gitlab.com/ee/user/project/merge_requests) and adding a contribution to this page.

---

Return to the main [all-remote page]({{< ref "_index.md" >}}).
