---
title: "Cross-Culture Collaboration Guide"
description: "This guide will help GitLab team members in effective and inclusive communication and cross-cultural collaboration globally"
canonical_path: "/company/culture/cross-culture-collaboration-guide/"
---

## Goal

As an organization with [67+ countries and regions](/handbook/company/team/) represented, it is ever-important for all of us to increase our cultural awareness, sensitivity, and understanding. This guide will help GitLab team members in effective and inclusive communication and cross-cultural collaboration globally; irrespective of culture or background.

### Individual Culture vs. Company Culture

An important principle in any global organization is the distinction between our cultural background vs. the GitLab company culture. A critical aspect of our recruitment process is ensuring the people we hire are aligned with our [company values](/handbook/values/).

Our diverse backgrounds help us live out our [Diversity, Inclusion & Belonging](/handbook/values/#diversity-inclusion) value, while alignment with our company values allow us to collaborate as a *team*. While maintaining respect for each team member's individual culture, GitLab culture and values should be what unites us. For many team members, some company values and the digital and [asynchronous](/handbook/communication/#internal-communication) way in which we work at GitLab may take some adjusting to during onboarding. We should support and encourage each other to [assume positive intent](/handbook/values/#assume-positive-intent) and live out our values daily!

### Research

There has been much research done on how to understand the cultural dimensions of a country/region and the impact different dimensions have on communication and collaboration. In our table below, we have provided an overview from two researchers who have spent years dedicated to defining different cultural dimensions. One of the most well-known pioneer studies conducted on cross-cultural groups and organizations was by Geert Hofstede in his book `Cultures and Organizations: Software of the Mind`. A more modern study that was published in 2014 also exploring cross-cultural collaboration in the workplace was conducted by Erin Meyer in her book `The Culture Map`. GitLab based our cultural dimensions on the research from these two experts, and aligned our dimensions to our values tailored to our company to help foster understanding and communication.

If you are interested in learning more about the research that inspired GitLab, you can review Hofstede's [cultural dimensions](https://www.theculturefactor.com/intercultural-management) in more detail in addition to his [cultural dimension comparison](https://www.theculturefactor.com/country-comparison-tool) tool to view how specific countries compare, or considering reading his book `Cultures and Organizations: Software of the Mind`. If you are interested in learning more about Erin Meyer's cultural dimensions, you can view a summary in this [article](https://hbr.org/2014/05/navigating-the-cultural-minefield), or read her book `The Culture Map`.

*It is important to note that while the dimensions listed below can help us understand general orientations and trends in several countries based on research, these dimensions are not absolute. Each person is unique and thus the dimensions are relative.*

### Cultural Dimensions

#### Cultural Relativity

Keep in mind that for all of the dimensions defined below, we need to be mindful of ***cultural relativity***. What matters is not so much any given country's tendency, but rather, their positioning in relationship to you. For example, the United Kingdom is *one of* the lowest context cultures. However, in comparison to the United States, which is *the* lowest context culture, the British could be interpreted as high context in their communication.

#### Cultural Dimensions Table

Note that for the `Values Alignment` section in the table below, [Diversity, Inclusion & Belonging](/handbook/values/#diversity-inclusion) is not explicitly listed. This is because becoming culturally aware and empathetic in our interactions in and of itself supports our Diversity, Inclusion & Belonging value. Thus, reviewing the table below and implementing awareness in your day-to-day interactions at GitLab demonstrates Diversity, Inclusion & Belonging.

|**GitLab** | **Meaning** | **Values Alignment** |
| ------     | ------      | ------      |
| Leadership Expectation |   This dimension refers to the difference between egalitarian and hierarchical leadership styles. Countries that  follow egalitarian models prefer "flat" organizational structures, making the distance between a manager and a team member low. Hierarchical cultures have a significant distance between manager and team member; status is very important and communication follows hierarchical flow.  |     Collaboration |
| Navigating Disagreement | The level of comfort and acceptance in regard to  or Engaging or Disengaging  in disagreement/debate varies drastically from culture to culture. Engaging cultures believe that healthy debate is positive for teams and appropriate, while Disengaging cultures believe that disagreement has a negative impact on team dynamic, disrupts harmony, and hurts the relationships overall. GitLab advocates for [constructive passionate debate](/handbook/values/#five-dysfunctions) and encourages us to have ["short toes"](/handbook/values/#short-toes). | Collaboration, Efficiency |
| Feedback Approach | Direct vs. indirect feedback, specifically in regard to improvement areas, can make a big difference in the interpretation of messages we try to relay, or [feedback](/handbook/people-group/guidance-on-feedback/#cross-cultural-feedback-considerations) we give. While we advocate for [transparency](/handbook/values/#transparency) and are [public by default](/handbook/values/#public-by-default), it is important to be mindful that some cultures can be less receptive to direct and public feedback than others. In direct feedback cultures, feedback on improvement areas is provided in a straightforward manner bluntly and is not softened by other positive feedback. It is acceptable for feedback to be provided in public settings.  In indirect feedback cultures, feedback on improvement areas tends to be given subtly and softly and is generally "sandwiched" between positive feedback. Feedback is only given in private settings.  | Transparency |
| Communication Style | While GitLab advocates [low-context communication](/handbook/communication/#internal-communication) (precision, simplicity, and clarity), it is important to be aware that many cultures are more accustomed to high-context communication (layered communication that is more "read between the lines"; messages are often implied versus directly expressed). We should be tolerant of all communication styles and ask for clarification when needed.  | Iteration, Results |
| Collaboration Focus | Task-oriented cultures tend to focus on the task at hand with speed and efficiency to produce results as soon as possible. Relationship oriented cultures tend to focus not only on the task at hand but also in cultivating and developing relationships to increase collaboration and efficiency as a team.  This may be harder to recognize in an asynchronous environment where there is less face to face interaction to build these relationships. | Iteration, Collaboration |
| Concept of Time | Different cultures abide by different concepts of time: linear time and flexible time. Characteristics of linear time include being punctual, following a set agenda, and starting and ending as scheduled. Flexible time cultures tend to put relationships before timeliness, are more flexible in their use of agendas, and will wait a few minutes for everyone to arrive. GitLab's sense of time tends to be more linear than flexible, we define [being respectful of others time](/handbook/values/#be-respectful-of-others-time) as including an agenda, documenting the outcome, and starting promptly ([we don't wait if people arrive](/handbook/communication/#video-calls) after the schedule start time).  | Results, Efficiency |

### Practices For Cultural Awareness

While the table above outlines GitLab's cultural dimensions, meaning, and values alignment, this section aims to provide a more practical "how-to" as a platform for applying the awareness the dimensions provide to every day interactions at GitLab. While the practices below can and should be implemented in all interactions, they become particularly important in cross-cultural communication.

#### Stay Values-Focused

It is the responsibility of every GitLab team member to live out our [values](/handbook/values/#credit). As highlighted above, GitLab culture and values are what unite us; our values provide common ground irrespective of our backgrounds. We should remind each other and ourselves to stay values-centered and let our values guide our interactions!

#### Assume Positive Intent

An operating principle of collaboration, [assuming positive intent](/handbook/values/#assume-positive-intent) is also critical for effective cross-cultural communication. Not everyone has worked in global environments before, and as humans, we all make mistakes. If someone says something that rubs you the wrong way, assume positive intent, explain how you feel in a 1:1 setting, and ask for clarification to ensure you have the full picture. We should give each other the benefit of the doubt in interactions.

#### Ask Questions

A lot of people love to share about their cultures! When in doubt, ask. Asking questions results in learning, which helps make us all more culturally aware.

#### Be Humble

***Recognize that your beliefs are not absolute***. There are 195 countries in the world, 4,200 different religions, and 7.5 billion people; each one of us has a unique set of customs and culture, even if our cultural backgrounds are similar. Awareness that different beliefs exist is a critical step in practicing effective cross-cultural communication.

#### Be Empathetic

Be empathetic towards others, their reactions, and their culture. There is often more than meets the eye, and it is important to remember that something "normal" to one person may not be normal to the other.

#### Set Expectations

Clearly set expectations around communication in order to establish and align on what works best for your team dynamic and the cultures within your team. Creating this awareness and alignment can help avoid misunderstandings and ensure cultural and personal backgrounds are respected.

### Stories from Team Members

#### Discussing Cross-Cultural Communication

Listen to the panel discussion on cross-cultural communication below hosted on 2022-03-23 with GitLab team members.

{{< youtube "XS4H_hVLF7o" >}}

**Key Session Takeaways**

1. In remote spaces, intentionality is important to build trust on teams. Ideas on how to do this include adding a social question to team meetings or hosting a social event to share about people's localities.
1. Assuming positive intent when communicating async can help us recognize and have compassion for other's experiences.
1. Everyone can be an ally and has a responsibility to check and fix their own biases when collaborating with others
