---
title: "The Ally Lab"
description: Learn what is an ally, how to be an ally and what it means to be an ally.
---

## What is an ally?

A diversity, inclusion and belonging "ally" is someone who is willing to take action in support of another person, in order to remove barriers that impede that person from contributing their skills and talents in the workplace or community.

Being an ally is a verb, this means that you proactively and purposefully take action and is not something forced upon you.

## How to be an ally

It is not required to be an ally to work at GitLab. At GitLab it is required to [be inclusive](/handbook/values/#diversity-inclusion).

Being an ally goes a step beyond being inclusive to taking action to support marginalized groups. The first step in being an ally is self-educating.

This ally lab will provide you with some of the tools, resources and learning activities to help you grow as an ally.

## Skills and Behaviors of allies

To be an effective ally it is important to understand some of the skills and behaviors great allies exhibit.

- Active listening
  - Neutral and nonjudgmental.
  - Patient (periods of silence are not "filled")
  - Verbal and nonverbal feedback to show signs of listening (e.g., smiling, eye contact, leaning in, mirroring)
  - Asking questions.
  - Reflecting back what is said.
  - Asking for clarification.
  - Summarizing.
- Empathy & Emotional Intelligence
  - **An example of this could be:** A colleague comes to you and tells you that their pronouns are being misused often at work and it is making them feel uncomfortable and they are avoiding social calls and interactions. Whilst you haven't experienced this yourself and unlikely you would experience this, you allow yourself to think of situations where you have felt uncomfortable at work before. You also put yourself consciously into the shoes of your colleague and think of a way you can practically help. You offer to your colleague that in the next 5 calls they participate in you will be on the call and actively point out misuse of their pronouns to other colleagues to take away some of the emotional burden.
- Active learning about other experiences
  - You go beyond performative actions for example black squares on Instagram for Black Lives Matter, but actively does the work to understand the pain, struggle and experience of those burdened.
  - **This could look like:** You are managing black team members, an incident has occurred externally that could affect the mental health of those team members. You actively research the experience and historical context of the trauma associated with the incident. You use this to ensure you are informed and able to appropriately apply empathy if a team member approaches you to ask for assistance.
- Humility
  - Non-defensive
  - Willingness to take on feedback
  - You aren't going to get it right all the time and you have to be ok with that. Be willing to take feedback on and not let it deter you from continuing to be an ally.
  - **Example of this could be:** You are in a safe space with an underrepresented group acting as an ally and absorbing information. A point comes up that you are passionate about and you talk over someone in the group and take over the conversation. After the meeting someone from the group jumps on a Zoom meeting with you and explains that it felt you took away the viewpoints of a number of people from the URG because you took over the conversation and interrupted an individual. You apologize, take on the feedback, ask for any tips on how to make sure it doesn't happen again and take the necessary steps. --- One of the mistakes that often happens here is being defensive or justifying the action. The group will already know you are operating with good intent but generally are wanting to help you level up in their lived experience.
- Courage
  - Comfortable getting uncomfortable
  - Speak up where others don't or can't
  - The empathy example is also a good example of this.
- Self-awareness
  - Own and use your privilege
  - **This could look like:** You are in a product meeting and the meeting will be making critical decisions about the product roadmap for the next three months and you notice that everyone in the meeting is of the same gender and race. You use your privileged situation in the meeting to point this out and ask the people in the meeting. Who should be invited to ensure we are getting a diverse perspective and viewpoint on the agenda items for the meeting?
- Action orientated
  - You see something, you say something
  - The example above is a good example of this: Ensure decisions and conversations have diverse voices. I.E. you are in a meeting and everyone looks the same, insist on other perspectives.
  - In a group setting when a discussion or comment is verbalized that could be controversial use language similar to this to course correct the conversation:
  - - "I would like us all to be aware of our language and/or acknowledgements and ensure we are being respectful to all individuals. Thank you."
  - - "I am practicing being an ally and as a reminder I would like to ensure we are all using inclusive language"

## What it means to be an ally

- Take on the struggle as your own
- Stand up, even when you feel uncomfortable
- Transfer the benefits of your privilege to those who lack it
- Acknowledge that while you, too, feel pain, the conversation is not about you

## Concepts & Terms

1. Privilege: an unearned advantage given to some people but not all
1. Oppression: systemic inequality present throughout society that benefits people with more privilege and is a disadvantage to those with fewer privileges
1. Ally: a member of a social group that has some privilege, that is working to end oppression and understands their own privilege
1. Power: The ability to control circumstances or access to resources and/or privileges
1. Marginalized groups:  a person or group that are treated as unimportant, insignificant or of lower status. In a workplace setting, employees could be treated as invisible, as if they aren't there or their skills or talents are unwelcome or unnecessary
1. Performative allyship: referring to allyship that is done to increase a person's social capital rather than because of a person's devotion to a cause. For example some people used #metoo during the Me Too movement, without actually bringing more awareness or trying to effect change.

## Tips on being an ally

1. Identifying your power and privilege helps you act as an ally more effectively
1. Follow and support those as much as possible from marginalized groups
1. When you make a mistake, apologize, correct yourself, and move on
1. Allies spend time educating themselves and use the knowledge to help
1. Allies take the time to think and analyze the situation
1. Allies try to understand Perception vs. Reality
1. Allies don't stop with their power they also leverage others powers of authority

See our [Ally Resources Page]({{< ref "ally-resources" >}}) for more resources on being an ally.

## Allyship & Empathy

### Being an Ally Requires Empathy

{{< youtube "1Evwgu369Jw" >}}

#### Responding with Empathy

**What to say, when you don't know what to say:**

- Acknowledgement of their pain.
"I'm sorry you are going through this." "That must be hard."
- Share how you feel.
"Wow. I don't know what to say." "It makes me really sad to hear this happened."
- Show Gratitude that the person opened up.
"Thank you for sharing with me." "This must be hard to talk about. Thanks for opening up to me."
- Show Interest.
"How are you feeling about everything?" "Is there anything else you want to share?"
- Be Encouraging.
"You are brave / strong / talented." "You matter."
- Be Supportive.
"I'm here for you." "I'm happy to listen any time."

**Boot and Sandal Methophor**

Imagine you are wearing a heavy boot (represents privilege) and you are stepping on someone's foot that is only wearing sandals (represents oppression). If someone says, "Ouch, you are stepping on my toes!" How do you react?

**Problems with common responses to mistakes become obvious:**

- **Centering the mistake around yourself:** "I can't believe you think I'm a toe-stepper! I'm a good person!"
- **Denial that others' experiences are different from your own:** "I don't mind when people step on my toes."
- **Derailing:** "Some people don't even have toes, why aren't we talking about them instead?"
- **Refusal to center the impacted:** "All toes matter!"
- Tone policing: "I'd move my foot if you'd ask me more nicely."
- **Denial that the problem is fixable:** "Toes getting stepped on is a fact of life. You'll be better off when you accept that."
- **Victim blaming:** "You shouldn't have been walking around people with boots!"
- **Withdrawing:** "I thought you wanted my help, but I guess not. I'll just go home."

**Instead, you would respond with the following:**

- Center the impacted: "Are you okay?"
- Listen to their response and learn.
- Apologize for the impact, even though you didn't intend it: "I'm sorry!"
- Stop the instance: move your foot
- Stop the pattern: be careful where you step in the future. When it comes to oppression, we want to actually change the "footwear" to get rid of privilege and oppression (sneakers for all!), but metaphors can only stretch so far!

### Improve allyship skills by following the three C's

- Consciousness
- Courage
- Compassion

### How diversity shows up on teams

Image

### Areas you can show allyship

**Recruiting & Hiring**

- Sourcing
- Interviewing
- Compensation

**Guidance & Support**

- Helping through challenges
- Listening and empathizing
- Providing perspective
- Mentorship

**Difficult Conversations**

- Performance conversations
- Ongoing feedback

**Growth & Career Development**

- Career planning
- Skill development
- Mentorship and sponsorship

### Examples of Allyship at GitLab

TBC

## Ally Lab Learning Group

{{< youtube "dPywm-j1iic" >}}

The Ally Lab Learning Group is an initiative to learn to become or be a better ally within a collaborative group of peers who are seeking the same aim of allyship growth. All team members have the ability to be an ally whether you are a part of an underrepresented group (URG) or not, there are URGs that may not belong to and you have the ability to be an ally to them. There will be regular intakes of team members into groups.

The next intake: [You can sign up here](https://docs.google.com/forms/d/e/1FAIpQLSd7tN0rj_Jh30BuSsF3wS73FEAZRLB5zxNt_AUOFvJzAPsdtg/viewform?usp=sf_link)

To sign up: TBC

**The Group:**

- ALLG Facilitator
- 5-10 team members
- Diversity within the group where self-identification is available

What you will need:

- The ability to have 1 synchronous 30-45min a week (Timezone convenient location)
- A higher intent to become an ally

What you will do:

1. **Session 1:** Async ally training and courses. Synchronous meeting to discuss what you have learned.
    1. [Explore Ally Allyship](https://trailhead.salesforce.com/content/learn/modules/equality-fundamentals/explore-allyship)
    1. [Cultivate Equality at Work](https://trailhead.salesforce.com/content/learn/modules/equality-fundamentals)
    1. [Communicating with Empathy](https://www.linkedin.com/learning/communicating-with-empathy/empathy-as-a-path-to-productive-conversations?u=2255073)
    1. [Effective Listening](https://www.linkedin.com/learning/improving-your-listening-skills-19238090)
    1. [Building Trust](https://www.linkedin.com/learning/building-trust-14841538)
    1. [The importance of trust](https://www.linkedin.com/learning/why-trust-matters-with-rachel-botsman/the-importance-of-trust?u=2255073)
    1. [How to engage meaningfully in allyship and anti-racism - OPTIONAL](https://www.linkedin.com/learning/paths/how-to-engage-meaningfully-in-allyship-and-anti-racism?u=2255073)
    1. [Inclusive mindset of committed allies - OPTIONAL](https://www.linkedin.com/learning/inclusive-mindset-for-committed-allies/becoming-a-true-ally?u=2255073)
1. **Session 2:** The importance of being an ally and why you want to be an ally.
1. **Session 3:** Work as a group to discuss a number of scenarios and how to tackle them as an ally.
1. **Session 4:** Together, write a commitment to allyship and the values you will abide by to be an ally.
    1. In the last session you will decide as a group a short commitment statement that should be shared on the Diversity, Inclusion & Belonging Sharing Page. Think about what you have individually and collectively learnt during the experience.

Create 2-5 values that, as a group, you will hold in your continuous learning in allyship and take into account when situations arise.

Once completed you now have a safe group to discuss allyship with, either to get advice, hold yourself accountable to or run through a situation. Things you can do post the 4 week ALLG:

- Schedule a quarterly or bi-yearly call with your group
- Ask members of your group for regular coffee chats to discuss the above
- Reflect regularly on your commitment and values you agreed to and situations where you could have displayed allyship

## Ally Training

We held a 50 minute [Live Learning](/handbook/people-group/learning-and-development#live-learning) Ally Training on 2020-01-28. The recording follows along with the [slide deck](https://docs.google.com/presentation/d/18Qyn2mBJu0Loq3x_RT5bL2lnL-3YHvac1sQhmqqZNso/edit?usp=sharing) and [agenda](https://docs.google.com/document/d/1lGPImuahahjDejI5-9cNNCg-NMQJ4GCHO6n0fcntjs8/edit?usp=sharing).

{{< youtube "wwZeFjDc4zE" >}}

<figure class="video_container">
<iframe src="https://docs.google.com/presentation/d/e/2PACX-1vRRWRr6Aclf-Ddft1MKjtwdQ98216WEGG7LWJ2UZ3MOSnRZ0-cMhaPNeHpjQ4kk4c7pKkpuV-nvDN-2/embed?start=false&loop=false&delayms=3000" frameborder="0" width="960" height="569" allowfullscreen="true" mozallowfullscreen="true" webkitallowfullscreen="true"></iframe>
</figure>

## External Ally Training

There are some essential skills that are required to be an ally, here are a number of trainings that will help you enhance your allyship skills. Some of these are not allyship specific but will sharpen your skills in those important areas.

- [Equality Ally Strategies](https://trailhead.salesforce.com/content/learn/modules/equality-fundamentals/explore-allyship)
- [Champion Workplace Equality](https://trailhead.salesforce.com/content/learn/modules/equality-fundamentals/put-allyship-practices-into-play-external)
- [Effective Listening](https://www.linkedin.com/learning/effective-listening/improve-your-listening-skills?u=2255073)
- [How to engage meaningfully in Allyship](https://www.linkedin.com/learning/paths/how-to-engage-meaningfully-in-allyship-and-anti-racism?u=2255073)
- [Becoming a true ally](https://www.linkedin.com/learning/inclusive-mindset-for-committed-allies/becoming-a-true-ally?u=2255073)
- [Building Trust](https://www.linkedin.com/learning/building-trust-14841538)
- [Why trust matters](https://www.linkedin.com/learning/why-trust-matters-with-rachel-botsman/the-importance-of-trust?u=2255073)

## Ally Learning Activity and Scenarios

## GitLab Diversity, Inclusion & Belonging resources

Allies familiarize themselves with GitLab's general DIB content

- [Diversity, Inclusion & Belonging page](/handbook/company/culture/inclusion/)
- [Gender and Sexual Orientation Identity Definitions and FAQ](/handbook/people-group/orientation-identity)
- [DIB training resources]({{< ref "inclusion#diversity-inclusion--belonging-training-and-learning-opportunities" >}})
- [Unconscious bias]({{< ref "unconscious-bias" >}})

## Ally Resources

Here are additional resources on being an ally

- [Guide to allyship](https://www.guidetoallyship.com)
- [5 Tips For Being An Ally](https://www.youtube.com/watch?v=_dg86g-QlM0)
- [Ally skills workshop](https://frameshiftconsulting.com/ally-skills-workshop/). Check out the materials section with [a handout PDF](https://docs.google.com/document/d/1B0zNV4WKVtIB2Rsret_kbZNjtxRrewk8vbg1HAhLzCU/export?format=pdf) (linking to many more resources), [slides PDF](https://docs.google.com/presentation/d/1ApXtF-9gQEE9XFH7LEAlxcF0W4HP0z-8WXDWul2KHZs/export/pdf), [videos](https://www.youtube.com/watch?v=wob68Nl2440), and more.
- [Why cisgender allies should put pronouns on their name tag](https://medium.com/@mrsexsmith/dear-cis-people-who-put-your-pronouns-on-your-hello-my-name-is-nametags-78c047ed7af1)
