---
title: "Sponsorship Program Guide"
description: "The process for Sponsorship Programs at GitLab"
---

## Sponsorship vs Mentorship

### Sponsorship

Sponsorship is defined as using your influence and/or power to advocate and positively impact the growth and career advancement of a team member. A sponsor is a senior leader with significant influence and responsibilities. A sponsor may then use this influence for activities such as:

- Advocating for career advancement opportunities
- Providing stretch opportunities to up skill via active projects
- Promoting sponsee visibility with other senior leaders
- Giving advice on "presentation of self" to sponsee
- Giving timely, honest feedback on skills, capabilities or experience gaps

At GitLab a sponsorship program can be a way of rewarding and growing top performing GitLab team members. Alternatively, it can be used to increase representation or provide visibility to underrepresented groups at GitLab, which can be seen via the [Sales Sponsorship Program Pilot for Black Team Members]({{< ref "dib-sponsorship-program" >}}).

This page outlines what sponsorship is and the pathway to creating a successful sponsorship program

### Mentorship

Mentorship is defined in our [Mentoring handbook page:](/handbook/people-group/learning-and-development/mentor#what-is-mentoring) Mentor relationships are an opportunity for individuals to learn from someone's personal experience, background, and perspective. These relationships build trust on a team, provide safe space to make mistakes, and encourage both personal and professional development.

[Harvard Business Review](https://hbr.org/2019/08/a-lack-of-sponsorship-is-keeping-women-from-advancing-into-leadership) defines the difference between sponsors versus mentors: "While a mentor is someone who has knowledge and will share it with you, a sponsor is a person who has power and will use it for you."

## Starting a DIB Sponsorship Program

A DIB sponsorship program can start in a variety of ways:

1. By request from a senior leader to a People Business Partner or DIB Team
1. By request of a People Business Partner as part of the departments ongoing people strategy
1. By the Diversity, Inclusion & Belonging Team as part of the ongoing DIB Strategy for that department or GitLab as a whole

When requesting a new Sponsorship Program these things should be taken into consideration

1. Bandwidth must be available to carry out the sponsorship program
1. A defined list of potential participants
1. Clear goals of the Sponsorship Program i.e; to provide growth opportunities to top performers or to increase leadership representation of a URG in the department

## DIB Sponsorship Program Outline

- The program can be 6/9/12 months in duration
- Create an issue highlighting the URG or at risk group, timeframe, potential start date
- Identify and nominate Executive Sponsorship Advocates
- Identify Sponsors & agreement to participate
- Nominate Sponsees & agreement to participate
- Sponsorship Training & Education
- Sponsorship Matching Process
- Begin program
- Feedback sessions 60 days, half way, end of program
- Next steps session
- End of Program

Stakeholders: E-Group Leader, Senior Leaders, DIB Team, Learning & Development, Sponsee Managers, People Business Partners

## Role of Executive Sponsorship Advocate

The Executive Sponsorship Advocates are nominated senior leaders by the E-Group Leader/PBPs/DIB Team to help evangelise the sponsorship program with there peers. They will share in the accountability for the success of the Sponsorship Program.

## Roles of a Sponsor

**A Sponsor is someone who has power and influence at GitLab and will use that power to advocate, elevate and impact a team members opportunities and career progression at GitLab.**

**A sponsor at GitLab is:**

- A Senior Leader at a minimum [job grade 10+]({{< ref "compensation-calculator#job-grades" >}}) and is not the sponsees direct manager.
  - The senior leader should be a People Manager or Manager of Managers
- Must have been at GitLab for 6+ months
- Be able to commit to the defined duration of the sponsorship program which will include
  - Sponsor Training
  - Kick-off calls
  - Bi-weekly 1-1 with Sponsee
  - Be able to fully commit and be held accountable for their role within the Sponsorship Program

**As a Sponsor you should be:**

- Be open and honest
- Listen and Learn
- Lean into discomfort in areas not familiar to you (e.g. cultural differences)
- Take risks with the relationship
- Advocate for your sponsee with intent
- Give feedback as appropriate
- Be intentional in building the relationship

**A sponsor will:**

- Use their influence and power to advocate for the sponsee potential for career advancement
- Use their influence to increase the visibility of the sponsee amongst other Senior Leaders at GitLab
- Use their influence to increase the visibility of the sponsee at GitLab
- Provide opportunities and space for risk-taking and growth
- Provide feedback on growth and skill development

**The sponsorship relationship may not provide all the above but the sponsor should be willing and able to provide some of the opportunities above to the sponsor.**

## Role of a Sponsee

**A Sponsee at GitLab will:**

- Be performing in your role in accordance with your managers expectations, which take into account performance exercises such as 9 box and not on a Performance Improvement Plan
- Be nominated to take part in the Sponsorship Program
- Be able to commit to the duration of the program
- Willing to commit to the overall expectations of the program as outlined throughout the handbook page

**As a Sponsee you should be:**

- Be able to lead the relationship with your sponsor
- Be able take risks with the relationship
- Trust is a vital part of the relationship
- Be able to do the work required based on feedback received and requirements for success
- Be able to request and give feedback as appropriate
- Be able to take personal responsibility for your career and be empowered to ask for what you need

**A Sponsee will:**

- Maintain or exceed their performance record
- Maintain trust & confidentiality in the relationship
- Assist the sponsor in insights to the business and challenging perceived norms
- Be an ambassador for our CREDIT Values
- Have aspirational goals for career development; within leadership or as a senior IC
- Have a growth mindset and will be able to continually learn
- Have the ability to take on special projects which will impact their growth
- Makes themselves available for opportunities and stretch assignments
- Consistently performing at or above the performance bar

## Role of Manager

- The manager will support the team member in ensuring that they have a Individual Growth Plan (IGP)
  - As well reassess the IGP at regular intervals during the sponsorship program
- The manager will regularly check in on the progress of the Sponsorship Program with their report
- The manager will regularly report on the success of the program to the leadership advocates of the program
- Participate in a manager of sponsees session

## The Sponsorship Process

### Before you begin

Create an issue in the [DIB Project](https://gitlab.com/gitlab-com/people-group/dib-diversity-inclusion-and-belonging/diversity-and-inclusion/-/issues/new)  to begin the process of developing the Sponsorship Program

### Key Stakeholders

Identify the key stakeholders of the program, likely stakeholders will include but not limited to:

- E-Group Member
- Senior Leaders of the department
- Sponsee Managers
- People Business Partners
- DIB Team

Ensure that you operate with a high degree of communication with the key stakeholders on project timing including: Communicaion dates, communication templates, leadership comms etc

### Timeframe

The timeframe of the program will be highly dependent on the goals of the program. We suggest a minimum of 6 months and maximum of 12 months for a formal sponsorship program. The idea is that after the formal program an informal relationship will continue with the successful matches.

### Identifying Executive Sponsorship Advocates

An Executive Sponsorship Advocate should be a senior leader who has the ability to influence other team members across the department around the program.

You should work with the E-group member and People Business Partners to identify the most appropriate leaders. Consideration should be given to:

- Tenure
- Seniority
- Scope of influence
- Previous DIB related expertise
- Accountability

### Identifying Sponsors

A sponsor must be able to fit within the criteria outlined above. When identifying appropriate sponsors you should:

- Consult with the People Business Partners for the department to ensure suitability
- Ensure all Sponsors meet the requirements
- Develop materials for sponsors outlining the program, taking into consideration the goals of the program, team members being sponsored, education material. You can utilize templates that already exist
- Develop a sign up form using the template
- Utilize the Executive Sponsorship Advocates to evangelize the program and encourage sign ups
- Provide a 2-3 week period for sign ups to occur

### Identifying & Nominating Sponsees

When identifying sponsees, first consider the goal of the sponsorship program and set out a criteria for Sponsees. This could be; must be rated 1-3 on the 9 box performance exercise or must be a member of xx URG and performing in the role. It could also be a combination of the two.

Utilize the number of sponsors to establish how many sponsees can participate in the program. Ideally each sponsor will only have 1 sponsee however exceptions can be made where applicable.

Once a criteria has been set and the number of sponsees established, identify with senior leaders and managers who should be nominated to participate. When nominating:

- Ensure all Sponsees meet the requirements
- Develop materials for sponsees outlining the program, taking into consideration the goals of the program, team members being sponsored, education material. You can utilize templates that already exist
- Develop a sign up form using the template
- Utilize the Executive Sponsorship Advocates to evangelize the program and encourage sign ups
- Provide a 2-3 week period for sign ups to occur

### Sponsorship Training & Education

Once sign ups are complete, it is important to provide training to the Sponsors and Sponsees. This should include training on:

- Accountabilities and Expectations of the program
- The responsibilities of being Sponsor or Sponsee

### Accountabilities & Expectations

### Sponsorship Matching Process

Once sign up has closed for the Sponsees, matching can begin. You should utilize the answers in the sign up form to match sponsees and sponsors appropriately. Other considerations include:

- The sponsor should be two job grade above the sponsee
- The sponsor should not be in the direct hierarchy of the sponsor
- Utilize the sign up form to match similar goals and experiences for the sponsee sponsor pairing

### Begin the program

#### Sponsorship Framework

To ensure a successful sponsorship relationship, we have built out a framework on how to ensure that you ultimately achieve advocacy. This framework is not linear, you may go back steps occasionally to ensure that authentic sponsorship can occur but if you follow the process, building and maintaining trust the process will work.

**Build**

Take the time to build a solid relationship with each other. This will be particularly important if you have no previous direct working relationship and can often take some time to cultivate. It is very important to build the relationship first before moving into authentic sponsorship.

Suggested Actions:

- Commit to regular 1-1s
- Understand the sponsees career development plan
- Set goals and expectations early

**Develop**

You have taken the time to build a relationship with each other, the next step is to develop that relationship by becoming action & capability focussed. In this step the sponsor will help guide the sponsee on areas of improvement in skills & capabilities. The sponsee is responsible for acting on feedback and being intentional about displaying these improvements to the sponsor.

Suggested Actions:

- Find and seek opportunities for the sponsor to observe the sponsees improvement areas
- Sponsee invites Sponsor to a team meeting where they are presenting
- Sponsor invites sponsee to a working group

**Commit**

This is where both parties agree to move forward with the next step, which is sponsorship and advocating for the sponsee. This can take many forms, such as; a formal discussion, the sponsor outlining actions to the sponsee or at the sponsees request. This is an opportunity to provide feedback, any uncertainties and to reestablish career development goals.

Suggested Actions:

- Participate in feedback session with sponsee

**Advocate**

Now that a commitment has been made and the sponsor is satisfied that the sponsee is ready for the next step. The sponsor actively and intentionally advocates for sponsees continued career development and advancement at GitLab.

### Feedback Process

There should be a series of feedback touch points during the program.

- 60 days - this should evaluate the strength of the matches, discover any additional resources that are required and remedy any issues early.
- Mid Way - this should evaluate what stage the sponsorship relationship is at, if the commitments are still being met and provide some additional encouragement to move the relationship forward.
- End of program - this should evaluate the effectiveness of the full program, any results that were achieved and an opportunity to gather iteration data.

#### Program Resources

- [Agenda Template](https://docs.google.com/document/d/1Ytt20sLjVAH_eokDHaBsH-w7M6hK1x44B4pr5s2unl4/edit)
- Sample emails and slack messages
- Successful Sponsorship Relationship Video
- Reminder resources

#### Communication Resources

Throughout the program, the program lead and Executive Sponsorship Advocates should communicate regularly with the participants. A great way of doing this is providing regular resources on sponsorship activities. Here is a list of helpful resources that you can use:

### End of Program

At the end of the program, we will conduct feedback sessions as above. We will also conduct a Next Step Plan.

This will solidify any expectations for after the program, whether that is to enter a more informal sponsorship program, on going advocacy for career development or growth.

## Goals & Benefits

**Goals:**

The goals of including Sponsorship Programs at GitLab is to help ensure that our top performers and team members from underrepresented groups are giving increased opportunities to work with senior leaders. This will increase engagement within these groups and ultimately increase the retention of team members.

**Benefits:**

Sponsor:

- Exposure to a diverse set of team members at GitLab, increasing their ability to lead diverse teams
- Exposure to new ideas and be challenged on the status quo
- Intentional talent management  & succession planning
- Better understanding of the challenges of team members from underrepresented groups

Sponsee:

- Increased exposure to GitLab and visibility to senior leaders at GitLab
- Access to feedback from a senior leader
- Ability to develop skills and capabilities
- Increased control over your career development plan

GitLab:

- A more diverse team at leadership team
- Increased retention of team members
- Attraction of underrepresented groups to GitLab
- Team members more motivated to maintain performance levels

## Suggested measureables

All programs should have some form of measurable for success, below are a few examples.

- Engagement survey data for the group
- Retention data for the group
- Team Member Experience Interview Data
- Program Satisfaction
- Career Advancement/Mobility of participants

## Training Videos & Materials

- [Training Slides](https://docs.google.com/presentation/d/1CKMGvJRtJWl9ot99kyHQW4m5G65Jr5nFSQH2HAW9oFI/edit?usp=sharing)
- [Kick Off Call Slides](https://docs.google.com/presentation/d/1LRkjVnX3AUw1PE22_AVQwobYVlOaPM4vvLT-kk8awzw/edit?usp=sharing)

## Informal Sponsorship Relationships

Sponsorship doesn't have to happen in the confines of a formal program. You may have a desire to sponsor a team member but no program exists as yet. This is something that is encouraged and we have seen happen successfully in the past, you can view this video as an example.

When entering an informal sponsorship relationship be sure to still outline and discuss the goals of the sponsorship. Follow the Sponsorship Framework to ensure success and hold each other accountable.

This will ensure a great experience for both the sponsor and sponsee.
