---
title: "Neurodiversity in the Workplace Short Course"
description: "This page hosts the read section of the Neurodiversity in the Workplace Short Course"
canonical_path: "/company/culture/inclusion/neurodiversity-short-course/"
---

In this course you will read or watch content created by the Diversity, Inclusion & Belonging team, curated from experts in the field via LinkedIn Learning and hear from GitLab Team Members who are neurodivergent. I am excited for GitLab Team Members to learn more about Neurodiversity and I want you all to remember the experiences that you will read or watch are all individuals, everyone's experience is different, what works for one person may not work for another. This course will hopefully give you some methods to help appreciate people as individuals with individual needs and to be more inclusive to neurodivergent team members. This is not a certification and the learning is a continuous process.

You can access this short course in [LevelUp here](https://levelup.gitlab.com/access/saml/login/internal-team-members?returnTo=https://levelup.gitlab.com/learn/course/neurodiversity-in-the-workplace)

### Exploring Neurodiversity

[Defining Neurodiversity via LinkedIn Learning, by Tiffany Jameson](https://www.linkedin.com/learning/hiring-and-supporting-neurodiversity-in-the-workplace/defining-neurodiversity?autoAdvance=true&autoSkip=false&autoplay=true&resume=false&u=2255073)
{.h4}

I speak to many organizations all around the world. When I talk about neurodiversity, most have never even heard of the word, so let's start there. Neurodiversity is an umbrella term for individuals who cognitively process differently than what society considers the norm.

Neurodiversity doesn't discriminate based on color or gender, and symptoms can present at different stages in an individual's life.

Now, Judy Singer coined this term in the late '90s, and it's not a diagnosis. It can be better described as a social movement, to view cognitive diversities from a strengths-based lens. So, why is it essential to understand neurodiversity? The World Health Organization reports 15% of humanity is living with a disability, and only a small fraction of organizations, less than 12%, are including this group in their diversity programs. We all feel the world shrinking, and the challenge we face is adapting to many identities. Color, religion, gender, and neurodiversity. So let's spend some more time talking about terminology. Terminology can get a little tricky, and is always changing.

For this course, I'll refer to the group as neurodiversity, and to the individual as a neurodivergent. I'll refer to those who are not neurodivergent as neurotypical. Keep in mind, there are arguments that there is no such thing as a typical brain, but we use that term to define people that would not traditionally fall under the neurodiversity umbrella.

There isn't a predefined list of what falls under the umbrella, it is a personal decision to be recognized as neurodivergent. However, in this course, we'll focus on human resource knowledge and support of

- Autism
- ADHD
- Dyslexia
- Dysgraphia
- General learning differences.

These groups make up a large portion of the population, and have many talents to lend to an organization. As an HR professional, you can guide your organization in learning how to hire, employ, and support this population to maximize this fantastic and talented workforce. Neurodiversity creates a new landscape of hiring and supporting employees. Human resource professionals can increase their competencies to support this group and educate the workforce to ensure inclusion for all types of minds. The world is ready to embrace neurodiversity. Neurodivergent people bring unique perspectives, solutions, and innovative ideas. Starting here is a great first step to embrace this population within your organization.

[Defining the spectrum of neurodiversity via LinkedIn Learning](https://www.linkedin.com/learning/hiring-and-supporting-neurodiversity-in-the-workplace/defining-the-spectrum-of-neurodiversity?autoAdvance=true&autoSkip=false&autoplay=true&resume=false&u=2255073)
{.h4}

Neurodiversity is an umbrella term but there are some impairments more commonly associated with neurodiversity. So let's drill down on the five areas I'll be highlighting in this course.

- First, autism spectrum. This is a broad term used to describe a group of neurodevelopmental differences. These manifest as nontraditional ways of communicating and interacting socially. Often, autistics demonstrate restricted and repetitive patterns of thought and behavior, sometimes getting stuck on a topic. An autistic's ability to learn deeply about topics and notice when there are inconsistencies brings value to any team. Almost 2/3 of autistics also have ADHD.
- ADHD, which stands for attention deficit hyperactivity disorder is one of the most common neurological disorders. So in the workplace, it presents itself as difficulties with working memory. Impulsivity, prioritizing, focusing, remembering plans, multitasking, coping with stress and also organizing. I find that this group of individuals are terrific at dynamic, creative and inventive thinking. Most of the successful salespeople I know have ADHD.
- Dyslexia and Dysgraphia and these overlap a lot. So dyslexia is characterized by difficulties with accurate or fluent word recognition and by poor spelling and decoding abilities. So outward signs include letter or number reversal, difficulty reading and spelling, difficulty with left versus right, trouble following multistep directions and slow handwriting that is difficult to read. It may take them longer to write than the average person and the person may express discomfort or stress while doing so. People commonly experience both dysgraphia and dyslexia together. Both of these groups uniquely embrace creative thinking, problem-solving, and the ability to decipher information, all skills that can add value to your team.
- And then last, we have the broad area of general learning difficulties. This refers to a condition in the brain that causes difficulties comprehending or processing information and is caused by several different factors. Individuals impacted may experience difficulty learning in a typical manner, but not the inability to learn. Keep in mind that each of these conditions lives on a spectrum, just because two people identify as autistic doesn't mean they present in the same way.

My son in his early years, had difficulty speaking, exhibited stimulatory behaviors that distracted him from learning and auditory processing that made him unable to correctly hear people talking, but we knew others who were also neurodivergent and were unable to speak. All these individuals were diagnosed with autism, yet it was impacting them differently in various aspects of their life.

It's important that your company supports the whole person, so you could include all the conditions that fall under the neurodiversity umbrella. When you think about your neurodivergent employees, consider what opportunities exist to use their special, creative and innovative talents to gain a competitive advantage.

[Understanding the challenges for five groups via LinkedIn Learning](https://www.linkedin.com/learning/hiring-and-supporting-neurodiversity-in-the-workplace/understanding-the-challenges-for-five-groups?autoAdvance=true&autoSkip=false&autoplay=true&resume=false&u=2255073)
{.h4}

One of the most important reasons a professional must understand neurodiversity is to fully appreciate and acknowledge the toll working in a neurotypical world has on many neurodivergent people. It starts with recognizing the natural differences in the way the human brain interprets information. By understanding these differences, you can begin to show empathy for those that experience life differently than you.

So let's chat about some of the common challenges for neurodivergent people in the workplace, starting with executive functioning.

- Executive functioning is a set of mental skills that include working memory, flexible thinking, and self-control. A person with strong executive functioning can multitask, is extremely organized, and has the ability to plan and prioritize tasks. These individuals work well in project management roles. Now, we use our executive functioning extensively throughout the day. When it's not working properly, it can show up as inability to focus, follow directions, handle emotions, and also, plan.
- Expressive language such as thinking on my feet, processing questions, or being able to speak at all. When in a conversation with a neurodivergent, lack of eye contact is common, often sending the wrong message of boredom or inattentiveness. Also, the use of repetitive or rigid language or even monologue about a topic of interest is common.
- Elements of communication, including nonverbal language, can also be a challenge for a neurodivergent to pick up on. Tone, facial expressions, and other non-verbal communication are parts of communication used to effectively send a message. Often, they miss these more subtle forms of communication. This creates a challenge when people are accustomed to certain reciprocal behavior from people they talk with. You won't always get that with the neurodivergent, but it doesn't mean the interaction is any less meaningful.
- Camouflage or masking. I like to explain it like this. Each morning, you wake up with a full cup of water. That's your resources for the day. Typically you lose a little water here and there throughout the day until you're pretty low. For some, that cup has a bunch of tiny holes in it, and before they can even get started with their day, their resources are being lost. Their energy switches to keeping water in the cup. Unfortunately, this activity only makes the cup drain quicker. The cup with holes is a representation of a neurodivergent's use of camouflaging or also called masking. So social camouflaging or masking is the behavior of trying to act normal, communicate normal and hide their neurodivergent traits. They social camouflage to escape the various stigmas associated with neurodivergent conditions or to escape bullying and ridicule they have experienced in the past. Think of it as post-traumatic stress and social camouflaging is their coping mechanism. This act leads to anxiety and burnout. Many neurodivergent people hide this string. Why do they feel like they have to hide this? Well, here's why. The general population doesn't understand these impairments, how they manifest and what they mean for their coworkers ability to perform work. Innocent ignorance of neurodiversity by co worker's is the number one reason an individual will tax their system by social camouflaging, but by you creating a neurodivergent-friendly environment, their energy translates into productivity and innovation for your organization, so before this group can be accepted, they must first be understood.

### Neurodiversity in the Workplace at GitLab

#### Personalisation

##### Personalisation of communication & management styles

The key to becoming a workplace that is built for all team members is to ensure that how you operate with all team members is from a personal perspective. It is easy to have one way of doing things, whether that is how you communicate with colleagues, manage team members, how you deliver feedback and much more.

Unfortunately, those modes are not going to work for everyone, each person has different needs and this is especially true for neurodivergent team members. As we saw, there are several potential challenges that neurodivergent people can face. To combat those challenges we should be asking questions of all team members regardless of whether they are neurodivergent when we are working closely with them or managing them. We do this so those team members who do not want to disclose they have a neurodivergence, people who are undiagnosed and more generally trying to make a workplace that is inclusive so all team members can thrive. Some examples could be.

**1. What is your preferred work, learning & communication style?**

Answers could be for example:

- Written information over verbal/video
- Structured work weeks and clear goals
- Clear agendas and no surprise meetings
- I am direct and to the point.
- I tend to talk to think and can go on tangents. I am open to being told that I am running off-topic.

**2. How do you like to receive feedback on your performance both constructive and positive?**

Answers could be for example:

- I like to receive feedback written and then have a discussion about it.
- I like to receive all feedback verbally first and then discuss in real-time.

You can also challenge yourself to ensure you are being clear about your intentions to ensure your intentions are not missed. Some team members may thrive in heated discussions and debates and not need assurances afterwards. Some team members could be in the exact same conversation but find it very stressful. Do not assume everyone's emotional response in a meeting or situation is the same. For example, you could assure all team members by saying something like:

- I wanted to let everyone know that we have great actions to move forward and I know that debates like this can be stressful.
- I would like to remind everyone of our operating principle to disagree, commit and disagree. We are good to move forward, thank you everyone for the discussion.

Servant leadership is very important when building an environment where neurodiversity can thrive and is described in the handbook as one of the important things in being a remote manager. It is also important when thinking about how to cultivate an inclusive environment. You will have to adjust your management style for all your team members to ensure that you set all team members up for success. Asking the questions above will allow you to apply the principles of servant leadership more effectively such as building trust, operating with empathy, growing team members and actively listening.

#### Bias & Perception

##### Challenging your bias & perceptions

If you haven't already read through our handbook page on unconscious bias and also read or taken the psychological safety short course. Everyone has bias and it is about recognising and challenging your bias which can inform your perceptions.

People who are neurodivergent can miss social cues or not provide certain social cues. This could elevate a biased response in those interactions. You may perceive someone as disinterested, uncommunicative or lacking knowledge. Ensure that when you encounter situations that you do not perceive as normal, cloud your judgment on that person's ability to do their work. Let our results value always be the indicator of success.

#### Our Team Members

You will learn from team members who are neurodivergent, talking about their experience, how they work at GitLab and some of the accommodations they have made in the workplace. You will see how each individual is different and there isn't a one size fits all approach. I'd like to thank all the participants for their openness and vulnerability which will no doubt help GitLab Team Members understand the intricacies of neurodiversity.

Kaitlyn Chappell: [Transcript](https://docs.google.com/document/d/14IXQimwsBqf8ppI3mtmDE2Ts9yhxqUCYAOKQgXRLlhE/edit?usp=sharing) - [Video](https://www.youtube.com/watch?v=FMTG9VL_bzs)

Matt Wilson: [Transcript](https://docs.google.com/document/d/1Ii78o4MizjGI8HygkgQ0JvcE7goBT88V-6TAt3V6xDU/edit?usp=sharing) - [Video](https://www.youtube.com/watch?v=LDOZ0gPHthE)

Mike Lindsay: [Transcript](https://docs.google.com/document/d/1WjFGzhZFdhb8UTG669-UwDcVuvS88JZwlw_TM4QdqsY/edit?usp=sharing) - [Video](https://www.youtube.com/watch?v=qM3FYf5sUXs)

#### What can you do next: Building a more inclusive environment for neurodivergent team members

- Build [**team member profiles**](https://gitlab.com/gitlab-com/people-group/dib-diversity-inclusion-and-belonging/diversity-and-inclusion/-/blob/master/.gitlab/issue_templates/Team-Member-Profile.md) or build your own team member profile and share it with your colleagues/manager. Personalisation is key, by focussing on the team members' individual working styles, communication styles and feedback loops, you will negate the need for disclosure and allow all team members to thrive. You can use this issue [template](https://gitlab.com/gitlab-com/people-group/dib-diversity-inclusion-and-belonging/diversity-and-inclusion/-/blob/master/.gitlab/issue_templates/Team-Member-Profile.md).

[**Neurodiversity Resources Handbook Page**]({{< ref "neurodiversity-resources" >}})

**Reasonable Accommodations**

This is covered in the [Neurodiversity Resources Handbook Page]({{< ref "neurodiversity-resources" >}}) but here are some articles that provide specific examples of reasonable accommodations for neurodivergent team members.

[Neurodiversity Hub for Employers](https://www.neurodiversityhub.org/resources-for-employers)

[Job Accommodation Network](https://askjan.org/)

[Neurodiverse Employees may need accommodations for remote work](https://www.shrm.org/resourcesandtools/hr-topics/employee-relations/pages/neurodiverse-employees-may-need-accommodations-for-remote-work.aspx)

**What can you do if someone discloses they are neurodivergent to you?**

- Team Member
    1. Be supportive
    1. Ask how you can help them in the workplace
    1. Ask if they need support in telling other members of the team
    1. Point them toward the Neurodiversity Resources Handbook Page
    1. Express that you are an ally and happy to be a confidant or support if needed
    1. Ask how you can be an ally for them
- Manager
    1. Be supportive
    1. Ask what accommodations can be made to help with their accommodations. If they do not know what accommodations will help, consider a focused 1:1 to discuss what they feel is missing and how best they can accomplish their work.
    1. Ask if they would like assistance in disclosing to their colleague if they intend to do so
    1. Approach feedback differently and ask what can you do to help.
    1. Follow through, ensure that any agreed accommodation & actions are put in place
