---
title: "Unconscious bias"
description: "Learn more about unconscious bias and how to recognize it."
---

## What is unconscious bias?

Unconscious biases are stereotypes about certain groups of people that individuals form outside their own conscious awareness. Nearly all our thoughts and actions are influenced, at least in part, by unconscious impulses. There's no reason bias should be out of scope.
Categorizing people based on social and other characteristics is a powerful  survival mechanism, as it helps to distinguish friends from foes and make quick "life or death" decisions based on "inner feeling". At the same time this is a fertile ground for growing stereotypes, prejudice, discrimination.

Biases help the brain create shortcuts for the decision-making process and detect threats. Our unconscious biases are based on our own experiences and they help us detect patterns and find in-groups, a basic survival mechanism below our conscious radar. If unconscious bias goes unchecked, it can lead to fixed general views of how people should act or behave, and/or negative out-spoken attitude towards a person or group.

Everyone has unconscious biases, the goal is to bring them to our consciousness and navigate them, in order to provide a more inclusive and empathetic work environment.

## How do I recognize it?

- **Gain self-awareness and be present** Pay attention to your body language and tone. Instead of reacting, set up a response. Monitor your self-talk.
- **Exhibit tolerance and patience; avoid assumptions** Choose to listen, pause, and consider first. Offer the benefit of the doubt. Don't jump to conclusions. Ask questions.
- **Make thoughtful impressions and decisions** Challenge your own default views. Take all options into consideration. Use informed decisions, not just your "gut".
- **Seek feedback and choose to use it** Don't avoid the conversation, seek it out. Ask for the feedback you need, not want. Achieve by understanding, not defending.
- **Remain open-minded and continue learning** Hold yourself and others accountable. Revisit, reflect, and review your day. Diversify your circles.

### Unconscious Biases to look out for (in ourselves and in others)

- **[Affinity Bias](https://web.archive.org/web/20201025085556/https://www.futurelearn.com/courses/diversity-inclusion-awareness/0/steps/39958)**: Biased towards people "who make me comfortable"; Biased against people "who make me uncomfortable".
- **[Affective Heuristic Bias](https://en.wikipedia.org/wiki/Affect_heuristic)**: Immediate emotional judgement influenced by superficial traits such as race, gender, age, or names.
- **Ageism Bias**: The tendency to have adverse feelings/perception about another person based on age.
- **Authority Bias**: The tendency to attribute greater knowledge to persons in positions of authority than they may actually possess.
- **[Confirmation Bias](https://www.verywellmind.com/what-is-a-confirmation-bias-2795024#targetText=A%20confirmation%20bias%20is%20a,creative%20than%20right%2Dhanded%20people.)**: People look for ideas or findings that confirm their existing belief.
- **Conformity Bias**: Tendency to take cues for proper behavior based on the actions of others. **Example:** studies show that people are more likely to donate to charity if they know/see others donating.
- **[Contrast Effect](https://effectiviology.com/contrast-effect/)**: A cognitive bias that distorts our perception of something when we compare it to something else, by enhancing the differences between them. For example, your performance evaluation of a team member is affected by the evaluation that you wrote for a different team member just before.
- **Gender**: The tendency to prefer one gender over another gender.
- **Height**: Tendency to judge a person who is significantly shorter or taller than what is "deemed as socially accepted" human height.
- **[Halo Effect](https://en.wikipedia.org/wiki/Halo_effect)**: Form of bias which favors one aspect that makes a person seem more attractive or desirable. **Example:**  If we think someone is good looking we might also think that they are intelligible and charismatic.
- **[Horn Effect](https://en.wikipedia.org/wiki/Horn_effect)**: Opposite of **Halo Effect**. Form of bias that causes one's perception of another to be overly influenced by one or more negative traits. **Example:**  Someone who has failed the project is always like that and incapable of improving.
- **[Name Bias](https://metro.co.uk/2019/09/17/unconscious-name-bias-damaging-10757825/)**: Form of bias which favors a person based on their name and the perceived origin of their name.

For further reading: Wikipedia has [a comprehensive list of cognitive biases](https://en.wikipedia.org/wiki/List_of_cognitive_biases) that influence us.

### Can I test it?

Unconscious bias is far more prevalent than conscious prejudice and often incompatible with one's conscious values. Therefore it would be good to have an instrument to detect and fight it.
The tool that achieved most popularity both in scientific circles and public is the [implicit-association test (IAT)](https://implicit.harvard.edu/implicit/), which is a collaborative research effort between researchers at Harvard University, the University of Virginia, and University of Washington. It is meant to reveal the strength of one's mental association between certain groups of people and certain traits. It is used to investigate biases in racial groups, gender, sexuality, age, and religion, as well as assessing self-esteem.

Though it has some [criticisms](https://qz.com/1144504/the-world-is-relying-on-a-flawed-psychological-test-to-fight-racism/), IAT can jumpstart our thinking about hidden biases:

- Where do they come from?
- How do they influence our actions?
- What can we do about them?

## Tips on Recognizing and Avoiding Bias

1. Understand we all have biases
1. Determine what your biases are
1. When you see it block it
1. Maintain your awareness
1. Be ok with having an opinion different from the group
1. Be wary of first impressions
1. Do research on stereotypes
1. When working globally understand that your perceptions of bias may simply be the result of a lack of understanding of cultural differences
1. When making critical business decisions, invite others who can broaden your perspective to help ensure there are no hidden biases in the decision

## Strategies for Managing Unconscious Bias in Practice

The [SPACE2 Model of Inclusion](https://drive.google.com/file/d/1TZ_bkpjtUjzZGipjEfjgPhtMXBKjd194/view) - Six evidence based techniques for managing bias in oneself and others:

- Slowing Down
- Perspective Taking
- Asking Yourself
- Cultural Intelligence
- Exemplars
- Expand

## Practical ways to reduce or avoid the impact of bias

- As an application reviewer or interviewer, if you find yourself biased positively or negatively, excuse yourself and ask someone else to review or interview that applicant. Being positively or negatively biased towards one candidate is unfair to all candidates.
- Data driven decision making. Rely on pre-defined measurable data points to reduce unconscious bias influences

## Recognizing Bias Training

On 2020-06-24 we held three Live Learning sessions to cover how to recognize bias. This recording is from the second session and includes content as well as a Q&A portion. The content in the video below follows along with this [slide deck](https://docs.google.com/presentation/d/1xl8beGDfymEfSDyuMcDAJlmvIlTRR06ECfF7UmjFrf8/edit?usp=sharing) and [meeting agenda](https://docs.google.com/document/d/1yrNA9JMBkJRRa1DXtC4TxKbZAQELjBU-E6TYwwfv9Hw/edit?usp=sharing). We also used Mentimeter during the sessions to ask the attendees questions. GitLab team members can view the [Mentimeter results](https://docs.google.com/spreadsheets/d/1qTpLBNdH8FvuVYPuK5WD7DnuK1xwbZEKS7h3ILtcVQo/edit?usp=sharing).

{{< youtube "nlkvRuafwYY" >}}

<figure class="video_container">
<iframe src="https://docs.google.com/presentation/d/e/2PACX-1vQKUZMuPXCYChjokOQlcOrAtKx2inQiwF6Xp-vMzMIyx6tYPLTQVyCzoN6LtGGMI0R0NtvGPyalhDJU/embed?start=false&loop=false&delayms=3000" frameborder="0" width="960" height="569" allowfullscreen="true" mozallowfullscreen="true" webkitallowfullscreen="true"></iframe>
</figure>

## Resources

### Inner resources

- [Ongoing discussion](https://gitlab.com/gitlab-com/diversity-and-inclusion/issues/27)
- [This MVC is based on Ashley Sullivan's comment here](https://gitlab.com/gitlab-com/people-ops/General/issues/379#note_208972342)
- [Diversity, Inclusion and Belonging at GitLab](/handbook/company/culture/inclusion/)

### External resources

- [Teaching Tolerance](https://www.tolerance.org/professional-development/test-yourself-for-hidden-bias)
- [Diversity and Outreach, UCSF](https://diversity.ucsf.edu/resources/unconscious-bias)
- [The Guardian: Unconscious bias: what is it and can it be eliminated?](https://www.theguardian.com/uk-news/2018/dec/02/unconscious-bias-what-is-it-and-can-it-be-eliminated)
- [Wikipedia: IAT](https://en.wikipedia.org/wiki/Implicit-association_test)
- [The world is relying on a flawed psychological test to fight racism](https://qz.com/1144504/the-world-is-relying-on-a-flawed-psychological-test-to-fight-racism/)
- [How to reduce unconscious bias at work](https://lattice.com/library/how-to-reduce-unconscious-bias-at-work)
- [Affinity bias](https://web.archive.org/web/20201025085556/https://www.futurelearn.com/courses/diversity-inclusion-awareness/0/steps/39958)
