---
title: Group Conversations
description: "Everything you need to know about GitLab's daily, recurring Group Conversations"
---

## Introduction

Group conversations are recurring events providing regular updates and an additional opportunity for team members to ask questions, across all GitLab teams on a rotating schedule. Group conversations support collaboration and transparency

All Team Members are invited to participate in Group Conversations by adding questions and comments in the [Group Conversation issue](https://gitlab.com/gitlab-com/group-conversations/-/issues), which is linked in every announcement by the respective host.

If you have suggestions for improving the Attendee or Meeting Leader experience please create a Merge Request (MR) to update this page — [everyone can contribute](/handbook/company/strategy/#why)!

Due to low attendance of the sync meetings, Group Conversations moved to being fully [asynchronous](/handbook/company/culture/all-remote/asynchronous/) in FY24-Q4.

## Group Conversation vs. Key Review

It's common to wonder what the difference is between these two meetings. Generally, they cover the same or similar content, but for different audiences.

|  | Key Review | Group Conversation |
| --- | ---------- | ------------------ |
| **Audience** | Management | General GitLab Team |
| **Tone** | Formal | Informational |
| **Discussion** | High-context | [Low-context](/handbook/company/culture/all-remote/effective-communication/#understanding-low-context-communication) |

The [Key Review](/handbook/company/key-review/) is intended for senior leadership to ask questions. The Group Conversation is open to the entire GitLab team to ask questions. We have both to give the senior leaders enough time to ask questions since the Group Conversations often have general questions unrelated to slide deck. Both are also a good place for sharing news and explaining initiatives. The same deck is generally used for both events, except that the Group Conversation one will have any material non-public information (MNPI) removed. Here's a brief discussion of why we have both meetings, and how they can operate effectively:
<figure class="video_container"><iframe src="https://www.youtube.com/embed/tLOMA3663XM"></iframe></figure>

## For Attendees

If you have questions around an upcoming Group Conversation, please be sure to bring it to the `#group-conversations` Slack channel and @tag the host!

1. Please add your questions as comments on the linked issue. Remember [First Post is a Badge of Honor](/handbook/communication/#first-post-is-a-badge-of-honor).
1. Please do not include customer names in your questions/comments.
1. Not everything has to be a question. Comments are welcome on the issue as well, whether it's as a reply to an existing discussion thread or as a new thread where others can contribute to the discussion.
1. Thanking and recognizing people is very important.
1. You can ask someone to elaborate on a slide to get more context.

## Hosts

The Host or DRI is the person leading the conversation, usually the group lead, subject matter expert, and overseer of the slides created for the Group Conversation. The host doesn't need to be the group lead, but the group lead is responsible for making sure that it happens.

Questions will generally be directed to the Host, and they will usually answer them unless they feel that another team member has more information or expertise to offer.

### Process for host

Complete this process within 7 days after the Key Review to host a Group Conversation.

1. Add your [presentation](#presentation) in the [Group Conversation Google Drive shared folder](https://drive.google.com/drive/folders/1Om1i9qrn1cZwxl7xRasV2mvrf91oyNOC).
1. Use [the default Group Conversation issue template](https://gitlab.com/gitlab-com/group-conversations/-/issues/new) to create a new issue for your Group Conversation. The steps below are included in the template as boilerplate to replace, but please ensure to:
   1. Fill in your group's name, and the date you're posting the announcement.
   1. The host's name as DRI. And assign the issue to them.
   1. Link of the Google Slides presentation (with edit or comment access to everyone at GitLab). See the [presentation section](#presentation) for details.
   1. Link to the video of your Group Conversation presentation on GitLab Unfiltered (recommended, but optional).
   1. Link to the Key Review Agenda (if applicable).
   1. Date and estimated time when you will come back to the group conversation issue to answer any questions. Generally, the date should be 3 working days from posting date. Set it as the issue due date for reminders to go out.
1. Post in `#whats-happening-at-gitlab` when ready. See the [template Slack announcement](#template-slack-announcement) which you can use, and personalize.
1. Cross-post in `#group-conversations`.
1. Set a reminder for the date/time when you've indicated you will answer any questions in the issue. The suggestion is between 2 to 3 business days after the issue is shared. Please resolve the comment thread once the question is answered.
   1. If there are questions that need a longer conversation, mention which Slack channel the conversation can continue, or link to a relevant issue.

### Template Slack announcement

```text
The <team> group conversation is ready!

Please see `${INSERT_LINK}` for the Group Conversation Issue, which includes links to the slide deck, what we've recently completed, and what we're currently working on. Any questions for the team, related to the slides or not, are most welcome. I will be answering them in 3 working days.
```

### Presentation

Use presentations to document everything people should know about your group. If the GC is for a group that didn't have a Key Review, and are preparing new slides, the slides should start with the top 3-5 highlights or top of mind updates that are relevant across functions, followed by additional information. These presentations are for attendees to review and generate questions from for the call, and attendees will often have [low context](/handbook/company/culture/all-remote/effective-communication/#understanding-low-context-communication) around your function or team.

Functions with Key Reviews should not create a new deck for a Group Conversation but should use their [Key Review deck](/handbook/company/key-review/#group-conversations-and-key-review-metrics) for the Group Conversation. If the Key review deck has MNPI, then a copy without MNPI should be created.

You can also record and upload a [YouTube video](/handbook/marketing/marketing-operations/youtube/) if there is additional context that would be beneficial to supplement the slides.

There are three layers of content in a presentation:

- Data, this is the contents of the slide.
- Take away, this is the title of the slide, so use: 'migration 10 days ahead of schedule', instead of 'migration schedule estimates', the combined titles of your slides should make a good summary.
- Feelings, this is the verbal and non-verbal communication in the video feed, how you feel about the take away, 'I'm proud of the band for picking up the pace'.

Best practices for presentations:

1. Save time and ensure asynchronous communication by writing information on the slides. Many people will not be able to participate in Group Conversations, either live or recorded, but can read through the slides.
1. To better engage team members outside of your team or function, presentations should ideally assume [low context](/handbook/company/culture/all-remote/effective-communication/#understanding-low-context-communication).
1. Slides with a lot of text that can be read on their own with lots of links are appreciated.
1. If you want to present, please consider [posting a recording to YouTube](/handbook/marketing/marketing-operations/youtube/) at least 72 hours before the meeting. Link it to the Google Doc (including specifying whether the video is private or public), and mention it in the relevant slack channels.
1. Once a quarter, add a slide covering items being actioned from the engagement survey.
1. Use this [slide deck](https://docs.google.com/presentation/d/16FZd01-zCj_1jApDQI7TzQMFnW2EGwtQoRuX82dkOVs/edit?usp=sharing) as the template for your presentation. Presentations should allow editing (preferred) or commenting from everyone at GitLab so that [everyone can contribute](/handbook/company/strategy/#why).
1. We encourage you to share metrics and key results during your Group Conversation. Please do not use cumulative metrics in your Group Conversations since those will usually show an upward trend and make it difficult to assess current performance. It is more appropriate to share cumulative metrics externally. See [#8 of the general presentation suggestions](/handbook/communication/#presentations) for more information about cumulative metrics.

For more general presentation best practices, please see our communication handbook's [Presentation section](/handbook/communication/#presentations).

#### Examples of good presentations

- [Strategic Marketing Group Conversation 2020-01-22](https://docs.google.com/presentation/d/1xSxP_AztHHtLcYFd12Mf5yUIMVy9BU6QZnSebrlO7oo/edit): This has lots of links and a [supporting YouTube presentation](https://www.youtube.com/watch?v=2RfNsIJ7lPM).

## Examples of Past Sync Group Conversations

All of the public live streamed Group Conversations can be found on the GitLab Unfiltered YouTube channel [Group Conversations playlist](https://www.youtube.com/playlist?list=PL05JrBw4t0KpUeT6ozUTatC-JbNoJCC-e).

<figure class="video_container"><iframe src="https://www.youtube.com/embed/EAtkUmww_7I"></iframe></figure>

<figure class="video_container"><iframe src="https://www.youtube.com/embed/V_UAe5dhrTc"></iframe></figure>

## Schedule & DRI

The Group Conversation schedule is set quarterly. The schedule is finalized the week before the start of each quarter by the EBA to the CEO.

The Scheduling DRI for each GC is encouraged to remind the DRI.

There is a [rotating schedule](#schedule--dri) with each Department having a conversation on a regular interval.
We usually do not have Group Conversations or Company calls during the last two weeks of December. We also tend to cancel these during [Contribute](/handbook/company/culture/summit/).

Please note: the frequency of Group Conversations does not recur on a specific cadence, but rather an estimated time (ex: the Portfolio Marketing GC could happen every other month, but does not happen specifically on the 4th Wednesday every other month). Groups Conversations without Key Reviews are optional, and these can be swapped with other groups without Key Reviews, or scheduled during an open day on the [schedule](#current-schedule).

If your Group Conversation is optional and you need to move the date, please work with your department's EBA.

| Group Conversation | DRI | Key Review? | GC Frequency | Alternate Hosts | Scheduling DRI |
| ------------------ | --- | ----------- | ------------ | --------------- | -------------- |
| [Marketing](/handbook/sales/) | Ashley Kramer | Yes | Twice per quarter | | EBA to CMSO |
| [Sales](/handbook/sales/) | Sales VPs | Yes (GTM Key Review shared with Marketing) | Monthly - rotates between VP of Commercial, VP of Enterprise, VP of Channel & VP of Customer Success | | EBAs in Sales |
| [People](/handbook/people-group/) | Wendy Barnes | Yes | Twice per quarter | | EBA to CPO |
| [Product](/handbook/product/) | [Month PLT Leader Rotation](/handbook/product/product-leaders/product-leadership/#product-group-conversation-leader-rotation) | Yes | Quarterly | | EBAs in Product |
| [Support](/handbook/support/) | Johnny Scarborough | Yes | Quarterly | @lbot @lyle @vparsons| EBA to Engineering |
| [Security](/handbook/security/) | Josh Lemos | Yes | Quarterly| | EBA to Security |
| [Development](/handbook/engineering/development/) | Tim Zallmann | Yes | Quarterly | | EBA to Engineering |
| [Infrastructure & Quality](/handbook/engineering/infrastructure-quality/) | Mek Stittri | Yes | Quarterly | | EBA to Engineering |
| [General](/handbook/ceo/) | Sid Sijbrandij | No | Every other month | | EBA to CEO|
| [Alliances](/handbook/alliances/) | Nima Badiey | No | Quarterly | | EBA to VP of Alliances |
| [IT](/handbook/business-technology/it) | Nabitha Rao | Yes | Quarterly | | EBA to VP of Business Technology |
| [Data](/handbook/enterprise-data/) | Amie Bright | Yes | Quarterly | | EBA to VP of Business Technology |

## Current Schedule

| Expected Posting Date | GC | DRI | Key Review Date? |
|----|---------|---|--------|
| Wednesday 2024-01-03 | Support | Lyle Kozloff, Lee Matos | December 20 |
| Thursday 2024-01-11 | Security | Josh Lemos | December 20 |
| Wednesday 2024-01-24 | Infrastructure & Quality | Mek Stittri | January 16 |
| Wednesday 2024-01-31 | IT | Nabitha Rao | January 23 |
| Thursday 2024-02-01 | Development | Tim Zallmann | January 24 |
| Thursday 2024-02-22 | IT | Nabitha Rao | February 14 |
| Wednesday 2024-02-28 | Product | Product Leadership | - |
| Monday 2024-03-18 | People | Wendy Barnes | - |
| Monday 2024-03-18 | Finance | Brian Robins | - |
| Thursday 2024-03-28 | Support | Johnny Scarborough | March 18 |
| Wednesday 2024-04-24 | Data | Amie Bright | April 18 |
| Wednesday 2024-04-24 | Security | Josh Lemos | April 1 |
| Wednesday 2024-05-01 | Infrastructure & Quality | Mek Stittri | April 25 |
| Wednesday 2024-05-22 | IT | Nabitha Rao | May 15 |
| Tuesday 2024-05-28 | Product | Product Leadership | - |
| Wednesday 2024-06-12 | Finance | Brian Robins | - |
| Monday 2024-06-17 | People | Wendy Barnes | - |
| Thursday 2024-06-20 | Support | Johnny Scarborough | June 13 |
| Monday 2024-07-01 | Security | Josh Lemos | June 17 |
| Thursday 2024-07-25 | Data | Amie Bright | July 18 |
| Monday 2024-08-05 | Infrastructure & Quality | Mek Stittri | July 25 |
| Thursday 2024-08-22 | IT | Nabitha Rao | August 14 |
| Wednesday 2024-09-11 | Product | Product Leadership | August 30 |
| Thursday 2024-09-12 | People | Wendy Barnes | - |
| Thursday 2024-09-26 | Support | Johnny Scarborough | September 18 |
| Monday 2024-09-30 | Security | Josh Lemos | September 19|
| Thursday 2024-10-24 | Data | Amie Bright | October 17 |
| Monday 2024-10-28 | Infrastructure & Quality | Mek Stittri | October 16 |
| Thursday 2024-11-21 | IT | Nabitha Rao | November 14 |
| Thursday 2024-11-28 | Product | Product Leadership | - |
| Wednesday 2024-12-11 | People | Wendy Barnes | - |
| Thursday 2025-01-02 | Support | Johnny Scarborough | December 16 |
| Monday 2025-01-06 | Security | Josh Lemos | December 18 |
| Thursday 2025-01-30 | Data | Amie Bright | January 23 |
| Monday 2025-02-03 | Infrastructure & Quality | Mek Stittri | January 23 |

## Examples of Past Group Conversations

All of the public live streamed Group Conversations can be found on the GitLab Unfiltered YouTube channel [Group Conversations playlist](https://www.youtube.com/playlist?list=PL05JrBw4t0KpUeT6ozUTatC-JbNoJCC-e).

<figure class="video_container"><iframe src="https://www.youtube.com/embed/EAtkUmww_7I"></iframe></figure>

<figure class="video_container"><iframe src="https://www.youtube.com/embed/V_UAe5dhrTc"></iframe></figure>

## Request a new Group Conversation

To request a new Group Conversation, please ping @exec-admins in the slack channel #group-conversations and they will assist you in scheduling a date.
