---
title: "GitLab Purpose"
description: "GitLab empowers everyone through knowledge sharing, job access, and our software platform."
canonical_path: "/company/purpose/"
---

## Purpose

GitLab's purpose is to help people increase their lifetime earnings through access to opportunities and the DevSecOps platform.

## Identifying GitLab's Purpose

GitLab's purpose lies at the intersection of these four circles.

1. World Needs:
    1. Individual progress (training and access to opportunities)
    1. Organization progress ([DevSecOps Platform](https://about.gitlab.com/solutions/devops-platform/), faster iteration)
1. Company skill: iteration (fast innovation, open source contributions)
1. Passionate about: open (to contributions, transparency)
1. Economic value: bundling into a single application

## How we support the purpose

### Training

Our knowledge sharing empowers everyone, not only to GitLab team members but also the world, through inclusive learning opportunities, mentorship programs, and transparently sharing how we operate.

#### How to run a startup company

1. 2400 page [handbook](/handbook) details how we approach almost any topic and is available to anyone with an internet connection
     1. Companies copy and paste from our handbook
     1. Y Combinator now recommends that startups ask 'what would GitLab do'
1. [Transparency value](/handbook/values/#transparency)
1. [YouTube Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A)
1. [CEO shadow program](/handbook/ceo/shadow/) also open to [people outside of GitLab](/handbook/ceo/shadow/#eligibility) who may be interested
1. [Certifications](https://about.gitlab.com/blog/2021/04/20/everyone-can-get-certified/) outside of GitLab skills, e.g. Diversity, Inclusion, and Belonging and Effective Communication

#### Using GitLab the DevSecOps platform

1. [Certifications](/handbook/customer-success/professional-services-engineering/gitlab-technical-certifications/) to demonstrate proficiency with GitLab
1. Best practices in DevSecOps are [easy through GitLab](https://about.gitlab.com/platform/)
1. Best inclusive practices are easy through GitLab ([rename of the default branch](https://about.gitlab.com/blog/2021/03/10/new-git-default-branch-name/), [pronouns in the product](https://twitter.com/gitlab/status/1402306208967561222))

#### Aimed at under-represented or under-resourced groups

1. [Coaching & mentoring program for people from underrepresented groups](/handbook/engineering/volunteer-coaches-for-urgs/)
1. [Morehouse College Advanced Software Engineering Course](/handbook/company/culture/inclusion/erg-minorities-in-tech/advanced-software-engineering-course/)
1. Targeted events such as [workshops organized for Rails Girls](/handbook/people-group/givelab-volunteer-initiatives/#rails-girls)
1. [Minorities in Tech (MIT) mentoring](/handbook/company/culture/inclusion/erg-minorities-in-tech/mentoring/program-structure/) for GitLab team members
1. [Women at GitLab Mentorship program](/handbook/company/culture/inclusion/tmrg-gitlab-women/mentorship-program/)

### Access to Opportunities

We empower how people work by providing thought leadership on remote work which spreads job opportunities more evenly across geographies, contributions to open source, and job access programs.

#### All-remote

1. Enable more companies to work remotely, which spreads job opportunities more evenly globally across regions and countries
1. Published [The Remote Playbook](https://learn.gitlab.com/suddenlyremote) and the [Remote Work Report](/handbook/company/culture/all-remote/remote-work-report/): with over 100,000 downloads, it's the de facto blueprint as the world transitions to remote work
1. GitLab's all-remote culture is being taught to execs and business students via case studies with [Harvard Business School](https://www.hbs.edu/faculty/Pages/item.aspx?num=57917) and [INSEAD](https://www.insead.edu/conversations/gitlab-can-all-remote-scale)
1. All remote and remote-first [job boards](/handbook/company/culture/all-remote/jobs/#all-remote-and-remote-first-job-boards)
1. All remote [certification](/handbook/company/culture/all-remote/remote-certification/) to allow more companies to hire remote team members
1. Reaching hundreds of thousands of remote transitioners via our [How to Manage a Remote Team](https://www.coursera.org/learn/remote-team-management) course on Coursera
1. REMOTE by GitLab Event
1. Network effects around evangelizing the remote movement: 30+ organizations openly [inspired by GitLab](/handbook/company/inspired-by-gitlab/)
1. [Asynchronous communication](/handbook/company/culture/all-remote/asynchronous/) gives flexibility which better allows child care providers to combine work with parental responsibilities
1. [Non-linear workday](/handbook/company/culture/all-remote/non-linear-workday/)

#### Commercial Open Source Software (COSS)

1. Creates more value than old models; jobs created for the open source offer as well as the availability of software to build upon
1. [Buyer Based Open Core model](https://www.heavybit.com/library/video/commercial-open-source-business-strategies/) and business model education
1. [Our Stewardship of GitLab](/handbook/company/stewardship/)

#### Accelerating tech careers

1. [GitLab for education](https://about.gitlab.com/solutions/education/) has issued 1.6M+ seats of top-tier GitLab to 800+ educational institutions in 65+ countries
1. Collaboration with [The Last Mile](https://about.gitlab.com/blog/2020/11/13/thelastmile-gitlab/)
1. Guidance and coaching on [how to use open source contributions to build resumes and network](https://thenewstack.io/the-opportunity-of-open-source-to-create-opportunities-for-others/)
1. Participation in internship programs such as [Outreachy](https://about.gitlab.com/blog/2021/04/15/outreachy-sponsorship-winter-2020/) and [Google of Summer Code](https://summerofcode.withgoogle.com/organizations/4961424868114432/)
1. [Engineering Internships](/handbook/hiring/emerging-talent/) at GitLab
1. [Engineering mentoring and coaching programs](/handbook/engineering/#mentorship-and-coaching-programs) for GitLab team members
1. [GitLab Learn](https://gitlab.edcast.com/) courses which can create pathways for targeted groups (for example, career transitioning or new to Open Source)

### DevSecOps Platform

The DevSecOps Platform brings together developers, operations and security professionals and empowers them to innovate at new levels-- making it faster, more secure, and more accessible.

#### Faster

1. Accelerate the software delivery process to meet business objectives
1. New way of making applications
    1. 5 minute production app, Ops2Dev
    1. Day 2 operations
1. Automate the following so it isn't a roadblock anymore:
    1. Secure
    1. Compliance
    1. Testing
    1. Running

#### More Secure

1. Simplify processes to comply with internal processes, controls and industry regulations without compromising speed
1. Run security scans earlier and for all projects

#### More Accessible

1. Allow anyone to be a creator
1. Make GitLab easier to use, higher [System Usability Scale (SUS)](/handbook/product/ux/performance-indicators/system-usability-scale/) score
1. Visibility into DevSecOps success

## Cadence and Alignment

Our purpose is on a 30 year cadence

### Mission

Our purpose informs [our mission](/handbook/company/mission), and our mission is the way we realize our purpose. [Our mission](/handbook/company/mission) is to make it so **everyone can contribute** by using our product, to our product, and to our company.

By making it so **everyone can contribute**, we increase access for people to be creators. With more contributors and more creators, we increase both the volume and velocity of innovation. More innovation drives economic progress that [benefits consumers, businesses, and the economy as a whole](https://www.ecb.europa.eu/ecb/educational/explainers/tell-me-more/html/growth.en.html). As a result, innovation both directly and indirectly increases the total volume of available opportunities and average value of each individual opportunity.

Access to a broader set of more valuable opportunities ultimately **increases people's lifetime earnings**.

[Our mission](/handbook/company/mission) is on the same 30 year cadence as our purpose. Our purpose informs our mission, which directly or indirectly informs the rest of the items in [our cadence](/handbook/company/cadence/). As a result, our purpose indirectly informs all of the items in [our cadence](/handbook/company/cadence/), and progress for the items on our [cadence page](/handbook/company/cadence/) like [Yearlies](/handbook/company/yearlies/) creates progress for both our mission and purpose.

## Purpose Resources

Additional Purposes resources:

1. [Creating a Meaningful Corporate Purpose](https://docs.google.com/document/d/1mXYu-Wf5lzcRC7yknSKCKpdgXx3DEO-E/edit)
1. [Find Your Why: A Practical Guide for Discovering Purpose for You and Your Team](https://www.amazon.com/Find-Your-Why-Practical-Discovering/dp/0143111728)

{{% include "includes/take-gitlab-for-a-spin.md" %}}
