---
title: GitLab Vision
description: Behind the scenes of The DevSecOps Platform
---

## Vision

Our vision captures what we want to deliver to customers in the next 10 years.

Today, we have the most comprehensive [AI-powered DevSecOps Platform](https://about.gitlab.com/platform/). This DevSecOps Platform shift is part of a larger trend: teams of all types are realizing that breaking down silos has compounding effects on productivity and collaboration. We see it with data and operations teams creating DataOps; we see it with machine learning and ops teams creating MLOps. As more companies (and more teams within a company) rely on our platform, we are positioned to become the **AllOps platform** — a single application for all R&D. This platform will offer significant and differentiated value to customers:

1. Platform efficiencies from a [DevSecOps platform](https://about.gitlab.com/direction/#devsecops-stages): This is [our main focus for the next 3 years](/handbook/company/strategy), because teams use us as a [DevSecOps Platform](https://about.gitlab.com/platform/) today. This includes using AI to enhance workflows.
1. Competitive advantages through [ModelOps](https://about.gitlab.com/direction/modelops/): Every company will need to become an AI company to stay competitive. This includes building, training, deploying, and rolling back AI models alongside the apps that consume them. Currently, DataRobot and Weights & Biases are the competitive solutions. We have begun iterating on this with an [MLFlow integration](https://docs.gitlab.com/ee/user/project/ml/experiment_tracking/mlflow_client.html) and a Model Registry.
1. Improved customer and internal coordination through [ServiceDesk](https://docs.gitlab.com/ee/user/project/service_desk/): GitLab customers need the ability to triage application incidents directly where their applications are built and deployed, so that they can tie incident resolution to the development backlog and track incident closure. Currently, [ZenDesk](https://www.zendesk.com/) and [JIRA Service Desk](https://www.atlassian.com/software/jira/service-management/features/service-desk) are the competitive solutions.

For the next few years, the majority of our focus is on providing a rich and comprehensive DevSecOps platform to our customers. This is detailed in our [company strategy](/handbook/company/strategy).

## Analysts

Gartner calls the combination of DevOps/MLOps/DataOps/AIOps [xOps](https://www.gartner.com/en/documents/4001009).

## Cadence

Our [Mission]({{< ref "mission" >}}) is on a 30-year cadence. It is the inspiration for this company vision, which is on a [10-year cadence]({{< ref "cadence#vision" >}}).

The vision here is reflected in our [company strategy](/handbook/company/strategy), which is on a 3-year cadence. You can find additional product vision details on our [direction page](https://about.gitlab.com/direction/#vision).

## Monitoring an evolving market

While we define our mission, vision, and strategy, we also acknowledge that we need to adapt with a changing market to meet customer needs. Netflix is a great example of this. Everyone knew that video on demand was the future. Netflix, however, started shipping DVDs over mail. They knew that it would get them a database of content that people would want to watch on demand. In other words, timing is everything.

Additionally, we must ensure that our Platform is open. If a new, better version control technology enters the market, we will need to integrate it into our platform, as it is one component in an integrated DevSecOps product.

### Entering new markets

[GitLab](https://about.gitlab.com) has taken existing, fragmented software tooling markets, and by offering a consolidated offering instead, have created a new [blue ocean](https://www.blueoceanstrategy.com/what-is-blue-ocean-strategy/). We would like to find more markets where we can repeat this same model.

The desirable characteristics of such markets fall into two stages: category consolidation and creation.

#### Category Consolidation

1. A set of customer needs that are currently served by multiple, independent software tools.
1. Those tools may already integrate with each other or have the possibility of integration.
1. Those tools operate in categories that are typically considered discrete (for example, with GitLab, SCM was one market and CI was another).
1. There is no current 'winner' at consolidating this market, even if there are some attempts to combine some of the tool categories within said market.
1. Users of the product are able to contribute to it — for example, with GitLab, many users are software developers who can directly contribute code back to the product itself.
1. When initially combined, the categories form a consistent and desirable user flow, which solves an overriding customer requirement.
1. We can offer a consolidated toolchain that is more cost effective for customers than purchasing, running, and integrating each tool separately.
1. We can do so profitably for the company.

#### Category Creation

1. By combining categories, a new overriding category, or market, gets created: the consolidated toolchain.
1. The sum of the categories combined should have desirable [CAGR](https://investinganswers.com/dictionary/c/compound-annual-growth-rate-cagr), such that entering the market means entering on a growth curve.
1. Not all of the individual categories need to be on the upward curve of the [technology adoption lifecycle](https://medium.com/@shivayogiks/what-is-technology-adoption-life-cycle-and-chasm-e07084e7991f) (TAL). It is, however, necessary that there are enough future categories with high CAGR that are early in their adoption lifecycle.
1. The ideal overlap of the TALs is that the peaks of the curves are as close to each other as possible, so that when one TAL moves to Late Majority, the next TAL is still curving upwards. This allows it to provide an organic growth opportunity for the company in the markets it is entering.

Our goal is to develop this model to be more quantifiable and formulaic, so that we can quickly and easily assess new opportunities.

### Mitigating Concerns

We acknowledge the concerns to achieving our goals. We document them in our [Mitigating Concerns page](https://internal.gitlab.com/handbook/leadership/mitigating-concerns/).

{{% include "includes/take-gitlab-for-a-spin.md" %}}
