---
title: "Customer Use Case Adoption"
description: "Drive cross-functional alignment around use case adoption as the north star KPI and #1 predictor of Churn & Contraction."
status: active
---

## Purpose

This working group is charged with driving the necessary cross-functional alignment, prioritization, and execution required to deliver improved customer adoption of key use cases within the GitLab platform. Following the 2023-05-16 Sales Key Review, there was a high-priority focus on driving customer use case adoption as the north star KPI and #1 predictor of Churn & Contraction. The formation of this working group was a direct outcome to accelerate efforts to win against GitHub and reduce Churn & Contraction.

**Desired Outcomes**

1. Drive **cross-functional alignment** around use case adoption across sales, customer success, product, data, finance, etc.
1. Mature **existing and new use cases and measures**, including thresholds
1. Build use cases as input into **actions** to drive the business

### FY25 Scope: CI and Security & Compliance

[FY 25 Yearlies](https://internal.gitlab.com/handbook/company/yearlies/) have specific goals around both CI and Security & Compliance adoption, and this working group is re-aligning to support and service both use cases.

### FY24 Refocusing of Working Group on CI Adoption

Effective 2023-08-17, the focus of the Customer Use Case Adoption working group pivoted explicitly to CI Adoption and driving the cross-functional workstreams required to achieve CI Adoption ARR of 50% by the end of FY24-Q4. Given the workstreams aligned upon, CI was the only Use Case focused on by this working group for the remainder of FY24.

## Attributes

| Property                       | Value      |
|--------------------------------|------------|
| Date Created                   | 2023-05-16 |
| Target End Date                | 2025-01-31 |
| Slack                          | [#wg_customer-use-case-adoption](https://gitlab.slack.com/archives/C0584NEKSRJ) |
| Google Doc                     | [Customer Use Case Adoption Scrum - Agenda](https://docs.google.com/document/d/1WtwXCK1r7hoco5O8oW5SIKiIWtXDr_WOLeWcIaDM7Nk/edit?usp=sharing)  |
| Epic - Primary                 | [Use Case Adoption Measurement & Improvement](https://gitlab.com/groups/gitlab-com/-/epics/2190) |
| Overview & Status              | See [Exit criteria](#exit-criteria) below |

## Exit criteria

Note that these goals are aspirational so we set a high bar (and potentially achieving something that is good enough vs. setting a low bar and not achieving something that is good enough).

### FY25

Included in our [FY 25 Yearlies](https://internal.gitlab.com/handbook/company/yearlies/) is a goal to `Accelerate visibility into usage and drive value by driving CI, Compliance and Security adoption`.  Supporting this Yearly are two (2) objectives:

- [ ] 80 of top 100 (child account) largest customers utilizing CI
- [ ] 65% of Ultimate ARR utilizing Security & Compliance

### FY24

- [ ] Improve CI Adoption ARR from 40% to 50% by the end of FY24-Q3
CI Adoption Initiatives
  - FY24-Q4: [CI Adoption - Acceleration Proposals to drive CI ARR to 50% by FY24-Q4](https://gitlab.com/groups/gitlab-com/-/epics/2250)
  - FY24-Q3: [CI Adoption - Acceleration Proposals to drive CI ARR to 50% by FY24-Q3](https://gitlab.com/groups/gitlab-com/-/epics/2225)

## Roles and Responsibilities

| Working Group Role                                | Person                        | Title                                                      |
|---------------------------------------------------|-------------------------------|------------------------------------------------------------|
| Executive Sponsor                                 | David DeSanto                 | Chief Product Officer                                      |
| DRI - CI                                          | Mike Flouton                  | VP, Product Management                                     |
| DRI - Security & Compliance                       | Hillary Benson                | Senior Director, Product Management                        |
| Facilitator                                       | David Tuan                    | Director, Strategy and Operations                          |
| Functional Lead - CSM                             | Michael Leutz                 | Director, Customer Success Management, EMEA                |
| Functional Lead - Sales                           | Open - TBD                    |                                                            |
| Functional Lead - Marketing (CI)                  | Dan Hom                       | Product Marketing Manager                                  |
| Functional Lead - Product (CI)                    | Jackie Porter                 | Director, Product Management                               |
| Functional Lead - Product (Security & Compliance) | Sam White                     | Group Manager, Product Management                          |
| Functional Lead - Professional Services           | Brian Will                    | Senior Manager, Professional Services                      |
| Functional Lead - Developer Relations             | Michael Friedrich             | Senior Developer Advocate                                  |
| Functional Lead - Customer Adoption Data          | Michael Arntz                 | Sales Strategy Manager                                     |
| Functional Lead - Enterprise Data                 | Israel Weeks                  | Director, Data and Analytics                               |
| Member - Customer Success Management              | Sherrod Patching              | VP, Customer Success Management                            |
| Member - Customer Success Management              | Luke Stahlman                 | Senior Customer Success Manager                            |
| Member - Customer Success Management              | Rachel Fuerst                 | Senior Public Sector Customer Success Manager              |
| Member - Customer Success Operations              | Nishant Khanna                | Senior Customer Success Operations Analyst                 |
| Member - Digital Customer Success                 | Michelle Harris               | Senior Program Manager, Customer Programs                  |
| Member - Enterprise Data                          | Miles Russell                 | Senior Analytics Engineer                                  |
| Member - Growth                                   | Paige Cordero                 | Senior Product Manager, Growth                             |
| Member - Marketing                                | Dave Steer                    | VP, Product Marketing                                      |
| Member - Professional Services                    | Niyati Shah                   | Senior Director, Education Services                        |
| Member - Sales Strategy                           | Brandon Butterfield           | Senior Sales Analytics Analyst                             |

## Multimodal Communication

- Apply the following labels to issues and epics to enable tracking and team wide visibility
  - `WorkingGroup::UseCaseAdoption`
  - `UseCase::CI` (CI)
  - `UseCase::Security` (Security & Compliance)
- Apply the appropriate [Working Group status labels](https://gitlab.com/groups/gitlab-com/-/labels?subscribed=&search=wg-status) for issues or epics
  - `wg-status::Not Started`
  - `wg-status::Ready`
  - `wg-status::In Progress`
  - `wg-status::Blocked`
  - `wg-status::Complete`
  - `wg-status::Cancelled`
- Formalize "asks" of the Working Group by filing an issue against the [Use Case Adoption - Working Group Asks](https://gitlab.com/groups/gitlab-com/-/epics/2232) epic to enable cross-functional visibility, collaboration, and prioritization
