---
title: "Product Development Flow Working Group"
canonical_path: "/company/team/structure/working-groups/product-development-flow/"
---

## Attributes

| Property        | Value           |
|-----------------|-----------------|
| Date Created    | August 31, 2020 |
| Target End Date | January 30, 2021 |
| Slack           | [#wg_product_development_flow](https://gitlab.slack.com/archives/C019KM43H4K) (only accessible by GitLab team members) |
| Google Doc      | [Working Group Agenda](https://docs.google.com/document/d/10pCsqXVXakRKYVKPmouX7C5g7T_1kBsufLRcN6nGZQI/edit#) (only accessible by GitLab team members) |
| Docs            | TBD |
| Epics/Issues    | [Main Epic](https://gitlab.com/groups/gitlab-com/-/epics/938/) / [Issue Board](https://gitlab.com/gitlab-com/www-gitlab-com/-/boards/2012861?label_name[]=wg-product-development-flow) |
| Label           | `~wg-product-development-flow` |
| Associated KPIs/OKRs | TBD |
| GitLab group for working group reviewers | `@wg-product-development-flow` |
| GitLab group for working group contributors (MR authors) | `@wg-contributors-pd-flow` |

## Problems To Solve

For more details please reference the [product development flow survey slides](https://docs.google.com/presentation/d/1BxUVcoPyjYkR7MOHn1aZGllMCqlH5eb27JKM_bb_uDA/edit#slide=id.g59bfc474c5_2_145).

**Doesn't Encourage Cross-Functional Collaboration**

- How can we promote optimal cross-functional involvement in the product development flow (e.g. where would we benefit from having TWs be informed earlier or where can QEs participate earlier)?
- How can we ensure tracks and phases don't silo activities and continually encourage cross-functional contribution #everyonecancontribute?

**Too Many Steps**

- How can we reduce the number of "required" steps in the product development flow  without losing key steps needed for convergence points (such as workflow states and release notes aggregation)?
- How can we better enable teams to work efficiently by providing the right amount of details in tandem with opportunity for personalization for their specific needs (e.g. an activities/outcomes model rather than just a step by step)?

**Too Prescriptive**

- How can we reduce verbosity in the product development flow (e.g. provide a better balance of visual snapshots and written descriptions)?
- How do we better focus teams on delivering value by enabling them to strike their own balance between when to build new features and when to improve existing features (e.g. detail out the Improve phase in an alternate style as a test run)?

## Business Goals

Iterate on the product development flow to shift away from a "step by step" and more toward being a container/playbook of strategies/tactics to provide teams with:

1. Various activities/outcomes to employ at each phase to identity what to build or improve to solve a problem.
1. Minimal, required processes teams need to follow at each phase to maintain efficient, transparent and predictable workflow cross-functionally.

### Protocols and Processes

**Creating Epics & Issues for the working group board**

To propose an idea or solution that addresses one of the [defined problems](https://gitlab.com/groups/gitlab-com/-/epics/938#problems-to-solve) - follow the below steps to ensure effective asynchronous collaboration:

1. Create an issue to address your proposal and add it to [Product Development Flow as a Framework epic](https://gitlab.com/groups/gitlab-com/-/epics/938)
1. We use [this issue board](https://gitlab.com/gitlab-com/www-gitlab-com/-/boards/2012861?label_name[]=wg-product-development-flow) as a single source of truth. Issues should be moved through the board from left to right
1. Assign newly created issues to [the Facilitator](/handbook/company/working-groups/product-development-flow/#roles-and-responsibilities) who is currently @fseifoddini for prioritization

**MR review process**

- Contributors will generate MRs and tag the Contributor group '@wg-contributors-pd-flow' for feedback first. [The Facilitator](/handbook/company/working-groups/product-development-flow/#roles-and-responsibilities) and Contributors will then review and align if the MR is merge-able (non-controversial) or if it needs more feedback before the merge
- Next, [the Facilitator](/handbook/company/working-groups/product-development-flow/#roles-and-responsibilities) or the MR author will tag in specific people and/or tag in the whole Reviewer group (which includes Executive Sponsors) '@wg-reviewers-pd-flow' for feedback before the merge
  - If unique action is needed from any individual, especially Executive Sponsors, they will be directly pinged. Otherwise, getting pinged as a Reviewer is a standard review/feedback before the merge cycle.
- Our goal is to minimize noise for Reviewers (inclusive of Executive Sponsors) and focus feedback efforts to move forward efficiently. If you want to follow every issue/MR, you're welcome to do so via our [WG board](https://gitlab.com/gitlab-com/www-gitlab-com/-/boards/2012861?label_name[]=wg-product-development-flow)

**NOTE:** Please pay attention to your To-Do list! We'll not hold the train on MRs for more than 24 hours, specially non-controversial ones.

### Exit Criteria

**Review and Optimize the current Product Development Workflow**

- Define the Required and Optional workflow phases.
- Optimize the existing labels currently required in each phase.
- Review the finalized Outcomes/ Activities section in different workflows to incorporate different issue types - `feature`, `bug`, `experiment`, etc.
- Build in early engagement and collaboration with all counterparts in each phase as needed.

**Define what success looks like for the PD-FLOW**

- Define goals and supporting metrics
- Define qualitative as well as quantitative ways to track, measure and iterate

**Dogfooding**

- Identify a Section/ group to dogfood the new flow.
- Document and iterate on suggestions and feedback.

**Downstream Process Review**

- Identify any downstream process changes that might need review.
  - [Quad Planning process](https://gitlab.com/gitlab-com/www-gitlab-com/-/issues/9130)

**Matrix and Dashboards**

- Document all dashboards that need to be updated.
- Define what matrix should be measured and how.
- Identify any new dashboard needs.

**Communication**

- Communicate the new product development flow change broadly.
- Conduct an AMA to answer all questions / concerns.

## Roles and Responsibilities

| Working Group Role    | Person                | Title                          |
|-----------------------|-----------------------|--------------------------------|
| Executive Sponsor     | Anoop Dawar | VP, Product Management |
| Executive Sponsor     | Christie Lenneville | VP of UX |
| Facilitator           | Farnoosh Seifoddini | Principal PM, Product Operations |
| Functional Lead       | Vincy Wilson (QE) | Manager, Quality Engineering - Growth & Govern |
| Functional Lead       | Jackie Bauer (UX/Product Design) | UX Manager, Enablement & Growth |
| Functional Lead       | Jeff Crow (UX Research) | Senior UX Researcher, Growth|
| Functional Lead       | Michael Karampalas (Product Management) | Principal PM, Growth |
| Functional Lead       | Justin Farris (Product Management) | GPM, Plan |
| Functional Lead       | Craig Norris (Technical Writing) | Technical Writing Manager |
| Functional Lead       | Thomas Woodham (Engineering) | Engineering Manager, Secure |
| Member                | Wayne Haber (Engineering) | Director Engineering, Threat Management |
| Member                | Nadia Udalova (Dev) | Product Design Manager |
| Member                | Keanon O'keefe (Plan) | Senior Product Manager |
| Member                | Tim Hey (Growth) | Principal Product Manager |
| Member                | Eric Schurter (Create) | Senior Product Manager |
| Member                | Mark Wood (Plan) | Senior Product Manager |
| Member                | Sarah Waldner (Monitor) | Senior Product Manager |
| Member                | Fabian Zimmer (Geo) | Senior Product Manager |
| Member                | Daniel Croft (Release, Package) | Senior Manager, Engineering |
| Member                | Jason Yavorska (CI/CD) | Director Product Management |
| Member                | Thiago Figueiró | Engineering Manager, Threat Management |
| Member                | Dan Jensen (Manage) | Engineering Manager, Analytics & Compliance |
| Member                | TBD (Data) | TBD |

## Working Groups

| Working Group    | Person                | Title                          |
|-----------------------|-----------------------|--------------------------------|
| Contributor       | Farnoosh Seifoddini | Principal PM, Product Operations |
| Contributor       | Wayne Haber (Engineering) | Director Engineering, Threat Management |
| Contributor       | Vincy Wilson (QE) | Manager, Quality Engineering - Growth & Govern |
| Contributor       | Jacki Bauer (UX/Product Design) | Product Design Manager, Growth & Fulfillment |
| Contributor       | Michael Karampalas (Product Management) | Principal PM, Growth |
| Contributor       | Justin Farris (Product Management) | GPM, Plan |
| Contributor       | Nadia Udalova (Dev) | Product Design Manager |
| Contributor       | Mark Wood (Plan) | Senior Product Manager |
| Contributor       | Fabian Zimmer (Geo) | Senior Product Manager |
| Contributor       | Daniel Croft (Release, Package) | Senior Manager, Engineering |
| Reviewer          | Anoop Dawar | VP, Product Management |
| Reviewer          | Christie Lenneville | VP of UX |
| Reviewer          | Jeff Crow (UX Research) | Senior UX Researcher, Growth|
| Reviewer          | Craig Norris (Technical Writing) | Technical Writing Manager |
| Reviewer          | Keanon O'keefe (Plan) | Senior Product Manager |
| Reviewer          | Tim Hey (Growth) | Principal Product Manager |
| Reviewer          | Eric Schurter (Create) | Senior Product Manager |
| Reviewer          | Sarah Waldner (Monitor) | Senior Product Manager |
| Reviewer          | Jason Yavorska (CI/CD) | Director Product Management |
| Reviewer          | Thiago Figueiró | Engineering Manager, Threat Management |
| Reviewer          | Dan Jensen (Manage) | Engineering Manager, Analytics & Compliance |

## Meetings

Meetings are recorded and available on
YouTube in the [Working Group - Product Development Flow](https://www.youtube.com/playlist?list=PL05JrBw4t0KoBbb2mGv4EYvr8tKKapb_6) playlist. Due to the subject matter of this working group and the high probability that every synchronous meeting will discuss sensitive customer information, the playlist is private and accessible by GitLab team members only.
