---
title: "Task Groups"
description: "An approach to addressing specific tasks that are cross functional
in nature. Task Groups are lean, focused groups consisting of subject matter
experts and led by a Directly Responsible Individual."
---

## What's a Task Group?

A Task Group is a streamlined, goal-oriented team formed to accomplish a
specific, well-defined objective. These groups are characterized by their lean
structure and focused approach, minimizing overhead and maximizing efficiency.
Task Groups are composed of subject matter experts who collaborate to rapidly
and effectively achieve their singular goal. This format is ideal for targeted
initiatives requiring specialized knowledge and swift execution.

### Differences between a Task Group and a Working Group

While both Task Groups and Working Groups are integral to achieving
organizational goals, they differ in structure, scope, and function.

#### Structure and Scope

- Task Group:
  - Focuses on a single, well-defined objective.
  - Composed of subject matter experts collaborating to achieve a specific
      goal.
  - Lean and agile, with minimal hierarchy and bureaucracy.
  - Ideal for tasks that require rapid, focused execution.

- Working Group:
  - Address broader, high-impact business goals.
  - Typically involves more complex and varied functions across the
      organization.
  - Has defined roles and responsibilities with a broader scope than Task
      Groups.
  - Requires an executive sponsor and often involves collaboration across multiple functions.

#### When to Use Each

- Use a Task Group when:
  - The objective is clear-cut and specific.
  - Speed and efficiency are priorities.
  - The task requires specialized knowledge from experts.
  - The organizational overhead of a Working Group can be avoided.

- Use a Working Group when:
  - The goal is complex and multifaceted, impacting various parts of the
      organization.
  - The project requires collaboration across different functions and teams.
  - There's a need for a structured approach with clearly defined roles.
  - The project has strategic importance warranting executive oversight.

## Roles and Responsibilities

### Task Group Directly Responsible Individual (DRI)

This role is pivotal, with the individual taking full accountability for the
group's success. They coordinate activites, lead meetings, and ensure the
group's objectives are met efficiently. The DRI is the main point of contact and
decision-maker for the group, bridging communication and action.

#### Member

Members are subject matter experts who actively participate in meetings and
contribute to task completion. They are responsible for staying informed via the
Task Group's communication channels, sharing insights with peers, and gathering
feedback. Members may work independently on tasks within the Task Group or
collaborate with others, playing a critical role in driving the group's
task forward.

## Guidelines

1. A Task Group is created, in part, to prevent proliferation of working groups.
1. Participation in some Task Groups requires a significant time commitment.
   Participants should have a clear understanding of their roles and the
   expectations for their deliverables within the Task Group. They should manage
   their time and capacity and quickly escalate if they feel unable to serve in
   or deliver in their role.
1. It is highly recommended that anyone in the Task Group with [OKRs](/company/okrs/) aligns them to the effort.

## Process

1. Create an MR with an overview page in the [task-groups/](task-groups/)
   directory. Ensure a brief description with an actionable objective is
   included. It is generally recommended that your manager approves the MR prior
   to merging.
1. Optionally, create an associated channel in Slack.
1. Announce the creation of the Task Group to the subject matter
   experts.
1. Interested members can create MRs adding themselves to the Task Group,
   ensuring that their manager is informed.
1. The DRI can use the Slack channel to set up initial communication
   guidelines.
1. The group should determine a roadmap for completion of the task, with an expected end date, as soon as
   they can.
1. Once the task is complete, the Task Group should be disbanded.

## Active Task Groups (alphabetic order)

1. [BootstrapVue Removal]({{< ref "bootstrap-vue-removal" >}})
1. [GitLab UI @vue/compat Compatibility]({{< ref "gitlab-ui-vue-compat" >}})

## Past Task Groups (alphabetic order)

1. [CSS Utilities]({{< ref "css-utils" >}})
