---
title: "Customer Success Management Handbook"
description: "The Customer Success Management team at GitLab is a part of the Customer Success department, acting as trusted advisors to our customers and helping them realize value faster."
---

## Customer Success Segments

[<button class="btn btn-primary" type="button"  style="padding: 15px 30px; font-size: 24px;">CSM AMER</button>](/handbook/customer-success/csm/segment/amer/)
[<button class="btn btn-primary" type="button"  style="padding: 15px 30px; font-size: 24px;">CSM EMEA</button>](/handbook/customer-success/csm/segment/emea/)
[<button class="btn btn-primary" type="button"  style="padding: 15px 30px; font-size: 24px;">CSM APJ</button>](/handbook/customer-success/csm/segment/apj/)
[<button class="btn btn-primary" type="button"  style="padding: 15px 30px; font-size: 24px;">CSE</button>](/handbook/customer-success/csm/segment/cse/)

## Mission Statement

Accelerate customer success by aligning passionate CSMs with customers to:

- Drive adoption aligned with business outcomes
- Enable customers in current and future GitLab use cases
- Expand ROI from GitLab

## What is a Customer Success Manager (CSM) at GitLab?

CSMs are accountable for customer adoption, measurable outcomes, customer satisfaction, and creating true customer advocacy. We create successful customers by enabling, training, and nurturing them throughout their journey. The following areas incorporate the remit of a CSM:

- **Customer Adoption -**  Ensure the customer is working towards or adopting their desired use cases to maturity. Ensure the successful onboarding of all intended users. Identify areas of adoption risk and establish mitigating plays and programs.
- **Delivering Positive Business Outcomes -** Ensure customers are meeting and exceeding their desired business outcomes so that customers can quantify and support their investment.
- **Trusted Advisor -** Establish "trusted advisor" relationships with the management and technical teams on the customer side while working seamlessly with our account team to deliver a best-in-class customer experience.
- **Account Expansion -** Lead adoption expansion beyond the customer's desired use cases and further customer return on investment (ROI). Partner with Sales to identify expansion opportunities and ensure we realize the expansion potential of a customer account.
- **Leading Business Reviews -**  Review and celebrate progress towards, or achievement of, the customer's desired business outcomes. Address challenges with a plan for mitigation, align on upcoming and future customer business objectives.

## High-Level Responsibilities of a CSM

<table><thead>
  <tr>
    <th>Responsibility</th>
    <th>Context</th>
    <th>How We Measure</th>
    <th><a href="/handbook/people-group/directly-responsible-individuals/#dri-consulted-informed-dci">DCI Roles</a></th>
  </tr>
</thead><tbody>
  <tr>
    <td><a href="/handbook/customer-success/csm/success-plans/">Success Plans</a></td>
    <td>Mutually agreed (Customer | GitLab) adoption plans that outline desired outcomes (e.g., improve cycle time), technical milestones required (e.g., migrate to GitLab, overcome constraints), timelines and DRIs.
    <br><br>
     These plans enable us to be proactive and ensure progress towards the customer's goals. As trusted advisors, we understand what drives value for our customers and help them achieve it.</td>
    <td>Every customer must have an active success plan</td>
    <td>DRI: CSM<br><br>Consulted: AE, SA, Customer<br><br>Informed: Leadership</td>
  </tr>
  <tr>
    <td><a href="/handbook/customer-success/csm/onboarding/">Onboarding</a></td>
    <td>There are several onboarding steps in both the new and existing customer onboarding playbooks. The CSM's role is to ensure all of these topics and enablements have been covered and documented.</td>
    <td>All customers are to be taken through the appropriate playbook (New, Existing Customer)</td>
    <td>DRI: CSM<br><br>Consulted: AE, SA, Customer<br><br>Informed: Leadership</td>
  </tr>
  <tr>
    <td><a href="/handbook/customer-success/csm/cadence-calls/">Cadence Calls</a></td>
    <td>The cadence call is a proactive call. For this call to be proactive, the CSM's responsibility includes those listed in the linked cadence call page</td>
    <td>Call frequency:<br><ul><li>Customer is engaged weekly or biweekly, monthly at a very minimum</li></ul><br><br>A CSM/CSE can expect to conduct a minimum number of calls as follows:<br><ul><li>CSMs: 5-7 calls per week</li><li>CSEs: 15 calls per week</li></ul></td>
    <td>DRI: CSM<br><br>Consulted: AE, Customer<br><br>Informed: SA, Leadership</td>
  </tr>
  <tr>
    <td><a href="/handbook/customer-success/csm/workshops/">Adoption &amp; Expansion</a></td>
    <td><ul><li>Driving platform adoption (use cases and licenses) in line with a customer's desired business outcomes is at the heart of the CSM role</li><li>Understand what the customer is currently adopting and partner with the customer on enabling this use case/feature</li><li>When an enablement or expansion playbook is open, the CSM actively drives the associated motion in the customer account</li></ul></td>
    <td>At any given time, a CSM will be actively driving expansion with half of their book (3-4 customers)</td>
    <td>DRI: CSM<br><br>Consulted: AE, Customer<br><br>Informed: SA, Leadership</td>
  </tr>
  <tr>
    <td><a href="/handbook/customer-success/csm/ebr/">Executive Business Reviews</a></td>
    <td><ul><li>We hold the business review at month 6, giving enough time passed to celebrate milestones achieved and enough time remaining to get adoption back on track where needed.</li><li>The CSM is the DRI for scheduling, preparing for, presenting, and following up on the EBR, and partners with both the account team and the customer in the creation of the presentation.</li></ul></td>
    <td>1 EBR per customer per year at a minimum</td>
    <td>DRI: CSM<br><br>Consulted: AE, Customer<br><br>Informed: SA, Leadership</td>
  </tr>
  <tr>
    <td><a href="/handbook/customer-success/csm/renewals/">Renewal</a></td>
    <td><ul><li>It is the job of the CSM to ask the 'soft' <a href="/handbook/customer-success/csm/renewals/#renewal-question">renewal question</a> 3-4 months before the renewal</li><li>This conversation and the outcome of this conversation are tracked in Gainsight using the 'renewal call' meeting type (within the timeline entry)</li></ul></td>
    <td>Every customer regardless of segment or region</td>
    <td>DRI: CSM, AE, Renewals team<br><br>Consulted: Customer<br><br>Informed: Leadership</td>
  </tr>
  <tr>
  <td><a href="/handbook/customer-success/csm/health-score-triage/">Managing Risk</a></td>
    <td><ul><li>A CSM actively manages risk in a customer account, quickly turning a customer to red when there is any potential risk of contraction or churn (even if this is unconfirmed)</li><li>The CSM is responsible for frequent communication to the account team about risk in their accounts and <a href="/handbook/customer-success/csm/escalations/">triggering/leading the escalation process</a> where needed</li></ul></td>
    <td>Risk is actively managed for all customers</td>
    <td>DRI: CSM<br><br>Consulted: AE, Leadership<br><br>Informed: Renewals team</td>
  </tr>
</tbody></table>

Please reference this page for an overview of the [CSM Rhythm of Business (daily to yearly)](/handbook/customer-success/csm/rhythm/)
Please reference this page for an overview of the areas your CSM will engage with you in: [CSM Points of Engagement](/handbook/customer-success/csm/services/)

### Customer Journey

![GitLab Customer Journey Map](/images/handbook/customer-success/customer-journey-map.png)

<table>
<thead>
  <tr>
    <th>Journey Stage</th>
    <th>Activities</th>
  </tr>
</thead>
<tbody>
  <tr>
    <td>Pre-Sales & Alignment</td>
    <td><ul><li><a href="/handbook/solutions-architects/sa-practices/value-stream-discovery/">Value Stream Discovery</a></li>
    <li><a href="/handbook/customer-success/pre-sales-post-sales-transition/">Sales to CS Handoff</a></li>
    <li><a href="/handbook/customer-success/csm/engagement/#customer-personas">Identify Personas</a></li></ul></td>
  </tr>
  <tr>
    <td>Onboard</td>
    <td><ul><li><a href="/handbook/customer-success/csm/onboarding/#kickoff-call">CSM Kickoff & Intro</a></li>
    <li><a href="/handbook/customer-success/csm/onboarding/#1st-cadence-call-future-growth-discussion--checklist">Establish Cadence Calls</a></li>
    <li><a href="/handbook/customer-success/csm/success-plans/">Create Success Plan</a></li></ul></td>
  </tr>
  <tr>
    <td>Enable</td>
    <td><ul><li><a href="/handbook/customer-success/csm/workshops/">Use Case Enablement Workshops</a></li>
    <li><a href="/handbook/customer-success/product-usage-data/use-case-adoption/">Measure Primary Use Case Adoption</a></li></ul></td>
  </tr>
  <tr>
    <td>Expand</td>
    <td><ul><li><a href="/handbook/customer-success/product-usage-data/use-case-adoption/">Expansion Discovery</a></li></ul></td>
  </tr>
  <tr>
    <td>Optimize & Renew</td>
    <td><ul><li><a href="/handbook/customer-success/csm/ebr/">Executive Business Review</a></li>
    <li><a href="/handbook/customer-success/csm/risk-mitigation/">Ongoing Risk Review</a></li>
    <li><a href="/handbook/customer-success/csm/renewals/">Renewal Discussions</a></li></ul></td>
  </tr>
</tbody>
</table>

## FY25 Vision & Strategy -3 Pillars

- [Vision & Strategy Deck](https://docs.google.com/presentation/d/1qIBbUYoclOGSplOeUAvRwBJGKNwlo41Z7Z2fnu8bZgA/edit?usp=sharing)  (Internal - GitLab Only)
- Success At Scale
- Use Case Adoption
- Success Plan Services

### Big Rock (Annual Strategy) Archive

- [FY23](/handbook/customer-success/csm/fy23)
- [FY24](/handbook/customer-success/csm/fy24)

## Handbook Directory

[CSM Team Metrics Overview (VIDEO)](https://www.youtube.com/watch?v=9b8VviLG3yE&t=2s)

### Changelog

- [CSM Process Changelog](https://docs.google.com/document/d/1xyaxc37iCDtfeabo2NXCRV31pNOdvieXoVDxJw_aXoM/edit#heading=h.h09e4t2jbjoh)
- [Gainsight Changelog](https://docs.google.com/spreadsheets/d/1QknfSfX50JFOhkHZoz2VjovREWK2fJkYBxr5HEjkT9Q/edit#gid=0)
-

### CSM Learning & Development

- [CSM Objectives and Key Results (OKRs)](/handbook/customer-success/csm/csm-okrs)
- [Overview of available resources, training plans & career paths](/handbook/customer-success/csm/csm-development/)
- [CSM Aspiring Leaders Program](/handbook/customer-success/csm/aspiring-leaders-program/)

### CSM Activities

- [CSM Onboarding](/handbook/customer-success/csm/csm-onboarding/)
- [CSM Rhythm of Business](/handbook/customer-success/csm/rhythm/)
- [Using Gainsight](/handbook/customer-success/csm/gainsight/)
- [CSM Quaterly Business Reviews](/handbook/customer-success/csm/qbr/)
- [CSM Responsibilities and Services](/handbook/customer-success/csm/services/)
- [CSM and Product Interaction](/handbook/product/product-management/#how-to-engage-product-managers)
- [CSM and Professional Services Interaction](/handbook/customer-success/csm/engaging-with-ps/)
- [CSM and Support Interaction](/handbook/customer-success/csm/support/)
- [CSM and Partner Interaction](/handbook/customer-success/csm/engaging-with-partners/)
- [Escalation Process](/handbook/customer-success/csm/escalations/)
  - [Infrastructure Escalation & Incident Process](/handbook/customer-success/csm/escalations/infrastructure/)
- [CSM-to-CSM Account Handoff](/handbook/customer-success/csm/account-handoff/)
- [CSM Roleplay Scenarios](/handbook/customer-success/csm/roleplays/)
- [CSM Retrospectives](/handbook/customer-success/csm/retrospectives/)
- [CSM PTO Guidelines](/handbook/customer-success/csm/pto/)
- [CSM READMEs](/handbook/customer-success/csm/readmes/) (Optional)

### Driving Platform Adoption

Landing Zones

- [CI Landing Zone](/handbook/customer-success/csm/adoption-landing-zones/CI/)

 Customer Metrics

- [Sample Questions & Techniques for Getting to Good Customer Metrics](/handbook/customer-success/csm/success-plans/questions-techniques/)

 Platform Metrics

- [Customer Use Case Adoption](/handbook/customer-success/product-usage-data/use-case-adoption/)
- [How To: DevSecOps Adoption Tracking in Gainsight](/handbook/customer-success/csm/devsecops-adoption-tracking/)
- [Use Case Adoption Metrics](/handbook/customer-success/csm/stage-adoption/)
- [The Customer Value Received with Service Ping](/handbook/customer-success/csm/service-ping-faq/)
- [Product Usage Data - Definitive Guide to Product Usage Data in Gainsight](/handbook/customer-success/product-usage-data/using-product-usage-data-in-gainsight/)
- [Metrics Based Product Usage Playbooks](/handbook/customer-success/product-usage-data/metrics-based-playbooks/)

### Other Lifecycle Management Activities

- [Transitioning a Customer from Pre-Sales to Post-Sales](/handbook/customer-success/pre-sales-post-sales-transition/)
- [Account Engagement and Prioritization](/handbook/customer-success/csm/engagement/)
  - [Non-Engaged Customer Strategies](/handbook/customer-success/csm/engagement/Non-engaged-customer-strategies/)
- [Account Onboarding](/handbook/customer-success/csm/onboarding/)
- [Success Plans](/handbook/customer-success/csm/success-plans/)
- [Cadence Calls](/handbook/customer-success/csm/cadence-calls/)
- [Managing Executive Relationships](/handbook/customer-success/csm/executive-relationships/)
- [Executive Business Reviews (EBRs)](/handbook/customer-success/csm/ebr/)
- [Customer Renewal Tracking](/handbook/customer-success/csm/renewals/)
- [Customer Health Assessment and Risk Triage](/handbook/customer-success/csm/health-score-triage/)
- [Risk Types, Discovery & Mitigation](/handbook/customer-success/csm/risk-mitigation/)
- [Workshops and/or Lunch-and-Learns](/handbook/customer-success/csm/workshops/)

#### Digital Customer Programs

- [Digital Customer Programs Handbook Page](/handbook/sales/field-operations/customer-success-operations/cs-ops-programs/)
  - [CSM Assigned Customer Programs](/handbook/sales/field-operations/customer-success-operations/cs-ops-programs/available-programs/#csm-assigned-account-programs)

### CSM Managers

- [CSM Manager Processes and CSM Leadership Team](/handbook/customer-success/csm/csm-manager/)
- [CSM Manager QBR Template](https://docs.google.com/presentation/d/1M18LeKTrzTIKNgl3Y_URC3z9xBUNUtPRJFiWXaEUuzM/edit?usp=sharing) (GitLab Internal)
- [CSM Promotion Template](https://docs.google.com/document/d/1UOcfUtrseaucIbnFmJkL8XsQwz4xKfj0IQcYbcRGSvI/edit) (GitLab Internal)

---

## CSM Tools

The following articulates where collaboration and customer management is owned:

1. [**Customer Collaboration Projects**](/handbook/customer-success/csm/customer-collaboration-project/): Shared project between GitLab team members and customer. Used to prioritize/plan work with customer.
1. [**Google Drive**](https://drive.google.com/drive/u/0/folders/0B-ytP5bMib9Ta25aSi13Q25GY1U): Internal. Used to capture call notes and other customer related documents.
1. [**Chorus**](/handbook/business-technology/tech-stack/#chorus): Internal. Used to record Zoom calls.
   1. [**Using Calendly with Chorus**](/handbook/customer-success/csm/calendly/): Instructions on Calendly set up with Chorus.
1. [**Gainsight**](/handbook/customer-success/csm/gainsight/): Internal. Used to track customer health score, logging [customer activity](/handbook/customer-success/csm/gainsight/timeline/#activity-types) (i.e. calls, emails, meetings)
1. [**Issue Prioritization Dashboard**](/handbook/customer-success/csm/issue-prioritization/): Internal. Used to track customer requested issues.

### Education and Enablement

In Customer Success Management, it is important to be continuously learning more about our product and related industry topics. The [education and enablement handbook page](/handbook/customer-success/education-enablement) provides a dashboard of aggregated resources that we encourage you to use to get up to speed.

## SFDC useful reports

### Tracking opportunities for your assigned Strategic Account Executive (SAEs)

To ensure that opportunities are listed with the correct Order Type, [this Salesforce report](https://gitlab.my.salesforce.com/00O4M000004agfP) shows you all of the opportunities that have closed, or are soon to close, with your SAEs. Tracking Order Type is important since CSM team quota and compensation depend on this. Please reference the latest [Sales Compensation Plan](/handbook/finance/sales-comp-plan/) information to know what is counted.

Next steps for you:

1. Customize [this SFDC report](https://gitlab.my.salesforce.com/00O4M000004agfP) where "Account Owner = your SAEs"; "CSM = You"
1. Save report
1. Subscribe to report when "Record Count Greater Than 0" and Frequency = Weekly (You'll get a weekly email as a reminder to look at the report)
1. If you find an opp that is tagged incorrectly, chatter (@Sales-Support) in the opportunity and let them know there is a mistake ([example](/handbook/customer-success/csm/#csm-tools))

## Related pages

- [Dogfooding in Customer Success](/handbook/customer-success/#dogfooding)
- [Customer Success & Market Segmentation](/handbook/customer-success/#customer-success--market-segmentation)
- [Responsibility Matrix and Transitions](/handbook/customer-success/#responsibility-matrix-and-transitions)
- [Customer Success' FAQ](/handbook/customer-success/faq/)
- [Using Salesforce within Customer Success](/handbook/customer-success/using-salesforce-within-customer-success/)
- [Customer Success Vision](/handbook/customer-success/customer-success-vision/)
- [GitLab Positioning](/handbook/marketing/positioning-faq/)
- [Product Stages and the POCs for each](/handbook/product/categories/#devops-stages)
- [How to Provide Feedback to Product](/handbook/product/product-management/#feedback-template)
- [Sales handbook](/handbook/sales/)
- [Support handbook](/handbook/support/)
- [Workshops and Lunch-and-Learn slides](https://drive.google.com/drive/folders/1qAymFTiXFEk-lRSNreIhaZ6Z62fdo_y2)
- [Researching Customer Questions](/handbook/customer-success/csm/researching-customer-questions/)
