---
title: "CSM Aspiring Leaders Program"
description: "A guide to help CSMs level up their skills to be ready for leadership"
---

## CSM Aspiring Leaders Program Overview

The CSM Leadership team is invested in ensuring CSMs have continuous career development and can reach their career goals. This page is a framework to help ICs who are interested in becoming a manager take deliberate steps to achieve that goal.

It's important for interested CSMs to know that going through this framework and completing all steps does not guarantee a promotion. Most importantly, a vacancy must be open, and an IC must apply and go through the interview process along with external candidates. Then, the IC must be the best person for the job, demonstrating leadership competencies and strategic vision and execution.

It is typical for a CSM to be in a Senior or Staff CSM role at GitLab prior to becoming a manager, as the responsibilities of a Senior CSM include taking on more leadership within their team. However, this is not required, and Intermediate CSMs can and have been promoted directly into a management role, although prior management experience is typically a factor.

## Ongoing Activities

As you progress through this guide, it's important to keep the following items top of mind at all times:

1. Have ongoing regular calls with your manager on your growth plan and progress towards your goals.
1. Create and keep up-to-date a record of your achievements that you can reference.
1. Identify any gaps in your skills so that you can focus your efforts on leveling up, through coaching, mentorship, and training.
1. Maintain high performance at your current job, showing competency and proactiveness with your book of business and your scope of work.
1. Demonstrate consistency in your leadership, through owning projects, helping your peers, and being a thought leader.

## Module 1: Explore

To kick off this guide, it's important to understand what being a manager entails at a high-level, why you specifically want to be a manager, and what you are looking for out of management.

1. Have a career growth conversation with your manager about your goals and their feedback for you, using the following example questions during your discussion:
   - Why do you want to be a manager?
   - What do you envision being a manager to be like?
   - What do you anticipate being the best part of being a manager and why? What about the worst part and why?
   - What team do you want to lead / what team is best suited for your skills and experience? Why?
1. Have coffee chats with multiple CSM Managers about their experiences in management (and, if applicable, their experience being promoted into the role from being an IC).
1. Review GitLab's [Growth & Development budget](/handbook/people-group/learning-and-development/growth-and-development/) and identify opportunities to use this benefit for growing your leadership skills.

## Module 2: Learn

Once you feel confident you're interested in exploring management, it's time to learn more about what management is like and grow your skills.

1. Find a mentor for yourself who is in a manager or higher role and can help you grow your leadership skills.
   - How to find a mentor:
      - Seek recommendations from your own manager or fellow CSMs.
      - Connect directly with existing managers via Slack or coffee chats to express your interest in finding a mentor.
      - Attend meetings outside of your existing sales segment for exposure to other CSM managers in action, e.g. as a Commercial CSM ask to attend a PubSec All Hands or QBR.
      - Be proactive and persistent!
      - Consider participating in the [GitLab mentorship program](/handbook/people-group/learning-and-development/mentor/company-program/) if currently open.
   - What to discuss in mentorship calls:
      - During your first call, suggest a meeting cadence going forward.
      - Be prepared and succinct; consider sharing an agenda ahead of time that includes your leadership goals and what questions you have for your mentor.
      - Ask for feedback on your existing work; consider sharing a success plan or success story that you're proud of, or a story where you feel like you could have handled a situation better.
      - Explore leadership styles; ask your mentor about theirs and share your vision of your own leadership style.
      - Leave each meeting with agreed-upon action items for both parties.
1. Read through the [leadership page](/handbook/leadership/) of the handbook.
   - See if any [recommended leadership books](/handbook/leadership/#books) interest you and, if so, [expense](/handbook/finance/expenses/#expense-policy-outline) them.
1. Take the [Elevate](/handbook/people-group/learning-and-development/elevate-programs/) course provided by the L&D team (formerly known as the [Manager Challenge](/handbook/people-group/learning-and-development/manager-challenge/)) if available.
1. Take the [Crucial Conversations](/handbook/people-group/learning-and-development/learning-initiatives/#crucial-conversations) course.
1. Review to see if there is a new [LifeLabs cohort](https://gitlab.com/gitlab-com/people-group/learning-development/training-curriculum/-/issues/29) coming soon.
1. Take the [New Manager Foundations](https://www.linkedin.com/learning/new-manager-foundations-2/) LinkedIn Learning course.
1. Take the [Being a Good Mentor](https://www.linkedin.com/learning/being-a-good-mentor/) LinkedIn Learning course.
1. Watch free webinars and training resources through [Sounding Board](https://www.soundingboardinc.com/request-demo/).
1. Review the [CEO Shadow Program](/handbook/ceo/shadow/) and potentially sign up for it (benefits include seeing firsthand how other leaders work and the types of discussions they have, among many others).
1. Develop relationships with other leaders in the organization, such as ASMs and SA Managers, through coffee chats and customer strategy.
1. Shadow 1:1 conversations between CS leadership to learn more about the types of conversations leaders have regularly.
   - Participants can opt to shadow the following 1:1 meetings:
      - Participant's Manager with Director/VP.
      - Participant's Director with VP (if applicable).
   - Work with the person closest to you in your reporting line for each meeting to arrange shadowing by reaching out to them in Slack or asking in a 1:1. That person will provide you with the needed details, including:
      - Invite to the meeting, with a notes document specifically for that session.
      - Any specific things to know ahead of the meeting, such as anything you may be asked to contribute.
   - Meeting owners: in preparing for your 1:1 to be shadowed by a member of the team, please ensure the following:
      - The meeting invite is provided to the team member with sufficient time for them to arrange their schedule to accommodate (typically at least a week in advance).
      - You provide a **separate** notes document for that specific session, and not your standard 1:1 running notes document.
      - If there is any input or contribution you would like from the team member during the meeting, inform them ahead of time so they can be prepared.
      - There may be circumstances for which the meeting owner will decline a shadow for a specific session, but the meeting owner should offer an alternative session for shadowing when this happens.
   - During the 1:1 meeting, discussion and topics are covered as they would be normally, to allow the team member to learn from their observations in a meaningful way. However, a few things should be considered:
      - Some points of discussion may be sensitive and not appropriate for the team member to be present for. Meeting owners should keep these items in their standard 1:1 running notes document so they remain private, and move these to the end of the meeting agenda. Once the meeting participants have reached these items, the meeting owner will ask the shadowing team member to drop from the meeting, and then the 1:1 can proceed.
      - The shadowing team member is encouraged to note any items for which they have questions, and the meeting owner is encouraged to build in time for those questions either throughout the 1:1 or at a specific point at the end of the session. The meeting owner should set expectations with the shadowing team member ahead of the meeting on when and how is best to ask questions (e.g. throughout the meeting as they come up, wait for a queue from the meeting owner at specific intervals, or at a designated point at the end of the meeting).
   - Following the 1:1, the shadowing team member should plan to discuss it with their mentor and/or manager to review their observations and identify any areas of focus from what they learned.
   - If a participant would like to shadow a given 1:1 pairing more than once, please feel free to ask! The purpose of this process is to provide learning opportunities for participants, so feel empowered to seek the opportunities that would help you in your learning path.

## Module 3: Practice

It's important to take the learnings you've gained and put them into action, so that you can have firsthand experience yourself. The below tasks will give you the opportunity to go through what a CSM Manager may in their daily work.

1. Participate regularly in OKRs as a primary contributor, showing consistency of participation, ownership of your tasks, collaboration with other contributors, and proactiveness during the OKRs.
1. Find a mentee that you are working with, helping them to achieve their own growth goals and coaching them through challenges and questions.
   - How to find a mentee:
      - Make it known you are interested in becoming a mentor and consider sharing why (e.g. mentors have made a big impact on you, you are interested in developing people outside your org, etc.). Do this in team calls, all-CSM calls, or via Slack channels like tim-tams.
      - Approach people directly that you feel may benefit or be interested in a mentor.
      - Seek recommendations from managers and above on anyone they think could be a good match for you.
   - What to discuss in mentorship calls:
      - Be present, be honest, and be vulnerable. Don't share just your successes - often the best learnings come from failures. Foster a safe environment for these conversations, where the mentee feels safe sharing both their failures and successes too.
      - Be prepared, and review any agenda they have provided in advance, taking time to think of examples to share or questions to ask.
      - Ensure you are giving your mentee your full attention during the call.
      - Utilize [coaching methods](/handbook/leadership/coaching/#how-coaches-coach) to help your mentee figure things out on their own.
      - Encourage your mentee to set realistic goals so they have something to strive for and can measure their progress.
      - Challenge your mentee to try new things and stretch themselves.
      - Take ownership of your action items and always deliver on anything you've said you'll do for your mentee.
1. Take ownership of a project from start to finish that benefits people outside of your immediate scope (e.g. the rest of the CSMs, other departments, a large number of customers, etc.).
   - A common example of this is participating in CSM Big Rocks and OKRs (which is why it's task 1 in Module 3!). However, CSMs are encouraged to identify and drive creative solutions for problems or gaps, outside of OKRs. A great way to find these opportunities is to think about what you wish could be better, or where you have a unique skillset or background that could help others. Here are some examples:
      - Identifying a gap in a process or tool (e.g. customer onboarding, Gainsight playbooks, issue/handbook/Drive organization, etc.), researching options, discussing feedback with customers and peers, creating new content where needed, and working with team members to launch the content.
      - Creating new/updated content and training on an topic related to the CSM role (e.g. EBRs, workshops/enablements, success plans, persona engagement, risk management, etc.) and sharing it with the wider CSM team.
      - Partake in or start a working group; these are typically long-term initiatives, but very valuable to have experience with (e.g. [the issue prioritization framework working group](/handbook/company/working-groups/issue-prioritization-framework/)).
1. Join CSM Manager meetings and own action items that come out of that meeting.
   - To attend a CSM manager meeting, ask your manager to invite you to the next planned occurrence within your region.
   - When adding the participant, the CSM manager should create a separate agenda doc for the upcoming occurrence and add it to the appropriate calendar event, sharing it with all participants and transposing any existing items as appropriate from the running doc
   - As a participant, you're encouraged actively participate in the discussion, assist in notetaking, and volunteer to drive next steps on any follow-up actions.
   - For exposure to different regions & segments, consider reaching out to a leader within another segment and following the same process.
1. Shadow & collaborate with your manager on things that are part of their responsibilities, such as: renewal forecasting, growth planning, metrics reviews, etc.
1. When your manager has upcoming PTO, volunteer and work with them on being backup for things like escalations, 1:1s if team members are open to it, being a representative at leadership meetings, etc.
1. Prepare a mock 30-60-90 day plan as if you were preparing to become a CSM Manager, and share it with your manager & mentor for feedback. This is a requirement of the interview process for CSM Managers, and it also is extremely helpful for new managers to guide their transition and helps set them up for success.

## Program Launch FY24Q2

Beginning May 2023, we will launch a pilot group for this program for any CSMs interested to join, where we hold regular calls and async discussion, discussing everyone's progress, questions, feedback, etc.

If you are interested in joining this pilot group, please keep an eye out for a sign-up form, or reach out to [Chloe Whitestone](/handbook/company/team/#chloe), who will be leading this pilot program and can answer any questions.
