---
title: "CSM Development"
description: "Available development paths and resources for Customer Success Managers at GitLab."
---

As a Customer Success Manager at GitLab, you should feel empowered to take the time to invest in yourself and your career, leaning into the [70-20-10 rule for development](/handbook/people-group/learning-and-development/career-development/#70-20-10-rule-for-development).

To be intentional about our commitment to continuous improvement, the first Friday afternoon of every calendar month is strongly encouraged to be protected and used for personal and professional development, either individually or in collaboration with other GitLab team members.

To this end, it is essential to understand what resources are available for your personal and professional development, and the remainder of this page strives to be a place for leadership and CSMs to contribute to the resources available for the progression and development of the CSM team.

## Key handbook sections, roadmaps and L&D platforms for enablement

1. [CSM Planned Enablement Roadmap for FY24](https://docs.google.com/presentation/d/1maP9grsRJTlEsPsvQSw3d2jxw6BB-tgnURmA2lvOC_I/edit#slide=id.g23e6c497812_0_432)
1. [CSM Enablement Corner](https://docs.google.com/document/d/1xyaxc37iCDtfeabo2NXCRV31pNOdvieXoVDxJw_aXoM/edit?usp=sharing) (updated Quarterly with Key Dates and CSM required actions)

<iframe src="https://docs.google.com/presentation/d/e/2PACX-1vTB9tOQWZ771-M2nrIQkqIpx3XF7f9q1xXbBRkW5D-_UAyksak626FVn0Ovrj0j7rHDurML4N8f83IY/embed?start=false&loop=false&delayms=3000&slide=id.g23e582b58af_0_829" frameborder="0" width="960" height="569" allowfullscreen="true" mozallowfullscreen="true" webkitallowfullscreen="true"></iframe>

## Customer Success Management - Learning and Development Resources

The content is divided into three key categories of competencies. [LevelUp](https://levelup.gitlab.com/learn/dashboard) is GitLab's Learning Experience Platform for certifications, learning paths and more! If you have ideas about a course you'd like to develop, consider checking out the [Learning Evangelist Training](https://levelup.gitlab.com/courses/learning-evangelist-training).

**💡 [Customer Success Management](#general-csm)     💬 [Soft Skills](#soft-skills)     🚀 [Technology and Domain Knowledge](#tech-domain)**

---

<a name="general-csm"></a>

### 💡 Customer Success Management

#### CSM Best Practises and Examples at GitLab

- [Chorus Playlist](https://chorus.ai/playlists/741604) gives you access to the recordings of the best CSM calls. The recordings are continuously updated, so keep this playlist bookmarked for best practices.

#### CSM Intership

- [CSM Internship for learning](/handbook/customer-success/csm/csm-internship/)

#### Customer Success Management

- [Customer Success Management Fundamentals](https://www.linkedin.com/learning/customer-success-management-fundamentals) (LinkedIn Learning)
- [Business Fundamentals for Customer Success Managers](https://www.linkedin.com/learning/business-fundamentals-for-customer-success-managers) (LinkedIn Learning)
- [Avoiding Common Pitfalls in Customer Success Management](https://www.linkedin.com/learning/avoiding-common-pitfalls-in-customer-success-management) (LinkedIn Learning)
- [Onboarding and Adoption Best Practices for Customer Success Management](https://www.linkedin.com/learning/onboarding-and-adoption-best-practices-for-customer-success-management) (LinkedIn Learning)
- [Engagement Evaluation Best Practices for Customer Success Management](https://www.linkedin.com/learning/engagement-evaluation-best-practices-for-customer-success-management) (LinkedIn Learning)
- [Value Realization Best Practices for Customer Success Management](https://www.linkedin.com/learning/value-realization-best-practices-for-customer-success-management) (LinkedIn Learning)
- [Building Rapport with Customers](https://www.linkedin.com/learning/building-rapport-with-customers/) (LinkedIn Learning)
- [Customer Experience: Journey Mapping](https://www.linkedin.com/learning/customer-experience-journey-mapping) (LinkedIn Learning)
- [Advanced Business Development Communication & Negotiation](https://www.linkedin.com/learning/advanced-business-development-communication-and-negotiation/taking-it-to-the-next-level) (LinkedIn Learning)
- [Sales: Customer Success](https://www.linkedin.com/learning/sales-customer-success) (LinkedIn Learning)
- [Customer Success by Nick Mehta, Dan Steinman, Lincoln Murphy, Maria Martinez](https://learning.oreilly.com/library/view/customer-success/9781119167969/) (O'Reilly Books)
- [The Customer Success Professional's Handbook](https://learning.oreilly.com/library/view/the-customer-success/9781119624615/) (O'Reilly Books)
- [Sales & Customer Success Learning Path in SQS](/handbook/sales/onboarding/sales-learning-path/): Parallel to the scheduled training sessions in the [Sales Quick Start (SQS)](/handbook/sales/onboarding/), with [Role-based content](/handbook/sales/onboarding/sales-learning-path/#customer-success-quick-start---role-based-curriculum) (Instructor-Led Sessions)

#### Leadership

- [CSM Aspiring Leaders Program](/handbook/customer-success/csm/aspiring-leaders-program/)

#### Executive Communication

As CSMs have positioned themselves to be more strategic and reach Director, VP, and CISO personas, we have to adjust our communication styles and consider how to cater them for executives. These resources will aid CSMs with executive presence and communication.

- We have two team members in L&D who are certified in [Crucial Conversations](/handbook/leadership/crucial-conversations/). We have 1-2 sessions per quarter.
- [Connecting with Executives](https://www.linkedin.com/learning/connecting-with-executives-2)
- [Issue: Executive Communication Best Practices](https://gitlab.com/gitlab-com/customer-success/csm/-/issues/712)
- [Google Doc (Actively being updated)](https://docs.google.com/document/d/1lkk_25XwOOw9eN-NqxuupZsDWRdWPbmFYD8RP8cWXz8/) - Lee Faus, Brian Wald, and Francis Ofungwu share themes (four pillars) they are hearing from executives around GitLab's platform
- Sandler Articles
  - [How to Use DISC Assessments to Appropriately Customize Workplace Communication](https://www.sandler.com/blog/how-use-disc-assessments-appropriately-customize-workplace-communication/) (Article)
  - [Up Front Contracts](https://go.sandler.com/dwood/insights/videos/coaching/elevating-your-up-front-contract-with-danny-wood/) (Article)
- [Pyramid Principle for Slide Presentation](https://www.myconsultingoffer.org/case-study-interview-prep/pyramid-principle/) (Article)
- [Tim Ferris - how I prepare for keynotes](https://tim.blog/2010/04/11/public-speaking-how-i-prepare-every-time/) (Article)

#### Public Speaking and Enablement

- [Top Facilitation Techniques and Tactics For Great Remote Workshops](https://www.youtube.com/watch?v=JsRxF0I3eaI) - 16 minutes, timestamped per question (YouTube Video)
- [How to Create and Run a Brilliant Remote Workshop](https://www.linkedin.com/learning/how-to-create-and-run-a-brilliant-remote-workshop/how-to-run-a-brilliant-remote-workshop?autoplay=true&resume=false&u=2255073) - 48 minutes, listen to Part 2 but know that GitLab will advise on tools to use for your workshops. (LinkedIn Learning)
- [GitLab Speaker Training](https://levelup.gitlab.com/access/saml/login/internal-team-members?returnTo=https://levelup.gitlab.com/learn/course/gitlab-speaker-training-2021) - 35 minutes, requirement for external speakers about GitLab
- [Tips & Tricks for an Engaging Remote Workshop](https://global.hitachi-solutions.com/blog/tips-tricks-for-remote-workshops/) (Article)
- [How to Run an Engaging Remote Workshop: Tips for Stress-Free Collaboration](https://dscout.com/people-nerds/remote-workshops) (Article)
- [10 tips on how to deliver an engaging remote workshop](https://excopartners.com/2021/10/09/10-tips-on-how-to-deliver-an-engaging-remote-workshop) (Article)
- [Communicating with Confidence](https://www.linkedin.com/learning-login/share?account=2255073&forceAccount=false&redirect=https%3A%2F%2Fwww.linkedin.com%2Flearning%2Fcommunicating-with-confidence%3Ftrk%3Dshare_ent_url%26shareId%3Db7EUHzikS6iSUIMO0n%252Fq9A%253D%253D) (LinkedIn Learning)
- [Dynamic Public Speaking by University of Washington](https://www.coursera.org/specializations/public-speaking) (Coursera)
- [Storytelling and influencing: Communicate with impact](https://www.coursera.org/learn/communicate-with-impact) (Coursera)

<a name="soft-skills"></a>

### 💬 Soft Skills

- [Professional Soft Skills Learning Pathway](https://www.linkedin.com/learning/paths/professional-soft-skills-learning-pathway) (LinkedIn Learning)
- [Kind Engineering: How to Engineer Kindness](https://www.youtube.com/watch?v=OGFsM2lcF60) (YouTube)
- [Secrets to Optimal Client Service](https://www.youtube.com/watch?v=hJbwyN4ZoCg) (YouTube)
- [Selling Solutions vs Solving Problems](https://www.youtube.com/watch?v=9ZuWLs7ZNpY) (YouTube)
- [Psychological Safety: Clear Blocks to Innovation, Collaboration, and Risk-Taking](https://www.linkedin.com/learning/psychological-safety-clear-blocks-to-innovation-collaboration-and-risk-taking/psychological-safety-clear-blocks-to-problem-solving-and-innovation?u=2255073) (LinkedIn Learning)
- [Improving Your Listening Skills](https://www.linkedin.com/learning/improving-your-listening-skills-19238090) (LinkedIn Learning)
- [The Six Morning Habits of High Performers](https://www.linkedin.com/learning/the-six-morning-habits-of-high-performers/six-practices-to-get-back-on-track-16454204?u=2255073) (LinkedIn Learning)
- [Unconscious Bias](https://www.linkedin.com/learning/unconscious-bias/) (LinkedIn Learning)
- [How to Make Strategic Thinking a Habit](https://www.linkedin.com/learning/how-to-make-strategic-thinking-a-habit/why-make-strategic-thinking-a-habit?u=2255073)  (LinkedIn Learning)
- [Leading with Emotional Intelligence](https://www.linkedin.com/learning/leading-with-emotional-intelligence-19884915) (LinkedIn Learning)

<a name="tech-domain"></a>

### 🚀 Technology and Domain Knowledge

#### GitLab for CSMs

- [Customer Success Education & Enablement (All-CS)](/handbook/customer-success/education-enablement/)
- Self Certifications are available on [LevelUp](https://levelup.gitlab.com/pages/certifications). Each exam has a corresponding free, self-paced course that covers the needed knowledge and skills:
  - [GitLab Certified Git Associate](https://levelup.gitlab.com/courses/gitlab-with-git-essentials-certification-exam)
  - [GitLab Certified Project Management Associate](https://levelup.gitlab.com/courses/gitlab-project-management-certification-exam)
  - [GitLab Certified CI/CD Associate](https://levelup.gitlab.com/courses/gitlab-ci-cd-certification-exam)
  - [GitLab Certified Security Specialist](https://levelup.gitlab.com/courses/gitlab-security-essentials-certification-exam)
- [GitLab 101](/handbook/people-group/learning-and-development/gitlab-101/)
- [GitLab 201](/handbook/people-group/learning-and-development/gitlab-201/)
- [Learning GitLab](https://www.linkedin.com/learning/learning-gitlab-14539757/) (LinkedIn Learning)
- [Continuous Delivery with GitLab](https://www.linkedin.com/learning/continuous-integration-and-continuous-delivery-with-gitlab/) (LinkedIn Learning)
- [Introduction to GitLab CI & DevOps with AWS](https://www.youtube.com/watch?v=PGyhBwLyK2U) (YouTube)
  - [Introduction to GitLab CI & DevOps with AWS - Course Notes](https://gitlab.com/gitlab-course-public/freecodecamp-gitlab-ci/-/blob/main/docs/course-notes.md) (Git Repo)
- [GitLab CI CD Tutorial for Beginners](https://www.youtube.com/watch?v=qP8kir2GUgo) (YouTube)

#### DevOps

- [DevOps Foundations](https://www.linkedin.com/learning/devops-foundations/) (LinkedIn Learning)

#### Software Development

- [Software Development Life Cycle (SDLC)](https://www.linkedin.com/learning/software-development-life-cycle-sdlc) (LinkedIn Learning)

#### DevSecOps

- [Get started with GitLab application security](https://docs.gitlab.com/ee/user/application_security/get-started-security.html)
- [Application Security in DevSecOps](https://www.linkedin.com/learning/application-security-in-devsecops) (LinkedIn Learning)

#### Git

- [Git Basics Episode 1 - What is Version Control?](https://git-scm.com/video/what-is-version-control) (External Video)
- [Git Basics Episode 2 - What is Git?](https://git-scm.com/video/what-is-git) (External Video)
- [Git Basics Episode 3 - Get Going with Git](https://git-scm.com/video/get-going) (External Video)
- [Git Basics Episode 4 - Quick Wins with Git](https://git-scm.com/video/quick-wins) (External Video)

#### Markdown

- [Handbook Markdown Guide](https://handbook.gitlab.com/docs/markdown-guide/)
- [GitLab Flavored Markdown (GLFM)](https://docs.gitlab.com/ee/user/markdown.html)
- [Handbook Style Guide](/handbook/about/style-guide/)
- [Markdown Tutorial](https://about.gitlab.com/blog/2018/08/17/gitlab-markdown-tutorial/)

#### Docker

- [Docker Crash Course for Absolute Beginners](https://www.youtube.com/watch?v=pg19Z8LL06w) (YouTube)
- [Docker Desktop on your Mac](/handbook/tools-and-tips/mac/#docker-desktop)

#### Kubernetes

- [What is Kubernetes - Kubernetes explained in 15 mins](https://www.youtube.com/watch?v=VnvRFRk_51k) (YouTube)
- [Kubernetes Crash Course for Absolute Beginners](https://www.youtube.com/watch?v=s_o8dwzRlu4) (YouTube)

## How PS Technical Instructors Teach Technical Concepts

These are videos of actual 8-hour courses given live to customers by GitLab's Education Services department. These are good examples of how to present technical concepts in a structured format.

> The Education Services team is working on shorter, edited versions of these class videos. They'll replace these links with the edited versions when they're available. For now just fast-forward through labs and breaks in these unedited class recordings.

Access codes and recording links can be found in this [internal doc](https://docs.google.com/document/d/1WNwz_2TbavLgEVG86eENu4Mf_StjYt77h-d-364l3bM/edit?usp=sharing).

## Career development

### Within the CSM job family

- The [CSM Job Family page](/job-families/sales/customer-success-management/) is kept updated with the roles and responsibilities of each level within the CSM job family
- The [CSM Skills Matrix](https://docs.google.com/spreadsheets/d/1_UEke64Qkz8wSyqfr_E9qqeAF6rX77w4vIH84Ckm_ts/edit#gid=0) enables a CSM to determine areas of opportunity in working towards their next level of seniority

### Within the CS org

- [The SA Job Family page](/job-families/sales/solutions-architect/) is kept update with the roles, responsibilities and technical expectations of an SA. For CSMs interested in moving into SA roles, they can work with their managers on learning paths to develop the technical and sales skills where needed.

### Within GitLab, outside of CS

- While there is no 'formula' for moving into roles in other teams, we welcome CSM growth and desire to explore alternative areas with GitLab.  For CSMs looking to move into different groups outside of CS, the first step is to review the job family requirements and connect with their manager on determining a path. It is encouraged for managers to connect with the group's team leaders in question to build out a development plan that will have the best chances of success.

## External Sources/Tools linked here

### LinkedIn Learning

[Handbook details about LinkedIn Learning](/handbook/people-group/learning-and-development/self-paced-learning/#linkedin-learning).

We also have a list of [Recommended Learning Paths](/handbook/people-group/learning-and-development/self-paced-learning/#linkedin-learning).

### Coursera

[Handbook details about Coursera](/handbook/people-group/learning-and-development/growth-and-development/#self-service-learning)
