---
title: "CSM Internship Program"

---

This page describes best practices for an [internship for learning](/handbook/people-group/learning-and-development/internship-for-learning/) with the CSM team.

Internships are a great way for a GitLab team member to learn about being a Customer Success Manager at GitLab. Use this guide for planning and executing an internship under an IC CSM who acts as the 'Intern Mentor'.

## How to find a mentor in the CSM team

The first step you will need to take in order to start an internship in Customer Success is to find a mentor from the [CSM team](/company/team/?department=csm). Feel free to reach out to any CSMs, particularly ones who are in a similar timezone to you to discuss an internship, or to reach out to a CSM Manager for guidance.

If you're not sure who to reach out to, you can also post in the [#customer-success](https://gitlab.enterprise.slack.com/archives/C5D346V08) Slack channel and express your interest in an internship and that you are looking for a mentor.

## Internship expectations

An internship with the CSM team typically lasts 3 months and is intended for the intern to get hands-on experience of being a CSM, so that they can make a decision if being a CSM is aligned with their career goals and if so will be ready to apply for a position when one opens. Completing the internship is not a guarantee of moving into a CSM role.

Interns and mentors should agree to a regular cadence of meeting. The recommendation is a weekly 30-minute call, perhaps extending to 1-hour depending on the agenda. The intern should be ready and able to commit at least 8 hours per week to the internship (20% time).

## Pre-internship tasks

1. The intern must get approval from their manager to participate in the internship
1. The intern must get agreement from a CSM to be their mentor
1. The mentor must get approval from their manager to participate in the internship
1. All parties (intern, mentor, and the two managers) must agree on a start date and weekly time commitment
1. The intern can optionally open an issue in the [People Ops Training project](https://gitlab.com/gitlab-com/people-ops/Training/issues/new) using the **Internship for learning** template
1. The intern is responsible for scheduling a weekly recurring 1:1 with their mentor to foster regular communication regarding intern role and responsibilities, which will include creating and maintaining a notes doc to document the internship plan, progress, and take notes during weekly 1:1s
1. The mentor will add the intern to the [#timtams](https://gitlab.enterprise.slack.com/archives/G8F1W2AGM) Slack channel, Global CSM biweekly team call, and the mentor's team call
1. The intern is expected to provide feedback on their experiences and receive feedback and guidance throughout the internship

### Timeline and Framework

Interns and mentors can follow the below guidelines to guide the internship and ensure the intern has a full range of exposure to being a CSM.

#### Week 1

**Kick-off call**

1. The intern and mentor will have their first call, in which they will to get to know each other, agree on what they intend to get out of the internship, and align on the plan.
1. The mentor will invite the intern to their upcoming customer calls (the mentor may choose to invite the intern directly, or simply create a separate invite just for them with the Zoom link).

**Async Material Review**

In order to make the most of the internship, it's expected for the intern to do async handbook review in order to have a baseline knowledge of the GitLab product and how the CSM team works.

1. Read pages in the handbook
   1. [CSM handbook](/handbook/customer-success/csm/), especially [CSM responsibilities](/handbook/customer-success/csm/#high-level-responsibilities-of-a-csm)
   1. [Account teams](/handbook/customer-success/account-team/)
   1. [Solutions Architect and CSM overlap](/handbook/customer-success/#overlap-between-solution-architects-and-customer-success-managers)
   1. [Support team overview](/handbook/support/)
   1. [Professional Services offerings](https://about.gitlab.com/services/)
1. Learn about Git & GitLab
   1. [GitLab 101 course](/handbook/people-group/learning-and-development/gitlab-101/)
   1. [GitLab 201 course](/handbook/people-group/learning-and-development/gitlab-201/)
   1. [What is Version Control](https://docs.google.com/presentation/d/16sX7hUrCZyOFbpvnrAFrg6tVO5_yT98IgdAqOmXwBho/edit#slide=id.g72f2e4906_2_29)
   1. [Git-ing started with Git](https://www.youtube.com/watch?v=Ce5nz5n41z4)
   1. [Start using Git on the command line](https://docs.gitlab.com/ee/gitlab-basics/start-using-git.html)
   1. [Learn Git Branching](https://learngitbranching.js.org/)
   1. GitLab Flow ([video](https://www.youtube.com/watch?v=InKNIvky2KE) and [documentation](https://about.gitlab.com/blog/2023/07/27/gitlab-flow-duo/))

#### Week 2

1. Shadow your mentor on customer calls, team calls, & account team calls
   1. Discuss with your mentor what work is involved before and after the call itself, have them share their screen as they do "admin work", and have them cc you on any communications before or after
1. Review one category of the DevSecOps lifecycle in depth every week: Create
   1. Read through the [Product Categories](https://about.gitlab.com/stages-devops-lifecycle/create/)
   1. Complete the [GitLab Certified Git Associate Learning Path](https://levelup.gitlab.com/learning-paths/certified-git-associate-learning-path)
   1. Be prepared to discuss with your mentor:
      1. How does this category provide value to a customer?
      1. Why would a customer choose GitLab over a compeititive tool?
      1. What features are most interesting to you and why?
      1. How would you approach discussing adoption of this use case with a customer?

#### Week 3

1. Shadow your mentor on customer calls, team calls, & account team calls
1. Review one stage of the DevSecOps lifecycle in depth every week: Plan
   1. Read through the [Product Categories](https://about.gitlab.com/stages-devops-lifecycle/plan/)
   1. Complete the [GitLab Certified Project Management Associate Learning Path](https://levelup.gitlab.com/learning-paths/gitlab-project-management-associate-learning-path)
   1. Be prepared to discuss with your mentor:
      1. How does this category provide value to a customer?
      1. Why would a customer choose GitLab over a compeititive tool?
      1. What features are most interesting to you and why?
      1. How would you approach discussing adoption of this use case with a customer?

#### Week 4

1. Shadow your mentor on customer calls, team calls, & account team calls
1. Review one stage of the DevSecOps lifecycle in depth every week: Verify
   1. 1. Read through the [Product Categories](https://about.gitlab.com/stages-devops-lifecycle/verify/)
   1. Begin working on the [GitLab CI Fundamentals Learning Path](https://levelup.gitlab.com/learn/learning-path/gitlab-ci-fundamentals) (modules 1-3)
   1. Based on what you read about the categories, be prepared to discuss with your mentor:
      1. How does this category provide value to a customer?
      1. Why would a customer choose GitLab over a compeititive tool?
      1. What features are most interesting to you and why?
      1. How would you approach discussing adoption of this use case with a customer?
1. Read the [cadence calls handbook page](/handbook/customer-success/csm/cadence-calls/)
   1. Prepare a sample agenda for an upcoming cadence call based on one of the customer calls you've shadowed and present it to your mentor

#### Week 5

1. Shadow your mentor on customer calls, team calls, & account team calls
   1. Get recommendations from your mentor on other CSMs whose calls you can shadow in order to get perspective from other customers and CSMs
1. Working with your mentor, take ownership of customer questions and follow ups, for example:
   1. Get experience researching docs, asking questions in Slack, etc.
   1. Practice finding feature requests
   1. Practice making feature requests
      1. What is the product team looking for? What questions do you need to ask your customer?
   1. Escalate a support ticket - what does the process look like, how do CSMs interact with support?
   1. Draft a follow up email for the mentor to send to a customer
1. Review one stage of the DevSecOps lifecycle in depth every week: Verify & Package
   1. Read through the [Package Product Categories](https://about.gitlab.com/stages-devops-lifecycle/package/)
   1. Continue working on the [GitLab CI Fundamentals Learning Path](https://levelup.gitlab.com/learn/learning-path/gitlab-ci-fundamentals) (modules 4-6)
   1. Be prepared to discuss with your mentor:
      1. Any modules/topics you struggled with understanding in the learning path
      1. Any questions you got wrong in the knowledge checks and what the correct answer is and why
      1. Any roadblocks you ran into with the hands-on labs
      1. How you would translate what you learned in the course to a customer conversation in order to increase CI adoption
1. Review the most recent release notes and give a short presentation/demo to your mentor on 1-2 new features

#### Week 6

1. Shadow other CSMs on customer calls, team calls, & account team calls,  helping with follow ups and questions as needed
1. Review one stage of the DevSecOps lifecycle in depth every week: Verify & Release
   1. Read through the [Release Product Categories](https://about.gitlab.com/stages-devops-lifecycle/release/)
   1. Complete the [GitLab Certified CI/CD Associate Exam](https://levelup.gitlab.com/learn/dashboard?query=ci%2Fcd#)
   1. Be prepared to discuss with your mentor:
      1. Questions in the knowledge check that you got wrong, what the correct answer is, and why
      1. Prompts in the hands-on lab that you struggled to understand or complete, what the correct answer is, and why
      1. If available, review your score with your mentor to identify areas of improvement if you need to take the course again
1. Review [account triage](/handbook/customer-success/csm/health-score-triage/)
   1. Ask your mentor to share their screen and walk through a customer's Gainsight 360, including scorecards, health updates in Timeline, and product usage data
   1. Review customer [escalations](https://gitlab.slack.com/archives/CL0S629QB) and the [process](/handbook/customer-success/csm/escalations/)
      1. Schedule a coffee chat with a CSM currently managing or who recently closed an escalation in order to learn about their experience

#### Week 7

1. Shadow other CSMs on customer calls, team calls, & account team calls,  helping with follow ups and questions as needed
1. Review one stage of the DevSecOps lifecycle in depth every week: Secure
   1. Read through the [Product Categories](https://about.gitlab.com/stages-devops-lifecycle/secure/)
   1. Begin working on the [GitLab Certified Security Specialist Learning Path](https://levelup.gitlab.com/learning-paths/certified-security-specialist-learning-path) (lessons 1-5 in GitLab Security Essentials)
   1. Be prepared to discuss with your mentor:
      1. How does this category provide value to a customer?
      1. Why would a customer choose GitLab over a compeititive tool?
      1. What features are most interesting to you and why?
      1. How would you approach discussing adoption of this use case with a customer?
1. Read through the [account onboarding handbook page](/handbook/customer-success/csm/onboarding/)
   1. Choose an existing customer or create a fake one, and prepare for a kickoff call with them, including a deck using the template provided
   1. Present the deck to your mentor, with them acting as the customer
   1. After you finish roleplaying, self-reflect and get feedback from your mentor
   1. If available, shadow your mentor or another CSM as they prepare for and give a kick-off call, including follow ups
   1. Discuss with your mentor the additional work involved beyond the kick-off calls, such as creating a collaboration project, updating Gainsight fields and CTAs, and best practices for the transition process (both from [pre-sales to CSM](/handbook/customer-success/pre-sales-post-sales-transition/) and [CSM-to-CSM](/customer-success/csm/account-handoff/))

#### Week 8

1. Shadow other CSMs on customer calls, team calls, & account team calls,  helping with follow ups and questions as needed
1. Review one stage of the DevSecOps lifecycle in depth every week: Secure & Software Supply Chain Security
   1. Read through the [Software Supply Chain Security Product Categories](https://about.gitlab.com/stages-devops-lifecycle/govern/)
   1. Continue working on the [GitLab Certified Security Specialist Learning Path](https://levelup.gitlab.com/learning-paths/certified-security-specialist-learning-path) (lessons 6-10 in GitLab Security Essentials)
   1. Be prepared to discuss with your mentor:
      1. Any modules/topics you struggled with understanding in the learning path
      1. Any questions you got wrong in the knowledge checks and what the correct answer is and why
      1. Any roadblocks you ran into with the hands-on labs
      1. How you would translate what you learned in the course to a customer conversation in order to increase CI adoption
1. Read about [success plans](/handbook/customer-success/csm/success-plans/)
   1. If you have access to Salesforce, choose a real customer and build a success plan for them using the [template](https://docs.google.com/presentation/d/1T-Y2WJ-mRqGey7b1YQMTKE3tVbBTnyY3a9HzaOpxPQ4/edit#slide=id.g27c03c31d08_1_500) based on the command plan, product usage data, and any reseach you can do independently (without looking at the existing success plan if it exists!).
   1. If you do not have access to Salesforce, ask your mentor to choose a customer and share their command plan details and usage data with you.
   1. Present the success plan to your mentor and get feedback
   1. Ask your mentor to share a success plan of theirs, then review it and provide constructive feedback on it: what's done well, what could be improved in your opinion, and what questions would you ask the customer to fill in any gaps
   1. Discuss approaches CSMs can take to upgrade a customer to Ultimate

#### Week 9

1. Shadow other CSMs on customer calls, team calls, & account team calls,  helping with follow ups and questions as needed
1. Review one stage of the DevSecOps lifecycle in depth every week: Secure
   1. Complete the [GitLab Certified Security Specialist Exam](https://levelup.gitlab.com/learning-paths/certified-security-specialist-learning-path)
   1. Be prepared to discuss with your mentor:
      1. Questions in the knowledge check that you got wrong, what the correct answer is, and why
      1. Prompts in the hands-on lab that you struggled to understand or complete, what the correct answer is, and why
      1. If available, review your score with your mentor to identify areas of improvement if you need to take the course again
1. Review the most recent release notes and give a short presentation/demo to your mentor on 1-2 new features

#### Week 10

1. Shadow other CSMs on customer calls, team calls, & account team calls,  helping with follow ups and questions as needed
1. Review one stage of the DevSecOps lifecycle in depth every week: Configure
   1. Read through the [Product Categories](https://about.gitlab.com/stages-devops-lifecycle/configure/)
   1. Be prepared to discuss with your mentor:
      1. How does this category provide value to a customer?
      1. Why would a customer choose GitLab over a compeititive tool?
      1. What features are most interesting to you and why?
      1. How would you approach discussing adoption of this use case with a customer?
1. Learn about Architecture/HA and what's best for each customer
   1. Learn about HA and our reference architectures
      1. [What is HA?](https://www.digitalocean.com/community/tutorials/what-is-high-availability)
      1. Review [architecture overview documentation](https://docs.gitlab.com/ee/development/architecture.html)
      1. Understand the differences between the different [reference architectures](https://docs.gitlab.com/ee/administration/reference_architectures/)
      1. Complete [HA Certification course](https://gitlab-training.gitlab.io/ha/) (pre-Gitaly) - **note** this course is no longer graded, but still helpful in learning about HA
      1. Review [Gitaly documentation](https://docs.gitlab.com/ee/administration/gitaly/)
      1. Understand our [GitLab Dedicated offering](https://docs.gitlab.com/ee/subscriptions/gitlab_dedicated/)
   1. Be prepared to discuss with your mentor:
      1. Ask them to share an architecture diagram from one of their customers
      1. Why a customer would choose SaaS vs self-managed vs Dedicated
      1. What you would tell a customer who has 500 users but wants to be HA
      1. Recommended upgrade paths and frequencies
1. Review Geo and discuss with your mentor the different use cases and why customers should use it and when
   1. [Documentation](https://docs.gitlab.com/ee/administration/geo/)
   1. [Geo FAQ](https://docs.gitlab.com/ee/administration/geo/replication/faq.html)

#### Week 11

1. Shadow other CSMs on customer calls, team calls, & account team calls,  helping with follow ups and questions as needed
1. Review one stage of the DevSecOps lifecycle in depth every week: Monitor
   1. Read through the [Product Categories](https://about.gitlab.com/stages-devops-lifecycle/monitor/)
   1. Be prepared to discuss with your mentor:
      1. How does this category provide value to a customer?
      1. Why would a customer choose GitLab over a compeititive tool?
      1. What features are most interesting to you and why?
      1. How would you approach discussing adoption of this use case with a customer?
1. Read about [Executive Business Reviews](/handbook/customer-success/csm/ebr/) (EBRs)
   1. Read about [managing executive relationships](/handbook/customer-success/csm/executive-relationships/)
   1. Complete [EBR micro-course](https://levelup.gitlab.com/courses/csm-onboarding-ebrs-and-customer-conversations)
   1. [Roleplay](/handbook/customer-success/csm/roleplays/) booking an EBR on a call with your mentor
   1. Look through Chorus if you have access or ask your mentor for recordings of successful EBRs
   1. Based on the success plan you created in week 8, build an EBR deck  using the [EBR template deck](https://docs.google.com/presentation/d/1X9N8eoEZrgUx486en8iN3ZxVtQgNYnY6bAHBKYOA6m0/edit#slide=id.g252615f021c_1_0) and present it to your mentor
   1. Be prepared to discuss with your mentor:
      1. What benefit do EBRs provide to us?
      1. What benefit do EBRs provide to the customer?
      1. What constitutes a successful vs a non-successful EBR?
      1. What was the hardest part about preparing an EBR?
      1. What would be your follow ups after an EBR?
   1. Shadow another CSM and help them prepare for a real EBR if one is coming up

#### Week 12

1. Shadow other CSMs on customer calls, team calls, & account team calls,  helping with follow ups and questions as needed
1. Review one stage of the DevSecOps lifecycle in depth every week: AI
   1. Read through [GitLab Duo offering](https://about.gitlab.com/gitlab-duo/)
   1. Be prepared to discuss with your mentor:
      1. How does AI provide value to a customer?
      1. Why would a customer choose GitLab over a compeititive tool?
      1. What features are most interesting to you and why?
      1. How would you approach discussing adoption of AI with a customer?
1. Give a plan-to-monitor demo to your mentor, covering what you've learned at a high-level
   1. The demo should be focused on value of the entire DevSecOps lifecycle, but you should be prepared to go deeper into any areas or features, as your mentor will act as a customer and ask you probing questions
1. Celebrate! You've completed the CSM internship :tada:
