---
title: CSM Executive Relationships
---

View the [CSM Handbook homepage](/handbook/customer-success/csm/) for additional CSM-related handbook pages.

---

At GitLab, successful partnerships between our Customer Success Managers and their customer executives are crucial to the success of our customers and our business. As CSMs position themselves to be more strategic and reach Director, VP, and CISO personas, we have to adjust our communication styles and consider how to cater them to executives. This page provides guidance on how CSMs can effectively partner with executives to drive value for our customers.

## Persona Engagement Flow

Often, CSMs are first introduced to GitLab Admins and champions who work directly with GitLab in their day-to-day, or their direct team does. While this is incredibly useful, and we should be cultivating these relationships, we also want to have executive-level relationships. Typically the flow for a CSM is to start by building strong relationships with admins and champions, then have them introduce the CSM to their leadership, and repeat the cycle until we get in the room with a decision-maker.

Sometimes, we can establish an executive contact and relationship early on, whether because they are involved in the pre-sales process and the AE has a close relationship, or because the admin/champion has a direct link to them and is able to get them involved.

### Build Relationships with GitLab Admin & Champions

Strong first impressions are important in building a successful and collaborative relationship with your customer. When being introduced to a new account, it is critical that you and the account team position the [Customer Success Manager role](/handbook/customer-success/csm/) as more than "technical support" or "technical point of contact." This limits the scope of the CSM role and lowers the probability of gaining access to executives. By positioning the CSM as a consultant focused on their business success and enablement, it opens up conversations around high-level business outcomes.

From there, asking deeper questions during the intro call is a great way to uncover the outcomes that are the highest priority for the customer. This could happen right after the initial sale, when you inherit a customer from another CSM, or even after having the account for a while in order to ensure continued alignment. Asking discovery questions such as those listed below are key to uncovering the problems your account is experiencing, the business impact of those problems, and the benefit that fixing those problems will have on their business.

- Why did you buy GitLab?
- What problems do you hope to solve?
- What is the impact of those problems on your business?
- What will solving those problems do for your business?
- What kind of results will tell you that you made the right decision in buying GitLab?
- What are the goals of your company short-term (3-6 months) and long-term (1+ years)?

It is critical to identify the champions and key influencers within the organization and make an effort to engage with them regularly. Schedule regular check-ins and provide updates on customer health, success stories, and any opportunities for growth or improvement. Oftentimes, successful customer partnerships require cross-functional collaboration. Make sure you work with your champion to identify stakeholders from other teams or departments that need to be involved in supporting the customer's success and coordinate efforts between the teams to ensure everyone is aligned on goals and priorities.

Sometimes, the day-to-day team might not understand the value of executive partnership and therefore defaults to gatekeeping us from engaging with executive personas, as they see us as "just another vendor". To handle this objection, CSMs should equip the team with value-led messaging to pitch [Executive Business Reviews](/handbook/customer-success/csm/ebr/) internally by displaying EBRs as great opportunities to demonstrate to their leadership all the great work our champions have done to meet their wider business goals, and ensure the team understands that our focus is on making them be successful, which can more easily be achieved if we are all aware of and in sync with leadership's expectations and objectives.

If you continue to have trouble engaging with your account, work with your colleagues in other departments to identify any existing relationships and collaborate on how to best engage with leadership in the account. For example, ask your sales colleagues if they have any existing relationships with the stakeholders in the account, or ask your CSM leadership if they know any peers at the customer.

As a CSM, you are responsible for ensuring the health and success of our customers. Providing regular updates on customer health is crucial to building trust and demonstrating the value of our solutions to executives. It is not uncommon for there to be gatekeeping when trying to get access to executives, but persistence and proactivity often are they key to succeed. It is important to continue to show value to the customer and handle common objections with [these recommended responses](https://docs.google.com/document/d/1WzvklnloC22WffVcLYupLy3kqSsEbHNtcj47xrb07As/edit).

### Demonstrate Value and Speak the Language of Executives

Once you have established who the executive stakeholder at your company is, it's crucial to make a good first and continued impression. Building a relationship with the executive team can make or break your success with an account. CSMs typically have one meeting to show their value to an executive, and if the executive is not engaged in that first meeting they are unlikely to join future meetings.

It's important to understand why building a relationship with the executive team is important in the first place:

- Leadership clearly determines overall expectations and business goals
- Leadership is able to hold the customer team accountable
- Alignment with leadership allows the GitLab account team to course-correct when needed, rather than too late
- Leadership owns the budget and spending decisions, including renewal and expansion

One suggestion is to use the [business model canvas](https://docs.google.com/presentation/d/1ZEImIuiPyK9XpdLKf57dRmFSH_jRWOUl/edit#slide=id.p8) to guide the conversation with executives. When communicating with executives, frame your messaging around the specific business outcomes they are trying to achieve. For example, if an executive is focused on reducing costs, communicate how our solutions can help reduce costs for their organization, while also allowing them to achieve more.

Sharing customer success stories is another excellent way to demonstrate the [value](https://docs.google.com/presentation/d/1ZEImIuiPyK9XpdLKf57dRmFSH_jRWOUl/edit#slide=id.p6) and [impact](https://docs.google.com/presentation/d/1ZEImIuiPyK9XpdLKf57dRmFSH_jRWOUl/edit#slide=id.p17) of our solutions to executives. Identify success stories that align with the executive's business objectives and share them during regular check-ins. This sharing of customer success stories can help build enthusiasm and support for our solutions and help identify opportunities to drive value.

It is also vital to [highlight ROI](https://about.gitlab.com/calculator/) to the executive team. Results prove to customers that they made a smart choice to invest their time, energy, and resources into your solution and that they received a return on their investment (ROI). Results show that you are solving problems and positively impacting their business. Results mean you are able to "close the loop" and measure your impact. When communicating with executives, highlight the ROI of our solutions and how they can help the organization achieve its business goals.

Furthermore, executives often have a broad view of the organization and its goals. When communicating with executives, focus on the big picture and how our solutions fit into the larger organizational strategy. Focus on [communicating how our solutions align with the executive's vision, mission, and values](https://docs.google.com/presentation/d/1ZEImIuiPyK9XpdLKf57dRmFSH_jRWOUl/edit#slide=id.p23). Some example questions you can ask to [identify what problems and priorities for the executive team](https://docs.google.com/presentation/d/1ZEImIuiPyK9XpdLKf57dRmFSH_jRWOUl/edit#slide=id.p9) are:

**[Impact Questions](https://docs.google.com/presentation/d/1ZEImIuiPyK9XpdLKf57dRmFSH_jRWOUl/edit#slide=id.p17):**

- What does it cost you when a vulnerability is found in production?
- What's the escalating cost the further down the remediation falls within your SDLC?
- Who is responsible for uncovering vulnerabilities?
- What are the implications when a vulnerability is found in production?
- What is the additional cost in people hours when a vulnerability is found in production?
- What is the legal risk to you when a vulnerability makes it into production?
- How does the speed of release impact the regulatory compliance motion?
- Do you have any metrics regarding the cost associated with a delay to a deployment?
- Do you have applications that generate revenue in which a delayed deployment also delays expected revenue?
- Do you have the ability to handle multiple deployments at once?  Is there a deployment bottleneck based on resourcing?
- How has the quality of your software impacted your trading business?
- What risks do slow deployments create for your business?
- What budget disruptions have you seen historically related to slow software development?
- How does having multiple tools to learn and work with impact your ability to onboard new employees?

**[Value Questions](https://docs.google.com/presentation/d/1ZEImIuiPyK9XpdLKf57dRmFSH_jRWOUl/edit#slide=id.p19):**

- What if you could release a new version every week? How would that positively affect you?
- If our solution could help you iterate software deployment velocity by 50%, what would that do for you and your team?
- If you could build software 10% faster, how would that improve your revenue?
- How could your feedback loop improve with your stakeholders if you were able to release daily as opposed to every couple weeks?
- How about reducing the frustration from your dev team every time they push changes into production? What that make your team happier and eager to work faster?
- If you were to streamline your toolchain to improve cycle time, where would you start? What would you like to remain the same?
- What are you doing today to improve cycle time? Describe how you would like to improve cycle time.
- How would your business benefit if it were not constrained by the speed of releasing product changes?
- What is your ideal solution?

Establishing shared metrics for success with executives is another approach to building a successful partnership. These metrics should align with the executive's business objectives and focus on the value our solutions provide to the customer. Work with the executive to identify key performance indicators (KPIs) that demonstrate the value of our solutions and track progress towards these metrics regularly.

- Use customer health scores, product usage data, satisfaction scores, renewal rates, and upsell opportunities to demonstrate how our solutions are contributing to the organization's success. For example, if a customer satisfaction score has improved since the implementation of our solutions, communicate that to the executives.
- Use data-driven insights: Executives rely on data to make informed decisions. Use data-driven insights to support your communication and demonstrate the value of our solutions. For example, use Gainsight health scores, [Value Stream Analytics](https://about.gitlab.com/stages-devops-lifecycle/value-stream-analytics/), and [code quality metrics](https://docs.gitlab.com/ee/ci/testing/metrics_reports.html) to demonstrate how our solutions contribute to the organization's success.

Finally, when working with executives, make sure to use [language that executives will understand](/handbook/communication/#simple-language) and avoid technical jargon. Use industry-specific terminology where appropriate, but be sure to provide context and explanations as needed. For example, if an executive is not familiar with a specific term or concept, explain it in simple terms that they will understand.  Here are some [common tips on communication with executives](https://docs.google.com/presentation/d/1ZEImIuiPyK9XpdLKf57dRmFSH_jRWOUl/edit#slide=id.p24).

### Continuous Engagement

Finally, it's essential to continuously improve your partnership with executives. Solicit feedback from the executive team on how the partnership is progressing and areas for improvement. Use this feedback to refine your approach and identify opportunities for growth and innovation. An annual [EBR](/handbook/customer-success/csm/ebr/) is a great opportunity to open this dialogue and learn ways in which we at GitLab can improve to make the customer's experience better. By implementing these best practices, CSMs can build strong partnerships with executives and drive successful outcomes for our customers.

It's recommended for each CSM to speak with an executive stakeholder at least annually, however each segment/region may warrant more frequent engagement, as follows:

- WIP - to be added

### Additional Resources

The below resources are internal-only:

- [Strategic Customer Engagement Workshop Recording](https://www.youtube.com/watch?v=IiScOF3bwFo)
- [Strategic Customer Engagement Workshop PPT](https://docs.google.com/presentation/d/1ZEImIuiPyK9XpdLKf57dRmFSH_jRWOUl/edit#slide=id.p1)
- [Strategic Customer Engagement Issue](https://gitlab.com/gitlab-com/sales-team/field-operations/enablement/-/issues/1171)
- [Executive Communication Best Practice Resources](https://gitlab.com/gitlab-com/customer-success/csm/-/issues/712)
