---
title: "Calls to Action (CTAs)"
description: "The Gainsight guide to using Calls to Action (CTAs) to assist you managing your accounts, making sure customers' needs are addressed, and planning for what's next."
---

A [CTA](https://support.gainsight.com/Gainsight_NXT/04Cockpit_and_Playbooks/01About/CTAs_Tasks_and_Playbooks_Overview) is a call to action that is tied to a customer and appears in a CSM's cockpit, as well as the account cockpit. CTAs can be created manually at any time, but some will automatically be created for you based on certain events or data.

To create a new CTA, go to your cockpit and click "+ CTA", then fill out the appropriate information. If a CTA will consist of multiple tasks over a period of time, click CTA after saving it, then click the three dots on the top right of the new right sidebar, and click "Add Task". You can add as many as needed and track your progress in the milestone section.

Watch a quick [video on Gainsight CTAs](https://www.youtube.com/watch?v=qkjmTh3Qad4&feature=youtu.be) to learn how to use them, best practices, and tricks.

### Cockpit

The Cockpit is the main place you'll go to manage CTAs, which can be opened from several methods. They can be automatically opened due to trigger points in a customer's lifecycle, a CSM can manually open them, or if a CSM logs a task in a [Timeline](/handbook/customer-success/csm/gainsight/timeline/) event that task will populate in the Cockpit.

The main Cockpit is located by using the far left navigation panel (under "Home") and clicking "Cockpit" to see all CTAs for all customers (this can be customized and refined, discussed below).

There are also individual C360 Cockpits for each customer, which can be located by navigating to the Customer 360 and clicking "Cockpit" in the left sidebar. Please note that C360 Cockpits do not include success plan objectives, while the main Cockpit screen does.

The Cockpit can be customized for your needs so that you can see what data is most helpful to you and your workflows.

1. Use the far left nav panel (under "Home") and click "Cockpit" to see all CTAs for all customers
1. At the top right of the screen (below "Cockpit"), you'll typically want to looking at the dashboard called "My CTAs" as it is a comprehensive overview of all CTAs assigned to you (however, you can choose another default view from the list or create your own view with even further customized options)
1. Click the "Due Date" dropdown button at the top right next to the search field to change the groupings of the CTAs as desired (you can group by Type, Company, Renewal Date, etc.)
1. Click the "+" button at the right of the column names, which will take you to a list of all possible fields you can add to the column list
1. Search and add any additional fields you want to see (a common column to add that is not included by default is "Next Task Due Date")
1. Click "Apply" to save your changes to the view (you can do this as many times as you want to test out different column fields)

To create and save a customized CTA view for yourself beyond the defaults, use the filter button at the top right; you can later access these views in the dropdown at the top left.

Once you have your Cockpit customized to your needs, you can also sort the rows by a column field by clicking on the name of a column, e.g. "Due Date".

Please note that any customizations you do for a Cockpit view will be consistent between the main Cockpit and individual C360 Cockpits.

### Types of CTAs

There are several "types" of CTAs, which will have different corresponding playbooks, so if you're looking for a particular playbook be sure to select the appropriate type. See below for each type and the corresponding [playbooks](/handbook/customer-success/playbooks/) for that type.

- Risk
  - [At-Risk](/handbook/customer-success/csm/health-score-triage/#triage-cta)
  - DevSecOps Risk
  - Low License Utilization
  - Non-Engaged Customer
  - Product Risk
  - Risk Escalation
  - Scale NPS Detractor
- Expansion (no playbooks associated)
- Lifecycle
  - Create Success Plan
  - Customer Offboarding
  - [Executive Business Review (EBR)](/handbook/customer-success/csm/ebr/#how-to-prepare-an-ebr)
  - Existing Customer Onboarding
  - High License Utilization
  - [New Customer Onboarding](/handbook/customer-success/csm/onboarding/)
  - New Customer Onboarding - SaaS email assist
  - New Customer Onboarding - Self-Managed email assist
  - Usage Data Enablement
  - Webinar Attended by Customer
- Activity
  - [New Account Handoff](/handbook/customer-success/csm/account-handoff/#account-handoff-cta)
- Renewal
  - [Upcoming Renewal](/handbook/customer-success/csm/renewals/)
- Digital Journey
  - Digital Adoption - CI Enablement
  - Digital Onboarding - SaaS Email Series
  - Digital Onboarding - Self-Managed Alternative Backup Strategies
  - Digital Onboarding - Self-Managed Email Series
  - Digital Onboarding - Welcome Email
  - Scale: 21 Day Post Onboarding - Calendly Clicked
  - Scale: 21 Day Post Onboarding - Calendly Not Clicked
  - Scale: 6 Month Check-in - Calendly Clicked
  - Scale: 6 Month Check-in - Calendly Not Clicked
  - Scale: Low License Utilization - Calendly Clicked
  - Scale: Low License Utilization - Calendly Not Clicked
  - Scale: One-Off Scale CSM Outreach
  - Scale Team: Day 14 Reach-Out
  - CSM Account Transitions

If the CTA you're opening does not fall into one of the playbook categories, choose the type that makes the most sense. If it's a common CTA, suggest creating a playbook for the it by [opening an issue](https://gitlab.com/gitlab-com/sales-team/field-operations/sales-operations/-/boards/1731118?&label_name[]=gainsight).

#### CTA Status

CTA statuses are defined below.

Available on All CTAs:

- New - Brand new CTA, has yet to be started
- Work in progress - CTA currently being worked on by a CSM
- Closed Success - This CTA was completed with a positive (or intended) outcome
- Closed Lost: Not a Priority - Customer doesn't see this as a top objective to pursue
- Closed: Already Solved
- Closed: Not Relevant
- Closed: Lack of Engagement

Available on Lifecycle CTAs only:

- Closed: Not needed

Available on Objective CTAs only (Success Plans):

- Closed Lost: Competitive Loss - This is explicitly when a customer is exploring solutions for additional use cases and selects another net-new vendor. This situation does not include losing out to the incumbent, which speaks more to didn't see the value.
- Closed Lost: Product Gaps - In reviewing the use case and features/capabilities, there were product gaps, or the customer believes the product does not meet their use case needs.
- Closed Lost: Responsible Team Unengaged - Another team other than the one we are engaged with owns the capability or permission needed for adoption. We have not been successful in engaging this other team.
- Closed Lost: Didn't See Value - Customer did not see the value to justify the investment, assuming the ability to drive adoption was within their scope of control.
- Closed Lost: Deferred To Later Date - The customer has shown material interest (i.e., committed, high-level of interest) in expanding but prefers to pursue at a different date. CSM in these instances creates a reminder CTA to bring the conversation back up.
- Closed Lost: Lack of Budget - Customer would need to up-tier to use the new stage in full and does not have the budget available.

### Snoozing CTAs

In Gainsight, you are able to snooze a CTA in order to keep it open but remove it from your main Cockpit until a later date (it will still show up in the C360 Cockpit).

Reasons to snooze a CTA instead of closing it:

1. The CTA isn't applicable at this point in time, but will be applicable in the foreseeable future. For example, if an account is newly CSM-qualifying and you receive a CTA to hold an EBR, use the snooze CTA functionality to push out the date within the next 3-6 months.
1. Ensure a similar/related CTA isn't fired. For example, if a CTA fires when you haven't updated CSM Sentiment, but you have a cadence call scheduled for next week, you can snooze the CTA for a week from now and avoid getting another CTA before you can meet with the customer.

To snooze a CTA, follow these instructions:

1. Open the CTA
1. Click the three vertical dotes
1. Click `Snooze`
1. Select a date for the CTA snooze to end, and select a reason for snoozing
1. Click `Snooze`

To update either `Snooze Date` or `Snooze Reason`, or to manually un-snooze the CTA, go to the CTA and click the three vertical dots again and change the details as required.

When a CTA is snoozed, it will not appear in the main Cockpit until the snooze ends or they are un-snoozed, but you can view snoozed CTAs by going to the C360 Cockpit which will show all CTAs. You can also update your main Cockpit filter to show snoozed CTAs by selecting the filter icon in the upper right corner and marking the `Is Snoozed` filter as `true`.

To request additional Snooze options, please open an issue in the [Gainsight issue tracker](https://gitlab.com/gitlab-com/sales-team/field-operations/customer-success-operations/-/issues/new?issue%5Bassignee_id%5D=&issue%5Bmilestone_id%5D=).

For more information and illustrations, review [Gainsight's documentation](https://support.gainsight.com/Gainsight_NXT/04Cockpit_and_Playbooks/Cockpit_Version_-_Old/User_Guides/Using_Call_to_Action_(CTA)_and_Task_Detail_Views#How_to_Use_the_Snooze_Option).
