---
title: "CSEs"
---

View the [CSM Handbook homepage](/handbook/customer-success/csm/) for additional CSM-related handbook pages.

---
**Overview**

At GitLab, we take customer success seriously, and our Customer Success Engineer (CSE) team plays a pivotal role in ensuring our global customer base receives unparalleled support and assistance throughout their journey with us. As a team, we oversee key processes (listed below) that are designed to empower our customers, enable our sales counterparts, and drive overall customer satisfaction. This aligns perfectly with the common pattern of being customer centric across our [company strategy](/handbook/company/strategy/).

1\. **[Customer Enablement Webinar Program](https://university.gitlab.com/pages/gitlab-user-webinars):**

- Informative and interactive webinars for customers.

- Empowers customers with GitLab knowledge and skills.

- Live Q&A session providing immediate answers to customer questions.

2\. **[Customer Enablement Hands-on Lab Program](https://university.gitlab.com/pages/gitlab-user-webinars):**

- Help customers gain practical experience with GitLab's features.

- Interactive sessions with Live Q&A.

- Enhances adoption, productivity, and business goals.

- Direct interaction with CSEs fostering trust and collaboration.

3\. **[Pooled CSE Model:](/handbook/customer-success/csm/segment/cse/cse-operating-rhythm/#cse-engagement-request-process)**

- Collaboration with Account Executives and Renewal Manager on how the customer is adopting the platform, including any potential risks or areas for improvement.

- Offers technical expertise and support for high-risk or expansion accounts.

- Ensures top-tier attention, leading to retention and expansion.

- Drives ultimate customer success.

4\. **Automated Email Campaign Process:**

- Timely automated emails at key customer lifecycle points.

- Provides valuable insights, tips, and resources.

- Supports customer success and keeps customers engaged.

- Enhances communication and customer satisfaction.

- [Email Content - GitLab Internal Only](https://docs.google.com/document/d/1Db6y_i2gPQrPnJkJpAAbfFKQtw4c5VgSFJcHKDG-4hk/edit)

### **CSE Operating Rhythm**

The [CSE operating rhythm](/handbook/customer-success/csm/segment/cse/cse-operating-rhythm/) outlines procedures CSEs use to engage with customers as well as how account owners can request CSE engagement outside of the normal operating rhythm during the customer lifecycle.

[For the ARR thresholds for the CSE customer segment please reference this Wiki page](https://gitlab.com/gitlab-com/customer-success/csm/-/wikis/CSM-Segments) (GitLab Internal).

![Customer Lifecycle Journey CSE](/handbook/customer-success/csm/segment/cse/CustomerLifecycleJourneywithMetrics-ScaleCSE_Nov-2023.png)

The [CSE DCI matrix](/handbook/people-group/directly-responsible-individuals/#dri-consulted-informed-dci) provided below is designed to serve as a guiding framework to improve collaboration across teams. Please note that this is applicable only to accounts interacting with a CSE. For accounts managed by a CSM or CSA, refer to the [CSMA's DCI](/handbook/customer-success/account-team/#customer-success-manager-csm/) on Rules of Engagement.

#### **Journey Stage: Pre-Sales & Alignment**

| Activities | Tasks | CSE | AE | RM | SA | PS | Support | Executive Sponsor | Product and Engineering |
|-------|------|------|-----|----|----|----|------|----|-----|
| Identify Tech Champion(s) | Define and engage key user personas for solution tailoring. | I |C,I||DRI|||||
| Sales to Customer Success (CS) Handoff | Ensure detailed information transfer from sales to CS for seamless transition. | I |C,I||DRI|||||

#### **Journey Stage: Onboard**

| Activities | Tasks | CSE | AE | RM | SA | PS | Support | Executive Sponsor | Product and Engineering |
|--------------|------------|------|-----|----|----|----|------|----|-----|
| General Advice for GitLab Setup and features implementation | As part of the onboarding campaign, an automatic post-onboarding email is sent by Gainsight. The customer can book a call with a CSE to go through their setup and needs. | DRI |C,I|I||||||
| Technical Integration and Setup Support | Provide direct assistance setting up GitLab (for example, architecture and deployment strategies) to fit customers' needs and goals. ||C,I|I|C,I|DRI||||

#### **Journey Stage: Enable**

| Activities | Tasks | CSE | AE | RM | SA | PS | Support | Executive Sponsor | Product and Engineering |
|--------------|------------|------|-----|----|----|----|------|----|-----|
| 1:1 Engagement with the customer, triggered by AE/RM, depending on the needs from the customer | Transactional engagement between the customer and the CSE to discuss a specific topic, which should be clearly defined by the AE/RM before the meeting with the customer. | DRI |C|I||||||
| Conduct 1:N Workshops and Webinars focused on customer enablement | Organized workshops and webinar sessions hosted for different customers aiming to enable and help users with key product topics. |DRI||I||||||
| Break'n'fix scenarios where there is a bug/the platform not behaving correctly | Cases where the customer expects someone to troubleshoot a bug or help with a specific feature setup. (In specific situations, the Support Engineering might communicate and inform the CSE about the support ticket)|(C,I)|||||DRI|||
| Measure Primary Use Case Adoption | Track and analyze the adoption rate of primary use cases when associated to requests originated from Renewals Managers or Account Executives.|DRI|I|I|I|||||

Comments: (C,I) - It will depend on the situation.

#### **Journey Stage: Expand**

| Activities | Tasks | CSE | AE | RM | SA | PS | Support | Executive Sponsor | Product and Engineering |
|--------------|------------|------|-----|----|----|----|------|----|-----|
| Expansion Discovery | Identify and pursue upsell and cross-sell opportunities. | (C) |DRI|I|C|||(I)||
| Account Health Checkups | Conduct regular assessments of account health to ensure ongoing customer success. | (C) |DRI|C,I|C|||||

Comments: (C),(I) - It will depend on the situation.

#### **Journey Stage: Optimize & Renew**

| Activities | Tasks | CSE | AE | RM | SA | PS | Support | Executive Sponsor | Product and Engineering |
|--------------|------------|------|-----|----|----|----|------|----|-----|
| Business Review (BR) | Conduct BRs to review successes, challenges, and future plans. |C|DRI|I|C|||C,I||
| Renewal Discussions | Initiate early discussions about renewal, leveraging insights from the customer journey.|C,I|C|DRI|C|||I||
| Monitor Client Satisfaction | Implement a structured feedback process to capture and act on customer insights, driving continuous improvement.|I|DRI|C,I|C,I|(C)||I|I|
| Facilitate Product Collaboration | Clearly capture customer needs via feature requests to assist Product Managers with feature prioritisation and product enhancement.|C,I|C|I|DRI|||I|C,I|
| Ongoing Risk Review | Active management of risk in a customer account, quickly turning a customer to red when there is any potential risk of contraction or churn and frequently updating the status.|C,I|DRI|C,I|C|||C,I||
| Escalation Management | Trigger/leading the escalation process (account escalation / STAR) where needed.|C,I|DRI|C,I|C||C,I|C,I|I|

Comments: (C), (C,I) - It will depend on the situation.

For an additional overview of our CSE team-specific responsibilities, please reference our Job Family: [CSE Responsibilities & Requirements](/job-families/sales/customer-success-engineer/)

### <i class="fa-solid fa-book" style="color: #B197FC;"></i> **CSE Content Handbook**

Content/1:many is a critical part of our strategy to drive customer adoption at scale across our very large book of business.  This requires dedicated resources/DRIs to execute this strategy.

To learn more visit our [CSE Content Team Handbook](/handbook/customer-success/csm/segment/cse/content) page.
