---
title: "CSE Team Member Onboarding"
---

View the [CSM Handbook homepage](/handbook/customer-success/csm/) for additional CSM-related handbook pages.

---
**Overview**

As a Customer Success Engineer (CSE), your onboarding experience will be a blended learning experience that includes virtual synchronous meetings, a [self-paced role-based learning path](https://levelup.gitlab.com/access/saml/login/internal-team-members?returnTo=https://university.gitlab.com/learn/learning-path/scale-customer-success-engineer-cse-onboarding) on GitLab University, and a hands-on virtual workshop called [Sales Quick Start](/handbook/sales/onboarding/) (SQS).

Your role based learning path is highlighted in this [role-specific onboarding guide](https://docs.google.com/document/d/1jY0YnL7whNVVK_VeoxRPjn-Iloj8_Su_3YOx0X1bKtw/edit?usp=sharing). Please make a copy of this document and check off items as you complete them.

**Learning Objectives for CSE Onboarding**

As a CSE, in addition to the [SQS learning objectives](/handbook/sales/onboarding/sqs-learning-objectives/), your onboarding is intended to fulfill the following learning objectives:

*Module 1: CSE at GitLab and Call Shadowing*

- Demonstrate understanding of GitLab Basics
- Express the Customer Success Vision
- Describe the role of CSE
- Complete the following certification: GitLab Certified Git Associate
- Express understanding of the DevSecOps Lifecycle
- Demonstrate ability to set up a GitLab demo environment

*Module 2: CSE Deep Dive*

- Describe the rhythm of business for a CSE
- Demonstrate comprehensive understanding of CI/CD
- Apply understanding of CI/CD
- Complete the following certification: GitLab Certified CI/CD Associate  GitLab CI/CD
- Demonstrate customer readiness by completing role play exercise

*Module 3: Technical Deep Dive*

- Explain best practices for customer onboarding
- Examine reference architecture
- Demonstrate comprehensive understanding of GitLab Agile Project Management
- Complete certification GitLab Project Management
- Demonstrate customer readiness by completing role play exercise

*Module 4: CSE Best Practices*

- Formulate comprehensive understanding of the DevSecOps adoption
- Identify how to request and track CSE engagement
- Differentiate rules of engagement for the CSE and other account team members (i.e., AEs, SAs, CSMs, etc)
- Apply use of Gainsight
- Demonstrate comprehensive understanding of GitLab Security
- Complete certification GitLab Security Specialist
- Demonstrate customer readiness by completing role play exercise

*Module 5: CSE Onboarding Conclusion*

- Explain CSE Escalations
- Identify recommended CSE meeting workflow
- Discuss customer readiness with your manager
- Complete Sales Quick Start prework
- Complete role-based onboarding learning path

**Milestones and Onboarding Roadmap**

![CSE Onboarding Journey Roadmap](/handbook/customer-success/csm/segment/cse/CSE-Onboarding-Journey-Roadmap.png)

**Expectations for Manager Support during Onboarding**

Your manager will be there to support you during your onboarding journey. Beyond the expectations laid out for your manager in your onboarding issue, they will be providing you with the following support:

*Month 1*

- Schedule recurring 1:1s and check in calls
- Provide guidance on who the new hire should schedule coffee chats with during their onboarding journey
- Review and discuss company policies
  - PTO policy
  - Family and Friends first culture
  - CREDIT Values
- Discuss any team specific expectations
- Review organizational structure
- Ensure new hire has access to all role-specific tools and appropriate Slack channels
- Align on a general plan to get customer ready including who to schedule your onboarding role plays with
- Ensure new hire is meeting appropriate milestone and expectations from week to week
- Identify skills to be mastered and resources available to accomplish learning objectives

*Month 2*

- Check in regularly with your new hire
  - Ask them if they are experiencing any challenges with GitLab's asynchronous culture
  - Discuss any general concerns
- Share constructive feedback on role plays that were completed during the onboarding learning path
- Ensure onboarding milestones are met and that new hire is completing required courses and certifications
- Align on whether your new hire is on track to be customer ready and how else you can provide support to get them ramped
- Discuss best practices and rules of engagement for CSEs

*Month 3*

- Decide on a regular cadence for 1:1 calls
- Prep your new hire for taking over assigned customers/accounts
- Consider shadowing some customer calls and provide feedback as needed
- Confirm that new hire has completed all mandatory and necessary onboarding activities including SQS and role-based learning path
- Discuss how their performance will be formally evaluated

*Beyond 3 months*

- Provide regular feedback on performance
- Partner with employee to develop an individual growth plan for goals they want to achieve in the coming year
- Discuss the following topics at length in the coming months by providing an overview of the topic, why is it important to customer / GitLab / CSE, what does good look like, what are some common pitfalls, and how success is measured:
  - Cadence Calls
  - Success Plans
  - EBRs
  - Customer Escalations
  - Customer Enablement
  - Gainsight Hygiene

**Expectations for Buddy Support during Onboarding**

*Month 1*

- Nurture a welcoming environment for the new hire
- Establish a recurring 1:1 meeting to check in on the new hire's progress on onboarding activities
- Provide assistance with any barriers or difficulty understanding concepts covered in the onboarding learning path and SQS
- Connect the new hire with members of the broad team to build a network
- Share helpful tips and resources that are beneficial during their onboarding and beyond

*Month 2*

- Provide opportunities for new hire to shadow you on calls as defined in the [shadow criteria](https://docs.google.com/document/d/1jY0YnL7whNVVK_VeoxRPjn-Iloj8_Su_3YOx0X1bKtw/edit#heading=h.1g07abmamci3) and assist with note taking
  - Debrief on calls and discuss feedback
- Align with new hire's manager on ways you can provide support

*Month 3*

- Co-lead calls with the new hire until they are ready to take over customer interactions independently
  - Share constructive feedback
- Inform new hire on how you can support them beyond their onboarding journey

**Graduation from CSE Onboarding**

In order to be considered as having graduated from your CSE onboarding journey, you need to have completed the following:

- Completed Sales Quick Start (SQS) prework on GitLab University
- Attended the SQS workshop and completed all relevant activities
- Completed your role based learning path on GitLab University
- Attained the following certificates:
  - GitLab Certified Git Associate
  - GitLab Certified CI/CD Associate
  - GitLab Certified Project Management Associate
  - GitLab Certified Security Specialist
- Completed role play activities and discussed feedback with your manager /  onboarding buddy

**Continuous Onboarding**

For high level information on enablement initiatives for the Customer Success Manager/Engineer teams, please refer to the [CS Enablement Corner](https://docs.google.com/document/d/1xyaxc37iCDtfeabo2NXCRV31pNOdvieXoVDxJw_aXoM/edit). Additionally, please be sure to check out the [CS Development Handbook](/handbook/customer-success/csm/csm-development/) page.

Be sure to join the [Customer Success Skills Exchange](/handbook/sales/training/customer-success-skills-exchange/) and [Field Enablement Spotlight](/handbook/sales/training/sales-enablement-sessions/#field-enablement-spotlight-sessions) sessions.

**Feedback**

Your feedback on the onboarding process is important to us and we welcome your thoughts and ideas about how we can improve in the future. Please share your feedback in the following issue: [CSE Onboarding Feedback](https://gitlab.com/gitlab-com/sales-team/field-operations/enablement/-/issues/2406).

**Resources**

- [CSE - New Hire - Onboarding Guide](https://docs.google.com/document/d/1jY0YnL7whNVVK_VeoxRPjn-Iloj8_Su_3YOx0X1bKtw/edit?usp=sharing)
- [Customer Success Engineer (CSE) Onboarding Learning Path](https://levelup.gitlab.com/learn/learning-path/scale-customer-success-engineer-cse-onboarding)
- [Sales Quick Start (SQS) Handbook Page](/handbook/sales/onboarding/)
- [#customer-success](https://gitlab.enterprise.slack.com/archives/C5D346V08) Slack Channel
- [Customer Success Enablement Issue Board](https://gitlab.com/gitlab-com/sales-team/field-operations/enablement/-/boards/4961994)
- [CSE Onboarding Feedback Issue](https://gitlab.com/gitlab-com/sales-team/field-operations/enablement/-/issues/2406)
