---
title: Workshops and Enablement Sessions
---

View the [CSM Handbook homepage](/handbook/customer-success/csm/) for additional CSM-related handbook pages.

---

## Overview

The CSM team's primary focus is to align with a customer's desired business outcomes, enable the customer in their current use cases, and expand their platform adoption.

Customers who adopt additional DevOps use cases with GitLab see an increased return on investment (ROI). They receive this ROI by increasing operational efficiencies, delivering better products faster, and reducing security and compliance risks.

One of the tools CSMs have to speed customer onboarding, increase user adoption, and drive stage adoption is to offer their customers **Workshops or Lunch-and-Learns** (generically referred to as enablement sessions).

## CSM-led Enablement and Expansion

**Use-case Enablement**: Enabling the use cases into which a customer expresses readiness to adopt as a part of their desired business outcome. CSMs enable customers by creating quick time to value, overcoming technical roadblocks, and ensuring stickiness. The CSM provides the customer with guidance on adopting use cases to maximize value attribution and to align adoption to the customer's desired positive business outcomes. CSM-led enablement can occur via workshops as listed below and is a part of the CSM-led customer success plan.

**Use-case Expansion**: Driving expansion into new use cases as a part of an account planning motion, in line with the SAE or AE, to ensure the customer receives increasing ROI and creates happy customers that grow. This motion starts with a discovery process to open the door to a more in-depth discovery, with demos and workshops focused on value-positioning that lead to the customer saying 'yes' and agreeing to adopt that use case. [The CSM can track this expansion within an existing success plan objective](/handbook/customer-success/csm/success-plans/#components-of-a-success-plan) or create a different objective to track this expansion initiative.

**Where do I track the use-case enablement and expansion?**
The steps to expand or enable on a use case are a part of the success plan, and are a part of a larger motion to drive towards a customer's desired business outcome [(leading to product adoption milestones being realized)](/handbook/customer-success/csm/success-plans/#components-of-a-success-plan)

## Frequency of Enablement Sessions

As often as needed.  For PR1 Customers, we look to see an enablement session at a minimum  every 6 months. For PR2, every 12 months.
The CSM first offers enablement sessions during onboarding so the customer is aware that they are available and the list of typical sessions that can be done.  Additionally, the CSM should offer a specific session when working with a customer on a use case enablement. The customer collaboration project now has a default issue that has the list of current offerings with a brief description.

Sessions should be [captured in Gainsight](/handbook/customer-success/csm/gainsight/timeline/#how-to-log-activities-in-timeline), which [drives the Engagement scorecard metric](/handbook/customer-success/csm/health-score-triage/#gainsight-scorecard-attributes-and-calculations).  Record the date and type of session it was as well as an approximate number of attendees.

## Type of sessions

There are two main types of sessions that can be offered.  Workshops are generally 1.5-2 hours and include the presentation, demo, and Q&A. These require more preparation and planning and are usually organized by the CSM in collaboration with other CSMs and SAs.

Enablement sessions are generally 1 hour and involve presentation, demo, and Q&A and are usually given by the CSM themselves.

### Currently available sessions

The following are already developed, have been given to multiple customers and are [available](https://drive.google.com/drive/folders/1NnDsqoc-KRdy7hF1jbo6H_59FwzpiKUc):

- **Intro to GitLab** *(for teams just starting with GitLab)* - General intro session that gives a high-level overview of GitLab
- **Developer Journey - Idea to Production** *(for developers, operations, security)* - Covers a typical workflow for a developer from getting assigned an issue to work on through creating the merge request, making changes and reviewing the pipeline results, and participating in code reviews
- **WebIDE and Markdown** *(for anyone looking to make changes to code or Pages)* - Covers what you can do with the built-in GitLab WebIDE to make changes to code, files, Pages directly from the GitLab web UI, as well as tips & tricks you can do with GitLab markdown in issues, merge requests, epics, Pages, etc.
- **Git Basics** *(for those who want to contribute on their local machine)* - Focuses on the command line interface into GitLab that a developer may need to pull/push code to/from the GitLab server
- **CI/CD Basics** *(for those who want to learn about automated build/test/deploy pipelines)* - Covers the basics of how to set up a pipeline to build, test, and deploy your code
- [**Advanced CI/CD**](/handbook/customer-success/workshops/ci-workshop/) *(for those interested in learning more about CI/CD)* - Requires basic CI/CD knowledge and covers advanced topics such as includes/extends, rules, child pipelines, and more (specific content will be curated)
- [**GitLab Security and Compliance**](/handbook/customer-success/workshops/secure/) *(for security, developers, managers, and PMs)* - Covers an overview of the security features including how developers see the scan results in the merge request and how security teams can review the results in the Security Dashboard
- [**DevSecOps Adoption Path**](https://gitlab.highspot.com/items/636013fdcba3439c837f10d7?lfrm=ssrp.1#1) *(for security & developers)* - A prescriptive and curated route to adopting GitLab Secure scanners to get the most ROI as quickly as possible with Secure. This is a great workshop for customers who are struggling with Secure adoption or are just beginning their journey on Ultimate and using GitLab Secure.
- **GitLab as a PM tool** *(for PMs, scrum masters, team leads, developers)* - Focuses on organization and use of epics, sub-epics, roadmaps, issues, labels, milestones, and boards
- **Issue, labels, and boards** *(for those interested in learning more about GitLab PM)* - Covers more tips & tricks on issues, labels, and boards and is good follow-on after the PM session
- **DevOps Metrics with GitLab** *(for managers, PMs, team leads)* - Goes over what the DORA4 metrics are, why it is useful to track them, and what is available in GitLab
- [**Innersourcing with GitLab**](/handbook/customer-success/workshops/innersource-workshop/) *(for teams interested in starting code-sharing initiatives internally)* - Goes over what is innersourcing, why it is useful, and what are the key things needed for success, followed by how to get started in GitLab
- **GitOps with GitLab** *(for teams looking to use GitLab for Infrastructure as Code)* - Goes over what is GitOps, how it is more than just Infrastructure as Code, what are the benefits, and how to get started with GitLab
- **GitLab Administration** *(for GitLab Admins of self-managed instances)* - Goes over GitLab components and architecture, installs, upgrades, admin area of the UI, common CLI commands, and back-ups
- **Permissions & Access with GitLab** *(for GitLab Admins of self-managed instances)* - Goes over permission access at the Group, Subgroup, Project, and Member levels, and discusses how to effectively tie access in with supported authentication protocols for on and offboarding
- **Administration on GitLab SaaS***(for GitLab Admins on GitLab.com)* - Goes over permissions, access, visibility, licensing, SaaS vs. Self Hosted, audit events and streaming, support, user activity, the future of GitLab Workspace, and all things that help admin roles using SaaS do their jobs

If you have additional sessions you want to contribute, please follow these instructions:

- Save the template deck to the [Lunch and Learns Google Drive folder](https://drive.google.com/drive/folders/1NnDsqoc-KRdy7hF1jbo6H_59FwzpiKUc) (eventually these will move to Highspot as our single source of truth)
- Update this handbook page to include the name of the session, intended audience, and a summary of the content/goals
- Update the [collaboration project template issue](https://gitlab.com/gitlab-com/account-management/templates/customer-collaboration-project-template/-/issues/44) to include the same

If you are interested in a session that doesn't exist yet, but you're not able or comfortable creating it, please post a message in [#tim-tams](https://gitlab.slack.com/archives/G8F1W2AGM) about what you would like to see!

### Offering the session

CSMs should offer sessions early during onboarding, and whenever working on a stage enablement. If the customer wants a session on a topic we do not already have slides for, request more time to prepare, and then work with the Customer Success team to help pull together some slides for the session. Then the newly created session can be added to the list of existing sessions available to other CSMs.

It is recommended to invite another GitLab team member to the session to help with notes, audience management (including obtaining screenshots of audience participants), and Q&A. This helper could be the Solutions Architect or Account Executive for the account, or it could be a fellow CSM.

Consider the typical length of the session when scheduling. It is recommended to coordinate with your champion on the following information:

- Who is hosting the session
- Will it be recorded
- Who is kicking it off

It is highly recommended to have someone from your regular cadence calls on the session, as some questions asked during the session may be specific to their instance configuration and they will need to answer those questions.

### Preparation for the session

The CSM should review the available content for [Workshops](https://drive.google.com/drive/folders/1qAymFTiXFEk-lRSNreIhaZ6Z62fdo_y2) and [Lunch-and-Learns](https://drive.google.com/drive/folders/1NnDsqoc-KRdy7hF1jbo6H_59FwzpiKUc) for the topic requested. CSMs can use the content as-is if they feel it will meet their needs or they can make a copy of the slides and customize it for their customer's needs.

CSMs should review the speaker notes to ensure they understand each slide, and add clarifications and notes to them as needed. Ensure you have a plan for what you want to communicate for each slide, but don't try to memorize what you are going to say.

Recordings of sessions that CSMs have previously run can be found [here](https://drive.google.com/drive/folders/11LeQbvUBwdqqWMplSb4iUTlxm7e7uXtD?usp=share_link) and may also be helpful to review as part of the preparation process.

### Conducting the session

Have your champion introduce you if possible. Use Presenter View in Google Slides to have the speaker notes available in a separate window. Run your slides off of your smaller monitor or on your MacBook screen if possible so the screen resolution is not an issue for participants with lower resolutions.

Introduce yourself and make sure you set ground rules if your champion did not.

For smaller groups (40), you can offer to allow them to come off mute to ask their questions.

For larger groups, it is recommended they put their questions in chat so you can address them at the appropriate time. It is recommended to pause periodically to take questions and also to ensure you stay hydrated during the session.

If you get lost or forget what to say, refer to your speaker notes. It is OK to read directly from them until you get back on track.  Feel free to reference other sessions that may cover a topic in more detail, even if you don't have that session planned, as this can generate demand for those sessions and lead to further user adoption and stage enablements. Also, if your customer is on Premium, don't shy away from mentioning Ultimate features during your presentation.

When you do pause for questions, try to answer them but it is OK to say you don't know and will research it and get the answer back to your champion. It is also OK if the question is answered in more detail in another session to simply refer to that session instead of taking too much time during the current one. It is not advised to give out your direct contact information to the audience and instead have them direct future questions to your champion.

### After the session

Send a copy of the slides used, and a link to the recording to your champion so they can share it with the participants and with those that could not attend the live session. Follow up on any question that could not be answered. Add a follow-up item to your next cadence call agenda to see what they thought went well and what could be improved for future sessions. Work to schedule other sessions based on demand. **IF there are participants you are not familiar with who attended the webinar, please follow up with your day to day contact to better understand if/how additional teams are using GitLab and what/if any trainings are needed.

## Session Notes

Similar to taking notes in a cadence call, it is useful to add to your running notes doc in each enablement session you run for the customer. Include a list of attendees, max participant count, record of questions and answers provided, and any follow-up items that were not addressed during the session

### Best Practices for Note-Taking & Planning

- Write down your *agenda* (including questions you want to ask). This way you can quickly add your notes for the specific context.
- If you're comfortable writing in [Markdown format](https://handbook.gitlab.com/docs/markdown-guide/), use it to quickly structure your notes in real time.
- Allow yourself time directly after the call to clean up your notes. Avoid scheduling back-to-back meetings.
- Practice slowing down call conversations. Stopping the dialog for a few seconds to say "let me write that down" tells the customer what they said is important to you.
- Ask your SAE/AE/SA to take notes with you. After the meeting combine and add detail.
- Use [Gong](https://us-81995.app.gong.io/home) to record your calls so there's less pressure for you to take note of everything.
- Sometimes it makes sense for somebody on the [account team](/handbook/customer-success/account-team/) to go back through the call in Chorus to transcribe it.
- Write notes in whatever is easiest and always copy them to your best source of truth. If you can write them in the source of truth in the first place, you'll be more efficient and consistent
- Leverage the [Workshop Planning Checklist](https://docs.google.com/document/d/1MQuIq8_QWvZJi_zKMzwkIf9Ewps4nezmcvQ6YuzomSA/edit) for planning calls with the customer
