---
title: "GitLab Product Training for Customer Success"
description: "As a Solutions Architect, Customer Success Manager, or Professional Services Engineer, it is important to be continuously learning more about our product and related industry topics. This handbook page provides an dashboard of aggregated resources that we encourage you to use to get up to speed."
---

## Overview of GitLab Product Training

As a Solutions Architect, Customer Success Manager, or Professional Services Engineer, it is important to be continuously learning more about our product and related industry topics. This handbook page provides an dashboard of aggregated resources that we encourage you to use to get up to speed. Although we aggregated and/or developed these resources for Customer Success team members, they are generic enough that all team members and partners can benefit from the education and enablement resources that we have published here.

## Overview of GitLab Feature and Use Cases

The GitLab product is organized based on the DevOps stages.

### DevOps Stages

If you're new to GitLab and the concept of "stages" are new to you, simply think of it as a category of related features that a customer finds value in with a **technical** narrative. The stages are organized in an infinite loop diagram to show the software development lifecycle from planning to development to release, with additional value for deployed applications with security and monitoring features. You can see a high-level overview of each stage on the [marketing page](https://about.gitlab.com/stages-devops-lifecycle/). Be sure to click the `Learn More` link for each stage to see more about the features of that stage.

One of the most helpful resources for understanding what GitLab does, the features in each stage, and how well the feature works is our [Category maturity](https://about.gitlab.com/direction/#maturity) chart. This may also be informally referred to as our "lovable feature chart".

If you understand what the stages are and want to dive deeper, you can look at the [product categories handbook page](/handbook/product/categories/) for a deep-dive on each of the stages, specifically the [hierarchy](/handbook/product/categories/#hierarchy) and the [DevOps Stages](/handbook/product/categories/#devops-stages).

For the purposes of education and enablement, we focus on the DevOps stages that the customer sees. There are additional stages that help GitLab as a business succeed, such as the [Growth stage](/handbook/product/categories/#growth-stage), [Fulfillment stage](/handbook/product/categories/#fulfillment-stage), [Enablement stage](/handbook/product/categories/#enablement-stage), and [Single Engineer Groups stage](/handbook/product/categories/#single-engineer-groups-section). Although these are not necessarily DevOps stages, the Engineering and Product departments use the stage terminology for consistency. **You do not need to spend time learning about these stages and can search for this information later if the need arises.**

## GitLab Product Topics

To align our education and enablement with our product, each of the topics below are grouped based on how GitLab product management and engineering defines it.

### DevOps Sections

---

#### Foundations Level

- [Dev Section Direction and Roadmap](https://about.gitlab.com/direction/dev/)
- [Ops Section Direction and Roadmap](https://about.gitlab.com/direction/ops/)
- [Security Section Direction and Roadmap](https://about.gitlab.com/direction/security/)

### Manage Stage

---

#### Foundations Level

- [Manage Stage Overview](https://about.gitlab.com/stages-devops-lifecycle/)
- [Manage Stage Direction and Roadmap](https://about.gitlab.com/direction/dev/#manage)

#### Intermediate Level

- [Value Stream Management Feature Docs](https://about.gitlab.com/solutions/value-stream-management/)
- [Audit Events Feature Docs](https://docs.gitlab.com/ee/administration/audit_events.html)
- [DevOps Reports Feature Docs](https://docs.gitlab.com/ee/administration/analytics/dev_ops_reports.html)
- [Code Analytics Feature Docs](https://docs.gitlab.com/ee/user/analytics/code_review_analytics.html)
- [Compliance Management Feature Docs](https://docs.gitlab.com/ee/administration/compliance.html)
- [Audit Reports Feature Docs](https://docs.gitlab.com/ee/administration/audit_reports.html)

### Plan Stage

---

#### Foundations Level

- [Plan Stage Overview](https://about.gitlab.com/stages-devops-lifecycle/plan/)
- [Plan Stage Direction and Roadmap](https://about.gitlab.com/direction/dev/#plan)

#### Intermediate Level

- [Issue Tracking Feature Docs](https://docs.gitlab.com/ee/user/project/issues/)
- [Time Tracking Feature Docs](https://about.gitlab.com/solutions/time-tracking/)
- [Boards Feature Docs](https://docs.gitlab.com/ee/user/project/issue_board.html)
- [Epics Feature Docs](https://docs.gitlab.com/ee/user/group/epics/)
- [Roadmaps Feature Docs](https://docs.gitlab.com/ee/user/group/roadmap/)
- [Requirements Management Feature Docs](https://docs.gitlab.com/ee/user/project/requirements/)
- [Quality Management Feature Docs](https://docs.gitlab.com/ee/ci/test_cases/index.html)
- [Design Management Feature Docs](https://docs.gitlab.com/ee/user/project/issues/design_management.html)

### Create Stage

---

#### Foundations Level

- [Create Stage Overview](https://about.gitlab.com/stages-devops-lifecycle/create/)
- [Create Stage Direction and Roadmap](https://about.gitlab.com/direction/dev/#create)

#### Intermediate Level

- [Source Code Management Feature Overview](https://about.gitlab.com/stages-devops-lifecycle/source-code-management/)
- [Source Code Management Direction and Roadmap](https://about.gitlab.com/direction/create/source_code_management/)
- [Code Review Feature Overview with 30+ Features](https://about.gitlab.com/stages-devops-lifecycle/create/)
  - [JIRA Integration Solution Overview](https://about.gitlab.com/solutions/jira/)
  - [JIRA Issues Integration Feature Docs](https://docs.gitlab.com/ee/integration/jira/)
  - [JIRA Development Panel Integration Feature Docs](https://docs.gitlab.com/ee/integration/jira/dvcs/)
  - [Multiple approvers in code review Feature Docs](https://docs.gitlab.com/ee/user/project/merge_requests/approvals/rules.html)
  - [Approval rules for code review Feature Docs](https://docs.gitlab.com/ee/user/project/merge_requests/approvals/rules.html)
  - [Merge request dependencies Feature Docs](https://docs.gitlab.com/ee/user/project/merge_requests/dependencies.html)
  - [Code Owners Feature Docs](https://docs.gitlab.com/ee/user/project/codeowners/)
- [Wiki Feature Docs](https://docs.gitlab.com/ee/user/project/wiki/)
- [Web IDE Feature Docs](https://docs.gitlab.com/ee/user/project/web_ide/index.html)
- [Live Preview Feature Docs](https://docs.gitlab.com/ee/user/project/web_ide/index.html#live-preview)
- [Snippets Feature Docs](https://docs.gitlab.com/ee/user/snippets.html)
- [Gitaly Source Code Project](https://gitlab.com/gitlab-org/gitaly)

### Verify Stage

---

#### Foundations Level

- [Verify Stage Overview](https://about.gitlab.com/stages-devops-lifecycle/verify/)
- [Verify Stage Direction and Roadmap](https://about.gitlab.com/direction/ops/#verify)
- [CI YouTube Playlist](https://youtube.com/playlist?list=PL05JrBw4t0Ko-mJZLo2uF3aQQuBfBaSKB)

#### Intermediate Level

- [Continuous Integration (CI) Feature Overview](https://about.gitlab.com/features/continuous-integration/)
  - [CI/CD Feature Docs](https://docs.gitlab.com/ee/ci/)
  - [CI/CD Concepts Docs](https://docs.gitlab.com/ee/ci/quick_start/)
  - [CI/CD Pipeline Docs](https://docs.gitlab.com/ee/ci/pipelines/)
  - [CI/CD Variables Docs](https://docs.gitlab.com/ee/ci/variables/)
  - [CI/CD Environments and Deployments Docs](https://docs.gitlab.com/ee/ci/environments/)
  - [CI/CD with Runners Docs](https://docs.gitlab.com/ee/ci/runners/)
  - [Auto DevOps Docs](https://docs.gitlab.com/ee/topics/autodevops/)
  - [CI/CD configuration with `.gitlab-ci.yml` Docs](https://docs.gitlab.com/ee/ci/yaml/)
  - [CI/CD authoring YAML reference for `.gitlab-ci.yml` Docs](https://docs.gitlab.com/ee/ci/yaml/)
  - [CI/CD Implementation Examples Docs](https://docs.gitlab.com/ee/ci/examples/)
  - [Migrate from CircleCI Docs](https://docs.gitlab.com/ee/ci/migration/circleci.html)
  - [Migrate from Jenkins Docs](https://docs.gitlab.com/ee/ci/migration/jenkins.html)
- [Code Quality Feature Docs](https://docs.gitlab.com/ee/ci/testing/code_quality.html)
- [Code Testing and Coverage Feature Docs](https://docs.gitlab.com/ee/ci/testing/unit_test_reports.html)
- [Load Testing Feature Docs](https://docs.gitlab.com/ee/ci/testing/load_performance_testing.html)
- [Browser Performance Testing Feature Docs](https://docs.gitlab.com/ee/ci/testing/browser_performance_testing.html)
- [Usability Testing Feature Docs](https://docs.gitlab.com/ee/ci/review_apps/#visual-reviews-starter)
- [Accessibility Testing Feature Docs](https://docs.gitlab.com/ee/ci/testing/accessibility_testing.html)
- [Merge Trains Feature Docs](https://docs.gitlab.com/ee/ci/pipelines/merge_trains.html)

### Package Stage

---

#### Foundations Level

- [Package Stage Overview](https://about.gitlab.com/stages-devops-lifecycle/package/)
- [Package Stage Direction and Roadmap](https://about.gitlab.com/direction/package/)

#### Intermediate Level

- [Package Registry Feature Docs](https://docs.gitlab.com/ee/user/packages/package_registry/)
- [Container Registry Feature Docs](https://docs.gitlab.com/ee/user/packages/container_registry/)
- [Helm Chart Registry Feature Docs](https://docs.gitlab.com/ee/user/packages/container_registry/#use-the-container-registry-to-store-helm-charts)
- [Dependency Proxy Feature Docs](https://docs.gitlab.com/ee/user/packages/dependency_proxy/)
- [Dependency Firewall Direction and Roadmap](https://about.gitlab.com/direction/package/#dependency-firewall)
- [Release Evidence Feature Docs](https://docs.gitlab.com/ee/user/project/releases/#release-evidence)
- [Git LFS - Feature Docs](https://docs.gitlab.com/ee/topics/git/lfs/index.html)

### Release Stage

---

#### Foundations Level

- [Release Stage Overview](https://about.gitlab.com/stages-devops-lifecycle/release/)
- [Release Stage Direction and Roadmap](https://about.gitlab.com/direction/delivery/)
- [CI/CD eBook](https://about.gitlab.com/resources/ebook-single-app-cicd/)
- [CI/CD YouTube Demo Overview](https://about.gitlab.com/blog/2017/03/13/ci-cd-demo/)

#### Intermeiate Level

- [Continuous Delivery Feature Overview](https://about.gitlab.com/features/continuous-integration/)
  - [See verify stage for full list of CI/CD resources](#verify-stage)
- [Pages Feature Overview](https://about.gitlab.com/stages-devops-lifecycle/pages/)
  - [Pages Feature Direction and Roadmap](https://about.gitlab.com/direction/plan/knowledge/pages/)
  - [Pages Feature Docs](https://docs.gitlab.com/ee/user/project/pages/)
- [Review Apps Feature Overview](https://about.gitlab.com/stages-devops-lifecycle/review-apps/)
  - [YouTube Webcast Feature Overview](https://www.youtube.com/watch?v=CteZol_7pxo&feature=youtu.be)
  - [Review Apps Direction and Roadmap](https://gitlab.com/groups/gitlab-org/-/epics/495)
  - [Review Apps Feature Docs](https://docs.gitlab.com/ee/ci/review_apps)
- [Advanced Deployments Feature Docs](https://docs.gitlab.com/ee/topics/autodevops/index.html#incremental-rollout-to-production-premium)
- [Feature Flags Feature Docs](https://docs.gitlab.com/ee/operations/feature_flags.html)
- [Release Orchestration Feature Docs](https://docs.gitlab.com/ee/user/project/releases/)

### Configure Stage

---

#### Foundations Level

- [Configure Stage Overview](https://about.gitlab.com/stages-devops-lifecycle/configure/)
- [Configure Stage Direction and Roadmap](https://about.gitlab.com/direction/delivery/)

#### Intermediate Level

- [Auto DevOps Feature Overview](https://about.gitlab.com/stages-devops-lifecycle/auto-devops/)
- [Auto DevOps Feature Docs](https://docs.gitlab.com/ee/topics/autodevops/)
- [Kubernetes Management Feature Overview](https://about.gitlab.com/solutions/kubernetes/)
- [Secrets Management CI Variable Docs](https://docs.gitlab.com/ee/ci/variables/)
- [ChatOps Feature Docs](https://docs.gitlab.com/ee/ci/chatops/)
- [Serverless Feature Overview](https://about.gitlab.com/topics/serverless/)
- [Infrastructure-as-Code Feature Docs](https://docs.gitlab.com/ee/user/infrastructure/)

### Monitor Stage

---

#### Foundations Level

- [Monitor Stage Overview](https://about.gitlab.com/stages-devops-lifecycle/monitor/)
- [Monitor Stage Direction and Roadmap](https://about.gitlab.com/direction/monitor/)

#### Intermediate Level

- [Runbooks Feature Docs](https://docs.gitlab.com/ee/user/project/clusters/runbooks/)
- [Incident Management Feature Docs](https://docs.gitlab.com/ee/operations/incident_management/)
- [Error Tracking Feature Docs](https://docs.gitlab.com/ee/operations/error_tracking.html)
- [Product Analytics Feature Docs](https://docs.gitlab.com/ee/user/product_analytics/)
- [Service Desk Feature Docs](https://about.gitlab.com/stages-devops-lifecycle/service-desk/)

### Secure Stage

---

#### Foundations Level

- [Secure Stage Overview](https://about.gitlab.com/stages-devops-lifecycle/secure/)
- [Secure Stage Direction and Roadmap](https://about.gitlab.com/direction/secure/)

#### Intermediate Level

- [Static Application Security Testing (SAST) Feature Docs](https://docs.gitlab.com/ee/user/application_security/sast/)
- [Dynamic Application Security Testing (DAST) Feature Docs](https://docs.gitlab.com/ee/user/application_security/dast/)
- [Fuzz Testing Feature Docs](https://docs.gitlab.com/ee/user/application_security/coverage_fuzzing/)
- [Dependency Scanning Feature Docs](https://docs.gitlab.com/ee/user/application_security/dependency_scanning/)
- [License Compliance Feature Docs](https://docs.gitlab.com/ee/user/compliance/license_scanning_of_cyclonedx_files/)
- [Secret Detection Feature Docs](https://docs.gitlab.com/ee/user/application_security/secret_detection/)
- [Vulnerability Management Feature Docs](https://docs.gitlab.com/ee/user/application_security/security_dashboard/)

### Govern Stage

---

#### Foundations Level

- [Software Supply Chain Security Stage Overview](https://about.gitlab.com/stages-devops-lifecycle/govern/)
- [Software Supply Chain Security Stage Direction and Roadmap](https://about.gitlab.com/direction/software_supply_chain_security/)

#### Intermediate Level

- [Container Scanning Feature Docs](https://docs.gitlab.com/ee/user/application_security/container_scanning/)

### Kubernetes Certification

---

#### Foundations Level

- [Kubernetes for Beginners Udemy Training](https://www.udemy.com/course/learn-kubernetes/)
- [CKA Udemy Training](https://www.udemy.com/course/certified-kubernetes-administrator-with-practice-tests/)
- [CKAD Udemy Training](https://www.udemy.com/course/certified-kubernetes-application-developer/)

#### Intermediate Level

- [Kubernetes Documentation](https://kubernetes.io/docs/home/)

#### Advanced Level

- [CKA Certification](https://training.linuxfoundation.org/certification/certified-kubernetes-administrator-cka/)
- [CKAD Certification](https://training.linuxfoundation.org/certification/certified-kubernetes-application-developer-ckad)
- [CKS Certification](https://training.linuxfoundation.org/certification/certified-kubernetes-security-specialist/)

### Infrastructure-as-Code

#### HashiCorp Terraform

---

#### Foundations Level

- [Hashicorp Learn Tutorials](https://learn.hashicorp.com/terraform)
- [GitLab Terraform Integration Docs](https://docs.gitlab.com/ee/user/infrastructure/)

#### Intermediate Level

- [Terraform Docs](https://developer.hashicorp.com/terraform/docs)
- [Terraform AWS Provider Docs](https://registry.terraform.io/providers/hashicorp/aws/latest/docs)
- [Terraform GCP Provider Docs](https://registry.terraform.io/providers/hashicorp/google/latest/docs)
- [Terraform GitLab Provider Docs](https://registry.terraform.io/providers/gitlabhq/gitlab/latest/docs)
- [GitLab Sandbox Cloud](/handbook/company/infrastructure-standards/realms/sandbox/#how-to-get-started)
- [GitLab Demo Systems Terraform Modules](https://gitlab.com/gitlab-com/demo-systems/terraform-modules)

#### Advanced Level

- [Terraform Associate Certification](https://www.hashicorp.com/certification/terraform-associate)

### HashiCorp Vault

---

#### Foundations Level

- [Hashicorp Learn Tutorials](https://learn.hashicorp.com/terraform)

#### Intermediate Level

- TODO

#### Advanced Level

- [Vault Associate Certification](https://learn.hashicorp.com/terraform)

### HashiCorp Consul

---

#### Foundations Level

- [Hashicorp Learn Tutorials](https://developer.hashicorp.com/consul/tutorials)

#### Intermediate Level

- TODO

#### Advanced Level

- [Consul Associate Certification](https://www.hashicorp.com/certification/consul-associate)

## O'Reilly Content Library

In order to facilitate an environment of learning and development, the Customer Success Team has access to the O'Reilly Learning Platform, which is integrated into [GitLab Learn](https://gitlab.edcast.com/log_in?auto_sso=true).  This content library contains thousands of books, videos and live learning courses to assist team members' with professional development and staying up-to-date with changing technology trends. Additionally, code sandboxes are included within the O'Reilly platform that team members's can utilize to practice new skills or hone existing ones.

To get started, here is a quick tour of what the O'Reilly Learning Platform can provide to our team, please check out this [short introductory video](https://www.loom.com/share/fca91ca4e127494fb5f4130b85eaa9ea).

If you do not already have a login are outside of the customer success organization, please let the Corproate Learning and Development Team know you are interested. You can also purchase a single licesne with the GitLab pricing by contacting Jason Baca at jbaca@oreilly.com.

### O'Reilly Answer Slack Bot

As part of GitLab's O'Reilly subscription, team members have access to the O'Reilly Answer Slack Bot. To get started, in Slack, just type `/oreilly-answers` followed by your tech question. It's that simple.

For example:

- `/oreilly-answers` How do I fine-tune a model?
- O'Reilly Answers will respond to your question with highly relevant snippets of content right within Slack.

**More Answers**

Use the "More Answers" button to flip through the suggested answers. O'Reilly will show a maximum of 8 possible answers and you'll be taken back to the first answer when you get to the end.

**Full Text**

To read the full text of an answer in context click the "Full Text" button and you'll be taken directly to that snippet of content within the O'Reilly Learning platform.

**Share Answers**

To share a helpful answer with others in Slack click the "Post" button and the answer you selected will be posted to the channel where you asked the question.

If you want to share an answer in a private channel you'll need to invite the O'Reilly Answers app to the channel first. Simply type: /invite @O'Reilly Answers

If you want to share an answer in a direct message you'll need to create a group message and include O'Reilly Answers in the group. You can add O'Reilly Answers the same way you would add another person.

## Additional Resources

- [Field Enablement Handbook Page](/handbook/sales/field-operations/field-enablement/)
- [Field Accreditation Handbook Page](/handbook/sales/training/field-certification/)
- [Sales Training](/handbook/sales/training/)
- [Communities of Practice](/handbook/customer-success/initiatives/communities-of-practice/)
- [Learn at GitLab](https://about.gitlab.com/learn/)
- [GitLab Releases](https://about.gitlab.com/releases/)
