---
title: Customer Success Playbooks
---

View the [Customer Success homepage](/handbook/customer-success/) for additional Customer Success handbook content.

---

Customer Success playbooks assist in selling, driving adoption, and ultimately delivering more value to customers via GitLab's DevOps platform. The below playbooks will include original content as well as links to other parts of the handbook.

## Structure of Playbooks

**Procedure**: Each Playbook contains the outline of steps to position, apply discovery questions, lead value discussions, and drive adoption (CSM only). The will be driven and tracked [via Gainsight](/handbook/customer-success/csm/gainsight/).

**Positioning**: Stage and use case value proposition and positioning with supporting collateral linked within Gainsight CTAs and Playbooks.

- Market requirements, personas, and differentiators
- Top features, stages, and categories
- Competitive assessments
- Customer slides
- Proof points, blogs, and customer success stories

**Discovery**: Discussion tools (e.g., discovery questions) using Command Plan approach.

**Adoption**: Adoption-related reference materials to accelerate adoption.

- Adoption map, noting recommend recommended features / use cases and sequence of adoption (where applicable)
- Analytics Instrumentation attributes to track adoption
- Product documentation (Content owner: Product and Engineering Teams)
- Enablement and training assets
- Paid services

## Types of Playbooks

- **Risk**: Represents negative trends with customers. Examples include low license utilization, non-engaged customer and product risk.
- **Event/Lifecycle**: Lifecycle-based and typically scheduled events. Examples include onboarding, EBRs, and success planning.
- **Opportunity/Expansion**: Enablement/Expansion which is tied to revenue and/or product growth. Examples include stage adoption and uptiering.
- **Objectives**: Tied to Success Plans and can only be created in C360 > Success Plans section.
- **Activity**: Tied to 360 Timeline Activities. Activity is generally used as the default CTA type for CTAs created from the Timeline feature automatically. Users can also create CTAs of this type from the Cockpit page. Example includes account handoff.
- **Digital Journey**: Represents the Customer Digital Journey content. Examples include digital onboarding and adoption email series.

## Catalog of Playbooks

The following playbooks are aligned to our [customer adoption journey](/handbook/customer-success/customer-success-vision/#high-level-visual-of-gitlab-adoption-journey) and support adoption of the related customer capability and [GitLab stage](/handbook/product/categories/). Within Gainsight, the CSM can manually add any Playbook ([instructions](/handbook/customer-success/csm/gainsight/#ctas)) to a Customer.

| Playbook Name                                                   | Automated/Manual | Type            | Internal Reference Link                                      |
|-----------------------------------------------------------------|------------------|-----------------|--------------------------------------------------------------|
| At-Risk                                                         | Automated        | Risk            |                                                              |
| Low License Utilization                                         | Automated        | Risk            |                                                              |
| Non-Engaged Customer                                            | Manual           | Risk            |                                                              |
| Product Risk                                                    | Manual           | Risk            |                                                              |
| Risk Escalation                                                 | Manual           | Risk            | [Opening an At-Risk CTA](/handbook/customer-success/csm/health-score-triage/#triage-cta)                                         |
| Create Success Plan                                             | Automated        | Lifecycle       |                                                              |
| Customer Offboarding                                            | Automated        | Lifecycle       |                                                              |
| Executive Business Review (EBR)                                 | Automated        | Lifecycle       | [EBR in a Box](https://drive.google.com/open?id=1wQp59jG8uw_UtdNV5vXQjlfC9g5sRD5K)                                             |
| High License Utilization: Growth Opportunity                    | Automated        | Lifecycle       |                                                              |
| New Customer Digital Onboarding: SaaS Email Series              | Manual           | Lifecycle       |                                                              |
| New Customer Digital Onboarding: Self-Managed Email Series      | Manual           | Lifecycle       |                                                              |
| New Customer Onboarding                                         | Automated        | Lifecycle       |                                                              |
| Onboarding Pilot                                                | Automated        | Lifecycle       |                                                              |
| Usage Data Enablement                                           | Manual           | Lifecycle       | [Service Ping FAQ](/handbook/customer-success/csm/service-ping-faq/)                                               |
| Agile Enablement Stage Adoption                                 | Manual           | Objective       |                                                              |
| Agile Expansion Stage Enablement                                | Manual           | Objective       |                                                              |
| CD Enablement Stage Adoption                                    | Manual           | Objective       | [Continuous Delivery/Release](/handbook/customer-success/playbooks/cd-release/)                                  |
| CD Expansion Stage Adoption                                     | Manual           | Objective       |                                                              |
| CI Enablement Stage Adoption                                    | Manual           | Objective       | [Continuous Integration/Verify](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/ci/) <br> [CSM CI Workshop](/handbook/customer-success/playbooks/ci-verify/)               |
| CI Expansion Stage Adoption                                     | Manual           | Objective       |                                                              |
| Configure Enablement Stage Adoption                             | Manual           | Objective       |                                                              |
| Configure Expansion Stage Adoption                              | Manual           | Objective       |                                                              |
| Create Enablement Stage Adoption                                | Manual           | Objective       | [Source Code Management (SCM)/Create Stage](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/version-control-collaboration/)                    |
| Create Expansion Stage Adoption                                 | Manual           | Objective       |                                                              |
| DevSecOps Enablement Stage Adoption                             | Manual           | Objective       | [DevSecOps/Security](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/devsecops/)                                           |
| DevSecOps Expansion Stage Adoption                              | Manual           | Objective       |                                                              |
| Geo Implementation                                              | Manual           | Objective       | [Info Sheet](https://docs.google.com/document/d/1Gn93NUWq4RxPvfxJRodEyvb-6-dLqUV6euPV8k9yIvw/edit)<br> [Discovery Questions](https://docs.google.com/document/d/1KgSHHsYFHPB__xA9rlUEbLBRYDlPl6FyKzn1V8I2Wfk/edit)<br>[Implementation Tips and Tricks](https://docs.google.com/document/d/1EhXT-_Wf0GrmDSh2vthca0sl6bWb-1hQruv2lHd4aFs/edit?ts=60356ba2) |
| Improve Cycle Time (Lead Time for Changes)                      | Manual           | Objective       |                                                              |
| Increase Deployment Frequency                                   | Manual           | Objective       |                                                              |
| Manage Enablement Stage Adoption                                | Manual           | Objective       |                                                              |
| Manage Expansion Stage Adoption                                 | Manual           | Objective       |                                                              |
| Monitor Enablement Stage Adoption                               | Manual           | Objective       |                                                              |
| Monitor Expansion Stage Adoption                                | Manual           | Objective       |                                                              |
| Package Enablement Stage Adoption                               | Manual           | Objective       |                                                              |
| Package Expansion Stage Adoption                                | Manual           | Objective       |                                                              |
| Selling Ultimate to New Customers                               | Manual           | Objective       | [Handbook link](/handbook/solutions-architects/sales-plays/)                                               |
| Server Migration - On-Prem to On-Prem                           | Manual           | Objective       | [GitLab Server Migrations Playbook](https://docs.google.com/spreadsheets/d/1cP6czE6zZ9EWT5HGOF2MGP2repiV0GI8a8V2i9iK9vM/edit#gid=0)                            |
| Server Migration - On-Prem to Self-Managed Cloud                | Manual           | Objective       | [GitLab Server Migrations Playbook](https://docs.google.com/spreadsheets/d/1cP6czE6zZ9EWT5HGOF2MGP2repiV0GI8a8V2i9iK9vM/edit#gid=0)                               |
| Server Migration - On-Prem/Cloud to K8S                         | Manual           | Objective       | [GitLab Server Migrations Playbook](https://docs.google.com/spreadsheets/d/1cP6czE6zZ9EWT5HGOF2MGP2repiV0GI8a8V2i9iK9vM/edit#gid=0)                               |
| Server Migration - Self-Managed to GitLab SaaS                  | Manual           | Objective       | [GitLab Server Migrations Playbook](https://docs.google.com/spreadsheets/d/1cP6czE6zZ9EWT5HGOF2MGP2repiV0GI8a8V2i9iK9vM/edit#gid=0)                               |
| Ultimate Uptier for Existing Customers                          | Manual           | Objective       | [Handbook link](/handbook/solutions-architects/sales-plays/)                                                |
| Account Handoff                                                 | Manual           | Activity        |                                                              |
| Update Stale CSM Sentiment                                      | Manual           | Activity        |                                                              |
| Upcoming Renewal                                                | Automated        | Renewal         |                                                              |
| Digital Adoption - CI Enablement                                | Manual           | Digital Journey |                                                              |
| Digital Onboarding - SaaS Email Series                          | Manual           | Digital Journey |                                                              |
| Digital Onboarding - Self-Managed Alternative Backup Strategies | Manual           | Digital Journey |                                                              |
| Digital Onboarding - Self-Managed Email Series                  | Manual           | Digital Journey |                                                              |
| Digital Onboarding - Welcome Email                              | Manual           | Digital Journey |                                                              |
| CSM Account Transitions                                         | Manual           | Digital Journey |                                                              |
| Find an Executive Sponsor                                         | Manual           | Objective |                                                              |
| Engage an Executive Sponsor                                         | Manual           | Objective |                                                              |

CSMs create playbooks to provide a prescriptive methodology to help with customer discussions around certain aspects of GitLab. We currently have a [Stage Adoption Guideline](/handbook/customer-success/csm/stage-adoption/) to assist with understanding where a customer stands, and we are working on merging adoption maps into the use case pages.
