---
title: "Professional Services EM Scoping Guidelines"
description: "Describes the process of scoping PS engagements."
---

## Scoping Information

We use the [Engagement Estimate TEMPLATES](https://docs.google.com/spreadsheets/d/1YKMyflzsA-VPEVobB82zC8-n0hlC-uRBtiNB7Fm-kZg/edit?usp=sharing) workbook as a starting point for determining the activities, duration, and price of a Professional Services opportunity.

Professional services opportunities with estimates totaling more than $50,000 USD require that the scoping issue be reviewed by a Technical Architect before an SOW is created. The Engagement Manager should add the `TA::Needs-Review` label to any scoping issue with an estimate greater than $50,000.  Once the TA has reviewed the estimate, they will change the label to `TA:Approved` to indicate that they have reviewed and approved the scoping issue.

When an Engagement Manager needs help with scoping due to complex technical requirements or other factors that need technical input, they can add the `Scoping::Needs_TA_Assistance` label to the scoping issue.  This label can be used to request that a TA join a scoping call or provide input on a technically complex solution proposal. A Technical Architect's assistance should be requested for any scoping issue or conversation related to GitLab architecture, assessing performance issues for a current implementation, requests for monitoring, or other technical implementation topics.

Applying this label will add the scoping issue to the [TA Board](https://gitlab.com/gitlab-com/customer-success/professional-services-group/ww-consulting/ps-plan/-/boards/4566296?label_name[]=Services%20Calculator).  The Engagement should also signal in slack, by mentioning `@ps-ta` that help is being requested, and provide additional details for the TAs to follow up on.

Once a TA has provided the requested assistance, they will change the label to `Scoping::TA_Assisted`.  Using these labels consistently will provide better visibility into the opportunities that currently require TA assistance, as well as historical data on the opportunities that have required TA involvement.

## Scoping Specific Types of Services

See the detailed notes pages for each service type below.

- [GitLab implementation scoping](/handbook/customer-success/professional-services-engineering/engagement-mgmt/scoping-information/implementation/)
- [GitLab Readiness Assessment (Health Check)](/handbook/customer-success/professional-services-engineering/engagement-mgmt/scoping-information/readiness/)
- [GitLab migration scoping - GitLab, Bitbucket Server, or GitHub (Enterprise or .com) -> GitLab](/handbook/customer-success/professional-services-engineering/engagement-mgmt/scoping-information/migrations/)
- [CI pipeline migration scoping](/handbook/customer-success/professional-services-engineering/engagement-mgmt/scoping-information/ci-pipeline/)
- [Transformational Services scoping](/handbook/customer-success/professional-services-engineering/engagement-mgmt/scoping-information/transformational-services/)

## Escalations in Scoping

There may be times when the EM and/or TA disagree with a solution approach that a customer has proposed for Professional Services.  In these cases, the scope should be escalated with the account team (SAE/AE, SA, CSM) by following these steps:

1. Schedule an internal call with the account team (SAE and CSM or SA depending on who you've been working with on scoping, possibly both).  Both the TA and EM should attend the internal call.
1. Lay out your reasoning for thinking the current solution path is not the correct path
1. Define alternate solutions that would be a better fit
1. Agree with account team on a communication plan with the customer, next steps, and the DRI for communication
