---
title: "Developing Software for Professional Services"
description: "Discover how professional services develops software."
---

Professional Services has a series of tools and applications that assist with our day-to-day operations and delivering services.

We strive for our tooling and applications to follow some common design structure patterns.

All of our tooling resides within the [Professional-Services-Automation](https://gitlab.com/gitlab-org/professional-services-automation) group on gitlab.com

## Standard Setup

## Python

We use Python for the majority of our backend development. Our dependency manager of choice is [Poetry](https://python-poetry.org/).

### REST API

Our default REST API framework is [Flask](https://flask.palletsprojects.com/en/2.2.x/).

### Default Libraries

Outside of the testing libraries list [below](#local-testing), we have a common utilities library called [GitLab PS Utils](https://gitlab.com/gitlab-org/professional-services-automation/gitlab-ps-utils) that contains several helper functions and classes to speed up prototyping and development time.

## Javascript

We use Javascript for any frontend development. Our Javascript framework of choice is [Vue.js](https://vuejs.org/). We manage our Javascript dependencies with NPM and manage our Node/NPM installations through [NVM](https://github.com/nvm-sh/nvm).

## Databases

We use MongoDB or DynamoDB. We interface with MongoDB using [PyMongo](https://pymongo.readthedocs.io/en/stable/) and DynamoDB with [PynamoDB](https://pynamodb.readthedocs.io/en/stable/).

## Local Testing

If we need to mock any AWS resources outside of AWS, we use [Localstack](https://localstack.cloud/).

For python testing, we use a mix of Pytest, mock, and unittest.

## Packaging and Deployments

We package our tools into Docker images or Pip packages. Our [evaluate](https://gitlab.com/gitlab-org/professional-services-automation/tools/utilities/evaluate) tool, for example, is packaged up into both. All our docker images are deployed to the tool's container registry on GitLab.com.

If we need to deploy any serverless WSGI-based applications to AWS, we use [Zappa](https://github.com/zappa/Zappa)

## Example folder structure

```bash
└── ps-tool              # Root of git repo
    ├── Dockerfile       # Dockerfile for packaging
    ├── ps-tool          # Python source directory
    │   ├── ...          # Any python code
    │   └── __init__.py
    ├── LICENSE
    ├── poetry.lock      # File generated by Poetry listing all installed packages. Must be source controlled
    ├── pyproject.toml   # Dependency file used by Poetry to track dependencies
    └── README.md
```
