---
title: "Remote Training Facilitation Best Practices"
description: "Find some tips and lessons learned for delivering a successful GitLab remote training ."
---

Making the transition from onsite trainer to remote trainer can be a challenge — there's a lot more you need to do to keep people engaged when the distractions of email, slack, browsing, and environment are outside of our direct control. Here are some tips and tricks developed by the GitLab Professional Services team, for presenters facilitating remote training sessions using video conferencing and webinar tools.

### Tips

#### Tip 1: Turn on video for all participants as appropriate

When you can see participants it keeps them accountable for paying attention, and you'll be able to observe the non-verbal cues indicating a wane in attention. On the other hand, if you have a large number of participants, having everyone's video on at the same time can be distracting -- in that case, you can invite specific participants to turn on their video when they are speaking. Also keep in mind that some participants may not be comfortable with sharing their video -- be sensitive to this and do not make video sharing a requirement.

#### Tip 2: Take frequent breaks

If your session will last more than 90 minutes, build in a break at least every 60 - 75 minutes. Let attendees know what time they need to return, and request they indicate their return by turning their video back on and/or raising their virtual hand (if that tool is available in our video conferencing software).

#### Tip 3: Break up a full day into two days

For a session you would normally deliver in 1 day onsite, break it up into two 3-4 hour sessions on two separate days. In between the days you can assign homework so that attendees can practice applying what they learned or complete pre-work ahead of the second session.

#### Tip 4: Ask frequent questions

At least every 10-15 minutes, ask attendees a question they must respond to. You can ask them as a group and wait for volunteers to answer. But if you're not getting a variety of attendees participating in providing responses to your questions, your next go-to approach is to randomly call on a participant individually to answer a question. This will motivate everyone to pay attention so that they are prepared when you pick on them. You might also consider employing the "attention getters" meaning smartphones, and have a session manager send questions as text messages to the learners' phones. In this way, the learners have learning collateral with them during and after the class session.

#### Tip 5: Encourage attendees to ask questions

At the beginning of the session show attendees how to ask questions using your video conferencing tools, whether that is virtually raising their hand or submitting questions using a Chat or a Q&A tool. Take frequent designated Q&A breaks at least once or twice per 60 minutes of instruction. In terms of the kind of questions you elicit, you may want to get to a point where the audience is not regurgitating the past. Rather, your learners begin to intuit what might be possible, and in that way, they begin to project their intuitions about the concept into the future. This type of engagement by the learners creates positive instructional opportunities, which can reduce learners' resistance to public speaking and improve observable attentiveness (e.g. smiling, nodding, shaking the head, using reactions, and chatting to everyone with questions).

#### Tip 6: Have a team member join as a moderator

A team member can play the role of session manager, managing questions coming in from the chat and being timekeeper, reminding you of breaks and Q&A points.

#### Tip 7: Minimize the text on your slides

- Avoid using text on your slides and use them as visuals to reinforce your key points.
- Include notes for yourself in the presenter notes area of your slides but use these only as key points -- do not read them out loud verbatim. Your audience will be turned off listening to you read.
- Provide attendees with access to the slides as soon as possible after the session.

#### Tip 8: Build in frequent activities

Include at least one activity for each hour of instruction. If possible, adjust the flow of your content so that attendees can jump right into their first activity within the first 20 minutes of your session.

### Tricks

Here are some of our go-to techniques to encourage remote engagement and collaborative learning.

#### Group note taking

- Create a shared Agenda/Notes document, for example a Google doc, and include the link to the file for all attendees to access.
- Populate the document with an outline of the topics you plan to cover.
- Direct attendees to take on group responsibility for taking notes during the session, especially when you are answering questions so that your responses are captured in the file.
- Make the file available to attendees after the session for their reference.
- If you have a post-session quiz you can include the link in this document.

#### Pinning

If your video conferencing software includes "pinning" capabilities, use these to your advantage to increase participant attentiveness.

- Adjust the settings so that as the presenter your video is always pinned as the main or largest video window during the presentation portions of the session.
- When you reach Q&A or interactive sections of the session, adjust your video setting again so that the active speaker's video is always displayed largest.
- When calling on specific attendees to answer a question, pin their individual video so that it is the largest one displayed.
- If your video conferencing software includes "panelist" and "attendee" roles which control who can display video, promote selected attendees to "panelist" so they can turn on their video as they respond to your question live.

#### Polls

If your video conferencing software includes "polling" capabilities, use them to increase engagement and interest.

- Set up polling questions in advance of the session and plan specific points in your session flow to display each question.
- Introduce each polling question and ask all attendees to participate in responding.
- Give attendees 30-60 seconds to respond, giving them a time check about 10 seconds prior to closing the poll
- Display the results of the poll for all attendees to view
- Share your thoughts about the poll results and connect the results to the topics you are about to cover.

#### Recording

- Record the session and make it available to attendees as well as individuals who registered but were unable to attend the live session.
- To ensure compliance with privacy laws, if your attendees are not employees of your organization, adjust your recording settings so that attendee video, names, and in-session chat messages are not recorded. During the session avoid using attendees' full names when calling on participants.
- Make the recording available in an asynchronous learning environment to scale availability of the training beyond current registrants and attendees.

#### Chat/Q&A pinning

Be sure to practice ahead of time with pinning your video conferencing Chat or Q&A panes to your window while you are in presenter mode with your presentation slides. This will enable you to quickly bring these panes into view so you can see questions coming in and respond in a timely manner during the session. Most video conferencing systems offer a variety of options for doing this whether you have dual monitors or a single monitor (for example, here are recommendations for pinning Chat while sharing a presentation in Zoom).

#### Taking and ending breaks

- When it's time to take a break, let attendees know what time they need to return.
- Add a note into your Q&A or Chat tool to indicate you are on a break and what time attendees should return.
- When the break is finished, ask attendees to use the "raise hand" tool to indicate they are back if you aren't able to see everyone on video.

#### Avoid too much of a good thing

- If your video conferencing platform offers multiple tools for communicating with participants -- for example Chat and Q&A -- consider using just one of these tools instead of both. This will reduce complexity and make it easier for participants to have all communication in one place. Zoom Webinars allows you to restrict Chat to panelist usage so that attendees can only use the Q&A tool for communicating their questions.
- Use a mixture of lectures, questions, discussions, demos, and lab activities. Don't rely on just one technique -- participants can become bored when too much time is spent using one method. On the other hand, avoid too much mixing or alternating too frequently between techniques, which can become disjointed or confusing for participants. It's all about finding the right balance for your audience.

#### Share the content, not your screen

Adhering to the F-shaped pattern for reading, it makes little sense to share your full screen. This UX rule may affect the way in which presentation content is developed: minimize the amount of right, white space that the learners need to see. Also, when presenting content, employ the F-shaped rule where the first line is the topic, and the following 2-3 lines are supporting sentences. From a development perspective, presentations with bullets would only include 3-5 topics, with supporting content in the presentation's speaker's notes.

#### If you're sharing your Terminal window, share your Terminal window

Our Terminals are our babies, and we nurture them with beautiful styles including backgrounds, fonts, and sizes. But if we consider what this looks like to our learners, who are limited by the size of their monitors and Zoom windows (you're showing a window in a window), our babies look like small, malformed, screen blips. What we need to do is increase the font size and create better contrast between the background and the font color. Also, as system log messages often print in a different color then your input text, be sure to configure the sys log output as well.
