---
title: "Services to Accelerate Customer Adoption"
description: "Discover the customer benefits and value of working with GitLab Professional Services."
---

## Overview

This [sales enablement](/handbook/sales/training/sales-enablement-sessions/) page is designed to help the GitLab Sales team understand our professional services offerings, how to [position](/handbook/customer-success/professional-services-engineering/positioning/) them to customers, and the [workflow for selling](/handbook/customer-success/professional-services-engineering/selling/) services.

### Resources

- Watch the live version of the [Sales Enablement Level Up Webcast](https://youtu.be/_04S2JhVZ5A) recorded on April 9, 2020.
- Check out the [enablement deck](https://docs.google.com/presentation/d/1VGfUC85NO74S5qaaNZ1yQydhZL3Be4ofBTG52xr_LEA/edit#slide=id.) used in this presentation. (Note: internal link)

<!-- ## Learning Objectives

1. Why sell Professional Services?
1. Services Portfolio
1. Current state & improvements
1. Services: Positioning and Process
1. Where to go for help -->

## Professional Services: What, Why and How

### What

So you've won a customer's business with a subscription deal to use gitlab, congratulations! Now you can focus on establishing a foundation of trust to grow the relationship. In order for your customer to get the most out of GitLab consider engaging them with professional services.

Our team can help your customer accelerate their DevOps Transformation by delivering services to improve operational efficiency, accelerate time to market and reduce risk through GitLab product adoption.

We accomplish these by offering [categories of services](/services/) to help ensure the initial GitLab rollout goes smoothly so the end users can get value as fast as possible.

#### Migration Services

We offer data and user [migration services](/services/migration/) to enable the customer to come from a variety of legacy systems (both SCM and CI/CD). We work closely with the GitLab import API team and have automation tools to facilitate the migration. We are continuously improving them with every nuanced customer migration service we provide. Read about a customer case study of a recent GitLab self managed to gitlab.com migration experience.

Migration services are always custom-scoped because of the variability of level of effort based on the amount of data and number of users in the source system(s).

#### Implementation Services

When customers choose GitLab self-managed, they typically need help building and configuring their software to meet their non-functional requirements (e.g. Availability, Performance, Security, Disaster Recovery, etc.). Our team of experts maintains a repository Infrastructure-as-Code and automation scripting to facilitate this while leveraging [gitlab reference architecture](https://docs.gitlab.com/ee/administration/reference_architectures/) best practices.

For gitlab.com users, [implementation services](/services/implementation/) focus mostly on how to organize GitLab groups and projects, how to establish role based access control, and other front end strategic decisions that typically need to be made up-front.

The implementation services [Rapid Results](/services/rapid-results/) packages have a standard SKU, but have specific bounds to the large cloud service providers and HA/DR architectural patterns. If your customers' needs fall outside of those bounds, you will need to engage in a [custom-scoping exercise](/handbook/customer-success/professional-services-engineering/selling/#custom-scoped-services).

#### Education Services

As with any new software being introduced at a company, users tend to need training to know how to use it. We have excellent [education services](/services/education/) that span the spectrum of basics to advanced; administrators to general users. All of our education services have standard SKUs, which makes the process easy for the ISR/SAE to offer to a customer.

#### Integration Services

Customers tend to have tools and systems with which they need to establish integrations. We offer [integration services](/services/implementation/integration/) for customers who need systems like LDAP, Jira, Jenkins, etc. to work with gitlab.

#### Advisory Services

Advisory services can be helpful to customers who have questions on how to best leverage GitLab to meet their company's ambitious goals related to DevOps or digital transformation.
Advisory Services typically follow a 3-step approach:

- A Discovery Session to align with the customer to better understand their goals or challenges, aswell as the current tooling and process.
- Asynchronous investigation to develop and iterate on a candidate solution.
- Delivery workshop to demonstrate the proposed solution or workflow, together with any further supporting guidance or recommendations

### Why GitLab Professional Services?

#### Customer

- **Faster value realization** - Help the customer setup the GitLab instance and migrate their data and users quickly to accelerate [time to first value](/handbook/customer-success/customer-success-vision/#time-to-value-kpis). Paired with education services to ensure the users know how to use the newly setup GitLab system is the way to the fastest initial adoption and sets the foundation for future stage adoption.
- **Improved customer experience** - Establishing best practices up front with our expert recommendations is the path to a great customer experience.
- **Access to GitLab experts / best practices** - On top of our team of experts, we can reach back to engineering and support to put the full weight of GitLab into solving a customer issue.

#### GitLab

- **Improved retention and expansion** - When customers get started with GitLab on the right foot, they spend less time on debt work (e.g. infrastructure maintenance or ) throughout their subscription period
- **Customer insights and feedback** - The PS Engineer will be working hands-on with the customer team and often gains insightful feedback on the software and customer relationship.

### How will we deliver?

1. Direct via the [GitLab Professional Services Engineering Delivery team](/handbook/customer-success/professional-services-engineering/#team-members-and-roles)
1. Partner delivered (future)

## How to order

Ordering services is done through an **Off-the-shelf SKU** or a custom-scoped **Statement of Work**.  See the [selling services workflow](/handbook/customer-success/professional-services-engineering/selling/) for more details.
For custom SOWs, initiate a scoping issue to capture the requirement using the [Services Calculator](https://services-calculator.gitlab.io/), and collaborate with your local [Professional Services Engagement Manager](/job-families/sales/job-professional-services-engagement-manager/).

## Resources

- [Services Categories page](/services/)
- [Full offering catalog](https://about.gitlab.com/services/catalog/)
- [Services Calculator for custom SOWs](https://services-calculator.gitlab.io/)
- [Professional Services Pitch Deck](https://docs.google.com/presentation/d/1CFR8_ZyE9r4Dk_mjoWGe4ZkhtBimSdN0pylIPu-NAeU/edit#slide=id.g3667cdc662_0_1)

## Command of Message questions to ask

### Increase Operational Efficiencies

- Tell me about the most important things that need to be done to make the rollout successful.
- Describe to me where you think there may be opportunities to accelerate your time-to-value?
- How much time could we save your teams by having a GitLab expert architect and deploy GitLab for you?

### Deliver Better Products Faster

- How would the business benefit from the ability to quickly and easily migrate teams?
- Describe how your developer productivity would be impacted by education around best practices for using GitLab, git or GitLab CI/CD

### Reduce Security and Compliance Risk

- How does your team manage the risk associated with adding a new tool or platform?
