---
title: "Professional Services Technical Architect"
---

## Who We Are

The Professional Services Technical Architect (TA) team at GitLab consists of highly skilled experts responsible for providing technical leadership, presales support, delivery oversight, and fostering collaboration across functional roles. With deep knowledge of GitLab's platform, DevOps practices, and industry best practices, we work closely with customers to understand their unique challenges and provide tailored solutions aligned with their business goals. Our team bridges the gap between technical and non-technical stakeholders ensuring clear communication and alignment throughout the scoping process and engagements.  We continuously seek ways to improve our services, deliver exceptional value, and enable customers to maximize the benefits of the GitLab platform for their DevOps transformation Journey.

## Pre-Sales Support

**Collaboration:**

The TA team assists Account Teams (e.g. Account Executives, Solution Architects, Customer Success Managers, and Engagement Managers) with technical sales by following the [MEDDPICC](/handbook/sales/meddppicc/) sales qualification methodology, acting as a trusted advisor during the scoping process, and providing Engagement Managers with strategic technical solutions to enhance the Customer Journey to full platform adoption.

## Expert Technical Assistance to Engagement Managers

**Technical Guidance and Solution Design:**

- Understand the [Customer Journey](/handbook/customer-success/customer-success-vision/#high-level-visual-of-gitlab-adoption-journey)
- Understand common customer change management workflows and incorporate security, compliance and observability into customer engagements.
- Assist the Engagement Managers in scoping the technical challenges that the customer is currently encountering.
- Approve Statements of Work (SOW) including deliverables and level of effort.

## Engage with an Architect

### General Rules of Engagement

1. It is the EM's responsibility to gather information about the potential opportunity prior to engaging the TA. This includes:
   - Ensuring the customer understands the value of the PS team, what we can offer, and how we can generally help customers drive value realization from their GitLab subscription purchase.
   - Positioning what we want to do 80% of the time in general ways, avoiding detailed technical scoping until necessary.
   - Helping align customer expectations with practical solutions before involving TA's.
1. In order for an Engagement Manager (EM) to engage with a TA, there should be an SFDC opportunity and scoping issue created. Additionally, in the scoping issue, the EM should be able to articulate the `current customer pain points` and `technical or organizational constraints`. If these are not present, the TA can push back on the EM to gather this information prior to joining internal or customer-facing calls.

### Establish Subject Matter Expertise

TA's Leverage their expertise to build trust and demonstrate the value of GitLab services in achieving desired outcomes.  They can help navigate challenging customer scenarios while continually communicating the value of GitLab services.

### Helping with Discovery Calls

Support effective discovery sessions to gather detailed requirements and insights.

**Role of EM:**

- Act as the facilitator, asking higher-level questions to guide the discussion.

**Role of TA:**

- Ask more detailed, technical questions, to ensure all necessary information is gathered for successful project planning.
- Clarify technical requirements and constraints, and document technical dependencies.
- Identify potential risks and challenges early in the discovery process.
- Provide insights on best practices and suggest innovative solutions based on past experiences.
- Ensure all technical aspects are comprehensively understood, documented, greed upon, and aligned to avoid creep and misunderstandings later in the project.

### Estimating Level of Effort (LOE) and Required Scope

Accurately determine the resources and time needed for the project.

**Role of TA:**

- Collaborate with EMs to figure out the LOE.
- Account for potential risks and develop a comprehensive scope of work.
- Utilize experience and technical knowledge to provide accurate estimates and assumptions.

### Helping Deliver Technical Details During Proposal

Ensure proposals are detailed and credible.

**Role of EM:**

- Lead the presentation of overall value proposition, timeline, cost, and schedule.

**Role of TA:**

- Add detailed technical insights, past customer experiences, and tribal knowledge.
- Substantiate the proposed plan and reinforce its feasibility and value.

### Scoping and Planning Guidelines

**Preparation:**

- Reach out to your assigned TA with at least one business day notice using the [PS and Sales team mapping](https://docs.google.com/document/d/1sdehii3Eqp_CiYsGT3dDb0nKbbtwpxKQlni7t3ZgfCs/edit#heading=h.1er41qhhpoj5)
- Provide relevant context, notes, and information needed for the scoping call, including business challenges and desired outcomes.
- If the TA assigned does not specialize in the topics discussed on the customer call, they are responsible for coordinating with the TA team to identify a suitable expert.
- If the assigned TA is unable to help find an alternative, redirect your request to #ps-ta-ama

### Scoping Related Questions

**Process:**

- Add the label `Scoping::Needs_TA_Assistance` to related GitLab issues with a clear request in the comments for TA follow-up.
- Update the label to `Scoping::TA_Assisted` to when there are no outstanding questions in the issue.

### Approvals and Review

**Review Process:**

- Add the `TA::Needs-Review` label to any SOWs not previously reviewed by a TA.
- Technical Architects will review within two business days, clarifying actions, assumptions, and deliverables.
- The `TA::Approved` label will be added once the SOW is reviewed and approved.

## General Inquiries and Discussions

**Communication:**

- Use the #ps-ta-ama channel on Slack for broader technical questions or role-related inquiries.
- Conduct discussions related to ongoing SOWs within the comments of the associated scoping issue to maintain context.

## Project Technical Leadership

**Responsibilities:**

- Act as a point of escalation to resolve critical issues quickly.
- Enable Professional Service Engineers and Partner Engineers to better understand the GitLab Platform and workflows.
- Transition from scoping to leading the delivery of larger engagements, such as transformations or multi-workstream projects.
- Focus on Discovery and clearing technical hurdles in engagements.
- Ensure that [Delivery Kits](https://gitlab.com/gitlab-org/professional-services-automation/delivery-kits) are iterated on during Delivery.
- Collaborate with the PMO to ensure project status is up to date in line with our Delivery [Methodology](https://gitlab.com/gitlab-com/customer-success/professional-services-group/ps-leadership-team/ps-delivery-methodology/-/wikis/home).
