---
title: Troubleshooting
description: "Information about monitoring and logging tools of Duo Workflow."
---

## Tools

Duo Workflow uses the following logging and monitoring tools:

1. [LangSmith](https://smith.langchain.com/o/477de7ad-583e-47b6-a1c4-c4a0300e7aca/projects/p/5409132b-2cf3-4df8-9f14-70204f90ed9b?timeModel=%7B%22duration%22%3A%227d%22%7D) - collects logs scoped to underlaying graph execution, including inforamtion like: LLM completions or tool calls
2. [gcp logs explorer](https://console.cloud.google.com/logs/query;query=resource.labels.service_name%3D%22duo-workflow%22%0A--%20jsonPayload.event:%22workflowID:%20%5C%221001722%5C%22%22%0A--%20jsonPayload.correlation_id%3D%2268bd87b3-fb70-4093-afb7-21f30ab6021d%22%0A--%20jsonPayload.level%3D%22error%22%0A;cursorTimestamp=2024-12-02T08:47:05.808340Z;duration=P1D?hl=en&invt=AbjExA&project=gitlab-runway-production) - The logs explorer for `gitlab-runway-production` gcp project. These logs include all logs generated by Duo Workflow Service (WARNING: this project collects logs also from other Runway services, so correct filtering is necessary to scope browsed logs to the right entity).
3. Sentry error tracking collects error traces for:
    1. [Duo Workflow Service](https://new-sentry.gitlab.net/organizations/gitlab/issues/?limit=5&project=36&query=&sort=freq&statsPeriod=14d)
    2. [Duow Workflow Executor](https://new-sentry.gitlab.net/organizations/gitlab/issues/?limit=5&project=40&query=&sort=freq&statsPeriod=14d)
4. Runway monitoring [dashboard](https://dashboards.gitlab.net/d/runway-service/runway3a-runway-service-metrics?from=now-24h&orgId=1&timezone=utc&to=now&var-PROMETHEUS_DS=mimir-runway&var-environment=gprd&var-region=$__all&var-type=duo-workflow) - this a grafana dashboard that tracks hardware resource consumption for Duo Workflow Service
5. [Tableau dashboard for internal events tracking](https://10az.online.tableau.com/#/site/gitlab/views/DuoRequestWorkflow/DuoWorkflow) - displays aggregated data collected with internal event tracking, showing additional product metrics like total number of workflows, or distribution between differnt workflow outcomes

## Tips and tricks

A typical investigation around problematic Duo Workflow execution follows steps listed below:

Based on a user report:

1. Ask the user for the `workflow_id` for the problematic workflow which is displayed in the list of workflows
2. Use the `workflow_id` from previous step to filter down [langsmith traces](https://smith.langchain.com/o/477de7ad-583e-47b6-a1c4-c4a0300e7aca/projects/p/5409132b-2cf3-4df8-9f14-70204f90ed9b) by applying a filter for `metadata` and `thread_id=[workflow_id]`
3. Use the `workflow_id` from 1st step to filter down logs in gcp logs explorer

Based on a Sentry issue:

1. Use Duo Workflow Sentry issue to locate problematic workflow's `correlation_id`.
2. Use the `correlation_id` from previous step to filter down logs in gcp logs explorer, example filter: `jsonPayload.correlation_id="e7171f28-706d-4a47-be25-29d9b3751c0e"`

In addition one can use a workflow's `workflow_id` that is being recorded either in sentry or in log explorer to filter down LangSmith logs using `thread_id` filter in _metadata_ and comparing it against `workflow_id`.
