---
title: Incubation Engineering Department
---

## Incubation Engineering Department

The Incubation Engineering Department focuses on projects that are pre-Product/Market fit. The projects they work on align with the term "new markets" from one of our [product investment types](https://internal.gitlab.com/handbook/product/investment/). They are ideas that may contribute to our revenue in 3-5 years time. Their focus should be to move fast, ship, get feedback, and [iterate](/handbook/values/#iteration). But first they've got to get from 0 to 1 and get something shipped.

We utilize [Single-engineer Groups](/handbook/company/structure/#single-engineer-groups) to draw benefits, but not distractions, from within the larger company and [GitLab project](https://gitlab.com/gitlab-org/gitlab) to maintain that focus. The Single-engineer group encompasses all of product development (product management, engineering, design, and quality) at the smallest scale. They are free to learn from, and collaborate with, those larger departments at GitLab but not at the expense of slowing down unnecessarily.

The Department Head is the [VP of Incubation Engineering](/job-families/engineering/development/incubation/management/vp/).

### FY25 Direction

In FY25 we will continue to mature some of our key projects and to contribute to new opportunities within the AI sphere to build upon the capabilities that GitLab offers.  Our current batch of projects are building  customer value and interest and achieving significant monthly growth milestones.  Our aim is to reach a level of maturity with these projects that allows us to graduate or reassign these groups to new opportunities.

Our success is tied to the community of developers and users that can benefit from our features, and strong collaboration and engagement with those groups is a key focus for this year. As our team matures, we need to be mindful of setting a culture of innovation and results. We do this through encouraging experimentation and autonomy, whilst being collaborative and transparent to internal teams and external stakeholders. The Incubation Engineering team is unique within GitLab in that the team members are not working on shared problems, but have the same challenges and shared experiences. We should ensure that successes and failures are documented and shared amongst team members to help each other grow and to minimise the inherent isolation and stress that can be part of this role.

### Investment Framework

The aim of the SEG's in the Incubation Engineering Department is to get ideas for new markets into the Viable category from our [maturity](https://about.gitlab.com/direction/#maturity) framework.  Ideas that we successfully incubate will become a stage or feature within the relevant areas of our product, with full Product, Engineering, UX and Infrastructure support for future development.

In some cases we may invest in an SEG and then decide to acquire an existing product or team in the same area. These situations are disruptive, but unavoidable, and we will work closely with the affected SEG to adapt.

In order to determine our investment into an SEG, we use the following assumptions:

- SEGs have a 25% success rate (as opposed to 5% of VC funded companies), due to the existing market reach and technical foundations of the GitLab product and the culture, processes and support from the wider organisation.
- SEG's mature categories at a 50% faster rate than regular GitLab Category Maturity features, due to the narrow focus of our investments.
- SEG's ramp up revenue as good as the best startups in the world (5 year to $100M ARR)

Reference:

- <https://kimchihill.com/2020/04/09/path-to-100m-arr/>
- <https://www.stephnass.com/blog/saas-ipo-roadmap>

### What is a New Market?

A new market in our product roadmap is a long-term bet to help us expand our Serviceable Addressable Market (SAM) over a 3-5 year time horizon.

We look at areas that fit within our [company mission](/handbook/company/mission/) that we currently do not service and have one or more competitors that have validated the customer need.  Our criteria for entering these markets is that there is at least one competitor that is attaining over $100M annual recurring revenue, or at least 3 venture capital funded startups that have taken over $5M in funding.  We track our understanding of these markets via this [internal document](https://docs.google.com/document/d/17nD0Pko3Ff-ensiE0SUl3atxassZlC7pEpuIvzTy8Ek/edit?usp=sharing).

We also manage projects that may not fit the above definition, but are well suited to the [SEG](/handbook/company/structure/#single-engineer-groups) model that we use as they require a degree of experimentation with significant risk of failure. These are significant defensive roadmap items that are important to work on to maintain our market share and competitive advantage in an area, but we cannot yet justify funding a larger R&D effort.

The Incubation Engineering Department is not suited to deliver regular roadmap items as they are typically smaller in effort, have less risk of failure, and have less scope for experimentation to determine product/user fit.

### Approach

Key to the success of Incubation Engineering is the ability to iterate on ideas quickly and move on when we can't find customer traction.  We should be able to ship ideas and grow their usage quickly.

Each project should be able to identify a vision and ship working code within the first month after inception, and then have regular monthly goals of continuing iteration and usage growth. SEGs that aren't well defined will require research to determine a direction. This research phase should include updates to the SEG handbook page, epics/issues, video update(s), and code where that makes sense. We should be aiming foremost for customer results, and not shipping features (even if they show usage) that don't demonstrate clear customer value.

Each SEG page has a list of the targets and progress for each month, and these should also be demonstrated in a [monthly showcase](/handbook/engineering/development/incubation/#demonstrating-progress).

## Current Focus

<div class="flex-row" markdown="0">
  <div>
  <a href="/handbook/engineering/development/incubation/mlops/" class="btn btn-primary" style="width:30%;margin:5px;white-space:normal;">MLOps</a>
  <a href="/handbook/engineering/development/incubation/service-desk/" class="btn btn-primary" style="width:30%;margin:5px;white-space:normal;">Service Desk</a>

  </div>
</div>

## Future Interest

<div class="flex-row" markdown="0">
  <div>
    <a href="https://about.gitlab.com/direction/package/#dependency-firewall" class="btn btn-primary" style="width:30%;margin:5px;white-space:normal;">Dependency Firewall</a>
    <a href="/handbook/engineering/development/incubation/developer-portal/" class="btn btn-primary" style="width:30%;margin:5px;white-space:normal;">Developer Portal</a>
    <a href="/handbook/engineering/development/incubation/devops-for-salesforce/" class="btn btn-primary" style="width:30%;margin:5px;white-space:normal;">DevOps for Salesforce</a>
  </div>
</div>

<div class="flex-row" markdown="0">
  <div>

  <a href="/handbook/engineering/development/incubation/istio/" class="btn btn-primary" style="width:30%;margin:5px;white-space:normal;">Istio</a>
  <a href="/handbook/engineering/development/incubation/secrets-rotation/" class="btn btn-primary" style="width:30%;margin:5px;white-space:normal;">Secrets Rotation</a>
  </div>
</div>

## Matured Projects

<div class="flex-row" markdown="0">
  <div>
    <a href="/handbook/engineering/development/incubation/ai-assist/" class="btn btn-primary" style="width:30%;margin:5px;white-space:normal;">AI Assist</a> matured to <a href="/handbook/product/categories/#ai-assisted-group" class="btn btn-primary" style="width:30%;margin:5px;white-space:normal;">AI Assisted Group</a>
  </div>
  <div>
    <a href="/handbook/engineering/development/incubation/apm/" class="btn btn-primary" style="width:30%;margin:5px;white-space:normal;">Application Performance Monitoring</a> matured to <a href="/handbook/product/categories/#observability-group" class="btn btn-primary" style="width:30%;margin:5px;white-space:normal;">Observability Group</a>
  </div>
  <div>
    <a href="/handbook/engineering/development/incubation/server-runtime/" class="btn btn-primary" style="width:30%;margin:5px;white-space:normal;">Server Runtime</a> matured to <a href="/handbook/product/categories/#remote-development-group" class="btn btn-primary" style="width:30%;margin:5px;white-space:normal;">Remote Development Group</a>
  </div>
  <div>
    <a href="/handbook/engineering/development/incubation/okr/" class="btn btn-primary" style="width:30%;margin:5px;white-space:normal;">OKR Management</a> matured to <a href="/handbook/product/categories/#product-planning-group" class="btn btn-primary" style="width:30%;margin:5px;white-space:normal;">Product Planning Group</a>
  </div>
</div>

## On Hold / Cancelled

<div class="flex-row" markdown="0">
  <a href="/handbook/engineering/development/incubation/airflow/" class="btn btn-primary" style="width:30%;margin:5px;white-space:normal;">Airflow</a>
  <a href="/handbook/engineering/development/incubation/jamstack/" class="btn btn-primary" style="width:30%;margin:5px;white-space:normal;">Jamstack</a>
  <a href="/handbook/engineering/development/incubation/no-code/" class="btn btn-primary" style="width:30%;margin:5px;white-space:normal;">No-Code / Low-Code</a>
</div>
<div class="flex-row" markdown="0">
  <a href="/handbook/engineering/development/incubation/real-time-collaboration/" class="btn btn-primary" style="width:30%;margin:5px;white-space:normal;">Real-time Editing (REID)</a>
  <a href="/handbook/engineering/development/incubation/cloud-seed/" class="btn btn-primary" style="width:30%;margin:5px;white-space:normal;">⛅🌱 Cloud Seed</a>
  <a href="/handbook/engineering/development/incubation/breach-and-attack-simulation/" class="btn btn-primary" style="width:30%;margin:5px;white-space:normal;">Breach and Attack Simulation (BAS)</a>
</div>
<div class="flex-row" markdown="0">
  <a href="/handbook/engineering/development/incubation/mobile-devops/" class="btn btn-primary" style="width:30%;margin:5px;white-space:normal;">Mobile DevOps</a>
</div>

## Demonstrating Progress

Our key focus is to ship software, we do this [Iteratively](/handbook/values/#iteration) and [Transparently](/handbook/values/#transparency) in an Agile way, concentrating on having something that works as soon as possible that we can build upon.

For each of our Investment areas, we aim to showcase our progress using the [Engineering Demo Process](/handbook/engineering/demos/).  On the tracking issue for each area, each SEG should provide a status update and a link to a video of the current functionality.  We should aim to develop a scorecard to help [grade](/handbook/product/ux/category-maturity/category-maturity-scorecards/#calculating-the-cm-scorecard-score) our progress against each of the key features we are trying to develop, and include this in the update.

We do this in order to ensure alignment with impacted teams at GitLab, to provide opportunties for [Collaboration](/handbook/values/#collaboration) from interested GitLab team members, community members, and users, and finally to demonstrate [Results](/handbook/values/#results).

### Mid Month Update Video

Around the 15th of the month each SEG should provide a short update video that covers the following key points:

- *What progress have we made?* Each week we should be moving closer to our goal of having a [Viable](https://about.gitlab.com/direction/#maturity) product or feature.
- *Current Usage and Used Feedback* We should strive to measure usage of our ideas from the beggining. How is the adoption of the idea we are working on?
- *What have we learnt?* Either through technical research, experiementation, or feedback, do we better understand the problem we are trying to solve?
- *What new decisions do we need to make?* Have we identified any new opportunities or options that need wider consultation to help address?
- *What is our next focus?* Our next demo is in a week - what do we want to showcase?
- *What is the recommended video duration?* We strive to maintain an "executive briefing" format for these videos, thus keeping the length around the ~3 minute mark.

### End of Month Showcase

At the end of the month, we should have a monthly showcase which demonstrates the current state of each project and future plans, and does not assume any prior knowledge of the progress or vision.

### Conventions for SEG Videos

When uploading a video to our YouTube channel, we should:

- Make sure they are public
- Use a consistent naming convention for the SEG. Take these as inspiration:
  - "Incubation Engineering - Mobile Ops - Update 4"
  - "Incubation Engineering - Breach and Attack Simulation - Update 2023-02-21"
  - "Incubation Engineering - Service Desk - January 2023 Showcase"
- Add the video to the Incubation Engineering playlist, and the playlist dedicated to each section
- Add it to the specific Incubation Engineer direction handbook page

### Latest Demos

*YouTube Playlists*

- [Latest Updates](https://www.youtube.com/playlist?list=PL05JrBw4t0KrQQ6BmQGY0Ji-vBaohNOlW)
- [All Videos](https://www.youtube.com/playlist?list=PL05JrBw4t0KqqLZP0Jue3w2hz2PR6XTHi)

## OKRs

The Incubation Engineering department commits to and tracks quarterly [Objectives and Key Results](/handbook/company/okrs/) (OKRs).

See [the list of Incubation Engineering OKRs in GitLab](https://gitlab.com/gitlab-com/gitlab-OKRs/-/issues/?sort=created_date&state=opened&label_name%5B%5D=Department%3A%3AExpansion&label_name%5B%5D=OKR&label_name%5B%5D=FY25-Q1&first_page_size=20).

## SEG Lifecycle

When an SEG is ready to be handed off to a product development group or other team inside GitLab, there will necessarily be some handover required. Product development groups who are going to be taking over the SEG can accelerate their work by [borrowing](/handbook/product/product-processes/#borrow) the Incubation Engineer. This will allow full-time and continuous support for up to 3 milestones.

## Key Performance Indicators

Incubation Engineering [Key Performance Indicators](/handbook/engineering/development/incubation/performance-indicators/#incubation-engineering-department-mr-rate)

## Where to find us

[Incubation Engineering Projects and Issues](https://gitlab.com/gitlab-org/incubation-engineering)

You can also reach us on Slack at `#incubation-eng` in [Slack](https://gitlab.slack.com/archives/incubation-eng) (GitLab internal)

## Playbook

The [Incubation Engineer's Playbook](playbook/) contains useful tips and tricks an Incubation Engineer may employ for SEG and project success.

## Offsites

From time-to-time Incubation Engineers get together to discuss and share ideas, learn from each other, and discuss the latest trends in the industry.

Details are logged in the [Incubation Offsites](offsites/) page.

The [Incubation Engineer's Playbook](playbook/) contains useful tips and tricks an Incubation Engineer may employ for SEG and project success.
