---
title: Development Talent Assessment Process
---

### Talent Assessment Process

Company-wide guidelines on the Talent Assessment can be found [here](/handbook/people-group/talent-assessment/#q4-formal-talent-assessment). The company timeline for the process remains SSOT, the guidelines below are meant to:

- Provide additional check points and due dates built into the company-wide timeline for Development specifically (as one of the larger departments at GitLab)
- Guidance on department-specific calibration section structure (attendees, leveling, etc.)
- Outline our strategy in terms of who we will be calibrating in the Development Department

#### Who Are We Calibrating?

Formal calibration will take place at the Senior Manager, Director, and VP levels. The thought process around who qualifies as an "outlier" for Performance and Growth Potential [is outlined here](/handbook/people-group/talent-assessment/#who-do-i-calibrate).

Calibration and assessment are two different steps in the process. The assessment phase is the process of assessing each team member to determine their Performance and Growth Potential, whereas the calibration phase (occurring after initial assessments are made) is when management calibrates across the stage/org/level/etc. to discuss and align on assessments. Every team member should be assessed and have supporting points to justify those assessments - but to make calibration sessions more focused and scalable, we focus on [outliers](/handbook/people-group/talent-assessment/#who-do-i-calibrate).

For Development specifically, we will calibrate:

1. Anyone in [Box 1](/handbook/people-group/talent-assessment/#the-performancegrowth-potential-matrix) aligned with [company-wide guidelines](/handbook/people-group/talent-assessment/#who-do-i-calibrate).
1. Anyone in Box 9 who has been with GitLab longer than 3 months (_Note: 3 months is measured from the kick off of the Talent Assessment cycle on 2023-10-16_)
1. Anyone assessed as `Exceeding` for Performance
1. Anyone hired in the last 3 months **not** assessed as [Too New To Rate](/handbook/people-group/talent-assessment/#too-new-to-rate)
1. Anyone promoted in the [Q3 promotion cycle](/handbook/people-group/promotions-transfers/#fy24-q3) (August 1st effective) or later **not** assessed as [Too New To Rate](/handbook/people-group/talent-assessment/#too-new-to-rate)
1. Anyone identified as Key Talent

It's important to note that while these will be our focus areas for calibration sessions, managers should feel free to raise any team member's assessment up for discussions if they have any questions or concerns. Calibrating outliers is not a limitation, but rather a structural adjustment to ensure this process is scalable and focused.

_Note: If individual teams want to calibrate every individual, they have the ability to do this/organize/structure separately, but the due dates remain in place across the department to ensure we have enough time to review and calibrate at the various levels in the company._

#### How To Assess Acting/Interim

For team members who have assumed an [Acting or an Interim role](/handbook/people-group/promotions-transfers/#interim-and-acting-roles), we will assess team members aligned with their _permanent positions_ (I.E. not the Acting or Interim position).

As the Talent Assessment impacts compensation, and Acting/Interim periods are not permanent, in the instance that a team member does not end up moving into the Acting/Interim role permanently, we would not want to have their compensation impacted by a temporary position.

#### Pre-Calibration Prep Work

In addition to the [calibration session pre work](/handbook/people-group/talent-assessment/#calibration-session-pre-work) on the Talent Assessment page, we ask that you complete the following:

1. Directors should conduct sub-department level calibration sessions ahead of the department-wide Development calibration sessions. In addition to calibrating on initial assessments, Directors are responsible for ensuring their respective teams assessments fall within the [expected distribution](/handbook/people-group/talent-assessment/#expected-distribution-performancegrowth-potential-company-wide) ahead of the department-wide calibration session for efficiency.

1. Performance and Growth Potential notes need to be added to the [session agenda doc](https://docs.google.com/document/d/1zrlZSfdNXpSZ09uvDM71KxH42RWBJxa6U1QTCTw05iI/edit#) for each team member at least 3 business days before the synchronous calibration session.

1. Managers should include 2-3 supporting points for each team member for the assessment under each section in the [agenda doc notes](https://docs.google.com/document/d/1zrlZSfdNXpSZ09uvDM71KxH42RWBJxa6U1QTCTw05iI/edit#) to help support the "why" behind the assessment. _Note: The overviews in the agenda document for calibration are meant to provide enough of an overview so peers have an understanding of the "why", while simultaneously not overwhelming with information and decreasing efficiency of the session. Please limit to 2-3 supporting points per team member._

1. Key Talent assessment need to be completed and added to the session agenda doc at least 3 business days before the live calibration session.

- If an individual is indicated as Key Talent, an explanation should be added to indicate how this individual qualifies as Key Talent against our [Key Talent definition](/handbook/people-group/talent-assessment/#key-talent). Reminder that the bar for Key Talent is set high, and that Key Talent makes up roughly ~10% of the entire population. In Development, we will be calibrating Key Talent from the Senior Manager level and above [aligned with guidelines](/handbook/people-group/talent-assessment/#process-to-determine-key-talent), meaning that while _everyone in the organization is eligible to be identified as Key Talent_, Senior Managers+ will be calibrating and making these final decisions. The rationale behind this decision is that it is important to have a holistic view of all team members when determining who meets the Key Talent criteria, which is why we require a certain scope when assessing Key Talent in the organization.

While calibrations and ultimate determinations will take place at Senior Manager+ level, inital recommendations begin in Workday and sit with team member's direct managers aligned with the [process](/handbook/people-group/talent-assessment/#process-to-determine-key-talent)

1. Every session attendee should review the Performance/Growth Potential assessments and Key Talent overviews for outliers asynchronously ahead of the session to be prepared for live discussion/calibration.

#### Calibration Session Structure

Given the recent organizational changes and the creation of two new departments (Core Development and Expansion) and expansion of our Infrastructure department, calibration this year for what was the Development department will be a mix of calibration across the new departments and across what was the Development department. Given that team members and leaders spent the vast majority of the year in the Development department, we want to ensure that a level of calibration is able to take place within these groups.

To increase efficiency within the department, we will be implementing a "pre" calibration touchpoint in which small groups of Senior Managers and Directors across what was the Development department calibrate their individual contributor outliers and discuss synchronously as a group. The goal of these small group calibration sessions is to:

1. Facilitate cross-functional feedback and ensure it remains as a core part of the calibration process
1. Minimize synchronous time and maximize efficiency
1. Ensure that the approach to assessment and calibration remains consistent and calibrated across what was the Development department as we transition into new departments

The small groups are responsible for calibrating Associate, Intermediate, Senior, and Staff level individual contributor outliers across their respective teams. Engineering Manager level outliers and Principal+ individual contributors will be calibrated in larger sessions with all of the department leadership present. When determining groups we took timezone, group size, and cross-functional alignment (I.E. not in the same reporting chain) into account. Group assignments are as follows:

- **Group 1:** Cheryl Li and Michelle Gill
- **Group 2:** James Lopez, Nicole Williams
- **Group 3:** Crystal Poole, Dennis Tang, and Darva Satcher
- **Group 4:** Phil Calder and Jerome Ng
- **Group 5:** John Hope and Chun Du
- **Group 6:** Nick Nguyen, Thomas Woodham, Sam Goldstein

We recommend that groups use the [Talent Assessment - Calibration Session template](https://docs.google.com/document/d/1zrlZSfdNXpSZ09uvDM71KxH42RWBJxa6U1QTCTw05iI/edit#heading=h.q1ptlqi506at) to ensure structure is similar to what we will use at the department level calibration sessions. Additionally, we ask that you please discuss the following things specific to Development to ensure you are prepared for questions that may arise at the department-wide sessions:

- _TO ADD_

**Small groups are responsible for scheduling their own calibration sessions at a convenient time for the group. The due date to complete small group calibration sessions to ensure we remain aligned to the department-wide calibration and division-wide calibration timeline is November 15, 2023 EOD PT.**

##### Calibration Schedule

The calibration schedule below only includes calibration sessions in which department leaders and People Business Partner presence is required. Leaders are responsible for organizing the small group calibration and any sub-department calibration sessions independently ahead of the sessions below kicking off.

| Session Number | Attendees | Calibration Level Focus | Session Date | Timezone Alignment | Duration | Department |
| --------------- | ----------------- |----------------- |----------------- |----------------- |----------------- |----------------- |
| Session 1 | Senior Managers+ (people managers only) + PBP | Engineering Manager level outliers | TBD | EMEA/Americas | 1.5 hours | Core Development |
| Session 2 | Senior Managers+ (people managers only) + PBP | Engineering Manager level outliers | TBD | APAC/Americas | 1.5 hours | Expansion |
| Session 3 | Senior Managers+ (people managers only) + PBP | Principal individual contributors | TBD | EMEA/Americas | 1 hour | Core Development |
| Session 4 | Director+ (people managers only) + PBP | Principal/Senior Manager level | TBD | APAC/Americas | 1 hour | Expansion |
| Session 5 | Director+ (people managers only) + PBP | Calibrate Senior Manager level | TBD | EMEA/Americas | 1.5 hours | Core Development |
| Session 6 | Department leaders and PBP | Calibrate Director/Distinguished level | TBD | EMEA/APAC/Americas | 2 hours | Core Development & Expansion |

#### Timeline

The company-wide Talent Assessment timeline can be found [here](/handbook/people-group/talent-assessment/#timeline) and is SSOT. Below are level-specific calibration due dates embedded within the overall timeline for the Development Department.

- 2023-11-16: Sub-department level calibration *_and_ small group calibration sessions are complete
- 2023-11-20 through 2023-11-24: Development department calibration sessions with Senior Manager+ people manager attendees
- 2023-11-27: Development department calibration sessions with Director+ people manager attendees
- 2023-11-28: Development department calibration sessions with department leader + PBP
