---
title: Development Department Learning and Development
---

## Resources

### Secure coding best practices

It is important that all developers are aware of [secure coding best practices](/handbook/security/secure-coding-training/) and refresh this knowledge periodically. This is tracked via Secure Coding Training Guidelines.

### Ruby on Rails Performance Training

The materials from an earlier Ruby on Rails performance workshop can be found on [internally shared Google drive](https://drive.google.com/drive/search?q=in:0ACCfBKgYFjLvUk9PVA).

#### Video Sessions

| Day | Topics | Video Links |
| --- | ------ | ----------- |
| Session - Day 1 | Intro and overview | [Monday](https://drive.google.com/drive/search?q=title:%22day%201%20session%22%20parent:15EaLvFMexoJu7pHQQdTDuInhFRk_lOLq) [Wednesday](https://drive.google.com/drive/search?q=title:%22day%201%20session%22%20parent:1dJ08oeWdff4BpcrlVjuRQIPARYXE-LGY) |
| Session - Day 2 | Tools | [Monday](https://drive.google.com/drive/search?q=title:%22day%202%20session%22%20parent:15EaLvFMexoJu7pHQQdTDuInhFRk_lOLq) [Wednesday](https://drive.google.com/drive/search?q=title:%22day%202%20session%22%20parent:1dJ08oeWdff4BpcrlVjuRQIPARYXE-LGY) |
| Session - Day 3 | SQL and N+1 Troubleshooting | [Monday](https://drive.google.com/drive/search?q=title:%22day%203%20session%22%20parent:15EaLvFMexoJu7pHQQdTDuInhFRk_lOLq) [Wednesday](https://drive.google.com/drive/search?q=title:%22day%203%20session%22%20parent:1dJ08oeWdff4BpcrlVjuRQIPARYXE-LGY) |
| Session - Day 4 | Queueing Theory | [Monday](https://drive.google.com/drive/search?q=title:%22day%204%20session%22%20parent:15EaLvFMexoJu7pHQQdTDuInhFRk_lOLq) [Wednesday](https://drive.google.com/drive/search?q=title:%22day%204%20session%22%20parent:1dJ08oeWdff4BpcrlVjuRQIPARYXE-LGY) |

### Database

Here is the information of a PostgreSQL query optimization bot at GitLab - Joe: [Blueprint](/handbook/engineering/infrastructure/library/database/postgres/query-optimization-bot/blueprint/) and [Design](/handbook/engineering/infrastructure/library/database/postgres/query-optimization-bot/design/).

### Frontend

#### Frontend Masters

[Frontend Masters](https://frontendmasters.com) allows you to advance your skills with in-depth, modern frontend engineering courses.

GitLab has an account with Frontend Masters and team members can gain access to it by creating an [Access Request](https://gitlab.com/gitlab-com/team-member-epics/access-requests/-/issues/new?issuable_template=Individual_Bulk_Access_Request) and select the best option for your situation ([single user](https://gitlab.com/gitlab-com/team-member-epics/access-requests/-/issues/new?issuable_template=Individual_Bulk_Access_Request), [bulk user](https://gitlab.com/gitlab-com/team-member-epics/access-requests/-/issues/new?issuable_template=Bulk_Access_Request), etc.) and, once approved by your manager, assign to the Access Request Provisioner listed in the [Tech Stack](https://gitlab.com/gitlab-com/www-gitlab-com/-/blob/master/data/tech_stack.yml) for this system. Once your access has been provisioned, you will receive an email to activate your account.

You can also join the [#frontendmasters](https://gitlab.slack.com/archives/C0151MXP6JH) Slack channel for course recommendations and discussion.

### GraphQL

We use GraphQL alongside our REST API at GitLab and are increasingly adding new features to the GraphQL API over time.

The GraphQL API can be added to by anyone, including [community members](https://docs.gitlab.com/ee/development/contributing/). We have a group of self-selected team members who are willing to help with any GraphQL questions you may have. You can get in touch with them by mentioning `@gitlab-org/graphql-experts` in any GitLab issue or merge request.

You can read more information about GraphQL at GitLab here:

- [Getting started with GitLab GraphQL API](https://docs.gitlab.com/ee/api/graphql/getting_started.html)
- [GraphQL frontend guide](https://docs.gitlab.com/ee/development/fe_guide/graphql.html)
- [GraphQL API style guide](https://docs.gitlab.com/ee/development/api_graphql_styleguide.html)
- [Introduction to GraphQL (graphql.org)](https://graphql.org/learn/)

We also run GraphQL office hours, which is a place where GitLab team members can ask questions and chat amongst peers about GraphQL at GitLab.

These meetings are currently run on a **weekly** cadence, alternating between timezones.

| Time in UTC | Organisers |
| ----------- | ---------- |
| +4:30 | [@ntepluhina](https://gitlab.com/ntepluhina) |
| +16:30 | [@seanarnold](https://gitlab.com/seanarnold), [@cablett](https://gitlab.com/cablett) |

### Engineering Management

One of the paths for engineers to progress in their career is a Management path. To explain more about the role
of Engineering Managers in GitLab, there is a series of conversations with team members explaining details of their work and their experience transitioning to management
[here](/handbook/engineering/development/training/em-role/).

### IC Leadership

Staff+ engineers and ICs aspiring to become Staff can benefit from resources and recommendations described
[here](/handbook/engineering/development/training/staff-plus-role/).

## Edcast / GitLab Learn

[GitLab Learn](https://gitlab.edcast.com/) is a Learning Experience Platform (LXP) meant to provide training and professional development for team members. We will continue being [handbook first](/handbook/about/handbook-usage/#why-handbook-first), and use this platform to organize, surface, and promote relevant content that exists today.

We encourage you to browse all of the channels offered in GitLab Learn, as new ones are regularly being added and updated. Here are some resources to start:

- [**GitLab Development Channel**](https://gitlab.edcast.com/channel/gitlab-development-learning-hub) - for Development-specific training resources
- [**Recommendations from Learning and Development**](https://gitlab.edcast.com/channels/discover-channels/3635) - a collection of channels recommended by the L&D team, including Mental Wellness and Leadership Development
- [**All Channels**](https://gitlab.edcast.com/channels/all)

## Process for Contributing

### Step: 1:   Submit a Request

Submit a request to the [lxp-contributions project](https://gitlab.com/gitlab-com/people-group/learning-development/lxp-contributions) using this [issue template](https://gitlab.com/gitlab-com/people-group/learning-development/lxp-contributions/-/blob/master/.gitlab/issue_templates/development_channel_contribution.md) to the appropriate GitLab Learn Carousel DRI based on the table below:

| Development Channel Carousels | DRI |
| ------ | ------ |
| Values | @pcalder |
| Mentoring | @whaber |
| Go | @steveazz |
| Ruby/Rails | @tkuah |
| Monitoring & Visualization | @andrewn |
| GraphQL | @m_gill |
| Apollo | @xanf |
| Vue | @ntepluhina  |
| Redis | @igorwwwwwwwwwwwwwwwwwwww |
| Sidekiq | @reprazent |
| Elasticsearch | @dgruzd |
| Deploys / Releases | @nolith |
| Management | @dsatcher |
| New Managers | @jeromezng |
| Leadership | @dsatcher |
| Security | @joernchen |

| Future Carousels | DRI |
| ------ | ------ |
| Gitaly and Git | TBD |
| GitLab Runner |  @tmaczukin |

### Step 2:  Carousel DRI Approves the Request

The Carousel DRI will review the request and approve or deny the request. Once approved, the recommended content will be added to the channel.

_Note: Carousel DRI's can only add content that exists in the platform already. If the content does not exist, the Carousel DRI will need to request that it be added first by consulting the learning and development team_

**Criteria for approval**

The following should be true for all content approved.

1. A carousel cannot have more than 10 courses (There can be exceptions to the rule, however we only want to highlight the most impactful courses here)
1. The Carousel DRI must complete the course or have confidence that it will contribute to professional development
1. Upon evaluating the course, the Carousel DRI concurs that this course should be added to the carousel

## What is a Carousel?

Carousels are defined here by the Learning and Development Team. For the Development channel, they are used to collect different content (courses, videos, handbook pages, journeys) on the same subject.

## What is a Carousel DRI?

Carousel DRI's are responsible for curating the content for a carousel within the Development channel in GitLab Learn. They are formally GitLab Learn Curators and will organize and maintain learning content while encouraging professional development.

If you are interested in becoming a Carousel DRI:

1. Become a GitLab Learn Curator
1. Open an MR to this page to assign yourself as the DRI for a given carousel
1. Get approval from at least 2 DRI's
