---
title: Work Of A Manager
---

* TOC

## The what and the why

_What does your manager do all day? What would it mean to become one?_

This document is about the **what** (and a bit about the **why**). It would take an entirely different - and much longer - conversation to talk about how to do each of these things _well_.

The summary: a manager's job is to build an organization that performs well, efficiently, and sustainably. (I've heard and used the term _well oiled machine._) This is especially important to internalize for ICs (individual contributors, meaning not managers) considering switching to the manager role: _management is not on top of your daily duties; it's an entirely different job._

Can you still do a bit of that old day job, like coding? Sure, but that's a "nice to have" from the perspective of the company. It may be essential to your sanity, so by all means dabble, but this dabbling must not take precedence. Your job is to enable people and build healthy, focused organizations..)

## This document is a framework

Use this document to think about a manager's work. It's intended to focus thought and break up the scope into manageable pieces. It is not intended to be prescriptive or exhaustive as to what you should do. The questions and exercises in this document may or may not have an immediate answer. They're meant to raise questions that you may wish to revisit from time to time.

**Read through and discuss the contents, as well as the results of the exercises, with a mentor or peer manager.**

## The matrix

Managers build the "well-oiled machine" by taking care of their direct and indirect reports, and their larger organization. They must align what the business needs, and what the team (and individuals) need. They must also care for themselves, and ensure growth and sustainability. It's essential for managers to balance day-to-day work with forward-looking work. The needs of the _now_ must be balanced with the needs of upcoming large projects, long-term career planning, staffing, and more.

Use this matrix to organize and visualize these concepts:

|             | Self | Individuals | Organization | Work |
| ----------- | ---- | ----------- | ------------ | ---- |
| Short term  |      |             |              |      |
| Medium term |      |             |              |      |
| Long term   |      |             |              |      |

### The columns

* **Self**: Processes relevant to yourself. Improving yourself as a manager, avoiding burnout, and working on your own career. Also meta-work that enables you to function, from mandatory trainings to tracking your achievements.
* **Individuals**: Processes relevant to individuals. The lives of the people that report to you (directly or indirectly), and any mentees in your charge. Their happiness, skills, careers, goals, and individual productivity.
* **Organization**: Processes relevant to broader collaboration: your team, or your whole organization. Interactions of people, organizational culture and structure, and how the team fits into the overall company landscape.
* **Work:** Processes relevant to the business and its overall goals. OKRs, roadmaps, and the team's deliverables. Picking, planning and organizing what work you will be doing - and, just as importantly, _not_ doing.

### The rows

* **Short term**: Daily work. Something you need to do to keep rolling. All input is already at hand. Effects are immediate.
* **Medium term**: Work that requires you to look forward or backward a few weeks or months. Use that broader perspective to do something, or lay a foundation for future work. Effects are usually realized later.
* **Long term**: Work that requires you to look beyond current commitments (often 6-12 months) to understand long-term needs. Drive strategy, prepare for eventualities, or lay a foundation to prepare you for this work. Effects are usually realized much later, although sometimes long-term goals can become urgent unexpectedly.

## Exercise 1: activities in detail

Take five (okay, 15) minutes and put some activities into each box. Think about _why_: if it's an activity done to keep individuals happy and productive (like actually talking to them from time to time) add it to box **Short term, Individuals**.

No, really. 🙂 You'll see mine after.

<details markdown="1">
<summary>My example Matrix (click to expand)</summary>

This is of course not an exhaustive list, but an illustration.

* **Short term, Self**
  * Keep notes of my daily activities
  * Process my input stream (Slack, email, issue updates) for planning
  * Take time off, update calendar, PTO issues etc
* **Short term, Individuals**
  * 1:1s: staying informed, ensure I'm available for helping
  * Read Slackbot updates
  * Process information into plans, and spot trends
  * Administrivia such as expense reports, getting new team members their laptops
  * Actual short-term help: "glue" work to connect people, projects and ideas
  * Actual logistics of talent assessment and promotions
* **Short term, Organization**
  * Conduct team meetings
  * Process information into plans, and spot trends
  * Help resolve any misunderstandings
  * Actual hiring process
* **Short term, Work**
  * Schedule work that's already been decided (like release planning) or make decisions based on existing roadmap and vision
  * Follow up on key issues, if need be, and unblock
  * Ensure that tasks are properly staffed by the correct people
* **Medium term, Self**
  * Maintain my prioritized TODO list
  * Grow and maintain my network. Notice opportunities and foster relationships
  * Collect medium-term feedback (such as upon project completion, or interaction finished)
* **Medium term, Individuals**
  * Mentor and coach
  * Spot recognition for good work (like `#thanks` channel and discretionary bonuses)
  * Keep an eye on continued performance
* **Medium term, Organization**
  * Plan team events
  * Plan trainings needed
  * Review productivity over time, and foster improvements where needed
  * Rrocess input from recurring meetings on different levels, and generate tasks
* **Medium term, Work**
  * Plan team events
  * Mid-term planning: what should we do next quarter that we aren't doing now?
  * Project staffing: who's going to work on that?
  * OKR progress tracking, and interventions if need be
* **Long term, Self**
  * Plan team events
  * Strategy plans, self. (Where do I want to be in five years?)
  * Career planning, self. (How do I get there?) Gap analysis
  * Education, self. Trainings, books, mentoring
  * Collect long-term feedback
* **Long term, Individuals**
  * Plan team events
  * Career planning for individuals, balancing their needs and wants versus available opportunities
  * Set people up for success: champion their goals, get them "in the room" for relevant discussions, get them recognition for long-term results
  * Happiness planning long term: how will work fit into their overall lives?
* **Long term, Organization**
  * Plan team events
  * Reassess organizational structure and fit into the larger org: what serves this team best?
  * Reassess skill mix: what do we need that we don't have?
  * Plan for staffing
  * Team and organization culture planning: what should change, what should be encouraged
  * Reassess team and organization values
  * Get recognition of and visibility for team results
  * Long-term feedback loops, and action items resulting from them
* **Long term, Work**
  * Strategic plans: keeping vision and roadmaps up-to-date
  * Translate company business goals into organization-level, actionable project ideas
  * Bring bottom-up initiatives to higher-level attention

</details>

## Exercise 2: relative importance of activities

Say you have some tasks ready to go in each box.

* Where should you focus your attention? What about over a longer period?
* What happens if you don't do some of this for a day, a month, or a year?
* How do you ensure that nothing important is forgotten?

## Exercise 3: quality control

Where in the matrix was your attention in the recent past? Where _wasn't_ it?

* What was the reason?
* What was the effect?
* What are some situations that require more focus on one box, rather than another?

## References

* [Transitioning to a manager role](/handbook/people-group/learning-and-development/manager-development/)
* [Becoming a GitLab manager issue](https://gitlab.com/gitlab-com/people-group/Training/-/blob/master/.gitlab/issue_templates/becoming-a-gitlab-manager.md)
* [Elevate training program](/handbook/people-group/learning-and-development/elevate-programs/)
* [High Output Management](/handbook/leadership/high-output-management/)
* [How to be a great remote manager](/handbook/company/culture/all-remote/being-a-great-remote-manager/)
