---
title: Pipeline Monitoring
description: Overview of our monitoring tools and practices
---

## End-to-end test pipelines

The test pipelines run on a scheduled basis, and their results are posted to Slack. The following are the end-to-end test pipelines that are monitored every day.

| Environment                               | Links                                                                                                                                                                                                                                                   | Tests type      | Frequency                                                                                                                                                                                                                                                      | Slack channel                                                                                                                       | Latest test report                                                                                           |
|-------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------|
| Production                                | [Pipelines](https://ops.gitlab.net/gitlab-org/quality/production/pipelines) \| [Chatops](https://gitlab.com/gitlab-com/chatops/-/blob/eb65043eda62102b0ca38dd0cd5afc36a9dcedb4/lib/chatops/gitlab/tests_pipeline.rb#L40)                                | Smoke           | [after each deployment to Canary](https://ops.gitlab.net/gitlab-com/gl-infra/deployer/pipelines) and [after a feature flag in production has been updated to *true* or *100%*](https://docs.gitlab.com/ee/development/feature_flags/)                          | [`#e2e-run-production`](https://gitlab.slack.com/messages/CCNNKFP8B)                                                                                                                  | [Production Sanity](https://gitlab-qa-allure-reports.s3.amazonaws.com/production-sanity/master/index.html)   |
| Canary                                    | [Pipelines](https://ops.gitlab.net/gitlab-org/quality/canary/pipelines) \| [Definition](https://gitlab.com/gitlab-org/release-tools/-/blob/72b34fb21ecea70aec3ac2ce4e2387189c24bd3b/.gitlab/ci/coordinated-pipeline.gitlab-ci.yml#L695-713)             | Smoke           | [after each deployment to Canary](https://ops.gitlab.net/gitlab-com/gl-infra/deployer/pipelines)                                                                                                                                                               | [`#e2e-run-production`](https://gitlab.slack.com/messages/CCNNKFP8B)                                                                                                                  | [Canary Sanity](https://gitlab-qa-allure-reports.s3.amazonaws.com/canary-sanity/master/index.html)           |
| -                                         | [Pipelines](https://ops.gitlab.net/gitlab-org/quality/canary/pipelines) \| [Definition](https://gitlab.com/gitlab-org/release-tools/-/blob/954ef48375acddcbf7dc68c541b1437ba8c5bc7c/.gitlab/ci/post-deploy-migrations-pipeline.gitlab-ci.yml#L182-194)  | Full            | [after each deployment to Canary](https://ops.gitlab.net/gitlab-com/gl-infra/deployer/pipelines)                                                                                                                                                               | [`#e2e-run-production`](https://gitlab.slack.com/messages/CCNNKFP8B)                                                                                                                  | [Canary Full](https://gitlab-qa-allure-reports.s3.amazonaws.com/canary-full/master/index.html)               |
| Staging                                   | [Pipelines](https://ops.gitlab.net/gitlab-org/quality/staging/pipelines) \| [Definition](https://gitlab.com/gitlab-org/release-tools/-/blob/954ef48375acddcbf7dc68c541b1437ba8c5bc7c/.gitlab/ci/post-deploy-migrations-pipeline.gitlab-ci.yml#L197-209) | Smoke           | [after each deployment to Staging-Canary](https://ops.gitlab.net/gitlab-com/gl-infra/deployer/pipelines)                                                                                                                                                       | [`#e2e-run-staging`](https://gitlab.slack.com/messages/CBS3YKMGD)                                                                                                                     | [Staging Sanity](https://gitlab-qa-allure-reports.s3.amazonaws.com/staging-sanity/master/index.html)         |
| -                                         | [Pipelines](https://ops.gitlab.net/gitlab-org/quality/staging/pipelines) \| [Definition](https://gitlab.com/gitlab-com/gl-infra/deployer/-/blob/29cab58a873dff1e49e9192bd6420d78e8e84bc8/ci/environments/gstg.yml#L238-248)                             | Smoke           | [after the execution of post-deploy migrations in Staging](https://ops.gitlab.net/gitlab-com/gl-infra/deployer/pipelines)                                                                                                                                      | [`#e2e-run-staging`](https://gitlab.slack.com/messages/CBS3YKMGD)                                                                                                                     | [Staging Sanity](https://gitlab-qa-allure-reports.s3.amazonaws.com/staging-sanity/master/index.html)         |
| Staging Canary                            | [Pipelines](https://ops.gitlab.net/gitlab-org/quality/staging-canary/pipelines) \| [Definition](https://gitlab.com/gitlab-org/release-tools/-/blob/72b34fb21ecea70aec3ac2ce4e2387189c24bd3b/.gitlab/ci/coordinated-pipeline.gitlab-ci.yml#L385-403)     | Smoke           | [after each deployment to Staging](https://ops.gitlab.net/gitlab-com/gl-infra/deployer/pipelines)                                                                                                                                                              | [`#e2e-run-staging`](https://gitlab.slack.com/messages/CBS3YKMGD)                                                                                                                     | [Staging-Canary](https://gitlab-qa-allure-reports.s3.amazonaws.com/staging-canary-sanity/master/index.html)  |
| CustomersDot Staging                      | [Pipelines](https://gitlab.com/gitlab-org/customers-gitlab-com/-/pipelines) \| [Definition](https://gitlab.com/gitlab-org/customers-gitlab-com/-/blob/e8d058a9f54aeae1218491ad34cdfd67d27d084f/.gitlab/ci/e2e.gitlab-ci.yml#L199-255)                   | Full            | [after each deployment to CustomersDot Staging](https://gitlab.com/gitlab-org/customers-gitlab-com/-/pipelines)                                                                                                                                                | [`#e2e-run-staging`](https://gitlab.slack.com/messages/CBS3YKMGD) [`#s_fulfillment_status`](https://gitlab.slack.com/messages/CL7SX4N86)                                              | [CustomersDot Staging](https://gitlab-qa-allure-reports.s3.amazonaws.com/cdot-e2e-staging/main/index.html)   |
| Staging Ref                               | [Pipelines](https://ops.gitlab.net/gitlab-org/quality/staging-ref/pipelines) \| [Definition](https://gitlab.com/gitlab-com/gl-infra/deployer/-/blob/10cc4811f5aae0a38b77cd5c9def954a0e2afac1/ci/environments/gstg-ref.yml#L177-191)                     | Smoke           | [after each deployment to Staging Ref](https://ops.gitlab.net/gitlab-com/gl-infra/deployer/pipelines).                                                                                                                                                         | [`#e2e-run-staging-ref`](https://gitlab.slack.com/archives/C02JGFF2EAZ)                                                                  | [Staging Ref Sanity](https://gitlab-qa-allure-reports.s3.amazonaws.com/staging-ref-sanity/master/index.html) |
| Preprod                                   | [Pipelines](https://ops.gitlab.net/gitlab-org/quality/preprod/pipelines) \| [Definition](https://gitlab.com/gitlab-com/gl-infra/deployer/-/blob/2279042064c45fdb10ce696d1c4ef12b72affbfd/ci/environments/pre.yml#L171-181)                              | Smoke           | [Every month for a few days before release, at 03:00 UTC](https://ops.gitlab.net/gitlab-org/quality/preprod/-/pipeline_schedules) and after [deployment to preprod](/handbook/engineering/infrastructure/environments/#pre) during Security and Patch releases | [`#e2e-run-preprod`](https://gitlab.slack.com/archives/CR7QH0RV1)                                                                        | [Preprod](https://gitlab-qa-allure-reports.s3.amazonaws.com/preprod-sanity/master/index.html)                |
| Release                                   | [Pipelines](https://ops.gitlab.net/gitlab-org/quality/release) \| [Definition](https://gitlab.com/gitlab-com/gl-infra/deployer/-/blob/10cc4811f5aae0a38b77cd5c9def954a0e2afac1/ci/environments/release.yml#L82-93)                                      | Smoke           | [Every month after the final release](https://ops.gitlab.net/gitlab-org/quality/release/-/pipeline_schedules) and after [deployment to Release](/handbook/engineering/infrastructure/environments/#release) during Security and Patch releases                 | [`#e2e-run-release`](https://gitlab.slack.com/archives/C0154HCFLRE)                                                                      | [Release](https://gitlab-qa-allure-reports.s3.amazonaws.com/release-sanity/master/index.html)                |
| GitLab `master` `e2e:test-on-omnibus-ee` | [Pipelines](https://gitlab.com/gitlab-org/gitlab/pipelines) \| [Definition](https://gitlab.com/gitlab-org/gitlab/-/blob/77a5b0b3f8f910d4fe89a3fed46c4da53b1e587e/.gitlab/ci/qa.gitlab-ci.yml#L77-88)                                                    | Full            | [scheduled pipeline every 2 hours](https://gitlab.com/gitlab-org/gitlab/pipeline_schedules)                                                                                                                                                                    | [`#e2e-run-master`](https://gitlab.slack.com/archives/CNV2N29DM)                                                                                                                      | [Master EE](https://gitlab-qa-allure-reports.s3.amazonaws.com/e2e-test-on-omnibus/master/index.html)        |
| GitLab `master` `e2e:test-on-omnibus-ce` | [Pipelines](https://gitlab.com/gitlab-org/gitlab/-/pipeline_schedules) \| [Definition](https://gitlab.com/gitlab-org/gitlab/-/blob/77a5b0b3f8f910d4fe89a3fed46c4da53b1e587e/.gitlab/ci/qa.gitlab-ci.yml#L121-135)                                       | Full            | [Daily at 4:00am UTC](https://gitlab.com/gitlab-org/gitlab/-/pipeline_schedules)                                                                                                                                                                               | [`#e2e-run-master`](https://gitlab.slack.com/archives/CNV2N29DM)                                                                                                                      | [Master CE](https://gitlab-qa-allure-reports.s3.amazonaws.com/e2e-test-on-omnibus-ce/master/index.html)     |
| GitLab `master` `e2e:test-on-gdk`         | [Pipelines](https://gitlab.com/gitlab-org/gitlab/-/pipelines?ref=master&amp;source=schedule) \| [Definition](https://gitlab.com/gitlab-org/gitlab/-/blob/77a5b0b3f8f910d4fe89a3fed46c4da53b1e587e/.gitlab/ci/qa.gitlab-ci.yml#L151-164)                 | Full            | [scheduled pipeline every 2 hours](https://gitlab.com/gitlab-org/gitlab/pipeline_schedules)                                                                                                                                                                    | [`#e2e-run-master`](https://gitlab.slack.com/archives/CNV2N29DM)                                                                                                                      | [Master GDK](https://gitlab-qa-allure-reports.s3.amazonaws.com/e2e-test-on-gdk/master/index.html)            |
| GitLab `master` `e2e:test-on-cng`         | [Pipelines](https://gitlab.com/gitlab-org/gitlab/-/pipeline_schedules) \| [Definition](https://gitlab.com/gitlab-org/gitlab/-/blob/77a5b0b3f8f910d4fe89a3fed46c4da53b1e587e/.gitlab/ci/qa.gitlab-ci.yml#L166-178)                                       | Smoke, Blocking | [scheduled pipeline every 2 hours](https://gitlab.com/gitlab-org/gitlab/pipeline_schedules)                                                                                                                                                                    | [`#e2e-run-master`](https://gitlab.slack.com/archives/CNV2N29DM)                                                                                                                      | [Master CNG](https://gitlab-qa-allure-reports.s3.amazonaws.com/e2e-test-on-cng/master/index.html)            |
| GitLab `master` Nightly                   | [Pipelines](https://gitlab.com/gitlab-org/gitlab/-/pipeline_schedules) \| [Definition](https://gitlab.com/gitlab-org/gitlab/-/blob/77a5b0b3f8f910d4fe89a3fed46c4da53b1e587e/.gitlab/ci/qa.gitlab-ci.yml#L137-149)                                       | Full            | [Daily at 4:00am UTC](https://gitlab.com/gitlab-org/gitlab/-/pipeline_schedules)                                                                                                                                                                               | [`#e2e-run-master`](https://gitlab.slack.com/archives/CNV2N29DM)                                                                                                                      | [Master Nightly](https://gitlab-qa-allure-reports.s3.amazonaws.com/nightly/master/index.html)                |

NOTE:
For information on how to investigate failing tests and pipelines, check out [Debugging Failing Tests and Test Pipelines](../debugging-qa-test-failures/index.md)

## Test metrics

For visibility on the test health, we have test execution results exported to:

- an [InfluxDb](https://influxdb.quality.gitlab.net/) instance and use [Grafana](https://dashboards.quality.gitlab.net/) dashboards to visualize the results
- a [Google Cloud Storage (GCS)](https://console.cloud.google.com/storage/browser/test_tools_infra_e2e_metrics) instance which is then accessible through [Snowflake](https://app.snowflake.com/ys68254/gitlab)

## Test reports

### Allure report

Another tool we have to present the test results is through the [Allure](https://github.com/allure-framework/allure2) test reports. Tests that run on pipelines generate Allure reports. The `QA` framework uses the [Allure RSpec](https://github.com/allure-framework/allure-ruby/blob/master/allure-rspec/README.md) gem to generate source files for the `Allure` test report. An additional job in the pipeline:

- Fetches these source files from all test jobs.
- Generates and uploads the report to the `S3` bucket `gitlab-qa-allure-report` located in `AWS` group project `eng-quality-ops-ci-cd-shared-infra`.

Each type of scheduled pipeline generates a static link for the latest test report according to its stage:

| Environment                  | Description                                                                                                                                               | Link                                                     |
| ---------------------------- | --------------------------------------------------------------------------------------------------------------------------------------------------------- | -------------------------------------------------------- |
| `master` (`gdk`)             | E2E test execution against [`gitlab-development-kit`](https://gitlab.com/gitlab-org/gitlab-development-kit) environment packaged in a `Docker` container. | {{< test-execution-allure-link "e2e-test-on-gdk" >}}     |
| `master` (`test-on-omnibus`) | E2E test execution against various configurations of `omnibus` images.                                                                                    | {{< test-execution-allure-link "e2e-test-on-omnibus" >}} |
| `nightly`                    | E2E test execution against various configurations of `omnibus` nightly images.                                                                            | {{< test-execution-allure-link "nightly" >}}             |
| `staging-full`               | E2E test execution against `https://staging.gitlab.com` environment.                                                                                      | {{< test-execution-allure-link "staging-full" >}}        |
| `staging-sanity`             | E2E test execution against various configurations of `omnibus` nightly images.                                                                            | {{< test-execution-allure-link "staging-sanity" >}}      |
| `staging-ref-full`           | E2E test execution against `https://staging-ref.gitlab.com` environment.                                                                                  | {{< test-execution-allure-link "staging-ref-full" >}}    |
| `staging-ref-sanity`         | E2E test execution against `https://staging-ref.gitlab.com` environment.                                                                                  | {{< test-execution-allure-link "staging-ref-sanity" >}}  |
| `preprod`                    | E2E test execution against `https://pre.gitlab.com` environment.                                                                                          | {{< test-execution-allure-link "preprod-sanity" >}}      |
| `production-full`            | E2E test execution against `https://gitlab.com` environment.                                                                                              | {{< test-execution-allure-link "production-full" >}}     |
| `production-sanity`          | E2E test execution against `https://gitlab.com` environment.                                                                                              | {{< test-execution-allure-link "production-sanity" >}}   |

These reports are also included in the pipeline status alerts on Slack.

### Test session issue

For each end-to-end pipeline that runs in the various environments we automatically test, we create a [test session issue](https://gitlab.com/gitlab-org/quality/testcase-sessions/-/issues) that contains the test session information. Test session issues group test results by DevOps stages, and link to [test cases](https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases), and [test failure issues](https://gitlab.com/gitlab-org/gitlab/-/issues/?label_name%5B%5D=QA).

Example of a test session issue: <https://gitlab.com/gitlab-org/quality/testcase-sessions/-/issues/72516>

Test session issues are a [workaround for a missing GitLab feature](https://gitlab.com/groups/gitlab-org/-/epics/3129). Once GitLab stores test data, we can improve failure reporting and management.

### Test result issue

Each test is associated to a [GitLab testcase](https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases).

```ruby
  RSpec.describe 'Stage' do
    describe 'General description of the feature under test' do
      it 'test name', testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/:test_case_id' do
        ...
      end

      it 'another test', testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/:another_test_case_id' do
        ...
      end
    end
  end
```

The test failure stack trace and the issue stack trace are compared, and the existing issue for which the stack trace is the most similar (under a 15% difference threshold) to the test failure is used. The test failure job is then added to the failure report list in the issue. Group label is automatically inferred based on the `product_group` metadata of the test.
