---
title: "Functional Analytics Center of Excellence"
description: "The FACE is a cross-functional group of functional analytics teams that aim to make our teams more efficient by solving and validating shared data questions which results in cohesive measurement approaches across teams."
---

## Welcome to the FACE of Data Handbook

{{% alert color="success" %}}
The FACE (functional analytics center of excellence) is a cross-functional group of functional analytics teams that aim to make our teams more efficient by solving and validating shared data questions which results in cohesive measurement approaches across teams.
{{% /alert %}}

## Context

The [central data team](/handbook/enterprise-data/) serves as the hub for all of our ["spoke" functional analytical teams](/handbook/enterprise-data/#how-data-works-at-gitlab); however, we have an opportunity to establish spokes between the spokes. Enter: the creation of the functional analytics center of excellence (FACE).

## FACE Teams: what functional analytics teams are participating?

|  **Team Name** | **Lead(s)** |
| :--------------- | :----------------- |
| [Product Data Insights](/handbook/product/groups/product-analysis/) | Carolyn Braza |
| [Marketing Analytics](/handbook/marketing/strategy-performance/) | Jerome Ahye |
| [Self-Service & Online Sales](/handbook/sales/self-service/) | Max Fleisher |
| [Sales Analytics](/handbook/sales/field-operations/sales-strategy/) | Melia Vilain & Noel Figuera |
| Customer Success Analytics | Michael Arntz |
| Digital Experience | Dennis Charukulvanich  |
| [People Analytics](/handbook/people-group/people-ops-tech-analytics/people-analytics/) | Adrian Perez |
| [Central Data Team](/handbook/enterprise-data/) | Israel Weeks & Jong Lee |
| [Engineering Analytics](/handbook/engineering/quality/engineering-analytics/) | Cynan de Leon |

## Objectives of the FACE

- **Efficiency**: it is not uncommon for our teams to be asked similar questions (eg how are trials converting) but it is inefficient and duplicative for each team to tackle these questions on our own.
- **Alignment**: in cases where we are tackling similar questions, we need alignment of the assumptions and methodology we are using to answer those questions. The FACE ensures we all deliver cohesive data stories.
- **Knowledge Share**: this forum will give us a formal venue to learn from one another as opposed waiting for organic moments of knowledge sharing.

## Outputs of the FACE

- **Cadence**: our teams will meet at least once every month if not more. We will knowledge share, align on joint quarterly projects, and develop/prioritize joint asks we have of the central data team. We will also have fun #StaySpoke.
- **Consolidated asks to central data team**: we have an opportunity to streamline, consolidate, and prioritize our asks to the central data team. We also partner with the central data team on data program-level evaluations and decisions (eg BI tooling).
- **Subject Matter Expert Lookup**: we will develop a documented list of people and their associated areas of expertise. SME's will also be able to document their source of truth resources (eg snippets, dashboards, reports).
- **Quarterly Projects**: we will propose and pick cross-functional projects for us to work on quarterly. This will make us all more efficient by assigning 1 DRI with 2 or more code reviewers.
- **Peer Review + Assumptions Approval**: as a part of the quarterly projects, we will establish a code peer review and assumptions approval process that will ensure we will all be enthusiastic adopters of the ultimate output.
- **Code Repo**: after a project has gone through the peer review and assumptions approval process, we will commit it to a repository that any data person can leverage in their work.

## Examples: what are the types problems the FACE tackles?

- How do free and trial sign-ups convert?
- How do we link namespaces to Salesforce accounts?
- How do we link leads/INQ to Salesforce accounts?
- How do we identify business emails v. junk account emails?

## Turn and Share Meetings

In line with our [Collaboration](/handbook/values/#collaboration) value, **Turn & Share** sessions are a way for us to share our work with other analysts (or anyone at GitLab who is interested). These sessions began in October of 2023. More details on these sessions are outlined below:

**Overall Goal**: Encourage each of the analytic teams at GitLab to reach out to each other for data resources and ideas on how to solve reporting, statistical, and data science problems of various complexity levels.

**General Guidelines for Discussions**

1. Work does not need to be completed or in a finished state to be presented.
2. Slides are not always necessary, unless that is easier for the presenter to share their thoughts.
3. Active participation during sessions is what we're striving for. Questions at the time of presentation can be very helpful for all, especially the presenter.

**Note**: Goal is not to solve the problems we have in the meeting, rather to discuss and share ideas and thoughts. For deep discussions, follow-up meetings should be scheduled with interested Team Members.

### Meeting Cadence

We strive to meet every three weeks, alternating between AMER and APAC time zones to facilitate consistent knowledge sharing and collaboration across functional analysts.

### Sign Up for Presenters

We will collect sign ups and coordinate meeting schedules & facilitators in this [sheet](https://docs.google.com/spreadsheets/d/1L1oFCzmjUT6HWi1DNOa31WISqVfHOMXp924e__Ao4Pg/edit#gid=1615918759)

### Meeting Documentation

- **[Agenda](https://docs.google.com/document/d/1H1AI-rwcubZ2UYuf8JGUiMUb7gLoeDXuPQ6Kmfyc2iE/edit#heading=h.2e7gftq6eevx)**
  - We collect notes, presentations, and Q&A during sessions.
- **Recordings** Meeting recordings are appended to the agenda post-session.

### Presenting SAFE Data

At times, presentations will contain data that is considered [SAFE](/handbook/legal/safe-framework/#safe). If this is the case it is important to take the following into considerations:

- Is everyone present able to see SAFE data? If the answer is no then it would be best to not share the visuals or create "mock data" that can be used for demonstration purposes.
- Is this being recorded? If the demo includes SAFE data, then the parts of the demo that include SAFE data should not be recorded. Even if everyone present can view SAFE data, visualized data cannot be recorded as the recordings are shared with a wider audience. It is best to stop the recording before sharing screen with the SAFE data in view or not record at all.

## Working With Us

- Slack channel: `#functional_analytics_center_of_excellence`
- Open an issue in our [Functional Analytics Center of Excellence](https://gitlab.com/gitlab-data/functional-analytics-center-of-excellence/) project
- Join our biweekly meetings or monthly project turn and shares: ask in our Slack channel
- Read our [meeting notes](https://docs.google.com/document/d/1fQ8zO1t4q_YkwatAlfSleFIG5iugQhx3pOiTxqCs4kk/edit?usp=sharing) and watch meeting recordings [access required]
