---
title: Finance
---

Welcome to the GitLab Finance Handbook
{.h2}

The GitLab Finance Department includes multiple Teams: Accounting, Financial Planning & Analysis, Tax and Business Operations Programs.

<i aria-hidden="true" class="fab fa-gitlab fa-fw icon-color font-awesome"></i> Quick Links
{.h2}

- [Finance Issues](https://gitlab.com/gitlab-com/finance/issues)
  - Please use confidential issues for topics that should only be visible to team members at GitLab.
- [Accounts Payable](accounts-payable/)
- [Expense Guidelines](expenses/)
- [Operating Metrics]({{< ref "key-review" >}})
- [Procurement](procurement/)
- [Sales Comp Plan](sales-comp-plan/)
- [Signature Authorization Matrix](authorization-matrix/)
- [Authorization Matrix Policy](authorization-matrix/#authorization-matrix-policy)
- [Stock Options](/handbook/total-rewards/stock-options/)

## Forms

- [2024 GitLab Inc W-9 Document and Certificate of Residence](https://gitlab.com/gitlab-com/Finance-Division/tax-team/-/issues/461)
- Form CA-590 - Please request by email to tax@gitlab.com

## Correspondence

- Please use the `#finance` chat channel in Slack for questions that don't seem appropriate for the issue tracker or internal email correspondence.
- **Accounts Payable**- inquiries which relate to vendor and merchant invoices, or team member's expenses should be sent to our Accounts Payable mailbox - *ap@gitlab.com*. You can also reach the AP team on Slack in the `#accountspayable` or `#expense-reporting-inquiries` chat channels.  Invoices that require payment processing should be sent to *ap@gitlab.com*.
- **Billing Operations**- customer billing inquiries should be sent to our Billing mailbox – *billing@gitlab.com*.
- **Accounts Receivable** - customer payment/remittance inquiries should be sent to our Accounts Receivable mailbox - *AR@gitlab.com*
- **Payroll**- inquiries which relate to contractor invoices should be sent to our Payroll mailbox - *nonuspayroll@gitlab.com*.

## CFO Approvals

- Please use the `#cfo-approvals` chat channel in Slack for alerting the CFO to a request for his approval
- Tag the CFO's Staff EBA in the Slack request for visibility and followup
- Appropriate Finance team members in the approval flow must approve prior to requesting CFO approval
- All requests must go through the appropriate approvals process, include a link to the Issue or description and receive all approvals prior to requesting CFO approval

---

<div class="text-center rounded-3 p-3 display-6 text-primary" style="border: 2px solid #5468ff;"><strong>We <i class="fas fa-heart orange font-awesome" aria-hidden="true"></i> Finance</strong></div>

## <i aria-hidden="true" class="fas fa-book fa-fw icon-color font-awesome"></i>Finance Handbooks{#finance-handbooks}

- [Accounting](accounting/)
- [Business Technology](/handbook/business-technology/)
- [Financial Planning & Analysis](financial-planning-and-analysis/)
- [Investor Relations](investor-relations//)
- [Tax](/handbook/tax)

---

## General Topics

### Legal and Financial Information

For commonly requested company information, please visit our [wiki page](https://gitlab.com/gitlab-com/finance/wikis/company-information).

### Company Accounts

Login information for the following accounts can be found in the Secretarial vault
on 1Password:

- FedEx
- Amazon
- IND (Immigratie en Naturalisatie Dienst, in the Netherlands) company number

If you need this information but cannot find it in your shared vaults, check with the People Connect Team members to get access.

### Fiscal Year

A fiscal year is a one-year period that corporations use for accounting and budgeting.
GitLab's Fiscal Year runs from February 1 to January 31. The fiscal year naming correlates to the ending month of the given fiscal year, for example FY25 is GitLab's fiscal year running February 1, 2024 to January 31, 2025.

- Q1: February 1 through April 30
- Q2: May 1 through July 31
- Q3: August 1 through October 31
- Q4: November 1 through January 31

| Fiscal Year | Calendar Year |
| ----------- | ------------- |
| FY25-Q1 | 2024-02-01 to 2024-04-30 |
| FY25-Q2 | 2024-05-01 to 2024-07-31 |
| FY25-Q3 | 2024-08-01 to 2024-10-31 |
| FY25-Q4 | 2024-11-01 to 2025-01-31 |

Refer to our [writing style guidelines](/handbook/communication/#writing-style-guidelines) for proper use of date formats.

### Revenue non-committee

- **Internal Management Members:** Chief Financial Officer (DRI), Chief Executive Officer, Chief Revenue Officer (model, guidance, plan, target)

## Invoice template and where to send

Vendor invoices are to be sent to ap@gitlab.com and payroll@gitlab.com for contractors. An [invoice](https://docs.google.com/spreadsheets/d/1sRA2uCpFblOleyVIslqM4YwbW27GkU5DTgwMLhgR_Iw/edit?usp=sharing) template can be found in Google Docs by the name of "Invoice Template".

Non-US contractors not from Hungary, Italy, Japan, New Zealand, Nigeria, South Africa, Switzerland, and Ukraine will get pay their monthly wages and expenses through iiPay. Here is the process:

- enter bank information in Workday under Bank Information tab. Note - new contractor should enter their bank information within 3 business days from their start date.
- enter VAT number if it is available
- submit monthly salary/bonus/commission invoice in through Google form by the 8th of each month (as described to you during onboarding)
- submit expenses through Navan Expense by the 8th of each month
- the scheduled payment date is the 22nd of each month
- iiPay will send out remittance advice along with the scheduled payment via your GitLab email address

Non-US contractors from Italy, Nigeria, South Africa, Switzerland, and Ukraine will need to send their monthly invoice for salary/bonus/commission and any [expenses](/handbook/finance/spending-company-money/) by the 15th to payroll@gitlab.com.

In many cases, VAT will not be payable on transactions between GitLab BV and EU-based
vendors/contractors, thanks to "Shifted VAT". To make use of this shifted VAT:

- The vendor/contractor writes the phrase "VAT shifted to recipient according to
article 44 and 196 of the European VAT Directive" on the invoice along with the
VAT-number of GitLab IT BV (NL860316828B01).
- On the vendor's VAT return the revenue from GitLab BV goes to the rubric "Revenue within the EU". It goes without saying that vendors are responsible for their own correct and timely filings.
- GitLab BV files the VAT on the VAT return, and is generally able to deduct this VAT all as part of the same return.

### Timesheets for Hourly Employees

1. People Ops and Finance will share a private Google Sheet with you where you will log your hours for each day in the "hours" column.
1. There is a dropdown in the "pay type" column, with the default being Regular. There are also options for Overtime, Vacation, Sick, and Bereavement. Choose the appropriate pay type for your time.
1. If you work overtime or more hours than agreed upon in your contract, please obtain approval from your manager and forward to Finance before payroll cutoff.
1. Your timesheet is due one day prior to the submit payroll date, which is outlined for the calendar year on your timesheet.

### How spend is allocated to departments

Budgets are aligned to departments, and budgets follow the owner who requested the spend. When determining who should request the spend, consider the owner of the outcome.

For example, work to enable a sales partner that will not be incorporated into the product would go to Sales. Work that will be part of the product and supported by engineering, should be charged to the Engineering budget.

### Finance Business Partner Alignment

| Function | Name |
| -------- | ---- |
| Customer Support | [R&D Finance](financial-planning-and-analysis/r-and-d-finance/) |
| R & D | [R&D Finance](financial-planning-and-analysis/r-and-d-finance/) |
| Sales | [Sales Finance](financial-planning-and-analysis/sales-finance/) |
| Professional Services | [Sales Finance](financial-planning-and-analysis/sales-finance/) |
| Marketing | [Marketing Finance](financial-planning-and-analysis/marketing-finance/) |
| G & A | Ellen Boyd and Jess Smith |

### Types of Work that the team does

1. Level 1: Keeping the lights on activity. Always striving to make this area as efficient as possible so more Layer 2 focus can be attained. Example: closing the books.
1. Level 2: Operational Efficiencies, Business Engagement and Partnering, actionable insights for the organization. Examples: improving close process, partnering with sales to make a business decision
