---
title: Accounts Payable
decription: >-
  This page contains GitLab's Accounts Payable department policies, procedures
  and guidelines.
---

This page contains GitLab's Accounts Payable department policies, procedures and guidelines. Our goal is to enable payments in a timely manner to both our team members and our external partners. We also provide useful links to other areas of the handbook that are relevant to the Accounts Payable procedures.

## <i id="biz-tech-icons" class="far fa-paper-plane"></i> Introduction

Welcome to Accounts Payable, commonly referred to as AP. You should be able to find answers to most of your questions in the sections below. If you cannot find what you are looking for, then please connect with us:

- **Chat Channel**: `#accountspayable`
- **Email**: `ap@gitlab.com`

## <i id="biz-tech-icons" class="fas fa-bullseye"></i> General Guidelines

- Vendors must be onboarded in Coupa to process invoices.
- All purchases/services with a total contract value over $5000 are **required** to have a purchase order, unless it falls under the [PO Exception Policy](/handbook/business-technology/enterprise-applications/guides/coupa-guide#how-to-receive-an-order). This also applies to one off purchases over $5,000.00. Repeat purchases from the same vendor should have a PO.
- Invoice Entity and Invoice Currency should be matched to the PO Entity and PO Currency.
- Ensure to indicate the PO number in the invoice copy. For Non-PO invoice, provide the related department to be charged.
- Vendors are highly encouraged to directly upload their invoices and match it to their PO using the Coupa Supplier Portal- in the event the vendor is unable to submit invoices via Coupa then they can email PDF copies to ap@gitlab.com.
- Payment Runs are completed on Thursdays. Invoices that are selected for payment on Thursday must be fully approved and vendors successfully on-boarded by end of day Tuesday of that week to be included in Thursday's payment run. The payments go out in the following days and may take 1-5 business days to reach the vendor's bank. This depends on the country, currency and the method of payment chosen.
- Invoices are paid strictly by the invoice due dates. Any **"Urgent Payment"** requests will be paid in the next available payment run as long as they have been fully approved and the vendor has been successfully on-boarded. **AP cannot accommodate same day payment requests**.
- Suppliers are to be paid via CoupaPay, ACH or Wire only. AP does not issue check payments.
- The cutoff for customer refund payments is the 25th of each month. Any customer refund requests received after the 25th will be paid the following month.

## <i class="fas fa-file-invoice"></i> Accounts Payable Processing

1. Vendor Invoices - These invoices are processed in Coupa either PO Backed or Non PO backed. Vendors must be set up or onboarded in Coupa and invoices must contain all required information like Invoice Number, Invoice Date, Payment Terms, PO Number, Invoice Amount, Currency, and Service Dates/Period to proceed with processing. Quotations, Order Forms, Agreements, Contracts are not valid for invoice processing, only "Invoice" is allowed.
    - If the invoice doesn't fall under the PO Exception Policy, please ensure the invoice has a corresponding PO before sending it to the AP Team for processing.
    - For PO Backed invoices, kindly ensure that the PO is already approved to proceed with processing and do not attach the invoice in the PO as AP Team will not be able to check/monitor that section.
    - Kindly ensure that the PO has enough balance to process the invoice. Do not provide a PO number that has been fully matched or already closed to the vendor as it may create confusion on both sides.
    - If you need to do a PO Change Request (e.g. to add funds in your current PO), please refer to this [video tutorial](https://www.loom.com/share/c932bc6308fd46939766dee333ca8401) from Procurement Team.
    - Vendors can process their invoice in their Coupa Supplier Portal using the PO Flip method. On this [link](https://compass.coupa.com/en-us/products/product-documentation/supplier-resources/for-suppliers/coupa-supplier-portal/set-up-the-csp/invoices/create-or-edit-an-invoice) please find **"Create an invoice from a PO"** for the video tutorial.
    - Vendors can also send their invoices to AP@gitlab.com. PO numbers are required to be reflected on the invoice copy or in the email body to avoid delays in processing.
    - For Non-PO invoices sent by GitLab DRI, please indicate the department to be charged instead and the Coupa approver.
    - If the invoice is received without a PO, the AP Team will reach out to the GitLab DRI and request to create a PO. Once the PO is created, DRI must email the AP Team for the PO number to proceed with processing.
    - External Supplier Forms are to be final approved by AP Team so that the vendor will be activated in Coupa, to provide our final approval, the vendor must comply with these two important documents so we can properly check the supplier form in our queue.
        - W9 for US vendors and W8 for NON US vendors
        - Bank details in a signed bank letterhead
    - You can learn more about Coupa in this [Coupa Guide Link](/handbook/business-technology/enterprise-applications/guides/coupa-guide/) and if you need further assistance you may also check the [Procurement Handbook Page](/handbook/finance/procurement/#-purchase-request-quick-guide).

1. Payroll Invoices - These are invoices provided by the Payroll Team for processing and will be manually input in Netsuite. Approval signatures are indicated on the invoice.
    - Invoices with amounts greater than or equal to USD $500,000 are required to have 2 signatories from the Payroll Team (Manager and Director).
    - Codings must be provided on the payroll banking tracker.

1. Special Invoices - Mostly these are related to reimbursements (e.g. Speaker Reimbursement, Interview Candidate Reimbursement, Ex-Team Member Reimbursement and BOD Reimbursements).
    - A template is required and must contain all the necessary information such as Vendor Name/Name of the person to be reimbursed, Invoice Date, Payment Terms, Invoice Amount, Currency, and Service Dates/Period. Receipts are required as a supporting document  for any reimbursement requests.
    - All templates must contain the full banking information of the beneficiary. If not applicable please put N/A.
        - Bank Name:
        - Beneficiary Name:
        - Beneficiary Address:
        - Account Number:
        - IBAN:
        - Routing/ABA number:
        - Wire Number:
        - Swift Code/BIC:
        - Sort Code:
        - Transit Number And Institution Number:
        - IFSC Code: (For India)
        - BSB Code: (For Australia)
    - For Speaker Reimbursement, kindly advise the related PO of the event that the speaker attended as we will align the recording of the expense same as the PO. The PO details can be indicated on the reimbursement template or in the email.

## <i class="fas fa-receipt"></i> Accounts Payable Payments

- The first step to getting an invoice paid is to review the appropriate [procurement process](/handbook/finance/procurement/).
- Make note that invoices are paid per the due date on the invoice or per the vendors payment terms in their contract, whichever comes first.
- Please note that **AP cannot process same day requests for payments**. We must follow the process outlined above and ensure all approvals are attained before paying.
- Payments are set up each **Thursday** and the money is released to vendors through the respective payment systems. It may take a few days for transfers to reach vendors depending on their location and the bank they use.
  - In order for an invoice to be included on the Thursday payment run, it must have been received and fully approved by the Tuesday. **For example**, if we are doing a payment batch on Thursday June 3rd, the invoice would have to be approved by end of day on Tuesday, June 1st in order to be included.
- Manual Payments are **only** applicable to the following:
  - Payroll Invoices
  - Speaker Reimbursement
  - Ex-Team member reimbursement
  - Interview Candidate Reimbursement
  - BOD Reimbursement

## <i class="fas fa-receipt"></i> Coupa Virtual Card

GitLab's preferred method of payment for suppliers is electronic funds transfer with supplier invoice provided as supporting documentation. In the instances where this option is not available with the supplier, [Virtual Card](/handbook/business-technology/enterprise-applications/guides/coupa-virtual-cards/), which is a temporary credit card, can be used as an alternative payment method.

## <i class="fab fa-gitlab fa-fw"></i> Fedex

- When needing to send a package on behalf of GitLab our main courier account is with FedEx.
- The first step is to contact AP in the #AccountsPayable channel to request the corporate account number.
- When sending a package **the Shipper MUST put their name under GitLab Inc in the sender field, or their full Cost Center for ex. Marketing - Field Marketing.** If you are unsure of your full cost center please go into your Workday application (click Profile icon > click Job > select Organization . look for Cost Center).
- Anyone failing to provide the correct information which will hinder AP's ability to properly code courier charges will not be allowed to use the company account in the future.

## <i class="fab fa-gitlab fa-fw"></i> Global Travel and Expense

- Please review the page on [Spending Company Money](/handbook/finance/spending-company-money/) to ensure that your spend is within GitLab's [Expense policy](/handbook/finance/expenses/).
- GitLab utilizes **Navan Travel** for all travel related Flights, Hotels, Train Travel and Vehicle Rental bookings and **Navan Expense** for all Employee reimbursable expenses.
- It also includes the preparation for **Navan Purchase Card** and **Physical Cards**.
- [Navan Purchase Card](/handbook/finance/expenses/#6-purchase-cards) - These are virtual cards only utilized by the AP team, and they are used solely for providing new Team Members with a $1,500 USD (or local currency equivalent) stipend for their home office set up upon onboarding.
- [Physical Cards](/handbook/finance/expenses/#5-physical-cards) - The purpose of this Navan Physical Card policy is to facilitate purchases necessary for the company operations and expedite the process in an efficient manner. Limit is set to $10,000 USD and provided upon request of an approved issue.
- If you have general questions about your expenses please submit a ticket to [HelpLab](/handbook/business-technology/enterprise-applications/guides/helplab-guide/#how-do-i-use-helplab).
- With the launch of HelpLab - We are kindly requesting that all questions be directed to the AP Admin team via the HelpLab ticket Process for [General Expenses Related Inquiry](https://helplab.gitlab.systems/esc?id=sc_cat_item&sys_id=f9c88a6a47f3f55067429ee0026d43b6).
- Please also review the Expense Policy and FAQ page for more guidance on the Expenses. These helpful information links can be found in the HelpLab tool under the Expenses > Quick links section.

## <i id="biz-tech-icons" class="fas fa-stream"></i> QuickLinks

<a href="{{< ref "../accounting#procure-to-pay" >}}" class="btn btn-lg btn-primary"><i class="fa-solid fa-file-invoice-dollar"></i> Invoicing and Payment</a>
<a href="{{< ref "../accounts-payable/corp-credit-cards" >}}" class="btn btn-lg btn-primary"><i class="fa-regular fa-credit-card"></i> Corporate Credit Card</a>
<a href="{{< ref "../procurement" >}}" class="btn btn-lg btn-primary"><i class="fa-solid fa-cart-plus"></i> Procurement</a>

### <i id="biz-tech-icons" class="far fa-flag"></i> Reference link

- [Coupa Tech Stack Guide](/handbook/finance/accounts-payable/tech-stack-guide-coupa/)
- [Navan Expense Stack Guide](/handbook/finance/accounts-payable/tech-stack-guide-liquid/)
- [Coupa Virtual Card guide for Accounts Payable](/handbook/finance/accounts-payable/coupa-virtual-card-guide-for-accounts-payable/)
