---
title: Global Travel and Expense Policy
---

## 1. POLICY

GitLab's Global Travel & Expense Policy is meant to provide guidance to all Team Members to ensure that we act in the best interest of our Company at all times. The purpose of this policy is to:

- Provide guidance around allowable reimbursable expenses.
- Ensure the best utilization of our Team Member's time.
- Drive transparency across all business travel related spend.
- Help Team Members understand that a centralized travel program results in improved safety, visibility, support and savings.
- Prevent violations of applicable anti-bribery and corruption laws.

## 2. Responsibilities

**Team Members**:

- As a public company, GitLab has an obligation to act in the best interests of the corporation and its shareholders. This obligation is shared by all Team Members and is the basis of our global travel and expense policy as a public company; Team Members must be thoughtful in spending the company's money.
- Use best judgment to ensure that all travel is business critical and all expenses are deemed "ordinary and necessary". Team Members should consider conducting meetings via audio or video conferencing when appropriate.
- Read, understand and adhere to GitLab's Global Travel & Expense policy.
- Team Members are also expected to inform their direct manager of all business trip plans prior to booking to ensure that the proposed trip is within their departmental budget. Team Members must receive Manager approval for any proposed business critical trips.
- Submit all expenses timely. All Team Members should submit expenses by the end of the fiscal quarter in which the expense was incurred. GitLab's fiscal quarter end dates are January 31, April 30, July 31, October 31.
- Follow-up with your manager or the AP team if they haven't approved your expense report.

**Managers and/or Budget Owners**:

- Ensure that Team members' expenses are in compliance with GitLab's Global Travel & Expense policy.
- We ask that managers set pre-trip awareness expectations within their teams to ensure that trips are business critical and budgeted for.
- Please work with your respective Finance Partner to know your specific team's budget and amount spent to date.
- Managers are expected to review their team's expenses in their entirety every month, and must flag any concerns immediately to the Accounts Payable team. Potential violations of GitLab's expense Policy as it relates to gifts and entertainment should also be flagged to the Legal department in a manner consistent with [GitLab's Whistleblower Policy](https://drive.google.com/drive/folders/1kB3k5FRnR3OUBP0Eyo3SxxyPKeiRFfUk).
- Managers will be required to sign off that they have reviewed their team's expenses.
- Managers will be held accountable for any unreported abuse by their Team Members.
- AP will flag Managers if further information is required for their direct reports.
- Please see the attached [Manager Policy](https://docs.google.com/document/d/1HQF-_fDIkjsmq-ExsFQwwTW-x8rocGKSDRZVdMYQudA/edit) for more details.

**Accounting**:

- Maintain and communicate the Global Travel & Expense Policy out to the Company on a regular cadence as updates occur.
- Ensure that expense reports are in compliance with the  Global Travel & Expense Policy.
- Provide clear and timely feedback to Team Members and managers regarding missing information, general questions, or "out of policy" issues, and escalate potential violations of the gifts and entertainment expense rules to the Legal department in a manner consistent with GitLab's [Whistleblower Policy](https://drive.google.com/drive/folders/1kB3k5FRnR3OUBP0Eyo3SxxyPKeiRFfUk).
- Review and process all expense reports that require AP Admin review, within 7 working days from the date submitted.

**Finance**:

- Maintain departmental budgets for Travel and Entertainment and Offsites.
- Work with respective Business Partners to provide specific team budgets and amounts spent to date.

## 3. General Guidelines

- Team members should submit receipts for every business expense. For Non-US Team Members, receipts are required for all expenses. US Team Members are required to only submit receipts for any expenses over $50 USD.  Receipts must contain vendor name, date of purchase, listing of what was purchased, and contains a full breakout of the subtotal and tax amounts. Snapshot from phone/computer screen of Applications, Card/Bank Statements are not an acceptable form of receipt.
- Team Members are not allowed to expense items on behalf of their managers.
Payments, gifts, favors, or entertainment for officials, employees, or representatives of government-owned entities are strictly prohibited, regardless of value.
- Expense claims for a single item up to $5,000 can be expensed via Navan. >$5,000 needs to go through the procurement process in Zip.
- Expense claims over 90 days from purchase date will not be reimbursed unless approved by the Manager.
- Navan Description box: Expense items must have a description filled out. This box is showing as optional but we require this to be filled in. This helps to correctly record the transaction and assist any reporting purposes downstream.
  - When filling in the description box , we ask for you to enter details of the expense so anyone looking at the line on a report can tell immediately (without the need of looking at the receipt) what the expense relates to and why it is claimed.
  - Please fill in the description box with details like : Items Purchased/Claimed, Period service relates to, Trip Details this claim relates to, Reason for trip, Clients Name, etc. If left blank, the expense will be bounced back to the team member to complete this portion.
- The maximum monthly limit to be reimbursed is $10K USD (or local currency equivalent). Once this limit has been reached, all expense items will need to be approved by the A/P team in Navan.  This limit may be increased for Team Members whose positions require more spend (eg. Field Marketing), but the increase request needs to be submitted via an issue for approval by the VP or higher in the Accounting Organization. Due to the nature of their roles, E-Group members have a maximum monthly limit to be reimbursed of $20K USD before additional approvals are required.
- Expenditures related to client entertainment or marketing must be necessary, prudent, and job-related.
- Expenses that span longer than a month must be submitted on a monthly basis (eg. Although you paid for a year upfront for the internet, you must divide the total by 12 months and submit the cost monthly), with the exception of VPN.
- Gift cards are not accepted as a form of payment for business expenses.
- Expense items must clearly state if the spend includes amounts for clients / non-Team Members. Tax requirements in certain countries require us to account for client spending differently.
- Anything submitted outside of these guidelines will be flagged as Out of Policy.
- All work-related expenses (internet, co-working space, other monthly subscription, etc.) are not reimbursable while on Leave of any kind.
- For PEO's, as you are aware with Navan, the system will automatically reimburse in the currency of the GitLab organization you are employed. To ensure you are reimbursed in the currency in which your PEO needs to be invoiced please submit your expenses in the payment currency you will be invoicing the PEO in. i.e. if you invoice your PEO in USD, then convert the expense into USD prior to submitting the expense report in Navan. This will then allow you to know the exact amount to invoice the PEO every month. If this is not doable then we will convert the currency using the FX rates from Netsuite on the day this expense is transferred to payroll for payment to the PEO. To find out the actual amount submitted in Navan, we can provide you a list of the expenses submitted for each month.  Please request this monthly by submitting a [HelpLab](/handbook/business-technology/enterprise-applications/guides/helplab-guide/) ticket so we can provide you the needed information.
- As with any third-party, it is best practice to limit the amount of personal data shared. The inclusion of personal data on your receipts is not required to submit an expense, so feel free to redact personal data for increased privacy. However, this is not a required step. For those that choose not to redact personal data from your expense receipts, the privacy and security controls in place at Navan were evaluated and they are designed to adequately protect your information.

### 3.1 Out of Policy Transactions

- Note that when expenses are flagged as "Out of Policy" in Navan, this does not necessarily mean the expense is "Out of Policy". It can also mean that additional review is needed due to a requirement for  certain attachments (eg. an approved issue) and/or additional approvals.
- Upon review, if more clarification is needed for a certain expense, the AP team will contact the Team Member in the Navan tool to ask for justification of the transaction before approving or rejecting the expense.
- The AP team will reach out to the Team Member's manager if additional approval is needed.
- If the claim is over the advised guidance, the claim will be rejected with a note for the Team Member. The Team Member should be able to rectify the claim and resubmit.
- Where the Team Member has already received approval from the manager, that approval should be attached as a receipt on the claim transaction.
- Any claim made which does not fall into the policy is not reimbursable.  If an item is out of policy and approved by your manager, then please obtain and attach your manager's approval email prior to submitting the expense. This will then be reviewed by the Expense team Admin and could need further approval from VP or higher in the Accounting Organization.
- There will be occasions where if you have claimed an item and it needs to be reimbursed back to GitLab, you will need to follow the repayment process in Navan for submission of the funds.

### 3.2 Trip Purpose Guidance

- When booking travel in Navan, it's important to select the proper trip purpose type from the "Trip Purpose" dropdown menu. Selecting the correct trip type is essential for accurate data reporting.
- The options for trip purpose include:
  - Company meeting - any travel for internal meetings or events (that are not listed separately) with no customers present
  - Customer visit - any travel for meetings or events where GitLab customers and prospects are in attendance including conferences, roadshows, field events, and customer meetings
  - Partner visit - any travel for meetings or events where GitLab partners are in attendance
  - Specific events - these will be visible in the trip purpose dropdown, ex: `FY25 GTM Onsite`

### 3.3 Other

- Out of Policy Transactions for all E-Group Members needs to be approved by VP or higher in the Accounting Organization.
- Any exceptions to the policy must be documented via an issue or an email with proper approvals from their manager and Finance team.

## 4. PROCEDURES

**Payment method**

- GitLab's default payment method in Navan is a central company card.
- Payment varies based on travel transaction type - air, hotel, car or rail (where applicable).
- Airfare: All airfare is charged immediately at the time of booking to the card on file. GitLab's central card is the default payment method in the system and will always be available.

**Following expenses are categorized for reimbursement purposes with specific policy definition attached to it. The limits below are in USD, please use local currency equivalents when considering other currencies.**

### 4.1 TRAVEL RELATED EXPENSES

#### Airfare

All business related flights need to be booked through Navan, and will be paid by GitLab travel card. For each flight search, Navan determines the price in real time. Also to note that while it is sometimes possible to find a cheaper flight outside of Navan, we get overall better rates in the aggregate with the buying power of the whole company. Even if a flight is cheaper outside of Navan, please book in Navan. Also submit a request under the `Expenses -> Travel Related Expenses` page of [HelpLab](/handbook/business-technology/enterprise-applications/guides/helplab-guide/) with screenshots of Navan's rate and the other airlines rate so the Expense team can address with Navan.

#### Advance Purchase

- Team Members should make air reservations as early as possible, in order to take advantage of discounted fares. Travelers will ideally book:
  - Domestic: At least 14 days in advance
  - International: At least 21 days in advance

The airfare policy in Navan is set up as a "Dynamic Policy" which calculates a fair market price for every search based on travel dates and destinations. Any purchases that are over 20% of the Dynamic Policy will be flagged for further review by your manager. Also note that anything booked outside of Navan will flag as "Out of Policy", and will need to be reviewed by your manager and the AP team.

#### Class of Service

- One class of upgrade is permitted with Manager approval for team members over 6'5"/2m in height.

#### Domestic Flights

- **Flights over 5 hours of consecutive flight time** - For domestic flights with a duration greater than 5 hours of consecutive flight time (each segment must be 5+ hours), team members are authorized to book the next class up from standard economy as long as it is below business class.

#### International Flights

- **Flights greater than 5 hours of consecutive flight time** - For international flights with a duration greater than 5 hours of consecutive flight time (each segment must be 5+ hours), team members are authorized to book the next class up from standard economy as long as it is below business class.
- **Flights exceeding 8 hours of consecutive flight time** - For those who travel frequently, defined as 3 or more trips per quarter internationally on flights of 8 hrs+ continuous flight time (minimum 6 flight segments with 8+ hours per segment), business class is permitted when traveling for any of the following reasons:
  - Meeting with customers
  - Speaking engagement
  - Representing GitLab at a conference

#### Frequent Flyer Programs

- Participation in frequent flyer programs must not influence airfare selection if it results in an out-of-policy option.
- Team Members may use personal frequent flyer miles or points for upgrades on business travel, however, Team Members will not be reimbursed for any respective charges.

#### Cancellations, Unused Tickets and Exchanges

- Team Members are responsible for canceling trips that they will no longer be able to attend.
- Flight cancellations typically result in flight credit/unused tickets that can be used going forward.
- Unused tickets must be used for future business travel whenever possible. If the Team Member knows they won't be able to use the ticket, please submit a request under the `Expenses -> Travel Related Expenses` page of [HelpLab](/handbook/business-technology/enterprise-applications/guides/helplab-guide/).
- Team Members may not personally benefit from any unused airline tickets.
- Please reach out to Navan Support if you need to change a flight.

#### Common Out-of-policy Airfare Flags in Navan

- The system automatically flags the following as out-of-policy:
  - Flight price selected is more expensive than the cheapest option + our buffer
  - Out-of-policy air class is selected
  - Flights booked less than 14 days in advance
- If the flight selected triggers any of these criteria, an email will automatically be sent to your manager for approval. Please provide sufficient reasoning to make approval easier and faster.
- After 24 hours without any manual action (approved/denied) the booking will automatically be accepted.

{{% panel header="**Coding**" header-bg="green" %}}
**Expense Type / Navan Policy Category:** Airfare
{{% /panel %}}

### Car Rental

- Rental Cars are reimbursable and should be booked through Navan, up to the intermediate car class, with a 7 day booking lead time. Rental Cars are reimbursable and should be booked through Navan, up to the intermediate car class, with a 7 day booking lead time.
- Please note that anything booked outside of Navan will flag as "Out of Policy", and will need to be reviewed by your manager and the AP team.
- Navan Confirmation should be attached to the claim along with the Car Rental Receipt.
- Team Members can claim gas expenses but not mileage, when renting a car.
- Fuel at $300 limit per day.

#### Additional Car Rental Guidelines

**A. Third Party Liability**

Purchase the liability insurance that is excess of the standard inclusion of State minimum coverage in the rental agreement at the rental agency. GitLab's insurance policy provides liability insurance for rental cars while conducting company business, but it may be excess over any underlying liability coverage through the driver or credit card company used to purchase the rental.

Purchase the liability offered at the rental counter if there are Non-US Team Members renting autos in the US or Canada. While workers' compensation would protect an injured US Team Member, other passengers may have the right to sue. To ensure that GitLab has protection when a Non-US Team Member invites another person into the car we recommend the purchase of this insurance when offered at the rental counter.

**B. Physical Damage - Collision Damage Waiver**

Do Not purchase the Collision Damage Waiver offered at the rental counter. GitLab purchases coverage for damage to rented vehicles. If travel to Mexico is required, purchase the liability insurance for Mexico offered at the rental counter. You should verify that the rental agreement clearly states that the vehicle may be driven into Mexico and liability coverage will apply.

Countries other than the US and Canada:

- Third Party Liability
  - Purchase the liability insurance offered at the rental counter when traveling outside the US and Canada. Automobile Bodily Injury and Property Damage Liability insurance are required by law in almost every country. Please verify this coverage is included with the rental agreement.
- Physical Damage - Collision Damage Waiver
  - Purchase the Collision Damage Waiver or Physical Damage Coverage offered by the rental agency when traveling outside the US and Canada.

In the event of an accident resulting in damage to the rental car, the Non-US rental agency will charge the credit card used to make the reservation with an estimated amount of repair costs if insurance is not purchased. If this happens, GitLab does not purchase Foreign Corporate Hired Auto Physical Damage Coverage to reimburse for damages.

{{% panel header="**Coding**" header-bg="blue" %}}
**Expense Type / Navan Policy Category:** Rental cars
{{% /panel %}}

### Hotels

- To be booked in Navan. When booked outside Navan - approval required by Manager and AP Admin.
- When you book Hotels through Navan Travel, the costs will need to be charged to a personal credit card.
- For business related bookings, you can submit the costs for reimbursement via the Navan Expense reimbursement tool.
- Please attach the Navan Reservation email confirmation to the claim.
- Hotel stays are reimbursable up to $300 USD (or equivalent local currency) inclusive of tax per night for standard rooms, with a 7 day booking lead time.
- However, the lodging policy in Navan is set up as a “Dynamic Policy” which calculates a fair market price for every search based on travel dates and destinations. This allows for some room in price in case the $300 USD limit is really not applicable to that area. And similar to airfare, any purchases that are over 20% of the Dynamic Policy will be flagged for further review by your manager.
- Always choose the refundable room booking unless the only available option is a non refundable room.
- The exception is the Corporate Events hotel room blocks organized by the internal team or if the conference hotel room block has better pricing than Navan.
- The hotel room block's pricing is generally within the bounds of the $300USD/night and in the event it is over that amount, please contact the AP team for an exception to be granted.
- Conference hotel room blocks or Corporate Events organized blocks will still need to be charged to a personal credit card and then submitted for reimbursement via Navan Expense.
- Always bring a credit card with you when traveling for company business if you have one. Hotels will generally expect you to have a physical credit card to present upon check-in. This credit card will be kept on file for the duration of your stay. Even if your lodging was pre-paid by the company or by using a company credit card, the Hotel may still require a card to be on file for "incidentals".

#### Additional Hotel Guidelines

- Dry cleaning is allowable if the stay is over 5 days. Room service is allowable as a meal for e.g. breakfast/lunch/dinner.
- Meals are to be segregated from the hotel bill and tagged under "Meals Company Provided" Category.
- Parking must be segregated and tagged under "Transportation".
- Movies, mini bars are not allowed as a claim.

#### Booking accommodations through Airbnb

- To be booked on the AIRBNB platform. Same restrictions in amount applies as the hotel expense.
- Booking through Airbnb is permitted if it is cheaper than a hotel stay for your trip
- Team Member to submit a manual expense in Navan using expense type "Lodging" and attach the receipt/invoice.

#### Self Stay Incentive Policy

- If you decide to stay with friends or family instead of a hotel / Airbnb for a business trip, you may expense up to a $50 appropriate host/hostess gift.

{{% panel header="**Coding**" header-bg="green" %}}
**Expense Type / Navan Policy Category:** Lodging
{{% /panel %}}

### Meals: Company Provided while Traveling

- Meals while traveling on Company business  are reimbursable, up to $100 USD (or local equivalent currency) per day.
- Each Team Member must submit their own receipts for reimbursement, so ensure to separate billing when going to meals with groups of Team Members. If this is not practicable to do due to the group size, then the most senior Team Member present should pay the bill and submit for reimbursement.
- To be used for team activities and food/beverages associated with travel on Company business. Refer to our Travel Handbook Page.
- Tips are acceptable up to 20% and should be detailed accordingly in the description box. This should be included in the final price to stay within the Policy limits. For US team members, cash tips under $50 do not need a receipt.
- Please also add a description for the trip/reason for travel.

{{% panel header="**Coding**" header-bg="green" %}}
**Expense Type / Navan Policy Category:** Traveling: meals for myself
{{% /panel %}}

### Mileage

- Based on Mileage driven and calculated by Navan. Team Members are prompted by Navan to enter their start and end locations.
- Mileage is reimbursed according to local law, e.g.  US rate per mile, rate per km in the Netherlands, or rate in Belgium. Refer to "How Mileage Rates are Based" section below.
- Should Show Start and End point of trip in Navan.
- Please include a reason for the trip in the description box.
- Team Members cannot claim both mileage and Electric Vehicle charging fees.

#### How Mileage Rates are Based

- The mileage rate is based on your legal entity's mileage rates for the current year. These will be updated yearly for tax compliance.
- However, for the following entities (due to limited visibility online), the default rate is set at $.50/mile… so please update the rate on your mileage if needed to match your local compliance laws: GitLab IT BV, GitLab Korea and GitLab Japan.

{{% panel header="**Coding**" header-bg="green" %}}
**Expense Type / Navan Policy Category:** Distance Driven
{{% /panel %}}

### Train

- The Train policy in Navan is set up as a "Dynamic Policy" which calculates a fair market price for every search based on travel dates and destinations. Any purchases that are over 20% of the Dynamic Policy will be flagged for further review by your manager.  Also note that anything booked outside of Navan will flag as "Out of Policy", and will need to be reviewed by your manager and the AP team.
- Trains booked through Navan will be paid by GitLab travel card.
- Train rides must be standard cabin class with a 14 day booking lead time.
- If you travel more than 3 train trips (6 segments) per quarter, and they are over 5 hours in duration; we will allow you to upgrade one class on the train.
- Yearly or Monthly Rail Discount cards are not reimbursable.
- Please note that anything booked outside of Navan will flag as "Out of Policy", and will need to be reviewed by your manager and the AP team.
- If booked within Navan and is flagged as "Out of Policy", please also refer to the "Booking shows Out of Policy" section below.

{{% panel header="**Coding**" header-bg="green" %}}
**Expense Type / Navan Policy Category:** Train travel
{{% /panel %}}

### Transportation/Parking

- Parking, Tolls, Taxi, Uber pertaining to travel to/from GitLab events, clients, or conferences is acceptable. Team Members are not permitted to expense both fuel/EV charging fees and mileage.
- Full Description of Trip should be stated in the Description box.
- Ground Transportation (taxis, ubers) at $300 limit per round trip and $150 limit for single trip.
- Parking and tolls  at $150 limit per day.
- All items booked which are over the limits set will need to have manager approval attached to the claim.

{{% panel header="**Coding**" header-bg="green" %}}
**Expense Type / Navan Policy Category:** Public transport, tolls & parking
{{% /panel %}}

### Travel (Other)

#### Travel Dates - Days before and after

The company will cover all work-related travel expenses. This includes lodging and meals during the part of the trip that is work-related. Depending on the distance of your travel, it can also include one day before and one day after the work related business. For example, if you are attending a 3 day conference in a jet lag-inducing location, the company will cover your lodging and meals those 3 days as well as one day before and one day after.

#### Internet - Travelling

- Internet while traveling is reimbursable for up to $50 USD (or local equivalent currency) per day.
- Please provide trip details on the description box.

{{% panel header="**Coding**" header-bg="green" %}}
**Expense Type / Navan Policy Category:** Traveling: internet access
{{% /panel %}}

#### Supporting nursing mothers

- If you are nursing while traveling on GitLab approved business, you can reimburse costs in order to travel with breast milk or ship your breast milk back home.
- You can expense:
  - Fees associated with a milk shipment service, such as MilkStork.
  - If a milk shipment service is unavailable, you may expense the cost of checking a bag while flying
  - Coolers or containers to store breast milk while traveling
  - Shipment costs and materials, including dry ice, packaging, styrofoam coolers, and labels.
- Check with your health plan to see if you are eligible for reimbursement for the cost of a breast pump or any other supplies.

{{% panel header="**Coding**" header-bg="green" %}}

- **Expense Type / Navan Policy Category:** Other
- **GL Code NON-COGS:** 6080 - Other Travel- Visas, Permits, Covid Tests
- **GL Code COGS:** 5080 - Other Travel- Visas, Permits, Covid Tests COGS
{{% /panel %}}

#### Personal Bookings

- In Navan, you have the ability to book Personal trips.
- Note that when selecting this option, a personal credit card will be required at time of booking.
- Personal trips will not have the option to be added to the GitLab invoice.

### 4.1 NON-TRAVEL RELATED EXPENSES

#### Books (Audio/E-Books included)

- Books are reimbursable if used to optimize your job position.
- Limit is set to $60/year.

{{% panel header="**Coding**" header-bg="green" %}}
**Expense Type / Navan Policy Category:** Books, dues & subscriptions
{{% /panel %}}

#### Business Cards

- Business cards are ordered from Moo as per the instructions provided by the People Connect team.
- To be ordered via Moo, attach a receipt from Moo. Refer to the [Ordering Business Cards](https://internal.gitlab.com/handbook/people-group/people-operations/people-connect/frequently_requested/#ordering-business-cards) handbook page.
- Limit is set at $150 per quarter.
- Expenses higher than this limit require manager's approval via email. The email should be attached to the expense transaction as an additional receipt.

{{% panel header="**Coding**" header-bg="green" %}}
**Expense Type / Navan Policy Category:** Office Supplies
{{% /panel %}}

#### Co-Working Space

- Coworking space is reimbursable for monthly space and one-off days during business travel.
- $700.00 Limit per month.
- The space should be located within a commutable distance of the Team Member's primary residence in their country of employment, with exception to One-off days (day passes) if the Team Member is traveling for business. This is for tax reasons.
- Co-working spaces need to be a professionally managed space. Leasing of apartments or private properties is prohibited.
- Coworking space is not reimbursable while on personal travel.
- Up to 5 One-off Days in a calendar month related to co-working space do not require Manager or Finance approval.
- If more than 5 days are booked in the month, then Manager and Finance approval (via submitting a request under the `Expenses -> General Expenses` page of [HelpLab](/handbook/business-technology/enterprise-applications/guides/helplab-guide/)) is required and needs to be obtained prior to submission of expenses.
- Copy of approved email must be submitted with first month submission.
- No contracts are allowed to be under the GitLab name and it must be under the Team Members name.
- The co-working space must be submitted monthly in the month it pertains to with full receipts to be provided.
- GitLab will not cover security deposits or advance payments for co-working space.
- Travel to and from the co-working space, parking, meals, beverages, access cards, insurance and other additional expenses in a co-working facility are not reimbursable. Only the rent for the space is reimbursable.
- If co-working space is used together with a combination of working from home, we will allow the reimbursement of the internet cost for where you spend most of your time. i.e. if you expense a co-working space for a full month then internet for home cannot be expensed. If you expense co-work for a few days in a month then home internet can be expensed in full.

{{% panel header="**Coding**" header-bg="green" %}}

- **Expense Type / Navan Policy Category:** Other
- **GL Code NON-COGS:** 6076 - Coworking Space
- **GL Code COGS:** 5076 - Coworking Space COGS
{{% /panel %}}

#### Conferences

- All costs associated with attending a conference to represent GitLab are reimbursable and an approved completed [G&D issue](/handbook/people-group/learning-and-development/growth-and-development/) will need to be noted in the expense report upon submission. Please refer to the [Growth and Development handbook page](/handbook/people-group/learning-and-development/growth-and-development/) for further details and requirements. The reimbursement limits currently denoted in the Growth and Development handbook page do not include the cost of travel to and from the conference, so please ensure you have Manager approval for the cost of the travel.
- Select classification or tag "Growth and Development" in Navan when you create expenses.
- Needs to have approved G&D Development issue which will be reviewed by AP Admin.
- No conference expense, with the exception of travel, should be allowed outside of G&D, unless the Team Member is a speaker for an event or required to attend an event for job related responsibilities (i.e. staffing or sales).

{{% panel header="**Coding**" header-bg="green" %}}
**Expense Type / Navan Policy Category:** G&D (Growth & Development)
{{% /panel %}}

#### Equipment

- These amounts were set after a thorough analysis and review of Team Members' expense data during the previous two years and benchmarked with other remote companies. Anything over this amount will be at the expense of the Team Member and no exceptions will be made.
- As you onboard and start your GitLab journey, new hires will receive a 1,500 USD (or equivalent local currency) stipend to help you towards setting up your home office in your first year. This will be issued to you as a Virtual Card, and you will be able to use that card to purchase items. The Virtual Card information will be sent to you by the Accounts Payable team via your Onboarding Issue. Please refer to the  [Navan End Users Guide](/handbook/business-technology/enterprise-applications/guides/navan-expense-guide/) for instructions on using and accessing your Virtual Card.
- Existing Team Members will get a yearly refresh of 500 USD (or equivalent local currency) to purchase upgrades, replacements, or enhancements to your home office setup. This only applies to Team Members who have been employed the entire previous fiscal year. This excludes laptops - please connect with the IT team if you require a replacement laptop.
- We want you to set up your office the way you want it. Although we don't want to put any restrictions regarding which office equipment you may purchase, we would like to outline what is covered under the term Office Equipment.
- What's included - Essential items which you will need to ensure you are able to perform your role in GitLab should include chair, desk, monitor, Laptop (provided), headset, external mic, external keyboard and external mouse.
- Further to this, items like additional monitors, laptop stand, external webcam, supplementary lighting, laptop bag/case, can also be considered and expensed using the Stipend/Allowance.
- Any items outside this will fall under an exception to the policy and will be subjected to review.
- In addition the following items are **not reimbursable**: Phones, watches, smart speakers, smart TVs/smart monitors, walking pads/treadmills and tablets.
- Purchasing from Private Sellers (e.g. either new or used equipment) is allowed. To expense them, attach the screenshot of your transaction with the seller showing the amount agreed upon, payment method, and item details in the description field. If paid via online transfer, attach the receipt for back up.
- If you have any doubts please connect with the Expense Team by submitting a request under the `Expenses -> Home Office Equipment` page of [HelpLab](/handbook/business-technology/enterprise-applications/guides/helplab-guide/). Please note that these purchases are still reviewed by your manager and accounting teams, and any misappropriation of these funds will be flagged.

##### New Hires- 1,500 USD (or equivalent local currency) Guidelines

- The virtual card provided will expire after one year of issue.
- Any unused funds will not roll over to the next year.
- The local currency FX rate will be calculated using the OANDA Currency Converter as of the date the virtual card is issued.

##### Existing Team Members- 500 USD (or equivalent local currency) Refresh Guidelines

- This is a yearly refresh amount. It will reset at the beginning of each calendar year (January 1 to December 31).
- The Navan Virtual Card cannot be used for the yearly refresh. Team Members should use their own method of payment and submit their expenses in Navan.
- Any unused funds will not roll over to the next year.
- Team Members hired within the previous fiscal year are not eligible. For example, a Team Member who started 2023-05-10 will get their first refresh amount on 2025-02-01.

{{% panel header="**Coding**" header-bg="green" %}}
**Expense Type / Navan Policy Category:** Work from home
{{% /panel %}}

### Team Member Significant Life Events and Team Member Gifts

- Cash or cash equivalents, such as gift cards, are not allowed; Qualified gifts are capped at $125 per transaction.
- Managers are able to send Gifts and Flowers on behalf of their team members in acknowledgment of significant life events such as well wishes ahead of surgery, or the loss of a loved one. Baby gifts are not reimbursable as GitLab already sends them a gift.
- Any People Manager can send a gift or flowers to any Team Member at GitLab to let them know they are thinking about them. Examples include:
  - A new Team Member recently purchased a new home and shared their news with others. A People Manager sends a "Home Sweet Home" doormat as a congratulatory gift.
  - While working a People Manager noticed a Team Member's children in the background of a Zoom call and surprised the kids with a new game.
  - A Team Member wasn't feeling well, which was noticed by a People Manager who sent a care package of food as a 'get well soon' gesture.
- Baby gifts are not reimbursable, as the GitLab People team already sends team members a congratulatory gift.
- The cost of the gifts and flowers provided to GitLab Team Members will be allocated to the senders departmental budget. The allowable cost for gifts is up to $125 USD (including shipping) per gift.
- If you would like to buy holiday gifts for your team, these need to be done personally and should not be expensed.
- People Managers are to use their own personal card for expense reimbursement. People Managers will need to be sure to use Team `EmployeeGiftsFlowers` and the account 6028 in Navan Expense for the expense.
- For further questions regarding expensing of gifts and flowers, please reach out to the AP team by submitting a request under the `Expenses -> General Expenses` page of [HelpLab](/handbook/business-technology/enterprise-applications/guides/helplab-guide/).

{{% panel header="**Coding**" header-bg="green" %}}

- **Expense Type / Navan Policy Category:** Gifts - internal
- **Classification:** EmployeeGiftsFlowers
{{% /panel %}}

### Internet

- Monthly service charges for the internet are reimbursable, but GitLab will not reimburse for any initial setup, equipment, change fees, or monthly insurance charges.
- Please expense internet costs monthly, reflecting current charges only (even if you pay by a different cadence).
- For Team Members in the Netherlands:
  - If you have not already completed the form as part of onboarding with our Netherlands payroll provider, fill in and sign the Regeling Internet Thuis form and send it to the HRSavvy team at payroll@savvy-group.eu. Please do not expense your Internet costs via Navan - these will be rejected.
  - If your address changes or the amount changes, please send a new form to the HRSavvy team, along with the invoice/letter for processing.
- This is a taxable expense for GitLab Ltd. United Kingdom Team Members assuming that the internet connection is used partially for personal use as well as business use.
- Policy is set at $80, anything over that amount will still be considered for approval as we know there are exceptions, and will be checked and approved on an individual basis depending on the user's circumstances, i.e. location etc.
- Itemized Receipt required.
- If an itemized bill is not available, costs will only be reimbursed for the element relating to Internet Access, i.e. if you pay for tv, internet and phone, the invoice should be divided by 3/# of services and we will pay this value only.
- No hardware costs for internet service is reclaimable. This includes routers, extenders/boosters, etc.
- If co-working space is used together with a combination of working from home, we will allow the reimbursement of the internet cost for where you spend most of your time. i.e. if you expense a co-working space for a full month then internet for home cannot be expensed. If you expense co-work for a few days in a month then home internet can be expensed in full.
- Team members for GitLab GmbH (Germany) should refer to this [page](https://internal.gitlab.com/handbook/finance/payroll/#non-us) for their country's specific guidelines of this expense.

{{% panel header="**Coding**" header-bg="green" %}}
**Expense Type / Navan Policy Category:** Internet access
{{% /panel %}}

### Laptops, insurance and repairs

- All laptops are purchased through GitLab unless a Team Member is in a region where GitLab cannot deliver a laptop.
- Team Member laptops can be refreshed after three years of employment. If a Team Member needs a replacement laptop due to damage, they must reach out to IT via an issue before purchasing a new one. See [Laptop handbook page](/handbook/it/end-user-services/onboarding-access-requests/) for your reference.

#### Repairs to company issued equipment

- If you need to replace a battery, laptop charger, or something small that does not affect the productivity or speed of the device, please go ahead and get that small item replaced and expensed.
- The category to use in Navan is 'Office Supplies'.
- Please get approval from your Manager if your equipment appears to be damaged, defective, or in need of repair
- Business Operations can advise on next steps to ensure you have the proper equipment to work.
- For loaner laptops: Do not hesitate when expensing a loaner laptop while your primary laptop is being repaired.
- Use your best judgment identifying a local vendor. Please check out our Laptop Repair page for more info.
- Needs to have an approved issue from the IT team.
- AP Admin needs to review expense for approved issue.

{{% panel header="**Coding**" header-bg="green" %}}
**Expense Type / Navan Policy Category:** Office Supplies
{{% /panel %}}

### Marketing- related expenses

- Small purchases for marketing events which are under $5,000 USD and which cannot be paid through the Procurement Process (Zip) are reimbursable.
- Up to $5,000 can be expensed via Navan.
- >$5,000 needs to go through the procurement process in [Zip](/handbook/business-technology/enterprise-applications/guides/zip-guide/).

{{% panel header="**Coding**" header-bg="green" %}}

- **Expense Type / Navan Policy Category:** Other
- **GL Code NON-COGS:** Multiple- will be required to choose GL account
- **GL Code COGS:** Multiple- will be required to choose GL account
{{% /panel %}}

### Meals with Clients and Partners

- Team Members are prohibited from providing anything of value, including meals, to any government official, government Team Member, or government representative (including any government prospects and government customers).
- Meals are otherwise reimbursable, however Team Members should be mindful of budget while claiming meals with clients and partners.
- $80 limit per person per meal.
- All Participants should be added (both internal and external participants) in the section provided.
- Please also add a description for the meal/event.
- The bill should be paid by the most senior Team Member present and submitted for reimbursement by that Team Member.

{{% panel header="**Coding**" header-bg="green" %}}
**Expense Type / Navan Policy Category:** Entertaining clients
{{% /panel %}}

### Office Supplies & consumables

- To maintain your home office equipment, items like compressed air to clean keyboards, pens, etc may be required from time to time.
- Limit is set at $50.00 per month.

{{% panel header="**Coding**" header-bg="green" %}}
**Expense Type / Navan Policy Category:** Office Supplies
{{% /panel %}}

### Phone Service

- Monthly service charges for cell phones are reimbursable for Team Members whose phones are vital to their position.
- Actual cell phone, phone accessories and family plans are not reimbursable.
- Policy is set at $80, anything over that amount will still be considered for approval as we know there are exceptions, and will be checked and approved on an individual basis depending on the user's circumstances, i.e. location etc.
- A note that Team Members using their phone service outside of their country should try to obtain a contract which includes roaming services.
- Itemized Receipt required.
- If itemized bill is not available, then the costs will only be reimbursed for the element relating to Phone Service, i.e. if you pay for tv, internet and phone, the invoice should be divided by 3/# of services and we will pay this value only.
- No monthly hardware costs for phone service is reclaimable.
- In addition Tablets, Watches, Phone Devices are not reimbursable.

{{% panel header="**Coding**" header-bg="green" %}}
**Expense Type / Navan Policy Category:** Cell phone
{{% /panel %}}

### Postage/Shipping/Customs Fees

- Postage/shipping/custom charges related to the sending and or receiving of work documentation or special packages can be reimbursed.
- Limit is set at $100.00 per transaction before being flagged for approval.

{{% panel header="**Coding**" header-bg="green" %}}
**Expense Type / Navan Policy Category:** Shipping & postage
{{% /panel %}}

### Professional dues, membership fees

- For bar license dues / fees, Team Members who are employed by GitLab as an attorney will supply evidence of payment for such fees and expensed via Navan.
- Other costs associated with professional dues and membership fees are reimbursable and an approved completed G&D issue will need to be noted in the expense report upon submission.
- Select classification or tag "Growth and Development" in Navan when you create expenses.
- AP Admin needs to review expenses for approved issue.

{{% panel header="**Coding**" header-bg="green" %}}
**Expense Type / Navan Policy Category:** G&D (Growth & Development)
{{% /panel %}}

### Software

- No software subscriptions are reimbursable.
- Team Members that would like to purchase software will need to go through the Procurement process.
- Please follow the Guidance from the [Individual Use Software Handbook Page](/handbook/finance/procurement/individual-use-software/).

### Swag

- All Swag related to customers, your team, events, giveaways, TMRG's, etc., are not to be expensed.
- For conferences, any gifts or swag related items to be given out are not to be expensed.
- Please refer to the [Merchandise Workflow Guidance](/handbook/marketing/brand-and-product-marketing/brand/merchandise-handling/#swag-shop) in the Handbook.
- Exceptions are only reimbursable with approval from the VP of department or the Swag team.

### Team Building

- To be used for team activities and food/beverages associated with special team events. Amount allowed is dependent on their department budget for the year.
-Team members to please use T&E accounts for their own individual expenses relating to any team building events (ie meals, travel, transportation) and tagging the classification to "FY25 Team Building Budget"
- In FY25, each e-group member has been allocated a budget per quarter for FY25-Q2 to FY25-Q4 for team building events.
- Each e-group member can use their discretion when using the budget.
- The budget should be used within the quarter the funds are allocated and unused funds cannot be moved to a different quarter.
- This budget should cover leadership offsites, Team Members get togethers, the holiday party and other virtual fun events.
- In Navan, the Team Member must code any related expense to GL code "Team events & meals" and Classification (under optional details) "FY25 Team Building Budget".
- The expense needs to be submitted in the same month as the event or if not possible due to the timing of the event, the latest acceptable submission will be before the end of the fiscal quarter that the event took place.

{{% panel header="**Coding**" header-bg="green" %}}

- **Expense Type / Navan Policy Category:** Team members to please use T&E accounts for their own individual expenses relating to any team building events (ie meals, travel, transportation)
- **Classification:** FY25 Team Building Budget
{{% /panel %}}

### Training/Tuition

- All costs associated with training or tuition are reimbursable.
- An approved [completed G&D issue](/handbook/people-group/learning-and-development/growth-and-development/) will need to be noted in the expense report upon submission.
- The Growth and Development benefit is managed in partnership by the Total Rewards and Learning and Development team.
- Select classification or tag "Growth and Development" in Navan when you create expenses.
- AP Admin needs to review expense for approved issue.

{{% panel header="**Coding**" header-bg="green" %}}

- **Expense Type / Navan Policy Category:** Other
- **GL Code NON-COGS:** 6065 - Training & Development
- **GL Code COGS:** 5065 - Training & Development COGS
{{% /panel %}}

### VPN Subscription

- Please read [Why We Don't Have A Corporate VPN](/handbook/security/product-security/architecture/zero-trust/#why-we-dont-have-a-corporate-vpn), and check out our [Personal VPN]({{< ref "personal-vpn" >}}) page regarding usage at GitLab.
- Policy is set at $150 per year.
- Yearly subscription can be submitted in one claim.
- Monthly subscriptions to be submitted monthly.
- Valid receipts to be submitted for all claims.
- Multi year Policy - only current year subscription can be claimed.

{{% panel header="**Coding**" header-bg="green" %}}

- **Expense Type / Navan Policy Category:** Other
- **GL Code NON-COGS:** 6060 - Software Subscriptions
- **GL Code COGS:** 5060 - Software Subscriptions COGS
{{% /panel %}}

### Visas/Permits/Covid Tests

- Travel Visas, Travel Permits, Covid Tests pertaining to travel to/from GitLab events, clients, or conferences is acceptable.
- Please provide a detailed description of expenses in the description box.
- Will flag approval required by AP Admin.

{{% panel header="**Coding**" header-bg="green" %}}

- **Expense Type / Navan Policy Category:** Other
- **GL Code NON-COGS:** 6080 - Other Travel- Visas, Permits, Covid Tests
- **GL Code COGS:** 5080 - Other Travel- Visas, Permits, Covid Tests COGS
{{% /panel %}}

### 4.3 Missing Receipt Affidavit

If a Team Member is missing a receipt, a Missing Receipt Affidavit will need to be completed and attached to the expense when submitted. Missing Receipt Affidavit located [here](https://docs.google.com/spreadsheets/d/179q0Wos-CemLCe1uxgMpZ80JukSC4KYx8JICFgHzN0I/edit?usp=sharing) (please ensure to make a copy). When attaching the receipt affidavit, the Team Member should attach the document as a PDF.

### 4.4 Reimbursement Payout Timelines

The procedure by which reimbursable expenses are processed varies and is dependent on contributor legal status (e.g. independent contractor, Team Member) and subsidiary assignment.

### Legal entities

- Team Members must submit their expenses through Navan.
- Expenses for GitLab Inc, GitLab Federal, GitLab Ltd (UK), GitLab BV (Belgium and Netherlands), GitLab GmbH (Germany), GitLab PTY Ltd (Australia and New Zealand), GitLab GK (Japan) GitLab LTD (Ireland), GitLab Korea Limited and GitLab Singapore PTE. LTD. are reimbursed via Navan within 7 business days for the expenses within policy or after approval by the Accounts Payable team (for out of policy expenses).
- The Team Member's bank account must be set up in Navan in order for payment to complete.
- Expenses for GitLab Canada Corp must be submitted and approved by the Accounts Payable team (for out of policy expenses) before the 1st day of each payroll period.
- Expenses for GitLab France S.A.S and GitLab BV Finland must be submitted and approved by the Accounts Payable team (for out of policy expenses) on or before the 6th of each month to ensure it is included in the current month's payroll.
- Navan will be implementing a Batched Payment system for team members who are reimbursed directly through Navan. If you submit multiple expenses during the week, Navan will batch these expenses into one single weekly payment that will be paid out on Mondays. These payments will include all approved expenses up until the Sunday evening prior, and should hit the team member’s bank accounts on Tuesday or Wednesday.

#### PEO (Professional Employer Organization/ Employer of Record and not a GitLab entity or Branch)

**Global Upside, Remote.com and Papaya Global**

- The list of Global Upside, Remote & Papaya countries can be found [here](/handbook/people-group/employment-solutions#peo-professional-employer-organization-employer-of-record-and-not-a-gitlab-entity).
- Team Members must submit their expenses through Navan.
- All expenses must be submitted and approved by the Accounts Payable team (for out of policy expenses) on or before the 6th of each month to ensure it is included in the current month's payroll.

**iiPay**

- Team Members must submit their expenses through Navan.
- All Individual contractors or C2C, with exception of Nigeria will be reimbursed by iiPay by the 22nd of each month. All expenses must be submitted and approved by the Accounts Payable team (for out of policy expenses) by the 6th of each month to be included in the current month payment. For contractors with C2C status, be sure to contact the Payroll team via HelpLab and submit a request under the `Expenses -> General Expenses` page of [HelpLab](/handbook/business-technology/enterprise-applications/guides/helplab-guide/) if you need to set up a separate bank for your expense reimbursement.

**CXC Global**

- The list of CXC countries can be found [here](/handbook/people-group/employment-solutions).
- Team Members must submit their expenses through Navan.
- All expenses must be submitted and approved by the Accounts Payable team (for out of policy expenses) on or before the 6th of each month to ensure it is included in the current month's payroll.
- GitLab Payroll Team will send the approved expense amount to CXC EMEA Payroll to include with the monthly salary.
- Team Members must include the approved expense amount on their monthly invoice as well.

### 4.5 Submitting Expenses on Behalf (or Requested By) Team Member's Manager

- A Team Member submitting expenses on behalf of their manager is a violation of our Expense policy and GitLab's internal controls. The AP team will review these on a quarterly basis during their review of the quarterly Manager issue. If this is found during the expense review process, the following actions will take place:
  - AP Admins to notify the Team Member, the Team Member's manager, the Team Member manager's manager, and Finance leadership team of the violation.
  - The expense is to be repaid to GitLab immediately and the Team Member's manager will need to resubmit the expense themselves.

## 5. Physical Cards

Please see Navan Physical Card policy [here](accounts-payable/corp-credit-cards/).

## 6. Purchase Cards

**Navan Purchase Card**

These virtual cards within Navan are only utilized by the AP team, and they are used solely for providing new Team Members with a $1,500 USD (or local currency equivalent) stipend for their home office set up. These cards were set up to ensure that Team Members do not spend outside of this amount, as well as ensuring the stipend is only available during their first year of employment. Within the controls in Navan, these cards are only accessible to the AP Admins team, and are not accessible to Team Members.

## 7. OTHER

### Setting up your Navan Account

Below is some more information to help you get set up with your [Navan](https://tripactions.com/) account.

- Log into Okta and click the Navan tile.
- Once you are in your dashboard, make sure to set up your info in your profile (see link from drop down menu under your name).
- Add your passport information to your profile (only passport information is accepted), this will populate your info directly when booking a flight.
- Team members can view if their reimbursements have been processed successfully or failed on both mobile and desktop versions. If the reimbursement fails, the team member will receive a notification and how to fix it in Navan.
- Now let's start booking!

### Navan Loyalty Program

- Travelers earn Navan Loyalty Points s when booking hotels in Navan.
- Users who book hotels for others will also earn loyalty points.
- The Navan Loyalty Program is visible in the platform, with a new loyalty program profile page to track your earn and redemption activity. Team members are able to redeem loyalty points for personal travel hotels. Users can redeem as little or as many loyalty points as desired - they can pay partially with loyalty points  and partially with a personal credit card if team members don't have enough loyalty points  to cover the full cost of the booking. Loyalty Points will be a form of payment on checkout when selecting a prepaid hotel rate.
- All loyalty points  can be retained by a user when they leave their company by activating a personal-only account. Companies cannot take back earned rewards.

### Sustainable travel considerations

- Even as an all-remote company, GitLab recognizes that some travel is necessary. These considerations aim to reduce the environmental impact of travel:
- Prefer virtual meetings and attendance over personal meetings, except when the event's objective is enhanced by meeting in real life.
- For short-distance travel, consider ground travel over air travel for information on short distance travel recommendations visit these examples from the University of Bern, University of Lund.
- Select trips with lower carbon emissions. When booking travel through Navan Tripactions you can view the total CO2 footprint for at the checkout screen.
- If you organize an in-person meeting, aim for a location that allows as many people as possible to travel in a sustainable way.
- Carbon offsets offered by airlines have dubious value, so aim to avoid air travel where it makes sense.

### Domain Name Registration and Maintenance Policy

#### Scope and Purpose

This policy applies to all GitLab team members registering, or maintaining a registration for, GitLab-related Domain Names, including GitLab-related Domain Names registered or used for sandbox or testing purposes.

Domain names are key assets in GitLab's intellectual property portfolio. Centralizing the registration and maintainance of domain names under the Infrastructure Shared Services group using GitLab's approved domain name registrar helps us track and protect these valuable assets. Please refer to the [Domain Names and DNS Records Handbook Page](https://internal.gitlab.com/handbook/it/it-self-service/it-guides/domains-dns/).

**"GitLab-related Domain Names"** when used in this policy means any domain name:

- registered or used for any purpose related to a team member's role at GitLab;
- containing the GitLab trademark (GITLAB) or one of its derivatives (like, amongst other things, git, glab, gtlb, gl); and/or
containing any GitLab key messaging term (like, amongst other things, DevOps, DevOps platform, all remote).

#### Registration of new GitLab-related Domain Names

- All GitLab-related Domain Names must be registered using the process outlined in the [dns-domain-purchase-request issue template](https://gitlab.com/gitlab-com/business-technology/engineering/infrastructure/issue-tracker/-/issues/new?issuable_template=dns_domain_purchase_request) maintained by IT Operations.
- Expense reports submitted by team members for expenses incurred on or after `2022-03-01` in registering new GitLab-related Domain Names will be rejected.

#### Transfer of existing GitLab-related Domain Names

- All GitLab-related Domain Names currently registered in the name of team members, or registered with unapproved registrars, should be transferred to GitLab using the process outlined in the [dns-domain-transfer-request issue template](https://gitlab.com/gitlab-com/business-technology/engineering/infrastructure/issue-tracker/-/issues/new?issuable_template=dns_domain_transfer_request) as soon as possible.
- Expense reports submitted by team members for expenses incurred on or after `2022-08-01` in maintaining registrations of GitLab-related Domain Names in the name of team members, or with unapproved registrars, will be rejected.

### Team Member Expense Temporary Advances

This relates To Laptop Advances only - If more information is required please email the AP team on AP@gitlab.com

### Expense Reimbursement for Terminated Team Members

If a team member whom you manage has left GitLab and comes to you with final expenses that are valid for reimbursement, please verify that they were not already processed in Navan and then contact Accounts Payable. You must submit valid receipts and a completed copy of the [Expense Reimbursement template](https://docs.google.com/spreadsheets/d/1TiSbp1C3-7WERqDanfBKTxdm5VevQ5QDOAiI_GaizBg/edit#gid=1450348181) along with your approval. Please note that we may also ask the terminated team member to provide valid banking details in order to process the payment to them. AP will do their best to process and pay the reimbursement to the individual within 1 week.
