---
title: "Financial Planning & Analysis"
description: "Welcome to the FP&A Team Handbook. Our missions is to maximize GitLab's long-term valuation by enabling e-group and FP&A to plan, prioritize, and execute effectively"
---

## Our mission

Maximize GitLab's long-term valuation by enabling e-group and FP&A to plan, prioritize, and execute effectively

## Our objectives

1. Facilitate aligned cross-functional execution of GitLab's [strategy](/handbook/company/strategy)
1. Bring predictability and operational rigor to GitLab
1. Ensure financial and operational goals of GitLab are defined, documented and achieved
1. Evangelize awareness of strategy and each departments role in achieving it
1. Ensure sound data-driven decision support
1. Ensure our public company narrative aligns with operating strategy

## How GitLab's FP&A plans to get there…

1. Manage the budget and planning processes for GitLab's Board Plan
1. Build and maintain a [long-term financial model](#long-range-outlook-lro) that identifies long-term strategy and financial targets
1. Define business drivers and [KPIs](/handbook/company/kpis/) in our operating and long-term models in collaboration with the business and measure efficacy of the business plan
1. Own the rolling forecast process and provide actionable insights to ensure departmental performance vs. plan and strategy
1. Drive quarterly earnings process as public company, including guidance and investor narratives
1. Provide insights on the business drivers to constantly look for opportunities to improve performance
   - Process Improvements
   - Analytics
   - Education

## Our team

FP&A comprises five different sub-teams to support our FP&A goals:

- [Corporate FP&A](corporate-finance/)
- [Sales Finance](sales-finance/)
- [Marketing](marketing-finance/)
- [R&D](r-and-d-finance/)
- [G&A](ga-finance/)

### Common Links

- [Finance Issue Tracker](https://gitlab.com/gitlab-com/finance/issues)
- [Analytics Issue Tracker](https://gitlab.com/gitlab-data/analytics) for all data, dashboard, or reporting requests
- [FP&A Job Ladder](/job-families/finance/finance-planning-and-analysis)
- [Adaptive Insights](adaptive-insights/)

### Key Slack Channels

- [#fpanda](https://gitlab.slack.com/archives/CLT54CDFE)
- [#fpa-ap-gl-collaboration](https://gitlab.slack.com/archives/C017VQ3G7V4)
- [#month-end-close-and-gl-team](https://gitlab.slack.com/archives/C02JHRNENE7)
- [#key-review](https://gitlab.slack.com/archives/CPQT0TRFX)

---

## FP&A Processes

### Annual Operating Plan ("AOP")

- **What**: The AOP includes the annual strategy, business plans/budgets for each function, plans for how we will achieve our key metrics and forecasts for all of our key metrics. The AOP is a three statement (Income Statement, Balance Sheet, and Statement of Cash Flow), non-GAAP bottoms-up plan that spans the current fiscal year. The revenue is forecast off of the bookings plan and expenses are planned at the headcount and vendor level.
- **Purpose**: GitLab's AOP identifies GitLab's company goals for the next year and strategies for achieving them. Provide guidelines to understand how much capital is needed to achieve these goals.
- **Governance**: The AOP is approved by the board of directors every year.

#### Annual Planning Steps

- Align executive team on strategic priorities
- Prioritize efforts aligned with three year strategy and annual themes
- Sign-off on financial priorities for the year
- Build out bottoms up integrated sales and marketing financial model with key assumptions documented so they can be tracked
- Set targets agreed upon by Product, Marketing and Sales
- Review product investments vs expected revenue generation
- Set expected amount for annual compensation increases
- Set targets for any contributors on a company based performance plan
- Provide a budget envelope to each e-group leader based on dollars that they can allocate into headcount and program spend
- Generate the expense Plan based on a headcount list, TBH list, vendor level spend list
- Headcount list communicated to talent acquisition, proposed vendor list communicated to procurement (future with Purchase Orders in place for existing vendors)
- Generate and document key assumptions
- Show trending of key metrics as output of the Plan
- Capture Plans to drive key metrics
- Capture X-functional dependencies of execution
- Document business plans for key drivers and initiatives of the year, e.g. new products
- Revise and update the annual sales compensation plan
- Set annual quota assignments for revenue producing roles

#### FY26 AOP Milestones

Key planning milestones are listed below. For a more detailed timeline and planning checklist please engage your FP&A business partner.

- 2024-09-09 (week of) CFO/CRO Meeting: Discuss range of bookings, % expense, and agree on Q4 overattain/underattain scenarios impact
- 2024-09-23 (week of) FP&A Meeting: Kickoff with Bottoms-up Targets with FP&A
- 2024-11-15: Bottom-up Envelope submissions and Investment Area business cases are due
- 2024-12-06: XFN eGroup Skips alignment on projects and dependencies
- 2024-12-09 (week of) eGroup Offsite: FY26 AOP Alignment Meeting
- 2024-12-12 Q3 Board Meeting: update planning progression and preview FY26 AOP
- 2025-01-21 eGroup Meeting: update planning progression and Q4 Board Deck preview
- 2025-02-12 eGroup ASYNC: FY26 AOP Final review
- 2025-03-27 Q4 Board Meeting:  Final Formal Approval of FY26 AOP

## Long Range Outlook ("LRO")

- **What**: The Outlook is a three to five year strategic and financial plan
- **Purpose**:
  - Identify and agree on long-term investments and capabilities that will position GitLab for success over the long-term.
  - Determine whether near-term priorities and funding need to change in order to achieve long-term goals and financial targets.
- **Outlook**:
  - Refresh and reaffirm the company's three year strategy.
  - Make recommendations to identify and categorize strategic investment options which adjust our strategy.
  - Focus on areas where decisions today meaningfully impact growth trajectory and/or investment needs.
  - Identify blockers to LT targets and drive to resolution, including incremental funding and/or reprioritization.
- **Financial plan**:
  - Set the financial envelope needed to achieve GitLab's long-term targets, including bookings, revenue, P&L and cash metrics.
  - Ensure healthy tension between funding investment needs and fiscal discipline / company efficiency.
  - Launch workstreams to resolve areas of tension before annual planning kick-off for the following fiscal year.
- **Principles**:
  - Focus on identifying drivers which would bend or shift growth curves, for both top-line and expense
  - Is a tops-down strategic and financial plan, not a bottoms-up operational plan
  - Cross-functional leadership buy-in required; not a finance-only numbers exercise
  - Public company benchmarking drive decisions around GitLab long-term targets
- **Governance**: The Outlook is reviewed and discussed by the board of directors every year.

### LRO Updates

The LRO is refreshed on an annual basis, occurring shortly after the fiscal year plan is finalized. After the LRO is refreshed, there may be additional updates throughout the remainder of the year, on a quarterly and ad-hoc basis to determine whether near-term priorities and funding are needed in order to achieve long-term goals and financial targets.

As part of the quarterly and ad-hoc updates to LRO, the following are included:

- Comparison to last LRO refresh across bookings, P&L, and cash flow
- 6 quarter rolling forecast, including bookings, P&L, and cash flow
- Comparison to peer benchmarking of similar revenue size for growth and efficiency metrics

The following are inputs in the LRO refresh and subsequent LRO updates:

- Capabilities and key investments across each business function (GTM, R&D, G&A), along with key cross-functional dependencies, risks/blockers
- GTM modeling: demand, productivity and supply capacity
- Total rewards strategy
- Expense YoY and % of revenue targets, HC/non-HC spend by department
- Book to bill to cash collection assumptions
- Seasonality of bookings and expenses
- Cash commissions
- PP&E/Capex purchases

The Corporate Finance team leads the LRO refresh and updates in collaboration with: e-group members to determine key investments, capabilities, and dependencies; GTM Finance team for sales productivity/capacity models, CTB, and bookings attainment; G&A Finance team for total rewards strategy, benefit assumptions; and the R&D Finance team to help inform on allocations, hosting/infrastructure expenses.

## Business Planning

### Business Planning Goal

For GitLab's top growth drivers and new products, drive and document alignment between contributors to success. Writing a business plan drives clarity of thought and operations. Agree on governance models to manage initiative success and cross-functional accountability. At a minimum, each business plan should cover:

- Explain what an initiative is, why we should be focused on it.
- Identify how each function will support its success, what are dependencies & risks.
- Identify how we measure success, e.g. pipeline or bookings goals.

### Business Planning Details

- **Product plan** - what are product features to ship, by when? What is committed and what is at risk? What are competitive considerations? If there are phases, what is in scope for each phase?
- **Pricing plan** - what is the pricing strategy, what are open decisions, what is the margin structure?
- **Marketing plan** - how will product marketing and demand generation support the business plan.
- **Sales plan** - what are the drivers of the sales plan? What is the quarterly Plan for  bookings? What are assumed attach rates, penetration rates, adoption rates, where is there uncertainty? What is the field enablement plan?
- **Services plan** - if applicable, how can enhanced services improve sales and adoption?
- **Operational plan** - what infrastructure do we need (fulfillment, IT, rev rec, legal, security, etc.)
- **Financial plan** - gross margin and contribution to P&L, if applicable

### Key Contributors

- Driver: FP&A
- Contributors
  - Product: lead PM(s), pricing lead
  - Marketing: leads within both Product Marketing and Demand Gen
  - Sales: Regional VPs, RS&A, GTM FP&A
  - Support/Services
  - As needed: fulfillment, IT, accounting, legal, security
- Approvers / Informed:
  - CFO, CRO, CMO, CPO, e-group

### Review and Governance

- Contributors (above) agree on business plan and review with e-group members for feedback. Include proposed measurement plan (e.g. bookings or pipeline goals)
- On a defined cadence (monthly or other), review product accomplishments vs. plan
- On a defined cadence (monthly or other), review GTM measures of success vs. plan
- On a defined cadence (quarterly or other), review P&L impact vs. plan
- Each quarter, refine success goals/metrics based on learnings to iterate on plan of record

## Quarterly & Monthly Cycle (incl. close, variance, forecast, guidance)

GitLab's FP&A team participates in a rigorous monthly close process.

### Goals

- Set clear deadlines to best support our accounting team and ensure timely delivery of information to executives
- Analyze the performance of our budgets and forecasts against actuals, identify insights which enable our executives to better make decisions.
- Update our internal forecasts and update our investor guidance to prepare for the quarterly earnings call
- Improve forecasting methodologies and approaches to hold ourselves accountable and drive accountability to the business owners of the budget

### Key Definitions

#### Actuals

- **What**: Actuals are results that have been reported or exist in a system that is designated as a single source of truth for the item that is being measured. Each month accounting closes the month and financial results are recorded in our ERP system and are published in our financial statements. These actuals are compared to the Plan and our forecasts.

#### Forecast at `FYyyyy-mm`

- **Purpose**: In a dynamic high-growth business, GitLab's needs may change through the year and we need to be able to predict what is going to happen.
- **What**: Forecast is a dynamic assessment based on current expectations of financial performance. The FP&A team will publish a monthly forecast for revenue driven by bookings and other key inputs and expenses driven by headcount and vendor spend. A monthly forecast does not extend the forecast period. For example in March 2020, the forecast will span from February 2020 to January 2021 with February actuals and a forecast for the period March 2020 to January 2021 — this will be called the (1+11) forecast.
- **Governance**: The Forecast at `FYyyyy-mm` is approved by the Head of FP&A and reviewed with the CFO.
- Note: Prior to locking and archiving any version in Adaptive, Corporate FP&A will update the FX rates in Adaptive using [Google Finance FX Rates](https://docs.google.com/spreadsheets/d/1ksPKt2TN2WGu1uFVkSb6fSkMmNHJdL-ZFZmfgT-ePEg/edit#gid=0).

#### Forecast at `FYyy-Qx`

- **Purpose**: In a dynamic high-growth business, GitLab's needs may change through the year and we need a guidepost to hold business leaders accountable. We plan our expenses at a high level (e-group) and we expect this group to make prioritizations and trade-offs while remaining accountable against the plan parameters. By formally reforecasting quarterly, we can quickly evaluate and incorporate new initiatives into our forecasting model. That being said, we do follow an annual plan to set our goals and measurement for our top-level targets of revenue, profitability and expense management and ensure we continue to  meet any public guidance previously communicated
- **What**: Forecast at `FYyy-Qx` is a dynamic assessment based on current expectations of financial performance. The (3+9), (6+6), and (9+3) quarterly forecasts include revenue driven by bookings and other key inputs and expenses driven by headcount and vendors.
- **Governance**: The quarterly forecast is approved by the Head of FP&A and reviewed with the CFO. It is then reviewed with e-group and the board of directors. e-group will be held accountable to the quarterly forecast for expenses.

#### Forecast Snapshots in Months 2-3 of each Fiscal Quarter

- **Purpose**: As a public company, GitLab needs to maintain a pulse on the P&L and key financial metrics. As a fiscal quarter develops, the snapshots inform the CFO and e-Group of our latest forecast and any adjustments from the previous snapshot view.
- **Cadence**:
  - **In Month 1 of the quarter**: once in week 2 (the week before FP&A's Month 1 forecast version lock)
  - **In Month 2 of the quarter**: weekly starting week 2 (the week before FP&A's Month 2 forecast version lock)
  - **In Month 3 of the quarter**: weekly
- **What**: P&L snapshots track company metrics against Wall Street expectations related to revenue, non-GAAP operating income and non-GAAP earnings per share and enable GitLab to make in-quarter spending decisions based on the latest estimates from FP&A. The forecast snapshots are developed by FP&A and presented to the CFO in order to facilitate decision-making. The P&L snapshot follows the [Finance Business Partners / Talent Acquisition Managers Headcount Forecast Interlock process](#finance-business-partners--talent-acquisition-managers-forecast-interlock) and is delivered to the CFO via a slide deck tracking week over week changes in the snapshot. A summary is also communicated to the CFO and FP&A team via the #fpa_private Slack channel.

### Monthly FP&A Close Timeline

These dates are based on an 8-day accounting close. Corporate FP&A will confirm the close date with the accounting team and update the FP&A Close calendar in Google accordingly. For FY23, the target is to close by WD 5 with full consolidation (including tax entries, eliminations) by WD 10.

#### Close timeline

- WD -3: AP Closed.
- WD -2: All accruals and JEs are due from FP&A
- WD -2: NetSuite Actuals for current month close included in Adaptive (performed by Corporate FP&A)
- WD 1: Headcount actuals loaded into Adaptive (performed by Corporate FP&A)
- WD 2: FP&A Flux distributed and is due one week after and/or one day after Accounting close
- WD 2: FP&A sends flash to the board (quarter only) - Bookings, revenue estimate and NGOI estimate
- WD 5: Revenue Closed. Start revenue, billings, collections variance analysis.
- WD 7: Final entries and allocations booked
- WD 8-9: FP&A review of AvF complete
- WD 9: Adaptive forecast locked

#### Other Key Dates

- Day 8: Snapshot ARR, customer count, net retention (note this is captured on Day 8, not WD 8)
- 2nd Tuesday every month: Variance deck shell distributed
- 3rd Tuesday every month: Variance deck pencils down and due to the Head of FP&A
- 3rd Thursday every month: CFO Variance meeting, with distro to FP&A Slack channel 24 hours before
- After accounting close: Revenue Committee Sync meeting between CEO, CRO, and CFO.

#### Accounting close expectations for FBPs

- FBPs will obtain a daily report with open invoices/POs from Misty and drive obtaining the required approvals and invoices from respective business partners.
- If you have questions for AP GL team, please ask in the [#fpa-ap-gl-collaboration](https://gitlab.slack.com/archives/C017VQ3G7V4) channel.

The Accounting close calendar can be found [here](https://docs.google.com/spreadsheets/d/1Hzl1IC3oAwI_eLV1UkZlknmIi6sfLEp_/edit#gid=1985211004).

#### Variance Meeting with CFO

Each month after the financials have been published, GitLab reviews all aspects of the business including Corporate Metrics, Bookings, Revenue, Gross Margins, Expenses. The goal of this meeting is to do a comprehensive review so that finance leadership has a pulse on the business and signs off on the financials. Based on insights from variance analysis, the FP&A team makes actionable recommendations to the CFO and e-group to ensure continued performance to Plan/Forecast.

The variance analysis will compare department budgets with actual results and examine any material differences between budgeted and actual costs. Additionally, the actuals for expenses will be compared to the quarterly rolling forecast. The expenses are reviewed at the divisional department level, allowing GitLab to measure progress in meeting its Plan or rolling forecast. The team also evaluates the accuracy of forecasts and will make adjustments to the next rolling forecast.

#### Variance and Flux Analysis

The study of differences between actuals and the Plan or Forecast. During the variance analysis processes the GitLab FP&A team analyzes and isolates any variance in question to the lowest level possible. The team reviews detailed items in order to identify the root cause of the variance. This could include transaction date, cost center, vendor, location, department or additional low level details.

The FP&A team takes the following into consideration while evaluating variances in relation to materiality thresholds:

- The percentage size of the variance (i.e. what was the overall variance by percentage)
- The correlation to other variance (i.e. did a immaterial difference in one place cause a material difference in another)
- The inherent character of the variance (i.e. does the expense correlate to the traits of the business)

The FP&A team delivers an FP&A expense flux review document at each monthly close, documenting and quantifying business drivers for variance. The goal is two-fold:

- **Control**: ensure accuracy of actuals. Analysts should aim for 90% coverage in explanations, e.g. if variance is $100, aim to list drivers for net $80 of the variance for any particular intersection above threshold. List drivers in descending order of impact, followed by large offsetting drivers.
- **Insights**: leverage insights gained from closed month to inform rolling forecast. Changes in business strategy/model, new accounting policies, and refinements on forecast methodology should be documented and incorporated into the new forecast.
- **Performance Indicator**: Variance percentage

We measure our team performance based on our forecast accuracy, also known as variance percentage. Variance percentage is defined as the difference between actuals and Plan or rolling forecast. We calculate it as follows:

- Variance Percentage (Plan) = (Actuals - Plan)/Plan or
- Variance Percentage (Forecast) = (Actuals - Rolling Forecast)/Rolling Forecast

Variance analysis should address any inputs or additional requests from the last [Variance meeting](https://docs.google.com/document/d/13dHJQSd4ynvB3N16ALZX43anueZlnz48gQbFfn5IXzk/edit), as applicable.

### Types of Threshold and Materiality

Generally accepted accounting principles (GAAP) does not provide definitive guidance in distinguishing material information from immaterial information. Therefore, GitLab uses a percentage based approach for defining materiality thresholds and can be found below. The Plan vs Actuals vs Forecast Sisense dashboard provides the data for the threshold analysis via a color coded legend.

Our goal is to have revenue and EBIT variance percentage within +/- 2% on a quarterly basis.
Key accounts and expenses by division should be within +/- 2% versus Plan or rolling quarterly forecast every quarter.

#### Variance Meeting with EVPs

EVPs are held accountable to meet the budget in dollars that they are given. The budgets typically are broken into headcount and program spend. Each finance business partner will run a meeting with their Finance leader and the EVP to review the past month. The information should be presented as timely as possible. Given the accounting close is 8 days, the team is asked to use pre-close numbers for the review to increase the speed of information. During the meeting, the Finance Business Partners will review GitLab results in addition to a detailed overview. Each division can expect to review the following during the monthly meetings:

- Company results
- Spending OpEx vs Plan
- Divisional level review including an executive summary with relevant insights and watchpoints
- Last month vs plan/rolling forecast
- Projection for the current quarter
- Detailed variance details that helps the EVP understand the financial picture of their expenses
- Discuss upcoming changes to financial processes that EVPs need to be aware of
- Discuss upcoming changes to help Finance Business Partner update the rolling forecast
- Discuss any budget lines that underspent and if money can be reallocated before quarter-end. Noting that converting program dollars to headcount is usually difficult as it impacts future periods.
- At quarter end, review the upcoming  quarter vs Plan for the Division and for each department on the quarter

Following the month-end close, the Finance Business Partners will create a variance deck and distribute department income statements to the related budget owners and the e-group members. Each department is then responsible for comparing these reports, which contain actual costs, to the budget. Departments, with guidance from the Finance Business Partners, should analyze their data and if necessary, discuss items of interest and take appropriate action. Any questions regarding the cost data should be discussed with the Finance Business Partner.

### Quarterly FP&A Close Timeline

The close timeline for each quarter follows the timeline above for monthly close and includes additional key dates and processes:

#### Guidance

- **Overview**: We provide quarterly guidance on key metrics of the business. At the earnings call for the previously concluded quarter, we provide guidance for the following quarter and the full fiscal year. For example, at the Q1-FY23 earnings, we will provide guidance for Q2-FY23 and updated FY23 guidance. We report guidance based on dollar ranges (except for weighted average shares outstanding which is given as a share estimate).
- We provide quarterly guidance on the following metrics:
   1. Revenue
   1. Non-GAAP Operating Income (NGOI)
   1. Non-GAAP Earnings Per Share (Non-GAAP EPS, or NGEPS)
   1. Weighted Average Shares Outstanding (WASO)
- **Cadence**: Following accounting close, the Corp team provides guidance proposals to the Head of FP&A for review. Following that review and any necessary iteration, the Corp team meets with the CFO and the Head of Investor Relations to review the guidance proposal, iterate, and finalize guidance figures.
- **Deliverable**: The deliverable to the CFO and the Head of Investor Relations is a slide deck with the proposed guidance range, implied guidance for the following quarters, comparable company benchmarking, and sensitivity analyses. The guidance proposed is also included in the Audit Committee and Board of Director deck materials.

#### Quarterly Earnings Process

As a public company we share financial results publicly after the close of each fiscal quarter or fiscal year. The purpose, timeline, and deliverables can be found on our Investor Relations page [here]({{< ref "../investor-relations" >}}).

---

## Headcount Forecast and Hiring Plan

### Definitions

#### **Single Source of Truth (SSOT) Headcount Forecast and Hiring Plan**

Financial Planning & Analysis (FP&A) team is the owner of SSOT for GitLab's **Hiring Plan** which contributes to our Headcount Forecast.

- Headcount Forecast is a live forecast in Workday Adaptive (a financial planning software)

  - Headcount Forecast includes all approved positions in AOP (i.e. Active, Planned and Backfill positions)
  - Hiring Plan is subset of Headcount Forecast (i.e.Planned and Backfill positions only)
- Hiring Plan is maintained by the Finance Business Partners (FBPs) and shared with Talent Acquisition (TA) team and Business Partners (BPs)
- Finance owns the Hiring Plan to ensure there is only one Headcount Forecast and Hiring Plan for the business
- Hiring Plan increases our predictability as a company and streamlines the hiring process
- Based on historical time to start data, new requisitions released via RLOA in a quarter can be expected to start in the following quarter at the earliest
- For questions specific to TA's process and REQ creation, please refer to [TA's section of the handbook](/handbook/hiring/talent-acquisition-framework/req-creation/)

### Position ID (PID)

Position ID is a unique identifier and is the link between approved headcount and the Hiring Plan

- Each position is approved and allows TA to open a role for the business
- Positions are all approved headcount in the Hiring Plan.
  - All approved headcount includes Active, Planned and Backfill positions
  - Only Planned and Backfill positions are included in the Hiring Plan
- All positions in the Hiring Plan are approved through:
  - Annual Operating Plan (AOP) cycle (beginning of each fiscal year)
  - [RLoA](/handbook/finance/financial-planning-and-analysis/#rolling-list-of-asks-rloa) cycle for any incremental roles through the year
  - Backfill due to attrition in the business
- Positions may be updated/changed during weekly interlock process (e.g. reallocated to different team, changed for different Role level)
- Each position is assigned with an unique identifier called Position ID (PID)
  - PID increases visibility and accuracy for headcount forecasting (count and dollars)
  - PID simplifies and provides transparency on modeled headcount (attrition and backfill)
  - PID is an unique identifier for positions assigned to all current and future approved headcount
- PIDs are created and assigned by Corporate FP&A (Corporate) when Hiring Plan is finalized or upon change request of existing position(s)
  - All approved Planned and Backfill positions are assigned with an GHPID (please refer to [TA's section on GHPID](/handbook/hiring/talent-acquisition-framework/req-creation/))
  - Not all positions are assigned with GHPIDs
  - Key difference between GHPID and PID
    - GHPID has 1-to-1 relationship with an Opening ID in Greenhouse (please refer to [TA section on Opening](/handbook/hiring/talent-acquisition-framework/req-creation/))
    - PID has 1-to-1 relationship with an approval headcount
    - Each PID has 1-to-1 relationship with a GHPID at any given time
    - **Illustrative example:** Employee **A** departs and business decides to backfill the same role
      - Departing employee A will have
        - PID: FIN-FY24-9999 (tied to Headcount Forecast)
        - GHPID: GH-FY23-999-0001 (issued to hire Employee A **in the past**)
      - To open the new requisition, we will need
        - **SAME PID:** FIN-FY24-9999
        - **NEW GHPID:** GHPID: GH-FY23-999-0002
- Starting from FY25 AOP cycle, GHPIDs will be generated through a consolidated process
  - All GHPIDs are system-generated by a FP&A internal Google Sheet, maintained and audited by Corporate
  - Each Planned and Backfill position will have a unique GHPID assigned by FBP(s)
  - GHPID will allow TA to open a requisition in Greenhouse.
  - If an approved role is not assigned with a GHPID, the job will not be opened in Greenhouse
- Finance Business Partners (FBPs) work with Business Partners (BPs) to discuss details of each approved headcount and enter final decisions of each position to Adaptive as SSOT Hiring Plan
  - Details of the position include, but are not limited to, Department, Job Title, Job Grade, Salary, Location
  - FBP include all PIDs (assigned by Corporate) for approved Planned and Backfill positions in Hiring Plan
  - FBP include all GHPIDs for roles eligible to be opened in Greenhouse
- Adding/removing/exchanging position(s) requires FP&A's approval through existing RLOA or rolling forecast. FBP will submit change request Google Form
- PIDs and GHPIDs are audited and reconciled by Corporate regularly
  - PIDs are reconciled **monthly** before each rolling forecast lock
  - GHPIDs are reconciled **weekly** before each weekly interlock
- Upon approval of the Hiring Forecast, FBPs share:
  - Headcount Forecast with Business Partners (BPs) through monthly review
  - Hiring Plan with both BPs and TA through live interlock sheets and release GHPIDs
  - TA partners will contact HMs and open a requisition in Greenhouse after GHPIDs are released

### Role Approval and Release Process

#### Process Overview

1. Hiring Plan
   - Finance Business Partners (FBPs) work with Business Partners (BPs) to discuss role details and enter final decisions to Adaptive as Hiring Plan
   - Hiring Plans are approved by Board of Directors (during AOP) or CFO & e-group (during RLOA).
   - All approved positions will be communicated by FBPs to TA partners, PBPs, and BPs
1. Requisition Release
   - Role details are added to Live Interlock sheets. Details allow TA to open a requisition in Greenhouse
   - Backfill requisition requires separate approval (below)
1. Hiring Manager create/review Job Family
1. Talent Acquisition partner opens requisition in Greenhouse
1. Formal approval to open role
   - When a requisition is opened in Greenhouse it is routed for approvals. The job approval requires approvals from Total Rewards, FP&A and Department Lead (VP+)
   - This allows the FBPs to check all details of the role and ensure consistency to SSOT Hiring Plan
      - If role details in Greenhouse do not reconcile to Hiring Plan in Adaptive, FBP will reach out to both TA and HM to resolve discrepancies
   - FP&A is also a required approval on all job offers (before the role is officially filled). This approval allows FP&A to confirm details of the job offer and ensure reconciliation to Hiring Plan
1. Run kick-off (aka Intake) with Hiring Manager

FP&A and TA discussed and agreed upon the above process. This SSOT process ensures consistency in Hiring Plan execution

#### Planned Positions

Planned Positions include all Net New positions to existing GitLab active employees.

1. Hiring Plan Approval of any Planned Positions are from:
   - Annual Operating Plan (AOP) cycle
   - RLoA cycle for any incremental roles through the year
1. Requisition Release
1. Hiring Manager create/review Job Family
1. Open requisition in Greenhouse
1. Formal approval to open role
1. Run kick-off (aka Intake) with Hiring Manager

#### Backfill Positions

Backfill Positions include all positions created due to departure or termination of an existing employee.

1. Hiring Plan Approval of any Backfill Positions
   - While GitLab strongly believes that a HM should be able to backfill each role upon termination and/or departure, HM should check with his/her leadership to discuss and decide whether there are changes to the backfill role
      - If changes are approved by leadership, please work with your FBPs to update details of the backfill positions.
      - FBPs evaluate change and ensure neutral dollar impact from role change/update
      - FBPs brief Corporate and request new/remove PID if applicable
      - Upon final decision, FBPs enter details into Adaptive and update Hiring Plan
1. Requisition Release
   - Upon a resignation, Hiring Managers (HMs) submit official notice to Workday (WD)
      - WD backfill notification will send to both TA and FBPs
      - WD backfill notification will allow Recruiter to create a backfill issue
      - All final decisions and details of the role(s) will be documented in the backfill issue
      - Recruiter can create a requisition in Greenhouse and move to the next step of the process
1. Hiring Manager create/review Job Family
1. Open requisition in Greenhouse
1. Formal approval to open role
1. Run kick-off (aka Intake) with Hiring Manager

### Hiring Plan Process

Both PID and GHPID are created and maintained by FP&A team as unique identifiers in Hiring Plan

#### Creating a Position ID (PID)

All PIDs are created by the Corporate FP&A team and are tied to Headcount Forecast (including Hiring Plan)

FP&A Position IDs increase visibility and accuracy for headcount forecasting (count and dollars) and simplify & provide transparency on modeled headcount (attrition and backfill).

- PID is an unique identifier for positions assigned by Corporate to **all** positions in Hiring Plan
- Add/remove/exchange positions requires FBP approval via existing process, e.g. RLOA or rolling forecast and submit change request Google Form [here](https://docs.google.com/forms/d/e/1FAIpQLSeHS97lg1Fz_SIQTisg-TOPHsXf6QMGw6vXfuEDkB_GY8pKfA/viewform)
- Positions reconciled regularly, e.g. monthly before each rolling forecast lock
- Position ID follows "**FIN-Fiscal Year-0000 (4-digit PID code)**" as naming convention
  - For example, if a role is opened in FY24, the PID is "FIN-FY24-0000"

#### Creating GHPID

All GHPIDs are system-generated by a FP&A internal Google Sheet

- Google Sheet GHPID generator is maintained and audited by Corporate FP&A weekly
  - FBPs will refer to GHPID generator and assign GHPIDs to all approved positions
  - **Future State:** Corporate will migrate GHPID generator to Workday (pending on Workday/Adaptive integration and Workday Position Management)
- GHPID is updated during weekly forecast interlock and regular forecast cycles.
- **Starting FY25 Annual Operating Planning, GHPID will follow "GH-Fiscal Year-Department Internal ID-0000 (4-digit GHPID code)"** as naming convention.
  - For example, if sales and/or marketing is hiring a role, the GHPID will be"GH-FY25-100-0001".
  - When a role is pushed into next fiscal year, the GHPID won't change
  - When a role is re-allocated into a different department, the GHPID won't change
  - Each GHPID is unique to each opening of a requisition
  - **Department internal ID** is from Netsuite as SSOT and consistent to Adaptive department code
  - Once a number has been used in Greenhouse for a job, it can not be reused. If the role is a future role and has been deleted, but was never input into Greenhouse, the FBP can use that number for its replacement or a different role since it was not used yet.

### Maintaining Hiring Plan

FP&A team is the owner and maintainer of SSOT for GitLab's Hiring Plan

1. Objective of this control is to ensure completeness, accuracy, and consistency of Hiring Plan
   - **Completeness**: all approved positions are assigned with PIDs and GHPIDs
   - **Accuracy**: no PID and GHPID is assigned to duplicated or deprecated positions
   - **Consistency**: ensure Hiring Plan in Adaptive is fully reconciled to details in Live Interlock Google Sheet and details in Greenhouse requisition
1. PIDs and GHPIDs are stored in Workday Adaptive (Adaptive) and are required fields in Hiring Plan
   - FBPs will update Hiring Plan weekly in Adaptive & update TA through weekly Interlock.
   - FBPs may update their Headcount Forecast on a more frequent basis (more than weekly) depending on their individual department's business needs
   - Updating Hiring Plan could require adding new roles, deleting roles, trading off roles, or adding backfills
1. Hiring Plan audit and reconciliation is performed by Corporate, including
   - Weekly GHPID audit and reconciliation through TA and FP&A Interlock
   - Monthly PID audit and reconciliation through monthly forecast lock
   - Corporate will reach out to FBPs if noticing any discrepancies and resolve them before monthly forecast lock

### Finance Business Partners / Talent Acquisition Managers Forecast Interlock

#### Purpose

The FP&A team and Talent Acquisition Managers collaborate to ensure understanding and implementation of the most up-to-date view of forecasted headcount-related expenses. This interlock enables GitLab to respond quickly and make live decisions through a weekly P&L forecast and the [rolling list of asks (RLOA) process](/handbook/finance/financial-planning-and-analysis/#rolling-list-of-asks-rloa). This process also ensures alignment and accuracy of headcount forecasts when FP&A locks its annual plan and monthly rolling forecasts. This process also tracks company metrics against Wall Street expectations related to non-GAAP operating income and non-GAAP earnings per share. Please see the [Headcount Metrics and Processes page](https://gitlab.com/-/ide/project/gitlab-com/www-gitlab-com/tree/master/-/sites/handbook/source/handbook/finance/financial-planning-and-analysis/headcount-metrics-and-processes/) for definitions and key metrics.

#### Headcount Live Dashboards

The Hiring Plan data is divided into four headcount forecast templates, one for each cost center with Cost of Goods Sold allocated among Sales and R&D. The data and analysis from the four templates roll into the Summary file. The four templates can be found in the [Headcount Live Summary Dashboard](https://docs.google.com/spreadsheets/d/1LmMiPMeBu2jW6APZ1SDNOk1OgLN6pyB01TrEVza40us/edit#gid=1019520422).

#### Cadence / Process

Unless otherwise noted in the HC Forecast calendar or communicated via Slack, the interlock process occurs weekly as follows:

1. **By noon (PST) Monday**, the Corp FP&A team downloads the data from Adaptive and refreshes the headcount forecast templates. Talent Acquisition also refreshes the headcount forecast templates with the latest data from Greenhouse.

1. **By end of day (PST) Wednesday**, the Talent Acquisition Managers and Recruiters review their respective roles line by line and make adjustments and comments related to expected start dates and other role details provided by the Finance Business Partners. If no indication is made for a specific role in the headcount forecast template, Talent Acquisition signals that the current indication is reasonable and indicative of a 50/50 "most-realistic" forecast. The Talent Acquisition Managers also pay close attention to any recruiting capacity restraints within any given quarter. In order to maximize transparency and understanding of any changes, the Talent Acquisition Managers and Recruiters provide comments (e.g., wrong GHP ID, rejection of an offer, delay due to business decision, etc.) for specific roles.

1. **By end of day (PST) Thursday**, the Finance Business Partners update Adaptive with their best estimates of the start dates of all planned personnel for the forecast period based on the input from Talent Acquisition in the headcount forecast templates. This reflects a 50/50 "most realistic" view of headcount expenses/timing.

1. **By end of day (PST) Friday**, the Corp FP&A team sends a P&L snapshot to the CFO incorporating any headcount forecast adjustments. Note: P&L snapshots are not provided during accounting close.

#### Communication

Communication related to the interlock takes place in the #fpa-ta_headcount_forecast Slack channel. All parties involved in the interlock are also granted access to the "HC Forecast" Google Calendar.

#### Deliverables

The Finance Business Partners and Talent Acquisition Managers collaborate to provide the most current and 50/50 "most-realistic" view of headcount-related expenses. This is done through the interlock process in the headcount forecast template and is ultimately uploaded into the Planned Personnel sheet in Adaptive.

The inputs loaded into Adaptive are then used to provide the CFO a weekly P&L snapshot in order to facilitate in-quarter spending decisions and ensure the company tracks vs.  guidance and consensus expectations.

---

## Expense Controls

1. The primary mechanism to ensure efficient spend of company assets is the [Procure to Pay]({{< ref "../procurement" >}}) process, and specifically completion of the [vendor and contract approval workflow]({{< ref "../procurement" >}}) prior to authorization. The procurement team or your finance business partner can assist with questions related to this process.

1. The second mechanism is the budget vs actual review to determine reasons for variances vs plan. See the section on [Variance Meeting with CFO](#variance-meeting-with-cfo)
 and [Variance Analysis](#variance-and-flux-analysis).

---

## Adaptive Planning

A manual on how to update and maintain Adaptive integration can be found [here](https://docs.google.com/document/d/11BytV1SWBcqkA6JdCDA3iS33uVlUgNSs9nAjBjhY84M/edit). This document is maintained by the Corporate FP&A team.

Adaptive Quarterly Roadmap

- The current Adaptive roadmap can be found [here](https://docs.google.com/spreadsheets/d/1vfJHmKmLJo2vSkOnN_pKh7cXh--IdE5CiQIy6X2JQKc/edit#gid=0)
- We expect to transition roadmap and requests into GitLab issues by Q2-FY23.
- Corporate FP&A will host Adaptive intake sessions with the larger FP&A team to intake, align and prioritize current and future projects.

## Rolling List of Asks (RLOA)

### Intent of RLOA Process

1. Reinvest back into the business when company expects to beat expectations
1. Enable e-group and leaders to make informed and fast business decisions
1. Create a repeatable and transparent quarterly process into incremental investments

### Expectations for Business Partners

1. Your FP&A partner will assist in maintaining a rolling list of asks (RLOA). This list includes prioritization/sequencing, rationale/ROI, and considerations against current FvP
1. In weeks 0-2 of each qtr (quarterly fcst), work with FP&A to make a final proposal, if needed, for additional investment over the rest of the fiscal year
1. By week 4 of each qtr (earnings guidance), funding decisions reviewed, prioritized, and decided by CFO and e-group

### Detailed Expectations for FP&A

1. **Throughout quarter,** FP&A maintains alignment with business needs.
   - FBPs, with the functional leader(s), maintain a RLOA file of key incremental investments from the business
   - FBPs, with the functional leader(s), prioritize the RLOA and develop a recommendation following the below timeline
1. **During quarterly RLOA process,** FP&A team finalizes RLOA proposal to share with e-group, and communicates decisions to functional leaders to enable business execution. Below is the timeline
   - **WD-1:** Corporate FP&A locks Prelim Forecast version and shares detailed daily calendar with FBPs
   - **WD+1:** FBPs prepare prelim variance package and review with BPs (Async) to help the business prioritize the asks
   - **Acct Close +2:** Forecast pencils down
        - Corporate FP&A and VP of Finance review Forecast prior to Final Forecast Lock
        - Corporate FP&A provide Prelim Forecast vs. Final Forecast view to FBPs
   - **Acct Close +3:** Final Forecast Lock, used for guidance, tax, etc.
   - **3 days prior to CFO Variance Review:** FBPs finalize prioritized RLOA list and submit to Corporate FP&A
   - **2 days prior to CFO Variance Review:** Corporate FPA creates a brief RLOA section (~2-3 slides) to include in CFO Variance Review package. RLOA section should include:
        - P&L from Final Forecast Lock and RLOA summary
        - Comparison of the functional expenses as a % of revenue after RLOA vs plan, guidance, and consensus
        - Comparison of headcount requests against recruiting capacity
        - Rationale for each request and Finance POV
   - **At CFO Variance Meeting (typically third Thu):** FP&A team reviews RLOA proposal with CFO & VP of Finance. Discussion around:
        - Incremental investments required from RLOA proposal
        - Make recommendation to e-group thereafter
   - **At e-group Review Meeting (typically Mon after CFO Variance Meeting),** CFO shares proposal for formal approval and inclusion into investor guidance
   - **After e-group Review Meeting,** FP&A team communicates approved incremental investments to functional leaders to begin execution

   *Note: WD is defined as Working Days, which are Mondays through Fridays, excluding Federal holidays.*

### RLOA Timeline

- **Throughout the quarter,** FP&A drives alignment with business needs through RLOA:
  - FBPs, **with the functional leader(s),** maintain a RLOA file of key incremental investments from the business
  - FBPs, **with the functional leader(s),** prioritize the RLOA and develop a recommendation following the below high-level timeline
- **Week 1:** Corporate FP&A kicks off RLOA and shares calendar with FBPs
- **Week 2:** Forecast pencils down
  - FBPs submit prioritized RLOA asks
  - Corporate FP&A provide forecast preview to FBPs
  - Corporate FP&A and VP of Finance review forecast and RLOA submissions to determine funding
- **Week 3:** CFO review RLOA proposal based on forecast vs. street consensus performance
  - FP&A reviews RLOA asks with TA to determine recruiting feasibility
  - Pre-tax forecast lock used for earnings call preparation (pending on RLOA changes in Week 4)
  - CFO reviews RLOA proposal based on forecast vs. street consensus performance
- **Week 4:** At e-group meeting, CFO shares proposal for formal approval and inclusion into final forecast lock and investor guidance
  - After formal approvals, business, FP&A, and TA collaborate to execute on RLOA approved asks
