---
title: CFO Shadow Program
---

## Overview

The CFO Shadow Program is an immersive 1 or 2 week assignment where team members can apply to shadow the CFO. The [70:20:10 model for learning](/handbook/people-group/learning-and-development#70-20-10-model-for-learning-and-development) shows us that most adults gain ~90% of their knowledge through experiential learning. While formal "classroom" style training plays an important role in teaching new concepts, real life experiences are critical to helping adults develop and retain new skills. The CFO Shadow program is a unique growth opportunity for team members who are looking to experience a "day in the life" of a CFO of a publicly traded company, gain greater cross-functional insight, and develop their general business and Finance acumen.

In the spirit of [boring solutions](/handbook/values/#boring-solutions), the CFO Shadow program mirrors the original [CEO Shadow program](/handbook/ceo/shadow#overview) in many ways, with some customizations.

## What to Expect

The CFO Shadow program consists of a 1 or 2 week rotation, depending on the CFO's availability, where the shadow attends nearly all meetings with the CFO on Tuesday, Wednesday, and Thursday typically. If 2 consecutive weeks are available, the CFO shadow can apply to be scheduled for both weeks. Meetings are all-remote, so the program does not require travel, and meetings are conducted in regular business hours in Eastern Standard Time.  Shadows should work with their managers to treat the Tues-Thurs of both weeks that they are participating in the program as time away from their day-to-day role so that they are able to focus primarily on the CFO Shadow experience. The days are commonly meeting heavy, so it's useful to plan to use any time at the end of the day to process what you learned, catch up on notes, or complete any small tasks assigned by the CFO.

## Eligibility

The CFO shadow program is now open to all team members.

To benefit the most from the types of meetings that the CFO attends, it's recommended that the participants have a general understanding of Finance, Business, Economics, and/or Accounting principles. CFO Shadows must be in good performance standing in their current role.

## How to Apply

1. Create a merge request to add yourself to the [rotation schedule](#rotation-schedule)
1. Assign your manager and ask them to approve (**but not to merge**) the merge request
1. Once your manager approves the merge request, assign the merge request to the [Sr EBA to the CFO](/handbook/eba/#e-group-member-ebas)

## Additional Preparation

### Confidentiality

Participating in the shadow program is a privilege where you will be exposed to confidential information. This is underpinned by trust in the shadows to honor the confidentiality of topics being discussed and information shared. The continuation of this program is entirely dependent on shadows past, present, and future honoring this trust placed in them. Please be aware that the role of CFO Shadow will place you on the Designated Insider list for that quarter. You will need to request pre-clearance to trade during the open window. More info on the Designated Insider list and pre-clearance can be found [here](/handbook/legal/publiccompanyresources/).

### Create an onboarding and offboarding issue

 We currently track onboarding and offboarding in the [cfo-shadow](https://gitlab.com/gitlab-com/Finance-Division/cfo-shadow) project.  For questions, reach out to the [Sr EBA to the CFO](/handbook/eba/#e-group-member-ebas) in the `#cfo-shadow` channel

 At this time, we do not have a "See One, Teach One" [rotational rhythm](/handbook/ceo/shadow#rotation-rhythm) in place, but as a CFO shadow you should be prepared to be a buddy to the following quarter's shadow as described in the onboarding issue.

### Consider adding goals

Develop goals for your time as a CFO Shadow and add them to your onboarding issue. To make your goals more actionable, you may want to use the [SMART goals framework](https://www.mindtools.com/pages/article/smart-goals.htm).

### Practice your introduction

It's important that you represent yourself correctly when joining meetings, both internally and externally. You can introduce yourself by stating your name, your normal title, and then by stating that you are in the CFO Shadow Program. The stated purpose should be to give participants an overview of the finance function at GitLab. You will update your Zoom name to "CFO-Shadow" to provide clarity for why you are joining calls.

It will be helpful to read more about introductions related to the [CEO Shadow Program here](/handbook/ceo/shadow#ceo-shadow-introductions)

### Review the CFO's calendar

Schedule a call with the CFO's [Sr EBA to the CFO](/handbook/eba/#e-group-member-ebas) to review the CFO's calendar to get an idea of what your upcoming days will be like.

## During the Program

During the program, you will gain valuable context from a variety of conversations that you'll be part of.

There will be short-term administrative tasks that you'll be asked to perform as the shadow.

1. Handbook updates
1. Prepare for, take notes during, and follow up on meetings

## Meetings

1. The CFO's Senior Executive Business Administrator will add you to all meetings that you can attend. There will be some meetings and events the shadows do not attend. Do not feel obligated to attend every meeting — all meetings are considered optional.
1. As a reminder, you should have your title updated within your last name on zoom. During the Shadow rotation update your title to "CFO Shadow". [Here](/handbook/tools-and-tips/zoom#adding-your-title-to-your-name) is the how to update your title as part of your last name to ensure it shows up on zoom.
1. Because candidate interviews are marked as "private" (busy) for confidentiality reasons, the Sr EBA will invite the shadows to those events directly. As a result, you will get an email from Greenhouse asking for candidate feedback, which is not necessary.
1. Meetings with those outside of GitLab may not be on Zoom. Prior to the call, check the CFO's calendar and load any other conferencing programs that may be needed. It may be necessary to dial in via phone for audio-conferences. If you have any problems confirming the link, reach out to the `#cfo-shadow` slack channel.

### Other Notes on Meetings

- Like all meetings at GitLab, meetings will begin promptly, regardless of the shadows' attendance.
- For the first iteration of the CFO-shadow program, the shadow may not attend e-group or quarterly board meetings to avoid overlap with the CEO Shadows who may already attend those calls.
- The CFO's Sr EBA will ask external people if they are comfortable with the shadows joining prior to the scheduled meeting, and will share a link to the CFO shadow page to provide context.
- Meeting agendas should be shared with cfo-shadow@gitlab.com, as shadows will be added to this email alias prior to the rotation, and removed at the conclusion of it. For agendas that contain sensitive information, the sensitive information should be removed and the document shared with "View only" access to restrict access to the document's history. Not all agendas will be shared, though, and the CFO Shadows should feel empowered to ask for access if that is the case. Sometimes, the answer will be "no" for sensitive reasons.
- There will be times where the Shadow will not attend meetings because a participant in the meeting is uncomfortable or prefers more privacy.

### Shadow's Responsibilities During Meetings

Meetings come in many different formats. Your responsibilities may change slightly based on the kind of meeting.

Here are the responsibilities shadows have during meetings:

| Meeting type                     | Notes?         | Timekeeping?   |
| -------------------------------- | -------------- | -------------- |
| 1-1                              | No notes unless requested | No timekeeping unless requested |
| Legal meetings outside of Key Reviews/GCs/etc. (see [doc](https://docs.google.com/document/d/1vkHile2eHVTEl1S7-qv4eEFDc64ghUSesBfvFNz7qfI/edit) for details)                | No notes       | Timekeeping    |
| 1-1 meetings with a GitLab [Board Member](/handbook/board-meetings/#board-of-directors)      | No notes       | Timekeeping    |
| Internal meeting (CFO not host)  | Notes optional | Timekeeping    |
| Customer Meeting    | Yes, please use the externally-shared collaboration doc | Timekeeping |
| Anything else (unless specified) | Notes          | Timekeeping    |

### Keeping time

Shadows are responsible for being aware of the current time and verbally providing timekeeping in many [types of meetings](#shadows-responsibilities-during-meetings). This allows participants to comfortably wrap up the meeting.

**Tips for time-keeping:**

- Decide who. Past shadows have found it helpful for the individual in the second week of the program to commit to keeping time when applicable.
- Understand meeting length. Use the calendar invite as an indication of how long the meeting should last. Remember, we do [speedy meetings](/handbook/communication/#scheduling-meetings).
- Shadows should provide a 5-minute and a 1-minute notification. You can write "Time check, 5 minutes" on Zoom chat.
- **If a meeting is running over the allocated time, unmute and verbally say "we're in overtime".** Don't wait for a break in the conversation.

**Tools to help.**

You can use this [shell script](https://gitlab.com/gitlab-com/content-sites/handbook/-/blob/main/scripts/setalarm.sh) (MacOS only) to run a timer for the desired number of minutes. The script will notify you 5 minutes before the end of the meeting, and will copy "We have five minutes left" to you clipboard, so you can paste the text directly in the Zoom chat in addition to verbalizing it. At the end of the meeting, the same will occur with "We are at time".

To use the script:

1. Download [setalarm](https://gitlab.com/gitlab-com/content-sites/handbook/-/blob/main/scripts/setalarm.sh), making sure to preserve the .sh extension. (recommended within your Home folder for easy access)
1. Load MacOS Terminal by running `Cmd+Space` and typing `terminal`.
1. Run `source setalarm.sh` to load the `setalarm` function into memory.
1. Then simply type `setalarm 50` to set a 50-minute timer (`setalarm` defaults to 25 minutes if no argument is provided).

Press `Ctrl+C` if you need to cancel the alarm. You may keep the terminal window running indefinitely so that it is at your finger tips throughout your program duration.

## Rotation Schedule

Finance team members have a high workload and may not be able to complete a full 3-day rotation. If you are interested in shadowing for the full or part of the weeks listed below, open the MR to add your name to schedule per the instructions on [How to Apply](#how-to-apply), and message the slack channel `#cfo-shadow` with the exact dates you are requesting.

| Start Date | End Date |Shadow Name |
|----|---------|--------|
| Tuesday 2025-01-07 | Thursday 2025-01-09 | Craig Patrick |
| Tuesday 2025-01-21 | Thursday 2025-01-23 | Stacy Cline |
| Tuesday 2025-02-18 | Thursday 2025-02-20 | |
