---
title: "Hiring & Talent Acquisition Handbook"
description: "Landing page for many of the handbook pages the talent acquisition team at GitLab uses."
---

At the core of our team's vision, mission, and strategy is our ability to impact GitLab's overarching [mission]({{< ref "mission" >}}): to make it so that **everyone can contribute to and co-create the software that powers our world**. When **everyone can contribute**, users become contributors and we greatly increase the rate of innovation.

As a Talent Acquisition team, we have an outsized impact on GitLab's ability to make this mission a reality, by connecting top talent to profound careers from wherever they are in a truly distributed, remote workforce.

### Talent Acquisition Vision Statement

To create globally inclusive access to opportunities so that **everyone can contribute to and co-create the software that powers our world**.

### Talent Acquisition Mission Statement

It is the Talent Acquisition Team's mission to predictably build distributed, representative teams that enable team members to **co-create** the future of software.

### Our Guiding Principles

As we set out to achieve this vision, we will continue to rely on core guiding principles to define how we build toward the future.

1. **Experience**: Stakeholder experience is central to our craft. We are a partner, an advisor, and an essential component to building high performing teams and culture at GitLab.
1. **Inclusivity**: We design fair and equitable processes into the fabric of what we do. We believe Talent Acquisition has an outsized impact on the make-up of our teams, and we strive to continue to build them with inclusivity as a integral piece of our craft.
1. **Predictability**: Our ability to have the right team members, in the right roles, at the right time is imperative to execute on our commitments and plans as an organization. We strive for predictability: to build accuracy in our forecasts and enable the business to look around corners through strong relationships and data driven decision making.

### Our Objectives and Roadmap

We strive to be as transparent as possible, but these sections are only available for our GitLab team members.
[Talent Acquisition Strategy](https://docs.google.com/presentation/d/1TxVaRaBommUMcRxCgrRq9kr2hWW25SBdAObMQdfylO8/edit#slide=id.g2832878d834_0_0)

## Talent Acquisition Pages and Processes

---

### Team Process Pages

- [TA Key Performance Indicators](https://internal.gitlab.com/handbook/people-group/talent-acquisition/key-performance-indicators/) Note: this page is currently in our internal handbook as they are a work in progress.
- [Meeting Cadence](/handbook/hiring/meetings)
- [Talent Acquisition Alignment]({{< ref "recruiting-alignment" >}})
- [Diversity, Inclusion & Belonging Talent Acquisition Initiatives](/handbook/company/culture/inclusion/talent-acquisition-initiatives/)
- [Triad Process]({{< ref "triadprocess" >}})
- [Quarterly Updates](https://internal.gitlab.com/handbook/people-group/talent-acquisition/quarterly-updates/) Note: Internal only

{{% details summary="Shared Definitions" %}}

- **Job:** A job refers to the job title (ex: Customer Support Specialist). This will also be what appears on external job boards. In the case there are multiple positions open that are the same, and we only want to list once, we can have multiple 'openings' (see next section) opened within one 'Job'. Each job will have a unique identifier called a Requisition ID (example- 1001).
- **Opening:** A job can have multiple openings attached to it (ex: you are hiring 3 Customer Support Specialists. You would then have 1 'Job' and 3 'openings' against that job). A job can have multiple openings against it, but an opening can not be associated with multiple jobs. Each opening will have a unique identifier called an Opening ID (example- 1001-1, 1001-2, 1001-3).
- **GHPiD:** GHP ID is the link between Adaptive (what we use to track our operating plan) and Greenhouse (our ATS). A GHP ID has a one to one relationship with an Opening ID. It is the key interlock between our hiring plans and our Talent Acquisition activity. This is a custom field in Greenhouse.
{{% /details %}}

### Candidate Handbook Pages

Please find pages for potential and active applicants below.

- [Candidate Handbook Page]({{< ref "candidate-faq" >}})
- [Talent Acquisition Privacy Policy]({{< ref "recruitment-privacy-policy" >}})

### Interviewer Processes

- [Interviewer Prep Requirements]({{< ref "interviewing" >}})
- [Conducting a GitLab Interview]({{< ref "conducting-a-gitlab-interview" >}})
- [Greenhouse for Interviewers]({{< ref "greenhouse/#for-all-interviewers" >}})

### Hiring Manager Processes

- [Hiring Manager Processes]({{< ref "talent-acquisition-framework/hiring-manager" >}})
- [Conducting a GitLab Interview]({{< ref "conducting-a-gitlab-interview" >}})
- [Greenhouse for Hiring Managers]({{< ref "greenhouse/#for-hiring-managers" >}})

### Candidate Experience Specialist Processes

{{% details summary="Greenhouse integrations you'll need" %}}

- [Prelude]({{< ref "prelude" >}}): To gain CES-level access to Prelude, ask your manager to message the Support team at Prelude.
- [Guide](https://support.greenhouse.io/hc/en-us/articles/360052205072-Guide-integration): Check with your manager if you do not have higher level access to navigate inside of Prelude.
- [DocuSign](https://support.greenhouse.io/hc/en-us/articles/205633569-DocuSign-integration)
{{% /details %}}

- [Candidate Experience Specialist Responsibilities](/handbook/hiring/talent-acquisition-framework/coordinator)
- [Prelude]({{< ref "prelude" >}})
- [How to Complete a Contract - CES Process]({{< ref "ces-contract-processes" >}})

### Recruiters and Sourcers

#### Opening a job

{{% details summary="Get your headcount assignments" %}}

- [How to open headcount on R&D](/handbook/engineering/hiring/#hiring-practices)
- [How to open headcount on Sales and G&A]({{< ref "req-creation#creation-and-approval" >}})
{{% /details %}}

{{% details summary="Open a req in Greenhouse" %}}

- [Instructions here]({{< ref "req-creation#opening-vacancies-in-greenhouse" >}})
- [Open a kickoff session]({{< ref "req-overview#step-3-complete-kick-off-session-agree-on-priority-level--complete-a-sourcing-session" >}})
{{% /details %}}

{{% details summary="Evergreen requisitions" %}}

- [Creating an evergreen req]({{< ref "req-creation#creating-an-evergreen-requisition" >}})
- [Evergreen req guide]({{< ref "evergreen-requisitions" >}})
- An Evergreen Job is a requisition that is 'always open'. More specifically, it is used when we have at least 3 openings for a particular job repeated each quarter. There is then one Evergreen job posted for internal, external and passive candidates. It is important that no candidate is hired to an Evergreen job, and instead is moved to an approved opening (aka an opening with a single corresponding GHPiD). TA Leadership will open EVG roles at the start of a fiscal year, with a quarterly review cadence, by leveraging the hiring plan and attrition assumptions. See the pages above for more information.
- {{% details summary="Tips and Tricks" %}}
- Know your department before you open your req. If you need to change the department name later, the approval chain will not automatically update. If this happens to you, please contact Enablement.
- We do not re-open jobs after they have been closed. This is because permissions and approvers may have changed in the time since the job was first closed.
{{% /details %}}
{{% /details %}}

{{% details summary="Post a job in Greenhouse" %}}

- [Post an **internal** job]({{< ref "req-creation#opening-vacancies-in-greenhouse-dri-recruiter" >}})
- [Post an **external** job]({{< ref "req-creation#publish-the-job-to-the-careers-page--review-greenhouse-configuration" >}})
- [Using Rules]({{< ref "req-creation#using-job-posting-rules-in-greenhouse" >}})
- [Auto-tags]({{< ref "greenhouse#auto-tags" >}})
- {{% details summary="Tips and Tricks" %}}
- Salary transparency: In select US states, GitLab discloses salaries in job descriptions in accordance with local laws. Total Rewards will add this information to the job's approvals page. When you create your *external* job post, utilize Pay Transparency Rules and select Hiring in the USA. If the job will not be posted in the US, select N/A.
- EEOC questions should be checked off in the US only
- [Click here]({{< ref "req-creation#choosing-the-correct-location-for-your-published-job" >}}) for more information on selecting the correct location for your job. This will help ensure that your LinkedIn listings are posted in the correct countries.
- Our jobs are now set up to automatically go to Indeed and Glassdoor and be posted as remote roles on both sites. Recruiters should unselect or leave unselected the option in Greenhouse to "publish to free job boards" as this requires us to input city, state, and country data that overrides the remote job listing. There is an automation in place to automatically send jobs to Indeed and Glassdoor.
{{% /details %}}
{{% /details %}}

{{% details summary="Req access and permissions" %}}

- As a member of the Talent Acquisition team, you have the ability to add team members to view your job with differing layers of access. By default, all team members can access the interview kit & scorecard of someone they're interviewing and this access does not need to be granted. For team members who require additional access, such as a Hiring Manager or their EBA, you will need to grant that access where appropriate. You can use [this guide](https://internal.gitlab.com/handbook/people-group/talent-acquisition/enablement-team/#greenhouse-admin-instructions) to help determine the appropriate access.
- As you are deciding what access level someone should have, default to the setting that allows the most confidentiality for a candidate. If a team member does not need access to scorecards, for example, we should be choosing an access level that does not allow them to see them. A job admin (someone with higher level permissions) typically should not be at the same level or a direct report of a job they have access to. Recruiters typically grant only Hiring Manager access - interviewers do not need special access and cannot access scorecards or candidate profiles through Greenhouse.
- To add or remove access in a job, go to 'job setup' and click 'hiring team'. Add or remove access under "Who can see this job?". Unfortunately, there is no way to bulk add or remove access. You can also add and remove access when creating your job from a template. If you are searching for a team member and cannot find their name, ensure that you do not have filters activated. **Do not grant admin access through templates,** because this could create problems in the future.
{{% /details %}}

{{% details summary="Set up scorecards and interview plans" %}}

- There are two elements of a scorecard: the Scorecard section and the Interview Plan section. Both are accessible through Job Setup.
- [**Scorecard**](/handbook/hiring/talent-acquisition-framework/req-creation/#update-the-scorecard) Depending on your department, you may have a lot of your scorecard options pre-filled. R&D scorecards are always set up for you, and may only require small tweaks depending on technical language or job grade.
- [**Interview Plan**](https://support.greenhouse.io/hc/en-us/articles/115002276366-Add-an-interview-question-to-an-interview-kit)
- {{% details summary="Tips and Tricks" %}}
- Name your interviews in a way that will help your Candidate Experience Specialist partner schedule your interview. We recommend 'Topic -  Interviewer - Time' i.e. 'Values Interview - Beyonce Knowles - 45 min'. If you are pulling from a large interviewer pool, you can discuss with your Candidate Experience Specialist partner if it makes sense to create a Prelude interviewer pool that will help with scheduling.
- Once you have set up the stages and interview names, add the specific interview questions asked into the "Interview Questions" section of the Interview Plan.
- If you need to make bulk changes to a large number of jobs' scorecards at once, Enablement has the ability to make bulk changes. Please contact them for assistance.
- Recruiters don't need to be the only ones adding interview questions to the interview plan. Invite your Hiring Manager to complete this task alongside you.
{{% /details %}}
{{% /details %}}

#### Interview Stages

{{% details summary="Stages Overview" %}}
Please note that the names of stages is important, and we should only have stages with the names listed below. Anything outside of these stages will not appear on reporting.

Scorecards are required in all stages that require interviews. Confidential, personal information and disclosures about being part of a protected class are never to be written in scorecards. Recruiters can add salary information into Private Notes outside of the scorecard to maintain confidentiality.

- **Get to Know Us:** This is an application review stage.
- **Qualified:** This is the stage where positive applications will be triaged. Candidates can wait here to be scheduled for interviews, to ensure the right mix of well-qualified candidates are screened at the right times.
- [**Screening:**]({{< ref "req-overview#screening" >}}) Phone or video interview with a recruiter, scheduled through Calendly.
- [**Assessment:**]({{< ref "req-creation#update-the-interview-plan" >}}) This is an optional stage where written assignments can be submitted. Learn more [here]({{< ref "req-creation#update-the-interview-plan" >}}).
- **Initial Interview:** This is the first video interview with a member of the team, which helps determine if they will move forward to additional interviews. This stage ensures we are utilizing the interviewers' and candidates' time thoughtfully, and is typically either a Hiring Manager or Technical interview.
- [**Team Interview:**]({{< ref "req-overview#team-interview" >}}) All other team interviews live here.
- [**Debrief:**]({{< ref "offer-process#debrief" >}}) This will come after the reference check stage for Engineering requisitions, because the reference checks will be initiated as the Justification (R&D's process for the Debrief stage) is initiated. For non-Engineering departments, this will be a holding stage where candidates wait until a decision is made, to track the time it takes for us to reach a decision on a candidate who has completed their interviews. See the [Engineering's Justification process]({{< ref "offer-process#debrief" >}}).
- [**Reference Check:**](#offers-and-closing-reqs) The reference check stage can sometimes be done in tandem with the Debrief and Background Check and Offer stages. They can be completed by the Hiring Manager or Recruiter.
- [**Background Check and Offer:**](#offers-and-closing-reqs) Recruiters move candidates into this stage once they're ready to receive their verbal offer. Before that time, this stage is where an offer is prepared and goes through approvals. This is the final stage in the process.
{{% /details %}}

{{% details summary="Scheduling tools in Greenhouse" %}}

- Candidate Experience Specialists use [Prelude]({{< ref "prelude#prelude" >}}) to schedule.
- Interview confirmations are sent through [Guide]({{< ref "guide#guide" >}}). Because of this, confirmations have calendar invites that can be downloaded rather than being sent through. For this reason, Recruiters are not able to be added to candidate interview invites.
{{% /details %}}

{{% details summary="Greenhouse for internal candidates" %}}

- There are a few elements of Greenhouse that are different for internal candidates. Please note that internal candidates refer to current, full time team members. Interns converting to full time, contractors, or rehires are not considered internal candidates.
- Interviews will always be scheduled as "private" events to ensure the candidate's privacy. Interviews will show up as "busy" events on candidate and interviewers calendars rather than showing as interviews.
- If internal applicants apply via our internal job board, the yellow "internal applicant" tag will automatically show in the GH profile. If you don't see this tag, you can add it by navigating to the "Details" tab in GH and scroll down to "Source & Responsibility". Click the pencil next to Source and select Internal Applicant from the drop down.
- CES will use the internal applicant's Google Calendar to find an appropriate time for them to meet, and do not need to be sent an availability email.
- Former GitLab team members who re-apply are not considered internal candidates. Their source should be whatever they used to apply (ie application), and you should add a "Former Team Member" tag to their profile.
{{% /details %}}

{{% details summary="Candidate Hygiene" %}}

- {{% details summary="Merging candidates" %}}
- Recruiters should [merge applicant profiles](https://support.greenhouse.io/hc/en-us/articles/115004506466-Merge-candidate-profiles) whenever you see the opportunity and can verify that the candidates are the same. Merging applicant profiles allows you to keep data up to date, and also ensures that you know the full application history of anyone who applies. Aside from Internal candidates who should be merged right before hiring, you can merge candidates at any stage of the process.
- All of Talent Acquisition has access to merge profiles. You can merge candidate profiles by viewing the right hand toolbar on an applicant profile, and clicking on either the alert that appears at the top of the toolbar or 'See More' in the 'Tools' section.Before beginning, please ensure that the profiles are a match for each other by verifying that their emails, phone numbers, and/or resumes are the same.
- When selecting which profile is Primary (right side), consider the following:
- As a default, the most recent applicant profile should most likely be the Primary one, unless the most recent is a Prospect.
- If this is an internal candidate, the most recent profile should always be Primary, but should not be merged until the candidate has accepted their offer to minimize the number of people with access to this information.
- After merging, check the Activity Feed and Details tabs to see what information was removed from old profiles and ensure that you have the most accurate Recruiter, Coordinator, and Source.
- If you have any questions, please contact the Enablement Manager because profile merges cannot be undone.
{{% /details %}}

- {{% details summary="Adding or transferring candidates between jobs" %}}
- If a candidate is in one job and needs to move to another, it's important to correctly determine whether they should be added or transferred. Both are accessible by clicking the 'Add, Transfer, or Remove Candidate's Jobs' button on the bottom right corner of your candidate profile.
- Before making any moves, always ensure the candidate does not have any interviews scheduled. Transferring will automatically remove scheduled interviews and make them invisible on the candidates' Guide, but will not cancel the interview from the interviewers' calendar or inform the candidate of what is happening. Always wait until the interview has been completed, or fully cancel the interview and reschedule under the new req.
- When you add a candidate to a new job, the candidate starts the new job with a clean slate. There will be no scorecards or forms from any other position. This should be chosen when you are starting a brand new hiring process and will not be considering scorecards from any other job, and want their application date to be the date that you add them.
- When you transfer a candidate from one job to another, most of their data before the reference check stage moves with them. Scorecards will be visible in the "Scorecards" tab and their original application date will remain. Scorecards that have not been submitted cannot be submitted after transfer, so make sure you collect those before you make your move. Offers and forms are also not transferable, so it's important to transfer before a candidate hits the Reference Check stage. When you are moving someone from an Evergreen req into the role they will be hired into, you should always transfer. There will be no record of the previous job in any reporting.
- Sometimes, deciding whether to add or transfer can be tricky. If a candidate interviewed for a role that was filled by someone else, and you get a new headcount a few months later, should you transfer them into the new job or add them and start over? One thing to consider is the implication your choice will have on the data. In this case, a candidate who transfers will appear to have been in the hiring process for months, when you've actually only been talking to them about this opening for a few days. At the same time, you want to save their scorecards because they'll be relevant for the new job. In another situation, you could have an applicant who was being considered for the role, was rejected by the Hiring Manager, but contacted a few months later when the scope of the role changed and they were now considered a good fit. The key to knowing when to transfer is understanding what impact it would have on our data, and what solution would paint the most **accurate** picture. If you're not sure whether to add or transfer, you should check in with Enablement to get another opinion.
{{% /details %}}

- {{% details summary="Rejecting candidates" %}}
- When rejecting candidates, it's important to carefully review all rejection reasons and pick the one that most accurately describes why a candidate is being rejected. This is because data is analyzed on a quarterly basis by the Talent Acquisition Leadership team, People Leadership Team, and E-Group.
- Once you've clicked the most detailed reason, include detailed context on the reason in the "Rejection Notes" box. Please be as specific as possible. For example, instead of writing "the candidate rejected because of compensation", write "the candidate rejected because the salary and equity that we offered was much lower than a competing offer."
- Please note that you cannot submit scorecards after rejecting a candidate.
- We will not cancel an interview within less than 24 hours' notice if the candidate is being rejected. The recruiter will notify the candidate that they are no longer in consideration for the role and present them with the option to continue with the scheduled interview slot. The interviewer must be informed, and will not discuss the feedback that led to the decline. The conversation will pivot to general opportunities at GitLab and answering any questions about the company and team that the candidate may have.
- If the candidate's interview is outside 24 hours, the interview should be deleted in Greenhouse before the candidate is rejected and notified. The candidate should always be notified if they've been rejected, and the recruiter  is responsible for declining the candidate. Any interviews scheduled will also not be automatically canceled, so you'll need to ensure this happens first.
- If the candidate does not join the interview room within 10 minutes or fails to complete their MR within the specified time before the interview, the interview will be cancelled and the recruiter will get in touch with the candidate and not schedule further interviews.
- If the candidate notifies us that they are unable to attend the interview before the scheduled time, CES can automatically reschedule using the candidates' current availability or by requesting fresh availability.
- If we have rescheduled at the request of the candidate and the candidate requests to move the interview again without reasonable explanation, the recruiter will automatically reject the candidate.
- We understand that there may be extenuating circumstances leading to the above situations where a candidate is unavailable or unprepared. It is at the recruiter's discretion to reengage or choose to reschedule.
{{% /details %}}
{{% /details %}}

#### Offers and Closing Reqs

{{% details summary="Reference Checks" %}}

- [Reference check information]({{< ref "offer-process#reference-reviews" >}})
- Reference check forms are mandatory. If you receive reference check information outside of the form and don't want a candidate to fill it out again, Enablement can help you adjust the form to collect the remaining information. These forms are important because they provide necessary information for the accuracy and completion of a contract.
- {{% details summary="Tips and Tricks" %}}
- These forms, just like an offer in Greenhouse, **do not transfer** when you move a candidate from one job to another. Ensure that your candidate is in the role they'll be hired for before sending.
- Completed forms live in a candidate's "application" tab. If you can't find the form, it's likely there!
- While nicknames, preferred last names, and PIAA details will save to the details page automatically, legal name will not. Please ensure the legal first and last name is set as the candidates' name before sending contracts.
- If you have a candidate in the Netherlands, they are required to provide their BSN and date of birth. Recruiters should add those fields into the offer.
{{% /details %}}
{{% /details %}}

{{% details summary="Offers" %}}

- [Creating an offer in Greenhouse]({{< ref "offer-process#offer-approvals" >}})
- {{% details summary="Common approval challenges" %}}
- Offer stuck in approvals: If the offer is stuck in the approvals chain because someone is out of office, the recruiter can talk to the approver's manager about an appropriate temporary adjustment and recommend this to the Enablement team. Recruiters should be proactive in reaching out to approvers if an offer is urgent or a candidate is being inconvenienced by a long wait time. If there is a known OOO, this discussion should happen before there's an offer waiting for approval. Enablement can help with any changes needed.
- Offer approvals chain is incorrect: If approvers are missing or incorrect, the Recruiter should contact a member of the Enablement team to adjust. The only people with access to make approvers changes are Enablement and Director, Executive Recruiting, who change approval chains to maintain confidentiality for executive positions. Often, approval chains are incorrect because you have chosen the wrong department, so it's important to choose the right one before opening your req.
{{% /details %}}
- [Verbal offer information]({{< ref "offer-process#verbal-job-offer" >}})
- [Declined offer steps]({{< ref "offer-process#declined-offers" >}})

{{% details summary="Background screens" %}}

- Contact the Senior Background Check Specialist at backgroundchecks@gitlab.com with any questions or requests for status updates.
- The most commonly asked question for candidates outside the US is, "Why can't I enter more than one past employer?" Outside of ​the US, candidates will only submit one former employer and Sterling is working as expected.
{{% /details %}}
{{% /details %}}

#### Sourcing at GitLab

- [Sourcing overview](/handbook/hiring/sourcing)
- [Identifying prospects]({{< ref "req-overview#step-4-identify--engage-top-talent-prospects" >}})

#### Notifications

There are no perfect or required ways to set up your Greenhouse notifications, but these are some of our recommendations.

{{% details summary="Slack" %}}

- To set up Slack to notify you when you're tagged in candidate notes, select your initials in the upper right hand corner of Greenhouse. From there, you can activate your Slack integration. Toggle the button to send @mentions to Slack. This is also a great button to point out to Hiring Managers so they are easier for the team to reach.
- Additionally, you will see a section for "Notification Preferences". Most recruiters will set these up, but they are optional if you prefer to only receive notifications by email.
{{% /details %}}

{{% details summary="Email notifications" %}}

- There are two ways to set up your email notifications. The first is to select your initials in the top right corner of Greenhouse, and under "notification preferences", select where you would like to receive notifications about jobs. This is an easy way for Hiring Managers to set up their preferences for all jobs at once, but may not be as easy for the Talent Acquisition team to remember to update.
- Instead, we would recommend setting your reminders either during your job setup process or after, by clicking into your Notifications tab of an individual job's Job Setup. Here, we recommend that you stay in the loop on your candidates by electing to receive emails every time a scorecard is submitted, an internal candidate applies, a referral is submitted, and an offer is fully approved. You can choose your name or "Candidate's Recruiter", but you'll want to be sure that you're listed as the recruiter on the role to make this work. Recruiters should double check during this time that no one is receiving notifications that should not (ie an interviewer receiving offer notifications) and adjust privacy settings accordingly.
- You can sync your emails between Greenhouse and Gmail. Greenhouse has a Gmail add-on that can help with syncing communications. You can learn more about it by [going here](https://support.greenhouse.io/hc/en-us/articles/360003111031-Greenhouse-Gmail-add-on).
{{% /details %}}

## Talent Acquisition Programs

### Referrals

- [Referral Operations]({{< ref "referral-operations" >}})
- [Referral Process]({{< ref "referral-process" >}})
- [Details on who is eligible for referrals]({{< ref "incentives#referral-bonuses" >}})

### Acquisitions

- [**Acquisitions**](talent-acquisition-framework/acquisitions/)

### Internal Mobility

- [Internal Hiring Process]({{< ref "internal-hiring-process" >}})
- [Posting a job internally]({{< ref "req-creation#post-the-job-internally" >}})
- [In the offer process]({{< ref "offer-process#offer-approvals" >}})

### Executive Hiring

- [Executive Search]({{< ref "executive-search" >}})

### Emerging Talent

**[Emerging Talent](emerging-talent.md)**

- [Associate Engineer Development](/handbook/hiring/associate-engineer-development/)

## Global Hiring Resources

{{% details summary="Global hiring links" %}}

- The ["country hiring status"](https://comp-calculator.gitlab.net/hiring_status/index) section within the compensation calculator is the best place to look for a list of current countries available for hiring.
- [This country list](https://docs.google.com/spreadsheets/d/1SLsLHcUaDqRUM0w0rWkISfA9NiZ3X6XRq--7IthqSYQ/edit#gid=1223524307), maintained by and accessible to recruiters, details specific information about each country that can help you answer candidate questions and prepare for potential hiring delays.
- For general questions about specific policies or whether we support certain types of visas or sponsorship, message #people-group-confidential. If the request is more involved, or requires a conversation, you can slack Harley Devlin.
{{% /details %}}

{{% details summary="PEO information and timelines" %}}

- For candidates who are located in Countries where we do not have an entity, we use a PEO (Professional Employment Organization).  The actual employment contracts will be sent and issued by the PEO who also handles the processing and payment of payroll and associated taxes and compliance in each of the countries on behalf of GitLab. The contracts themselves are between the individual and the PEO.
- GitLab is currently hiring into three PEOs
- [Remote.com]({{< ref "ces-contract-processes#remotecom" >}})
- [Global Upside]({{< ref "ces-contract-processes#preparing-employment-agreements-for-gitlab-team-members-employed-via-global-upside" >}})
- [Papaya]({{< ref "ces-contract-processes#how-to-add-the-new-hire-to-the-remote-platform" >}})
- The following timelines to onboarding are advised:

**Remote.com:** [remote.com onboarding timeline](https://support.remote.com/hc/en-us/articles/4411262104589-Employee-Onboarding-Timeline)

| Country | Working days |
|------|------|
| Austria | 9 |
| Denmark   | 9 |
| Hungary | 9 |
| Italy  | 9 |
| Mexico  | 3 |
| South Africa  | 5 |
| Spain  | 7 |
| Switzerland | 7 |

**Global Upside:**

| Country | Working days |
|------|------|
| India   | 7 business days |
| Philippines   | 17 ( Including 7 business days for pre hire medical test and 3 business days for social registration) |
| Kenya   | 7 business days |
| Costa Rica   | 12 ( Including 5 business days for social registration) |
| Latvia   | 8 ( Including 1 business day for social registration) |
| Chile   | 12 ( Including 5 business days for social registration) |

**Papaya**

Processing for the United Arab Emirates could take up to a month, so we recommend start dates at least 6 weeks after the offer is generated.
{{% /details %}}

## Other Hiring Pages

- [Greenhouse]({{< ref "greenhouse" >}})
- [Talent Acquisition Process Framework]({{< ref "talent-acquisition-framework" >}})

## Additional Resources

- [Overview of Job Families](/handbook/hiring/job-families)
- [Background checks](/handbook/people-policies#background-checks)
- [Benefits]({{< ref "benefits" >}})
- [Compensation]({{< ref "compensation" >}})
- [Contracts](https://internal.gitlab.com/handbook/people-group/people-operations/people-connect/employment_contracts/)
- [GitLab talent ambassador]({{< ref "gitlab-ambassadors" >}})
- [Onboarding]({{< ref "general-onboarding" >}})
- [Stock options](/handbook/total-rewards/stock-options/)
- [Visas]({{< ref "visas" >}})
