---
title: Candidate Handbook Page
description: "This page outlines what hiring looks like at GitLab. We share the latest information about our processes and practices to ensure you have the information you need to feel confident during the interview process."
---

The GitLab Candidate Handbook is a space for recent applicants and candidates progressing through the interview process. We encourage every prospective job seeker to spend time learning more about the work we do, our culture & values, and what to expect during our hiring process.

The goal of curating these resources is to outline what hiring looks like at GitLab. We share the latest information about our processes and practices to ensure you have the information you need to feel confident during the interview process. The resources referenced here offer guidance on what to expect during each step of the interview process, where we hire, best practices for virtual interviewing, and other useful information.

## Interview Stages

The interview process consists of the following stages:

1. Application Process
1. Screening Call
1. Assessment (required for certain roles)
1. Technical Interview (required for certain roles)
1. Team Interviews
1. References & TMRG Connection
1. Offer & Background Screening

## Application Process

### How to submit an application

{{% details summary="External applicants" %}}
All of our open positions can be found on our [jobs page](https://about.gitlab.com/jobs/all-jobs/). You can view jobs by department and/or location. Click on a job that interests you and select the "Apply Now" button at the top of the page to fill out an application.
{{% /details %}}

{{% details summary="Internal applicants" %}}
Interested in another role internally? Review internal mobility eligibility [here]({{< ref "internal-hiring-process#team-member-responsibilities" >}}).

If you are a [current team member and are interested in applying]({{< ref "promotions-transfers#department-transfers" >}}) for a current vacancy, please follow the steps below.

1. Log in to your [Greenhouse account](https://gitlab.greenhouse.io/dashboard)
1. If you are a GitLab team member who signed in to Greenhouse you can access the [Internal Job Board](https://gitlab.greenhouse.io/internal_job_board). If you do not yet have a Greenhouse account, you can activate yours by clicking the Greenhouse tile in Okta.
1. You can also access the internal job board under the "Helpful Links" section. For more information (and screenshots!), feel free to read the [Greenhouse help article](https://support.greenhouse.io/hc/en-us/articles/200913945-Employee-Access-to-Internal-Job-Board).
1. Click on the position title that interests you.
1. You will be redirected to the vacancy description and application form, where you will be asked to fill out basic personal information, provide your resume, LinkedIn, GitLab username, and/or cover letter, and answer any vacancy-specific application questions, as well as answer a voluntary Equal Employment Opportunity questionnaire if the position is open to US applicants.
1. Once you have finished, click "Submit Application" at the bottom.
{{% /details %}}

### Who can apply?

{{% details summary="Equal Opportunity Employer" %}}
GitLab is proud to be an equal opportunity workplace and is an affirmative action employer. GitLab's policies and practices relating to recruitment, employment, career development and advancement, promotion, and retirement are based solely on merit, without regard to all legally protected classes, including, but not limited to: race, color, religion, ancestry, sex (including pregnancy, sexual orientation, or gender identity), national origin, age, citizenship, marital status, gender identity, disability and genetic information (including family medical history), and any other status protected by federal, state or local law. GitLab will not discriminate on the basis of disability or veteran status.
{{% /details %}}

{{% details summary="No solicitations" %}}
At GitLab, we do not accept solicitations from recruiters, recruiting agencies, headhunters, or outsourcing organizations. If you email us about this type of opportunity, [we'll reply](https://gitlab.com/gitlab-com/people-group/talent-acquisition/-/blob/master/Email%20Templates/third%20party%20agency%20response.md) with [a link to this paragraph](#who-can-apply) to indicate that we'd like to be removed from the contact list.
{{% /details %}}

### I applied for a job on your careers page. What's next?

Thanks for your interest in GitLab! Our team will reach out if they need more information from you. In the meantime, read about what you can expect during the interview process below.

If your experience is a good fit for the role, we will be in touch soon. Please note that it's not possible for us to respond to every candidate, but we aim to review every application.

### A recruiter reached out. How do I know they're real?

Scammers often target job seekers by impersonating companies like GitLab, using the GitLab name and GitLab team member names. Scammers have been observed requesting job seekers pay thousands of dollars for "technology equipment" after job seekers completed an in-depth, fake job application interview process.

Check out the ["What to know about a fake job scam impersonating GitLab"](https://about.gitlab.com/blog/2023/06/29/fake-gitlab-job-scam/) blog post for warning signs and tips on how to protect yourself.

## Screening Call

### Screening Call expectations

If it is determined that you qualify for continued consideration, the assigned Recruiter will conduct a screening call with you. Calls can last anywhere between 30 and 40 minutes (some specialist roles require more time), depending on the conversation. The Recruiter will wait 5 minutes for you to show up to the appointed video call, which is always shared via email. If you do not show up to the interview, or do not reach out in advance to reschedule, you will be classified as a no show and be disqualified. We will unreject when circumstances beyond your control cause you to miss a scheduled call.

You, the recruiter or the hiring manager can terminate the discussion at any point during the interview if either party determines that it isn't a fit. Be as transparent and honest as possible and provide feedback.

Depending on the outcome of the call, the talent acquisition team or manager may either reject or move you to the Team Interview stage.

{{% details summary="Example Screening Call questions" %}}

1. Why are you interested in GitLab?
1. What are you looking for in your next position?
1. Why did you join and leave your last three positions?
1. What is your experience with X? (for each of the skills listed in the position description)
1. [STAR Method](https://www.themuse.com/advice/star-interview-method) questions and simple technical or skills-related questions
1. What is your current location and do you have any plans to relocate? (relevant in context of compensation, country-hiring guidelines, and in case an offer would be made)
1. Do you require visa sponsorship or a work/study permit to work for GitLab? Or do you require the work permit to be transferred to GitLab? If the answer is yes, we will not be able to proceed, [unless you currently hold a work permit in the Netherlands]({{< ref "visas#dutch-work-permits" >}}). You can refer to the [Visa and Sponsorship]({{< ref "visas#visas-and-sponsorhip" >}}) handbook section for further clarity.
1. What is the notice period you would need if you were hired?
1. Is this salary range in line with your expectations? At GitLab, we are committed to paying competitively and equitably. Therefore, we set our offers based on market pay rather than a candidate's pay history. We walk through the [Compensation Calculator](https://comp-calculator.gitlab.net/) with each candidate so that we can address any gaps in expectations early on. Only candidates who are in the team interview stage or later can access our [compensation calculator](https://comp-calculator.gitlab.net/) by following `applicants sign up`.

At the end of the screening call, the Recruiter will tell you what the next steps will be, if any. There should be time for you to ask any questions you may have.
{{% /details %}}

## Team Interviews

### Team Interviews expectations

After the Screening Call, a candidate will move into the Team Interviews stage if the Recruiter decides that the candidate is fit for the role. Team Interviews may consist of behavioral, panel and/or [technical interviews]({{< ref "technical" >}}) (certain positions).

Feel free to ask your Recruiter which type of interview you can expect.

## Optional TMRG Connection

During the [reference](#references) stage in the interview process, candidates will get the option to speak with a GitLab team member who is a member of our [Team Member Resource Groups](/handbook/company/culture/inclusion/erg-guide/#definition-of-the-tmrg---team-member-resource-groups) (TMRGs) to learn about what it's like working at GitLab from someone who they can relate to.

When you receive a reference form, you will have the option to opt-in for a conversation with a member of the [TMRG](/handbook/company/culture/inclusion/erg-guide/#how-to-join-current-tmrgs-and-their-slack-channels) of your choice. Our Candidate Experience team (CES) will then reach out and coordinate this Zoom call for you. You can also read about how we [field this request](/handbook/company/culture/inclusion/talent-acquisition-initiatives/#speaking-with-tmrg-members-in-the-hiring-process).

### Interview Process FAQs

{{% details summary="How to request for a reasonable accommodation" %}}
At GitLab we pride ourselves on ensuring that everyone can contribute. To make certain that everyone's interview experience is a positive one, we encourage those who require a reasonable accommodation to successfully carry out the interview process, to reach out to `ces@gitlab.com`. The Candidate Experience team along with Talent Acquisition leadership will work with you to define and accommodate those needs. This could include but is not limited to the following:

- Translation Services
- Use of additional services or assistive technologies
- Assistance in setting up Closed Captioning for interviews
{{% /details %}}

{{% details summary="I've started the interview process at GitLab, but haven't heard back from anyone recently. What do I do?" %}}
Feel free to send an email to your Recruiter to get a status update on where you are in the interview process.
{{% /details %}}

{{% details summary="Can I have the hiring team's email addresses so I can send them a note?" %}}
If you'd like to send a note to the hiring team, please send it to your Recruiter and they will forward it on.
{{% /details %}}

{{% details summary="Can I interview for multiple roles at the same time?" %}}
In the event that you are interested in more than one opening, there is no limit on the number of roles you can apply for but keep in mind the following:

1. You will have to complete a full interview process for each role you apply to, so be mindful of the time commitment for each application you submit.
1. Due to capacity, the recruiting team will only process 3 of your applications at a time based on which ones you decide to prioritize. Any other applications outside of the 3 will be processed after the prioritized roles's interviews are completed.
1. In the effort to be as transparent as possible and avoid sending multiple competing GitLab offers, there will be an added step to the process after your final interview where you will discuss with your recruiter which role you're interested in before any official offer documents can be sent.
1. If you already have interviewed with us, you can apply for a different role again, but please take note that there may be a cooldown period of 6 months or more if it's a similar role, depending on the reason for not moving forward which is communicated by the recruiter.

Example of dual Interview process outline

1. Application Process
1. Screening Call
1. Assessment (required for certain roles)
1. Technical Interview (required for certain roles)
1. Team Interviews
1. Discussion with your recruiter on which role you're interested in
1. References
1. Offer sent for role discussed in step 6 & Background Screen

**For internal candidates only (in addition to the above guidelines)**

1. If you are interviewing for two roles within the same job family and job grade, the offers will be the same.
1. If you are interviewing for two roles in different job families the offers may be different.
{{% /details %}}

{{% details summary="I've been rejected, when can I reapply?" %}}
If your application is rejected because you are insufficiently qualified for the role, you are welcome to reapply to the same position once 6 months have passed. If you gain the skills, experience, or knowledge we outlined in our [feedback to you](/handbook/hiring/interviewing/#rejecting-candidates), you are welcome to reapply at any time.
{{% /details %}}

{{% details summary="I already passed the technical interview, will I need to repeat that stage if I reapply?" %}}

If you are reapplying to a role in R&D and have already completed interviews following a technical interview, your technical feedback also remains valid for up to 6 months as long as you are applying to the same job family. The recruitment team will aim to run a reduced interview process in this scenario, however, if you are reapplying outside of the 6 month window or applying to a different job family, you will be required to restart the interview process with us again.

{{% /details %}}

### Inclusive interviewing

The GitLab team understands the importance of inclusive interviewing, and we strive to ensure our hiring team is well versed in every aspect of diversity, inclusion, and cultural competence. A positive and comfortable candidate experience is our priority.

### How we conduct remote interviews on a global scale

{{% details summary="How we work during holidays" %}}
As an all-remote, global company, GitLab gives all team members the flexibility to determine their [time away from work]({{< ref "paid-time-off" >}}), including the holidays they observe.
There will likely be holidays that our candidates observe that a Recruiter, Hiring Manager, or CES may not.
If there's a time during the year when a significant portion of the company will be taking time off, we'll be sure to send a communication to all active candidates to let them know of a possible delay in communication.
Please note that not every member of the team will be observing that holiday, so you may still receive emails from them.
{{% /details %}}

{{% details summary="How we schedule interviews on a global scale" %}}

1. Once you have completed a screening call with the recruiter and are ready to be scheduled for the Team Interview stage, you'll receive an email requesting availability. To move through this process as quickly as possible, please give us many different days and times spread across at least 2 weeks. This will prevent us from having to reach out again asking for more availability, as some interviewers could be across many different time zones. Sometimes if the interviewer has a schedule that is difficult to fit interviews into, we'll suggest specific times and dates via your availability link.
1. After receiving your availability, we will compare it to the interviewers' working hours. If we find a match, we will schedule an interview and send you a link to a Guide and invite in your time zone to download to your computer. If we do not, we will reach back out and work with you to find an alternative. Sometimes there is a very small overlap between time zones, so we appreciate your patience as we identify alternatives!
1. If you need to reschedule, follow the special instructions in your confirmation email if the interview is within 24 hours. You can also email ces@gitlab.com anytime.
{{% /details %}}

## References

### How references are conducted

References will be collected towards the end of the interview stage and they must be checked before or as an offer is made. The Hiring Manager or hiring team will contact your references. These reference checks will be performed in accordance with the applicable law of the jurisdiction. Where applicable, a reference check can also be used in the final decision for making an offer. The reference check is not the sole factor for a decision to hire or not hire an individual. However, in conjunction with the interview scores and the interview team feedback, all of these factors go into the hiring decision.

Three references will be requested and at least one needs to be a past manager. If you have only had 1 manager, and it is at your current company, it is okay to skip the manager reference (though at least two total references will still be required).

## Offer & Background Screening

Depending on your location, a [background screen]({{< ref "people-policies#background-screenings" >}}) will be initiated at the same time as references or once an offer has been extended.

## Where does GitLab hire people?

At GitLab, we hire people from all over the world and all walks of life. Diversity, Inclusion & Belonging  is one of our [core values](/handbook/values/). As an [all-remote company](/handbook/company/culture/all-remote/) we do face challenges with hiring in certain countries. Each country has unique and complex rules, laws, and regulations, that can affect our ability to conduct business, as well as the employability of the citizens and residents of those countries. It unfortunately affects the employability of the citizens and residents of those countries. We are growing and continuously exploring our hiring capabilities in a variety of geographies. At present we are focusing our hiring in countries where we have entities & PEO's (Professional Employer Organization).

{{% details summary="Take a look at the countries where we currently hire below." %}}

Please refer to a specific job listing to see if the position is hiring in the country where you are located. You check our [handbook](/handbook/people-group/employment-solutions#country-hiring-guidelines) for more in-depth information

| Country                                                        | Employed through an Entity or PEO  |
| -------------------------------------------------------------- | ---------------------------------- |
| Australia                                                      | Entity                             |
| Belgium *                                                      | Entity                             |
| Canada                                                         | Entity                             |
| Finland *                                                      | Entity                             |
| France *                                                       | Entity                             |
| Germany                                                        | Entity                             |
| Ireland                                                        | Entity                             |
| Italy *                                                        | Entity                             |
| Japan                                                          | Entity                             |
| South Korea                                                    | Entity                             |
| Netherlands                                                    | Entity                             |
| New Zealand *                                                  | Entity                             |
| Singapore                                                      | Entity                             |
| United Kingdom (England, Scotland, Wales, Northern Ireland)    | Entity                             |
| United States                                                  | Entity                             |
| United States (Public Sector)                                  | Entity                             |
| Austria *                                                      | PEO                                |
| Brazil *                                                       | PEO                                |
| Chile *                                                        | PEO                                |
| Costa Rica *                                                   | PEO                                |
| Denmark *                                                      | PEO                                |
| India *                                                        | PEO                                |
| Kenya *                                                        | PEO                                |
| Latvia *                                                       | PEO                                |
| Luxembourg *                                                   | PEO                                |
| Mexico *                                                       | PEO                                |
| Philippines *                                                  | PEO                                |
| South Africa *                                                 | PEO                                |
| Switzerland *                                                  | PEO                                |
| Sweden *                                                       | PEO                                |
| UAE *                                                          | PEO                                |

Note: In countries with a star (*) hiring is limited to only certain roles
{{% /details %}}

## What's it like to work at GitLab?

Our [mission]({{< ref "mission" >}}) makes it clear that we believe in a world where everyone can contribute. We make that possible at GitLab by [running our operations on our product]({{< ref "using-gitlab-at-gitlab" >}}) and staying aligned with our [values](/handbook/values/).

{{% details summary="Explore the resources below for a deeper understanding of working at GitLab — one of the world's largest all-remote companies" %}}

- [Life at GitLab](https://about.gitlab.com/jobs/)
- [How We're Changing the Look of DevOps and Remote Work, One Iteration at a Time](https://builtin.com/brand-studio/gitlab-changing-look-devops-remote-work?utm_source=linkedin&utm_medium=social_media&utm_campaign=gitlab)
- [GitLab's guide to starting a new remote role](/handbook/company/culture/all-remote/getting-started/)
- [Life at GitLab Content Library](/handbook/people-group/employment-branding/content-library)
{{% /details %}}

### What our team members are saying

Interested in hearing about life at GitLab straight from our team members? You can hear right from them by checking out our [careers page](https://about.gitlab.com/jobs/) and clicking on the "See How" button under each team member feature or by heading to our [Builtin page](https://builtin.com/company/gitlab).
