---
title: "Conducting a GitLab Interview"
description: "Helpful information about how to prepare and conduct interviews for GitLab"
---
## **Overview**

Interviewing can be challenging for both parties involved. In a relatively short space of time, a decision must be made about the potential collaboration. This page aims to provide clear guidelines to ease the interview process for everyone.

## Interviewer Training Requirements

New internal interviewers must complete the [interviewer training module in Level Up](https://university.gitlab.com/access/saml/login/internal-team-members?returnTo=https://university.gitlab.com/learn/course/interviewer-training), or as a part of the [Becoming a GitLab Manager issue template](https://gitlab.com/gitlab-com/people-group/Training/-/blob/master/.gitlab/issue_templates/becoming-a-gitlab-manager.md).

It is typically expected for new hires to focus on and complete their onboarding for at least two weeks before being part of an interview team. There may be extenuating circumstances where a team member needs to participate in interviewing sooner than this, but they should always complete the interviewing training module in LevelUp and discuss the role thoroughly with their manager and the recruiter prior to being on an interview team.

## Interviewing Philosophy

Being an interviewer is an area where you have an outsized impact on our ability to grow and accomplish the business goals we have as an organization. Your role is to use skill-based questions to gauge a candidate's fit for GitLab. You also have the opportunity to paint a picture of our work environment, values and team spirit. Remember, interviews can be nerve-wracking, so create a comfortable space for candidates to shine. It's your input that enables hiring teams to make informed hiring decisions and ensure we are continuing to inclusively grow our teams with the right teammates, in the right roles, at the right time.

### Confidentiality

Please note the importance of confidentiality in the interview process for both internal and external interview processes. Candidates should not be discussed outside of the hiring manager management chain. It is important to respect the privacy of all candidates who apply for positions at GitLab, whether they are internal or external.

All feedback should be recorded in Greenhouse and/or discussed live with the hiring manager and/or interview team as applicable.

## Before the Interview

### Familiarize yourself with the job description

- Ensure you've read the description of the role you're going to be interviewing candidates for. This can be found in the job family page.
- If you have any questions about the scope of the role, the team, or the responsibilities of the position after you've read through those resources be sure to reach out to the Hiring Manager with your questions.

### Align with the Hiring Manager on competencies

- It's important to have a clear understanding of what you are assessing during your time with the candidate. Your recruiter will partner with the Hiring Manager and the rest of the interview team to ensure alignment.

### Review the interview kit in Greenhouse

- In the interview kit, you'll be able to view the candidate's resume, the description of the interview you're expected to lead, the scorecard you'll be evaluating the candidate against, and the suggested questions you ask during the interview.

### Make sure you're up to date on our latest Talent Brand assets and accomplishments

- Make sure you know our latest headcount, notable awards, messaging, and other facts about working at GitLab. Take a look at these talent brand resources to help guide your conversation with candidates.

Learn more about pre-interviewing preparation in the Interviewer Training Module in [Level Up](https://university.gitlab.com/access/saml/login/internal-team-members?returnTo=https://university.gitlab.com/learn/course/interviewer-training).

## During the Interview

### Interview Structure

It's important to allocate the right amount of time for each part of the interview. You can think of the structure of an interview as having 3 parts: 1) introductions, 2) questions for the candidate, and 3) questions from the candidate.

**Time allocated to each part of the interview:**

1. Introductions = 5%
1. Interviewer questions for the candidate = 80-85%
1. Candidate questions for the interviewer = 5-10%

### Quick Tips

- Show up prepared and on time.
- Be cognizant of where the candidate is at in the interview process. Are you the first interviewer? Are you the third? Be aware that the candidate has likely repeated themselves quite a bit and has already asked many of the general questions they had about the position in previous interviews.
- Build rapport and put the candidate at ease. Introduce yourself, tell your GitLab story, ask how the candidate is doing.
- Talk about your relation to the job and how you'd work together based on your position.
- Set expectations on how the interview will run.
- As candidates move through the interviewing process, interviewers take notes within Greenhouse. As they move through the process, interviewers have the opportunity to review any specific notes previous interviewers have left for them, although the full feedback notes from previous interviewers are obscured from current ones in an effort to avoid creating bias. Hiring managers, executives, and people ops are able to see all feedback notes at any time.
  - Let the candidate know you are taking notes
  - Be an active listener
    - Concentrate on the candidate - remove all distractions (turn off notifications on your phone, slack, email, etc.) Look at the candidate - make sure to look at your camera and not at another screen
    - Try not to interrupt - validate your assumptions by explaining what you understood, and allow the candidate to correct your understanding of the story Silence is golden
- Cover the prepared topics/questions without being mechanical
  - Work with the hiring team to set up the interview plan in Greenhouse ahead of the interview to ensure all the areas you want to cover are in the scorecard.
  - Try to cover the prepared topics, but keep the conversation smooth - it is ok to skip around.
  - Redirect the conversation as needed - you are in charge of keeping the conversation focused and timely. It is common for candidates to be nervous and overextend on a question, and interrupting might be necessary. To handle this scenario, you might:
    - instruct the candidate at the beginning of the interview that you might need to interrupt them to move to a different topic ("I want to make sure we have the opportunity to cover everything, so it is my job to guide the pace of the discussion. Sometimes, we'll go into more depth, other times, I will ask that we move on to the next topic. Please understand that I'm not doing so because I'm not interested in what we're talking about at the time, it's merely to keep us on track.")
    - interrupt them and explain why they are being interrupted ("Thanks for that - I'll have to cut you off there, thanks, I understand what you're saying. I want to make sure you have a fair go for the rest of the interview so we have to be efficient with the time we have.")
- Consider adding the question to the meeting chat after verbalising. This helps avoid communication issues and be more inclusive.
- There is an unbalanced power relationship during the interview, and interviewers should be mindful of this fact. The interviewer is in a powerful position: they provide input that could decide if the candidate will move forward or not. Be as friendly and approachable as you can. This has the added value of getting people comfortable (over time) and allows you to get much better data.
- Interview for soft skills. Pick some behavioral questions to get data on what the candidate has done before and how their behavior aligns with the [company values](/handbook/values/). You will be asked to evaluate how the candidate's values align with our own in your feedback form, and asking behavioral questions is the best way to assess this.
- If a candidate discloses outside project(s) or activity(ies), please notify the Recruiter.
- Always encourage the interviewee to ask questions at the end, and be frank in your answers.
- Be willing to discuss what went well and any concerns you may have.
- Manage expectations - Don't make promises on what they can expect, but tell them that their Recruiter will be in touch with the next steps
- Thank the candidate for their time.

## Inclusive Interviewing

As an interviewer, it's crucial that you create an inclusive interview environment. This not only ensures a fair and equitable assessment of candidates, it also enhances your ability to recognize diverse strengths and contributions from each individual.

The section below outlines questions and topics that are not allowed to be discussed during an interview and offers guidance on steering conversations back to job-related topics.

### Illegal Interview Questions

1. Be aware of the kinds of questions you can and can't ask by attending or revisiting LevelUp training. It's important to adhere to legal guidelines and avoid discriminatory inquiries.
1. It's important to focus on the candidate's ability to perform the job responsibilities rather than personal characteristics or background.
1. Refrain from any personal, icebreaker-type questions that may inadvertently lead to discrimination or reveal protected information about a candidate. For instance, asking a candidate about a particular holiday could elicit information about the candidate that an employer finds undesirable yet is still legally protected.
1. Refrain from asking any questions related to protected classes such as age, race, gender, gender identity, religion, sexual orientation, marital or family status, pregnancy status, national origin, ancestry, physical or mental disabilities. These questions are not only illegal, but irrelevant to assessing a candidate's qualifications for a role.
1. Protected classes may differ by country, so it's important to adhere to the strictest country definitions to ensure compliance regardless of a candidate's location.
1. To find out more about discrimination laws specific to the country of a candidate you're interviewing, you can reach out to the legal-employment and/or talent acquisition team.
1. If a candidate brings up personal information related to a protected class, acknowledge their comment and steer the conversation to job-related topics. Do not include this in your interview notes, as it is not relevant to the job.
1. Examples of illegal interview questions include inquiries about marital status, age or any other protected characteristic.
1. Avoid discussing compensation, equity, country hiring guidelines, availability or confidential company information during the interview. These topics should be redirected to the Recruiter to discuss with the candidate.

## Competencies

As mentioned, 80-85% of the interview should be for you to ask relevant job-related questions. Behavioral and situational interview questions are designed to assess a candidate's past experiences and potential future actions through real-world examples and hypothetical scenarios.

Remember that good interviews are consistent for everyone to ensure an objective and unbiased assessment of candidates throughout the process.

### Behavioral Interview Questions

The goal of behavioral questions is to get the candidate to share data on past experiences. Previous behavior is considered the most effective indicator of how a person is going to act in the future. It is important to remember that skills and knowledge can be learned easier than habitual behaviors can be changed, especially when candidates are unaware of the impact of the undesired behaviors.

The questions are usually in the form of: "Can you tell me about a time when…?"

The kind of answer that we are looking for is to get a story that is structured following the **Situation, Task, Action, and Result (**[**STAR**](https://en.wikipedia.org/wiki/Situation,\_task,\_action,\_result)**)**. Ask for an overview, an executive summary, of the case at hand. In order to avoid lengthy answers from the candidate at this stage consider briefly explaining the STAR structure before asking your first behavioral question. Stating something like - "These questions are behavioral, so try and structure your response by briefly outlining the situation, describing the task to be performed, outlining the actions you took and explaining the results."

**Some things to pay attention to:**

- What the candidate chose to highlight in their response is important. Are you able to get enough specific information out of their explanation and your follow up questions to sufficiently evaluate their behavior?
- Is it clearly explained? Are you able to follow the information? If it is a technical story and you are a non-technical interviewer, are things being explained in a way that is easy to understand?
- Is there a result or was the story left unfinished? Is it still going on?
- Was the result measured in any way? How does the candidate validate the result and match the expectation? Was there an expectation set to begin with?

There is no right answer; what matters here is to listen to the candidate and gather data on how they are telling the story.

These questions can be quite unbalancing and can increase the stress during the interview. Again, be kind and help the candidate understand what you are looking for, and provide an example if one is needed when you notice the candidate is blocked.

It can also happen that the candidate does not have a story to share with you; that is okay. It's just another data point that should be added to the feedback (I failed to get data on …). Just move to the next question and be sure to have a few questions as a backup.

### Situational Interview Questions

A situational interview question presents a hypothetical but potential real-world scenario to a candidate, so that you can understand how they would handle specific situations. The reason we ask situational interview questions is so we can feel confident in a candidate's skills and their potential capability to do this specific job. We are looking for people to join our team who have the skills and competencies to do the role at hand, not just someone who has done this exact thing before elsewhere.

Situational interview questions allow the opportunity to understand a candidate's approach and ability to be successful, regardless of the opportunities they have had to demonstrate that in the past.

Example: "If you were assigned a project with a tight deadline and limited resources, how would you prioritize tasks to ensure the successful completion of the project?"

## Candidate Evaluation and Scorecards

### Interview feedback

In Greenhouse, you will use an "interview kit" when interviewing a candidate, which has text for feedback and scorecards for skills and values. Your feedback is crucial in helping the Hiring Manager make their hiring decisions.

We want to highlight the strengths and weaknesses of the candidate in an easy to absorb, standardized way. Every scorecard must include Pros and Cons. This helps the talent acquisition team gather data that will be presented to the candidate in the form of feedback. Remember, if something is not relevant to the job, it should not be written down.

It is important that scorecards are completed within 24 hours so Talent Acquisition can keep the hiring process moving and ensure a positive candidate experience.

We encourage you to read our detailed handbook page on discussing scorecards and best practices before submitting your scorecard.

Scoring is defined as follows (all divisions but Engineering):

- **Strong Yes** - Exceeded expectations of the competency (meets requirements and aligns with values)
  - You have no significant questions and are confident (to the best of your knowledge with the information at hand) that the candidate would succeed in the role.
- **Yes** - Met expectations of the competency (meets requirements, but may have some yellow flags)
  - You think the candidate is qualified for the role, but you are either not certain, or still have some outstanding questions that should be addressed at a later stage.
  - By default, Yes candidates should move forward in the interview process, although hiring managers should use their judgment and look for patterns in any outstanding questions or areas where it's difficult to get insight into a particular candidate. It may be appropriate to reject a candidate who does not receive stronger feedback through our process.
- **No** - Did not meet expectations of the competency (meets few requirements, has many yellow flags, may not align with values)
  - You think the candidate is unqualified for the role, but have some doubts or believe they performed well enough that strengths in other areas could mean that they are still able to succeed in the role.
  - Hiring managers should use their discretion to determine whether or not to continue the interview process with any candidate that receives a No vote.
- **Strong No** - Strongly did not meet expectations of the competency (does not meet requirements, red flags, not aligned with values)
  - You are certain this candidate is not qualified and/or not a good fit for the role.
  - There are significant flags related to Diversity, Inclusion and Belonging where this hire may create an unsafe work environment for others.
  - Candidates who receive a Strong No vote should almost always be rejected immediately by the hiring manager.

**Engineering Division**

The scoring definitions for GitLab's Engineering Division are defined differently than the rest of the company. Rather than scores representing the probability of a hire, they are meant to reflect the candidate's interview performance. This allows us to expect scores to fit the [normal distribution](https://en.wikipedia.org/wiki/Normal_distribution). The probability densities of Strong yes and Strong no should be greater than one [standard deviation](https://en.wikipedia.org/wiki/Standard_deviation) away from the mean.

- **Strong Yes**
  - Extends Yes
  - Meets an unusually large proportion of our "nice to have" criteria for the role
  - Brings interesting qualities that we were not necessarily looking for
- **Yes:** All must-haves criteria that were evaluated in the interview were present
- **No:** One, or more, must-have criteria that were evaluated were found to be missing
- **Strong No**
  - Extends No
  - The candidate demonstrated clear opposition to either our Collaboration, Diversity, or Results values
  - The candidate demonstrated unwillingness to learn our Efficiency, Iteration, or Transparency values

**Shadowing Interviews**

While it is possible to shadow interviews as a trained, regular interviewer to maintain your skillset, please be considerate of those who are actively working to become an interviewer and allow them priority in choosing when to shadow.

Just like those leading an interview, shadowers should ensure that they are not shadowing someone who they have referred to GitLab. This helps to remove bias from the interview process and does not allow specific candidates disproportionate access to interview feedback.

If you are shadowing an interview, part of this process should be taking notes and writing feedback in addition to the interviewer. Take notes using the scorecard just like you would if you were leading, but do not submit the scorecard because you are still considered to be in training during this period. As an interview training best practice, we recommend that a debrief meeting occur between the interviewer and shadow trainee after the interview to compare feedback notes (ideally in a sync meeting). Only one official scorecard should be submitted by the main interviewer. Even if you receive multiple prompts and reminders from Greenhouse as a shadow interviewer, please ignore.

More info on [engineering hiring practices](/handbook/engineering/hiring/#hiring-practices).

### Level Categories in Engineering Scorecards

Whereas the scoring definitions company-wide describe the probability of hire, the scoring definitions in the Engineering Division are meant to reflect the candidate's interview performance. To further support the ability to utilize interview results to hire across all levels, we have added a 'Level' category to R&D scorecards.

In this category, the interviewer can define the level the candidate scored on, and add details on why they scored a candidate on the particular level. The added value of this category is that the interviewer can score the candidate on multiple levels (ex. the Senior level and the Intermediate level).

This scorecard feature will increase sharing of candidates that, for example, may meet the 'must-have' criteria on an Intermediate level position but did not meet all of the 'must have' criteria on a Senior level. The dual score, when applicable, will help recruiters and hiring managers with candidacy decisions. Interviewers should use the notes section to capture the why behind their score and provide any additional detail that is directly relevant in assessing leveling.

---

### Unhelpful vs. Effective Feedback Examples

#### Unhelpful Feedback Example

**Competency:** Clear communication across all levels and departments

**Key Takeaways:** Overall, I think he was the best candidate I have seen thus far. Plus, he is a diverse candidate. He reminded me of myself in many aspects. He had a well thought out presentation that was easy to understand, but I wish his example was more detailed.

**This is a poor example of feedback for a few reasons:**

1. Mentions information about a protected class.
1. Compares the candidate to other candidates, which can lead to biases like affinity and contrast bias.
1. Lacks specific information and examples.

---

#### Effective Feedback Example

**Competency:** Clear communication across all levels and departments

**Key Takeaways:** The candidate had multiple examples of how they led large discussion groups, including for E-group members. They also facilitated a difficult conversation between two VPs who were arguing about a recent policy change. I do, however, have a concern about their ability to engage with people that they manage with clear instruction. They gave an example of a poor performer and how they didn't feel the direct report was listening, but acknowledged a few times that they changed project directions and could have given more sufficient notice. The candidate admitted that this may be due to changing expectations frequently and at the last minute.

**In comparison to the previous feedback example, this feedback is effective because it is:**

1. More specific
1. Aligned with the specified competencies
1. Relevant to the role
1. Includes featured examples
