---
title: "Interviewing at GitLab - Customer Support"
description: "Tips on how to prepare for your interview - Customer Support"
---

## Most common open roles in Customer Support

- [Support Engineer](/job-families/engineering/support-engineer)
- [Support Engineering Manager](/job-families/engineering/support-management)
- [Support Operations Specialist](/job-families/engineering/support-readiness-specialist)

## Tips on how to prepare for your Support Engineer interview

What is it like to interview for the Support Engineer role at GitLab? Here are some tips and general guidelines for the recruitment stages:

### 1. Application

Before submitting your application, read through our [Employment Solutions](/handbook/people-group/employment-solutions#country-hiring-guidelines) page to review the list of countries we are currently hiring in.
When applying for the Support Engineer role at GitLab, make sure to upload the resume that will highlight your skills and experience, so that you are noticed! Review the role's description carefully to understand if this is a good match, not only in terms of your technical skills but also in terms of your expectations from the role. It's a customer-facing role, so you should be comfortable when interacting with people daily. If you like solving puzzles, love helping people, have a passion for DevOps and open source, if you feel confident in your Linux skills and if the role excites you, it's probably a good match!

A well-written resume or a detailed LinkedIn profile will increase your chances to be selected for this role. Read the requirements carefully and make sure that some of those specific areas are outlined in your resume/LinkedIn profile. In the Support Engineer role, we especially pay attention to your experience/knowledge of:

- Customer support
- Linux systems administration
- Git version control
- CI/CD
- Rails/PostgreSQL console (or experience with MVC frameworks/scripting)
- DevOps methodologies

If you don't have the experience with all the desired areas that are mentioned in our requirements, don't worry! We would like to encourage you to apply nevertheless. We look for candidates that have a diverse blend of experience with the above, and one thing that all our successful Support Engineers have in common is resourcefulness. Mindset goes a long way! As long as you feel confident in your Linux skills and you enjoy interacting with customers, there are chances it could be a good match.

While cover letters are optional, they are an amazing opportunity for you to show your motivation for joining GitLab and the Support team. Cover letters don't have to be lengthy or overly detailed, but they should show your sincere motivation. We do love reading them!

It is important to us to create an accessible and inclusive interview experience. While applying, please let us know if there are any adjustments we can make to assist you during the hiring and interview process.

Now it's time to get excited! Here are some links that might help you understand our company and the role even better:

- [Values](/handbook/values/)
- [GitLab Company Culture](/handbook/company/culture/)
- [Informal Communication in an all-remote environment](/handbook/company/culture/all-remote/informal-communication/)
- [Support Team Handbook](/handbook/support)
- [Support Engineer Responsibilities]({{< ref "support-engineer-responsibilities" >}})
- [Support Workflows](/handbook/support/workflows)
- [Support Team Member Time Off]({{< ref "support-time-off" >}})
- [Jobs at GitLab - Frequently Asked Questions]({{< ref "candidate-faq" >}})
- [Working for GitLab - A Support Engineer's perspective](https://about.gitlab.com/blog/2020/08/10/working-for-gitlab-a-support-engineers-perspective/)
- [A series of blog posts by Cynthia, our Staff Support Engineer](https://cynthiang.ca/2020/06/16/reflection-part-1-my-first-year-at-gitlab-and-on-becoming-senior/)

### 2. Take-home assessment

If you are selected for the role, you will be moved forward to the next step. The first step of the recruitment process is the take-home assessment, which is written and asynchronous. You can expect two emails sent out to you simultaneously:

- A welcome email from the Recruiter
- An email with the take-home assessment attached.

The purpose of the assessment is to verify the basic requirements for the role to make sure you'll be successful in the Support Engineer position at GitLab. You will have 6 calendar days to complete it and submit your answers back to us, but in case anything unexpected comes up and you require more time, please communicate it to us.
Take your time to work on your answers, as the take-home assessment is a very important step in the recruitment process for this role. Make sure to:

- provide details in your answers (in a way that they are still relevant to the questions)
- address all the areas that you're being asked to consider
- double-check if your scripts run correctly
- proofread to make sure you did not make any errors (including grammar and punctuation)
- write the answers in your own words if you use external sources
- cite your external sources
- submit your answers in the desired format via the link provided in the take-home assessment email.

After you submit your answers, we will take 1-3 days to grade your assessment and reach out to you with feedback.

### 3. 40-Minute Screening call with a Recruiter

The purpose of this call is to learn more about you, your expectations and your experience. On our part, we endeavor to learn how well we align in terms of: us being able to support your growth and aspirations if you join GitLab; how your skills, both technical and soft, match our needs in Support Engineering and at GitLab; how we can meet your expectations.

This is more of a general conversation during which we would like to learn more about your professional experience and your motivation for joining our GitLab Support Team, but you might expect a few technical questions as well. We will also discuss your hiring eligibility and availability, and we will go over our compensation calculator.

Don't forget to prepare questions for us, we love them! This goes for all the interviews that happen as the next steps, too. Feel free to ask us about anything Support or GitLab-related.

You might expect to hear back from us via email within three business days from the Screening call.

### 4. 90-Minute Technical Interview with a member of the Support team

Successful candidates will be moved to the next step: Technical Interview.

The Technical Interview will involve live break-fix/bug-fix scenarios, as well as customer scenarios. You will need to have access to a terminal with Bash or similar. You will also need to have an SSH key pair loaded locally so you can connect to the server. Windows users must have 'Git Bash for Windows' installed prior to the call.

If you're unable to install software on your computer you may be able to use the free tier of a cloud provider. See a video one of our Support Team [preparing Google Cloud Shell for the Support Tech Interview](https://youtu.be/qvAd9O2z6To).

It is important to have knowledge of the GitLab product. We recommended getting some hands-on experience before your interview. Spend time installing and using GitLab to get more familiar with the software and how to use it. Read through documentation and tutorials on using/configuring/troubleshooting GitLab.

- Read the [Intro to GitLab](https://docs.gitlab.com/ee/#new-to-git-and-gitlab)
- [Install GitLab](https://about.gitlab.com/install/) locally and explore the product
- Have a look at [common issues](https://docs.gitlab.com/omnibus/troubleshooting.html)
- Read through the online [forum](https://forum.gitlab.com/search?q=error) to see what errors stand out
- Read over some [useful commands](https://gist.github.com/dnozay/188f256839d4739ca3e4) when logging in locally to your GitLab installation

Review and practice:

- [Basic Linux Commands](https://www.dummies.com/article/technology/computers/operating-systems/linux/common-linux-commands-196529/)
- [Basic SSH Commands](https://www.ssh.com/academy/ssh/command)
- [PostgreSQL](https://docs.gitlab.com/ee/ci/services/postgres.html)
- [Git](https://docs.gitlab.com/ee/topics/git/commands.html)

Familiarizing yourself with these will help with your communication through the hiring process, as well as prevent any roadblocks, and keep you focused on the tasks asked of you.

Remember to stay calm and do your best! We appreciate that everyone gets the interview jitters and we are not here to be intimidating. Practice makes perfect, so try and set aside some time to practice/study to be as best prepared as you can be. If you get stuck along the way, try searching on the forum to see if you are able to find a solution to your troubles! Google can also be a great resource, which you are able to use even during your interview. Knowing how to find the answer is just as important as the knowledge you already have.

Feel free to ask for clarifications in case the instructions/end-goals of a task are not clear. Together with that, you are welcome to prepare any questions for our Support Engineers!

You might expect to hear back from us via email within three business days of the Technical Interview.

### 5. 60-Minute Behavioral Panel Interview with Support Engineering Managers

Successful candidates will be moved to the next step: Behavioral Panel Interview.

When a candidate gets the opportunity to interview with more than one member of the hiring team at once, this is called a panel interview (as they speak with a panel of interviewers). For candidates, this can be a benefit as they get to meet with more members of the team in a shorter time frame, which means they spend less time scheduling and attending interviews. For interviewers, this means that they get to work together to learn more about a candidate and can benefit from each other's viewpoints and experiences.

At this stage, you will meet with two of our Support Engineering Managers. Panel interviews are conversations, not tests. You might expect more specific, behavioral-based interview questions that will be about your experience, history, and opinions. If you'd like to feel prepared, we would recommend you familiarize yourself with a STAR method of interviewing.

GitLab appreciates cultural diversity instead of cultural conformity, thus the managers assess values fit, rather than culture fit.

You might expect to hear back from us via email within three business days of the Behavioral Interview.

### 6. 60-Minute Interview with a Senior Manager or Director of Support

Successful candidates will be moved to the next step: Senior Manager/Director Interview.

You made it this far - congratulations! This is the last interview that will be similar to the previous one, which means that there will be more behavioral-based questions. At this point, try to relax and continue being your true self that got you to this stage - the most difficult part of the interview process is already behind you.

You might expect to hear back from us via email within three business days of the Senior Manager or Director of Support Interview.

### 7. Reference Checks

Successful candidates will be moved to the Reference Checks.
We will reach out to you and ask for three professional references to contact about your professional experience.

- One of your references should be your past or current supervisor or manager.
- You do not need to provide a reference at your current position if you do not feel comfortable.
- If any of your references are not proficient in speaking or writing in English, we will take that into consideration when contacting them.

If you don't have a long history of professional employment (E.g. if you've only held one position in your entire career) and are unable to provide us with some of the references, please let us know and we can always work around it to find a solution.

After you provide us with your references, now it's time to relax! The hiring manager or the hiring team will contact the references you share with us. It will take us some time to gather the information and it depends on how soon we hear back from your references. Don't worry if you don't hear back from us for a couple of days. If we run into any roadblocks, we will definitely inform you. We will keep you updated at least once a week so that you know what the status is.

### 8. Offer

Successful candidates will subsequently be made an offer. Once the offer is ready, the Recruiter will reach out to you to schedule a Zoom call to discuss its details.

Questions? Check out our [Jobs at GitLab - Frequently Asked Questions]({{< ref "candidate-faq" >}})
