---
title: "Interviewing at GitLab - Infrastructure"
description: "Tips on how to prepare for your interview - Infrastructure"
---

## Most common open roles in Infrastructure

- [Backend Engineer](/job-families/engineering/infrastructure/backend-engineer)
- [Site Reliability Engineer](/job-families/engineering/infrastructure/site-reliability-engineer)
- [Database Reliability Engineer](/job-families/engineering/infrastructure/database-reliability-engineer)
- [Engineering Manager](/job-families/engineering/infrastructure/engineering-management)

## Tips on how to prepare for Infrastructure interviews

What is it like to interview for roles in the Infrastructure department at GitLab? Here are some tips and general guidelines for the recruitment stages:

### 1. Application

When applying for roles at GitLab, make sure to upload the resume that will highlight your skills and experience, so that you are noticed! Review the role's description carefully to understand if this is a good match, not only in terms of your technical skills but also in terms of your expectations from the role.

If you choose to, you can learn even more about the infrastructure department and it's various subdivisions in the handbook. Group pages offer a breakdown on teams Mission, Targets, Team Members and Approach to Work.

[Infrastructure at GitLab](/handbook/engineering/infrastructure/)

- [SaaS Platforms](/handbook/engineering/infrastructure/team/platforms/)
  - [Delivery Group](/handbook/engineering/infrastructure/team/delivery/)
  - [Scalability Group](/handbook/engineering/infrastructure/team/scalability/)
  - [Dedicated Group](/handbook/engineering/infrastructure/team/gitlab-dedicated/)
  - Production Engineering group with [Ops](/handbook/engineering/infrastructure/team/ops/) and [Foundations](/handbook/engineering/infrastructure/team/foundations/)

A well-written resume or a detailed LinkedIn profile will increase your chances to be selected for this role. Read the requirements carefully and make sure that some of those specific areas are outlined in your resume/LinkedIn profile. In Infrastructure Engineering, we especially pay attention to your experience/knowledge of:

- Linux systems administration
- CI/CD
- Programming/scripting experience with languages such as Ruby or Go.
- Monitoring and Observability
- Cloud technologies and container orchestration
- On call and incident management

If you don't have the experience with all the desired areas that are mentioned in our requirements, don't worry! We would like to encourage you to apply nevertheless. We look for candidates that have a diverse blend of experience with the above.
It is important to us to create an accessible and inclusive interview experience. While applying, please let us know if there are any adjustments we can make to assist you during the hiring and interview process.

Now it's time to get excited! Here are some links that might help you understand our company and the role even better:

- [Values](/handbook/values/)
- [GitLab Company Culture](/handbook/company/culture/)
- [Informal Communication in an all-remote environment](/handbook/company/culture/all-remote/informal-communication/)
- [Incident Management](/handbook/engineering/infrastructure/incident-management/)
- [Coding at Scale](/handbook/engineering/infrastructure/team/scalability/#regarding-coding-at-scale)
- [Infrastructure careers and internships](/handbook/engineering/infrastructure/career/)

### **2. 30-Minute Screening call with a Recruiter**

The purpose of this call is to learn more about you, your expectations and your experience. On our part, we endeavour to learn how well we align in terms of: us being able to support your growth and aspirations if you join GitLab; how your skills, both technical and soft, match our needs in Infrastructure and at GitLab; how we can meet your expectations.

This is more of a general conversation during which we would like to learn more about your professional experience and your motivation for joining our GitLab Infrastructure Department, but you might expect a few technical questions as well. We will also discuss your hiring eligibility and availability, and we will go over our compensation calculator.

Don't forget to prepare questions for us, we love them! This goes for all the interviews that happen as the next steps, too. Feel free to ask us about anything Infrastructure or GitLab-related.
You might expect to hear back from us via email within three business days from the Screening call.

### 3. 90-Minute Technical Interview with a member of the Infrastructure team

Successful candidates will be moved to the next step: Technical Interview. The Technical Interview varies depending on the team and position that you are applying for. We will share more information about what to expect and what to prepare ahead of this round if required. If there is prep work, it will be limited to about an hour.

The technical interview will require a GitLab account, if you are not yet familiar with GitLab we recommend getting some hands-on experience with GitLab before your interview. See [Intro to GitLab](https://docs.gitlab.com/ee/#new-to-git-and-gitlab) for a general introduction. If you don't have an account, you can create one on the [sign-up page](https://gitlab.com/users/sign_up).

While not necessary for the interview, the following links will help you to understand a bit more about the responsibilities of the Infrastructure team:

- [Incident Management](/handbook/engineering/infrastructure/incident-management/)
- [Change Management](/handbook/engineering/infrastructure/change-management/)
- [Production Architecture](/handbook/engineering/infrastructure/production/architecture/)
- [Infrastructure Runbooks](https://gitlab.com/gitlab-com/runbooks)
- [Production Readiness](/handbook/engineering/infrastructure/production/readiness/)
- [Open and closed incidents for GitLab.com](https://gitlab.com/gitlab-com/gl-infra/production/-/issues/?sort=updated_desc&state=all&label_name%5B%5D=incident&first_page_size=20)

To help you understand more about the team you are interviewing with, we share information about your interviewer (including their GitLab profile) ahead of each team interview via Guide.

Feel free to ask for clarifications in case the instructions/end-goals of a task are not clear. Together with that, you are welcome to prepare any questions for our Engineers! You might expect to hear back from us via email within three business days of the Technical Interview.

### 4. 60-Minute Hiring Manager Interview

Successful candidates will be moved to the next step: A behavioral or scenario based Manager interview.

At this stage, you will meet with the hiring manager for the position you are applying to. Generally speaking for Engineering roles this would be the Engineering Manager. For management positions this might be a Senior Manager or Director instead. During this call you might expect more specific, behavioral-type interview questions that will be about your experience, history, and opinions. If you'd like to feel prepared, we would recommend you familiarize yourself with a [STAR method](https://www.themuse.com/advice/star-interview-method) of interviewing and reminding yourself of previous success stories, learnings and achievements. GitLab appreciates cultural diversity instead of cultural conformity, thus the managers assess values fit, rather than culture fit.

You might expect to hear back from us via email within three business days of the Behavioral Interview.

### **5. 60-Minute Peer Interview with a member of the team**

Successful candidates will be moved to the next step: A behavioral / scenario based peer interview, with a member of the team that you are interviewing to join.

Similarly to the Engineering Manager interview, this call will be focused on further discussion about your past experience, background and opinions. Worth noting this round is a great opportunity to ask your own questions and dig into what life is like here with someone that is in a similar position to the role you are interviewing for!

You might expect to hear back from us via email within three business days of the Peer Interview.

### 6. Leadership Interview

Successful candidates will be moved to the next step: Senior Manager/Director/VP Interview.

You made it this far - congratulations! This is the last interview. You should expect more behavioral and scenario based interview questions so your preparation for this call can be similar to the previous two rounds. At this point, try to relax and continue being your true self that got you to this stage - the most difficult part of the interview process is already behind you.

You might expect to hear back from us via email within three business days of the Leadership Interview.

### 7. Reference Checks

Successful candidates will be moved to Reference Checks. We will reach out to you and ask for three professional references to contact about your professional experience.

One of your references should be your past or current supervisor or manager.
You do not need to provide a reference at your current position if you do not feel comfortable.
If any of your references are not proficient in speaking or writing in English, we will take that into consideration when contacting them.

If you don't have a long history of professional employment (E.g. if you've only held one position in your entire career) and are unable to provide us with some of the references, please let us know and we can always work around it to find a solution.

After you provide us with your references, now it's time to relax! The hiring manager or the hiring team will contact the references you share with us. It will take us some time to gather the information and it depends on how soon we hear back from your references. Don't worry if you don't hear back from us for a couple of days. If we run into any roadblocks, we will definitely inform you. We will keep you updated at least once a week so that you know what the status is.

### 8. Offer

Successful candidates will subsequently be made an offer. Once the offer is ready, the Recruiter will reach out to you to schedule a Zoom call to discuss its details.

Questions? Check out our [Jobs at GitLab - Frequently Asked Questions]({{< ref "candidate-faq" >}})
