---
title: "Referral Operations"
description: "This page is for information regarding the backend process of the Referral Process."
---

This page is for information regarding the "backend" of the [Referral Process]({{< ref "referral-process" >}}).

#### Adding a Referral to Workday (People Connect Team)

People Connect will review the following guidelines to ensure the correct amount is being awarded with the One Time Payment in Workday.

1. Ensure that the current team member is eligible for a referral based upon the [requirements]({{< ref "referral-process#referral-bonus-eligibility" >}}).
1. Review when the referral was submitted in Greenhouse
    - `Job` > `Application Review` > `Applied On YYYY-MMM-DD`
    - Our current referral bonus amount as of **2023-11-20** is listed [here](/handbook/total-rewards/incentives/#referral-bonuses).
    - If the referral was submitted between **2022-06-01** and **2023-11-19**, then the following referral amounts apply:
        - $1,500 base referral bonus for a new hire.
        - $1,500 supplemental referral bonus for a hire from a ["select underrepresented group"](https://about.gitlab.com/culture/inclusion/#examples-of-select-underrepresented-groups).
    - For candidates referred multiple times, the referral date is determined by the date the referral was submitted for the position the candidate ends up accepting.

#### Transferring Referral Submissions to Greenhouse

Per the current [Referral Submission Process]({{< ref "referral-process#submitting-a-referral" >}}), Team Members will submit referrals through Greenhouse if the vacancy is posted externally and via Issues if the vacancy is **only** open internally. When a new Issue appears, please do the following:

1. Assign the Issue to yourself (upper right corner).
    - *Reruiting Operations & Insights* is responsible for assigning the appropriate *Sourcer(s)*.
        - The appropriate *Sourcer(s)* is determined by referencing the **Hiring Team** page of the requisition.
1. Check to make sure the Issue is marked as `Confidential`.
    - *Reruiting Operations & Insights* will ensure this setting is enabled.
1. Check to see if the vacancy is posted on the external [Job Board](https://boards.greenhouse.io/gitlab/) and if it is, **tag** the *Referrer*, **comment** that they'll need to submit their referral directly in Greenhouse per [these instructions](/handbook/hiring/referral-process/#submitting-a-referral-in-greenhouse), and **close** the Issue.
    - *Reruiting Operations & Insights* will check to make sure the vacancy is only posted internally.
1. If the vacancy is **only** open internally, go to your Greenhouse dashboard and click `+` > `Add a Referral`.
1. Reference the Issue to see what should be entered in the following fields:
    - **Job**
        - If a specific requisition is **not** specified, follow-up with the referring Team Member to determine the appropriate role as "general" referrals are **not** accepted.
    - **First Name** - `Required`
    - **Last Name** - `Required`
    - **Email** - `Required`
    - **Social Media** - `Required`
        - e.g. LinkedIn
    - **Resume** - *Optional*
    - **Relationship** - `Required`
        - If *"Relative"* is selected, please confirm how they're related and add that to the `Family Relationship` field on the **Additional Details** tab.
    - **Location** - `Required`
        - Add the provided location to the *Location* field on the **Additional Details** tab.
    - **Referral's Email** - `Required`
    - **Work History** - *Optional*
    - **When We Reach Out** - *Optional*
    - **Referral Notes** - *Optional*
1. Click `Add this referral` to submit them.
1. Go to the candidate's profile, click the `Details` tab, and scroll down to the **Source & Responsibility** section.
1. Hover over **Source** and click the `Pencil` icon, then edit `Who Gets Credit` with the name of the *Referrer* and click `Update Source`.
1. Send a email to the referred candidate. Select `Email REFERRAL_NAME` in the right column and select the **Default Referral Confirmation Receipt** email template.
    - Make sure that the email is sent from the `no-reply@gitlab` alias.
    - Add the referring Team Member to the `CC` field.
    - Click `Send Email`.
1. Follow-up in the Issue and confirm that the referral has been submitted and please mention that the Team Member will be able to follow their referral in the **My Referrals** section of their Greenhouse dashboard.
1. **Close** the Issue.

#### How to Respond to Referral Update Requests

Our Inbound Sourcing team runs point on responding to questions related to referrals in the #talent-acquisition slack channel and ensures that the referrer is credited as the source of a referred candidate.

The Talent Acquisition Team uses the a GitLab Service Desk to track incoming emails to the `referral@gitlab` email. These emails will, in turn, show up as `Issues`.

To set-up notifications for the [Referral Service Desk Project](https://gitlab.com/gl-talent-acquisition/operations/), please do the following:

1. Click on the `Bell` icon in the upper right corner (next to `Star` and `Clone`).
1. Go to `Custom Settings`.
1. Click `New Issue`.
1. Close the window.

To take action on Issues in that project:

1. Click `Issues` in the left menu bar.
    - This is where incoming `referral@` emails will be; any open Issues here will need to be addressed.
1. Click on the new `Issue`.
1. Assign it to yourself (upper right corner).
1. Read the Issue.
1. Add the appropriate label(s).
1. Look-up the candidate in Greenhouse, if applicable.
1. Respond to the Issue by commenting and please be sure to do so just as you would with any other GitLab communication.
    - e.g. *"Hi, NAME. Thank you for reaching out about the status of your referral. Per our [SLA]({{< ref "referral-process#referral-statuses" >}}), please allow us 5 business days to review the submission. `@RECRUITER` is responsible for this role and they'll provide the candidate with an update soon."*
    - e.g. *"Thank you for the referral. `@RECRUITER` is responsible for this role and will provide you with an update soon."*
1. Please be sure to `@-mention` the responsible Recruiter so that they're aware an update is being requested.
1. If one comment addresses the entirety of the message, comment and **close** the Issue. If further information is needed, comment and leave the Issue open.
1. The Recruiter will reassign the Issue to themselves once they pickup the communication. They may also add any applicable labels.
1. The Assignee will **close** the Issue when communication is complete.

#### Referral Roundup Sessions

Our Talent Acquisition Team occasionally organizes *Referral Roundup Sessions*.

The objective of theses sessions are to gather referrals, region-specific information about where you're based, and teach you skills related to sourcing and Greenhouse.

Each session will have a corresponding Issue linked and in that, we ask that you please add information regarding appropriate companies to source from, local meet-up groups, conferences, job boards to advertise on, and any other information you believe will be beneficial to our hiring efforts in your area.

A Talent Acquisition Team Member will attend these sessions, so they be able to address any questions that arise on sourcing, LinkedIn, or Greenhouse.
