---
title: "Referral Process"
description: "GitLab's Referral program is fairly straight-forward, there are several nuances to be mindful of. This is a review of the program rules and eligibility."
---

If you know someone who would be a great addition to the GitLab team, please submit them as a Referral. If they're successfully hired and all Referral criteria is met, you'll receive a Referral Bonus!

While the Referral program is fairly straight-forward, there are several nuances to be mindful of. Please take a moment to review the program rules and eligibility outlined below.

For process instructions regarding referrals, please visit the [Referral Operations]({{< ref "referral-operations" >}}) page.

#### Defining a Referral

"Referring", "sourcing" and "endorsing" are similar activities, however there are distinctions based on their respective familiarity and confidence in regards to the prospective candidate. Referral bonuses are granted to referrals only.

**Referral** - someone you have worked with in the past, or have developed a close personal relationship. This person should align with our values and the requirements of the role, someone you would choose to work with again if the opportunity arises.

**Endorsement** - Endorsements are not referrals, they are treated as a recommendation or you advocating for someone. Examples include someone you know applies and they then ask you to refer them. This is not a referral as you didn't proactively encourage them to apply. Another example could be you've heard good things about someone, but haven't directly worked with them. To endorse the candidate, check who the Recruiter is on the [Internal Job Board](https://gitlab.greenhouse.io/internal_job_board) and contact them via Slack after they've applied directly. You should include:

- The candidate's full name.
- The role.
- Please provide a description of how you know the candidate and why they are aligned with the role with GitLab.

Ensure you inform the person that you are endorsing them and that they allow you to do so.

**Sourcing** - Proactively sourcing candidates and adding them to Greenhouse. These candidates are not referrals as you cannot personally vouch for their work or alignment to our values.

A Referral is **not**:

- Someone the Talent Acquisition Team has already sourced, screened, or been in contact with for the same requisition or job family.
  - This applies to *Prospects* as well as *Candidates*.
- Someone you **do not** know and **would not** be able to speak about confidently.
- Someone you sourced or someone who reached out to you regarding a vacancy through social media (LinkedIn, Blind, etc). If someone you have **not** worked with reaches out requesting to be referred, you could respond with the message below. Please adjust the order and content to reflect your own style and tone as needed:
    > *"Thank you for your interest in GitLab. Unfortunately I cannot refer you for the position as we have not had a chance to work together. To ensure we maintain an [inclusive (https://about.gitlab.com/company/culture/inclusion/)](/handbook/company/culture/inclusion/) recruiting process, I cannot influence your application. We would prefer you apply for the position you have in mind directly via our [Jobs page (https://about.gitlab.com/jobs/)](https://about.gitlab.com/jobs/). This will ensure the right GitLab team member reviews your profile!"*
- Someone who applied via a unique link you shared from Greenhouse on a social site (a.k.a. a `Social Referral`).
  - While the unique link creation/sharing feature is in the `Add a Referral` section of Greenhouse and reads, *"Share your link with people interested in working at your company
Every time someone clicks on your link and applies for a job, your hiring team can track you as a source,"* this is **not** considered a referral because there's **no** way of determining who clicked a link on Twitter from a genuine referral, for example. For that very reason, `Social Referrals` are **ineligible** for the referral bonus. Regardless, the promotion of our vacancies is always appreciated!
- A former (or "Boomerang") Team Member.

Other Referral clarifications:

- *Contract* or *temporary* roles, including *Internships*, are **not** eligible for Referral Bonuses.
  - However, if the *Intern* is converted to a *Team Member* for the same/similar role, then the referring Team Member will receive a Referral Bonus per the [referral bonus guidelines]({{< ref "incentives#referral-bonuses" >}}) upon transitioning to the new employment status.

#### Referral Bonus Eligibility

All GitLab team members are eligible for the [Referral Bonus]({{< ref "incentives#referral-bonuses" >}}), except in [certain circumstances]({{< ref "incentives#exceptions" >}}).

#### Submitting a Referral

All GitLab Team Members should submit a referral by submitting them directly through Greenhouse if the vacancy is open **externally**.

To ensure a seamless referral process, it's important to adhere to our established guidelines. While a common approach involves asking the candidate to apply directly and notifying TA afterward, this method bypasses some of the enhanced steps we've implemented for referrals. Following the formal referral process guarantees:

1. **Direct notification to the relevant recruiter**: The assigned recruiter promptly receives a direct notification of your referral, minimizing the risk of oversight.
1. **Thorough review of the application**: Referral applications undergo a comprehensive review.
1. **Efficient handling to maximize referral impact**: By reducing double-handling, we optimize the time spent on referrals, ensuring a more effective and streamlined process.

##### Expectations of Referrer

As we continue to scale, so does the volume of referrals we receive. Referrals are a great source of candidates for the TA team, however reviewing referrals who gave little-to-no relevance to the role takes time away from other candidates who are more aligned. Before referring someone, please ensure you have:

1. Check alignment with the Job Post
    - The referring team member has reviewed the job post to ensure that their referral's experience aligns with the required skills. While they don't need to meet all requirements, alignment with the majority is essential.
1. Confirmed they live in a location we can hire in by checking the [Country Hiring Status](https://comp-calculator.gitlab.net/hiring_status/index) page in the Comp Calculator. If the country is **not** listed or is marked as `Not Open for Hiring`, we will have to reject the candidate so unfortunately they cannot be referred.
1. Communication with the Referral
    - You have informed the person that you are referring them.
1. Candidate [referred through Greenhouse](/handbook/hiring/referral-process/#submitting-a-referral-in-greenhouse) with a Detailed Referral Description

- *Must complete* required fields, including a comprehensive description of how you know the candidate you are referring and why they are aligned to the role with GitLab. Provide detailed information such as specific qualifications, skills and relevant experiences that make the candidate a strong match for the specific role. The fields are:
    1. How do you know this person?
        - Previous co-worker/colleague
        - Friend or family member
    1. Where is this person located? (Please confirm they're in a location we can hire in)
    1. How long have you worked with or known this person?
    1. Please provide a comprehensive description as to why this person is aligned to this role (include specific qualifications, skills and relevant experiences that relate to the job post)
        - **Bad Example** - "XX wants to work in a remote workforce. They bring a lot of experience in Program Management"
        - **Good Example:** - "XX has a proven track record in Program Management within a Product Organization. When I worked with them at XYZ company, they worked specifically with net new product launches, partnering with monetization teams on bringing new products to market. This makes them a strong fit for the Product Program Manager role at GitLab."
    1. If the candidate is interested in more than one role, please list the other roles below.
    1. Anything else we should know about this referral?
    1. Note: If this person has already applied and their application has been reviewed, this is considered an endorsement.

If the person you wish to refer has already submitted an application, please still submit your referral through Greenhouse with the details required. The Recruiting team will then merge the profiles. Referrer input is most valuable at the start of the process, so we will only consider referrals before the candidate's application has been reviewed. You'll be notified directly by the relevant recruiter if their profile as already been reviewed. It's important to note that, despite our best efforts, individuals who apply without following the proper referral procedure may not receive the same experience as those referred through our formal channels in Greenhouse.

##### Submitting a Referral in Greenhouse

Before submitting your referral, please check the [Country Hiring Status](https://comp-calculator.gitlab.net/hiring_status/index) page in the Comp Calculator to see if GitLab can hire in the country where your referral lives. If the country is **not** listed or is marked as `Not Open for Hiring`, we will have to reject the candidate for the open vacancy so unfortunately they cannot be referred.

1. Login to [Greenhouse](https://gitlab.greenhouse.io) and click the `Add a Referral` button in the top menu bar.
1. Fill-in all the required fields (designated by a red asterisk) and as many of the non-required fields as possible.
    - Of note:
        - We recommend you upload an up-to-date version of the candidate's resume to ensure the relevant recruiting team(s) have all information available to evaluate the candidate. If no resume is available please include a link to their LinkedIn profile.
        - When selecting a `Job` from the dropdown, make sure that an `Office` is **not** selected.
            - If you **don't** see the desired vacancy there, please remove all filters and try again. If the position is not listed, it is not available externally either because we received a high enough volume of applications, it is not ready for posting, or it is available to internal candidates only.
        - While the `Social media` field is not required, we highly encourage that the referral's LinkedIn URL is provided.
        - If your referral is interested in multiple roles, please refer them to their top choice role. In the referral notes you can mention in which roles the person is interested as well. The recruiter will review the referral and take the appropriate action.
1. Click `Add this referral` and you'll see the referral in the `My Referrals` section of your dashboard.
1. If you'd like to introduce a candidate to the TA team, but do not have enough information to feel confident making a referral, you can follow the instructions in Greenhouse to share your social referral link with those people rather than submitting a referral on their behalf.

To see what positions are available to submit an external candidate for please visit the [Careers at GitLab](https://about.gitlab.com/jobs/) page.

**Things to note:**

- A referral must be submitted to a **specific requisition** - general referrals are **not** accepted.
- If you see `CURRENT TEAM MEMBERS ONLY -` before a requisition, please note that the requisition is for **Internal Team Members only**; please do **not** submit a referral.
- Please keep in mind that it is up to the Recruiter and/or Hiring Manager's discretion to move forward with your referral once submitted, based on skill/experience alignment to their role.

#### Referral Statuses

You can stay up-to-date on the status of your referral(s) in the **My Referrals** section of your Greenhouse dashboard. If you have any questions regarding your referral, please send an email to the `referrals@gitlab.com`or post in the #talent-acquisition Slack channel and the relevant Recruiter will DM you. Please note that the Talent Acquisition Team is **unable** to provide candidate-specific feedback to Referrers (i.e you); only to the Candidate themselves at later interview stages according to our typical feedback process. Due to the volume of submissions we receive and to treat all candidates fairly, we are unable to provide feedback on resume submissions; only post-interview. You can expect Referrals to be reviewed by the Hiring Team within **5 business days** of their submission.

Although we place special emphasis on Referrals, we treat Referral interviews the same as we do non-Referrals. Referral interviews should not be more or less demanding than any other interview.

Additionally, it's possible that a Referral could be marked as Rejected in Greenhouse prior to any other communication from the Talent Acquisition Team. If you'd like to share an update on the hiring process with your Referral, please reach out to the Talent Acquisition Team first.

To prevent wrongful hires, Referrers need to keep their bar high. Interviewers and Hiring Managers should avoid bias based on the Referrer's status. There should be **no** favoritism based on previous experience working with a Referral after the candidate is hired.

#### Referral Bonus Payout

For details regarding the *Referral Bonus Payout*, please visit [this page]({{< ref "incentives#referral-bonuses" >}}).

#### Process for and expections of Recruiter

As a way of ensuring a consistent and positive experience with both the candidate and team member, it's important that the Talent Acquisition team follows these steps:

1. [Ensure referral notifications are turned on in Greenhouse for your roles.](https://support.greenhouse.io/hc/en-us/articles/360029035211-New-referrals-notification#:~:text=Configure%20new%20referrals%20notification%20on%20a%20job,-To%20begin%20new&text=Click%20Job%20Setup%20from%20the,Click%20Configure.)
1. Referrals should be reviewed and actioned within 5 business days of submission
1. If the Referral has expressed interest in multiple roles, please flag their profile with the relevant Recruiters to confirm which role aligns best (if any)
1. Actions to be taken:
    1. **Reject** - If the candidate isn't suitable, reject using the referral rejection email template.
    1. **Move to Qualified for:**
        1. Additional Hiring Manager review. This should only be done to gather a second opinion, not as a gate for all candidates.
            - Set a reminder for 2-3 days after pinging the Hiring Manager to follow up if you haven't heard back.
        1. The referral aligns to the role however there are late stage candidates in process already, inform the referral via email and referrer via DM.
            - If we don't prceed with current candidates in final stages, revisit the referral and progress if appropriate.
            - If the role is filled, ensure the referral is rejected and sent the "Position Filled" email template.
            - If the referred candidate is aligned to a role but we proceed with another candidate, an option is for the Recruiter to setup a networking call to keep the candidate in mind for future roles.
    1. **Progress** - candidate is aligned to the role
        1. Move them to *Qualified*
        1. Send application questions to confirm sponsorship requirements, location, EEOC, etc.
        1. Move to screening if all requirements are met, reject with appropriate template if not.
        1. Follow standard process from this point forward.

##### Additional considerations for the talent acquisition team

- Review and action any outstanding candidates in the [Weekly Referral Report.](https://docs.google.com/spreadsheets/d/18MU7LMql_j3SIbAXvfIN4bmS5ZtAyghSOt_nwOMk_wo/edit#gid=828364844)
   1. The first tab shows a summary of all referrals in Greenhouse by Recruiter. Pay close attention to referred candidates that have been sitting for 5+ days indicated in yellow, orange and red.
   1. If the candidate is attached to multiple requisitions in Greenhouse then disposition the candidate in Greenhouse using the rejection reason `Moved Forward In Different Role` > click `Reject and Don't Send Email`

#### Common Referral Situations

- Your Referral was referred by someone else.
  - In the event that your claimed Referral was submitted by someone else, the **first** Team Member to have submit the candidate will be considered their *Referrer*.
    - In the event of **multiple** *Referrers* claiming ownership on a similar vacancy, it will be up to the *Referrers* to decide how to split the Referral Bonus and inform People Ops of that compromise.
      - When such a situation arises, a People Ops team member will notify the Referrers and what will need to happen next.
- If you referred the candidate to **dissimilar** vacancy, then you would be named their *Referrer* for that specific vacancy.

- If the Referrer is part of the Hiring Team they'll...
  - ... recuse themselves from interviewing the candidate and the Hiring Manager will choose a replacement Interviewer.
- When a Referral is from a Referring Manager they...
  - ... may choose to move the candidate on in the interview process, even if the candidate received a "no" from a fellow Interviewer - we **don't** operate on a single-veto basis.
  - ... will review all information and feedback about the Referral (giving both positive and negative feedback fair consideration) and will make the final hire or no hire decision.

For any additional questions, please post in the #talent-acquisition Slack channel.
