---
title: "Sourcing"
description: "Sourcing has proved itself to be a great channel for attracting the best talent, this page details how we source talent at GitLab."
---

## Purpose of Sourcing

The speed with which we can grow our team is dependent on the rate at which we find qualified candidates. We believe that embedding strategic sourcing in our Talent Acquisition practice allows us to not only provide an accurate snapshot of the total addressable market before we make a hire, but also, it is our opportunity to be intentional around building representation into the top of our funnel. It allows us to grow GitLab and build an even more diverse team in the most efficient way possible, while also sustaining our culture.

## Our Candidate Sources

- **Applications** - a person who has actively applied to one of our open roles through a job advertisement/posting or an event.
- **Referrals** - a person has been referred by a current GitLab team member.
- **Sourced (aka Passive)** - a person who is found during sourcing (searching) efforts by the TA team with or without the help of the hiring team (Source-a-thon).
This person is of interest, but has not interacted with the Talent Acquisition (TA) team or Hiring Manager yet.

## Prospects vs. Candidates

- **Prospect** - a person is qualified for a potential future or current role at GitLab, but has not yet formally engaged with moving forward to enter the interview process. There is basic information available (LinkedIn, Blogs, Conference Talks, etc.) and are housed in our CRM talent community.
- **Candidate** - a person that is interested in an active position at GitLab and is engaged in the interview process (which starts with a recruiter phone screen). These individuals are then tracked in our Applicant Tracking System to engage through the interview process.

## Sources & Their Definitions

<table>
<tr>
<td>

### Sourcing Strategy/Type Greenhouse

[Greenhouse Sourcing basics](https://support.greenhouse.io/hc/en-us/articles/115003931231-Sourcing-the-basics)

</td>
<td>

**Definition**
</td>
<td>

**Sub Custom Sources**
</td>
</tr>
<tr>
<td>Company Marketing</td>
<td>Candidates that applied directly to a job post.</td>
<td>

- Internal Applicant
- Job Pages On Your Website

</td>
</tr>
<tr>
<td>Prospecting</td>
<td>Prospects that have yet to express interest in GitLab/a role reached out to by a current GitLab team member.</td>
<td>

- Paid External Tools (*broken out individually*)
  - LinkedIn (Prospecting i.e. LinkedIn Recruiter)
  - SeekOut
- Social Media
- Greenhouse Sourcing (Prospecting via our CRM)
- Other Sourcing Tools - this indicates any tool we used that we do not have a paid agreement.

</td>
</tr>
<tr>
<td>In-Person Event</td>
<td>Prospects and/or candidates we met at an event, conference, or otherwise whether in person or remotely.</td>
<td>n/a</td>
</tr>
<tr>
<td>Referrals</td>
<td>Prospects that enter a role's pipeline via a Greenhouse referral submission by a current GitLab team member.</td>
<td>

- Referral
- Note: Social Referrals (applications via a link shared by team members) are counted as direct applicants in our metrics.

</td>
</tr>
<tr>
<td>Agencies</td>
<td>

Similar to Outbound Sourcing, however, this pool includes prospects found using 3rd party vendors. *This is most applicable to Executive TA*.
</td>
<td>

See Greenhouse for the complete list.
</td>
</tr>
<tr>
<td>Third-Party Boards</td>
<td>Job boards we pay for, or AAP-related partners that we use for EEOC compliance.</td>
<td>

- Direct Employers 1-5
- BuiltIn
- Glassdoor
- LinkedIn
- LinkedIn (Ad Posting)

</td>
</tr>
<tr>
<td>Social Media</td>
<td>Any social media utilized that is not a sourced candidate. </td>
<td>

- Social Media
  - Example: someone responding to a LinkedIn post that isn't a referral or someone actively sourced by a recruiter.

</td>
</tr>
</table>

## Our Top of Funnel Commitment

GitLab uses the term ["underrepresented"](/handbook/company/culture/inclusion/#examples-of-select-underrepresented-groups) and it is meant to be a way of recognizing that we need more of what we do not have in all aspects of our business. There are many studies that have focused on understanding the benefits of representation in the workforce, and one worth noting is a McKinsey & Company study from 2020. This study found that companies in the top quartile for ethnic and cultural diversity were 36% more likely to have above-average profitability than companies in the bottom quartile. The study analyzed data from more than 1,000 companies in 15 countries*.

As a Talent Acquisition team, we are in a unique position to impact the future of GitLab through intentionally building inclusive hiring practices. One of the key elements of that is the application of thoughtful sourcing strategies to build a balanced top of the funnel. This is not the only thing we are doing to ensure we set ourselves up for success, but it is a main focus for FY24.

- McKinsey & Company. (2020). Diversity wins: How inclusion matters.

### Why focus on top of the funnel?

Statistically, our application and referral candidate pools look very similar to our current team member community. For Talent Acquisition, we know our biggest, direct opportunity to impact our mission toward building a representative workforce is in our sourcing efforts. We are committed to building a sourcing strategy for every search to provide a balanced top of the funnel that is representative of the talent market. In order to measure these efforts, we have introduced a new metric: the sourcing rate %.

### How will we measure the impact of our efforts?

Sourcing rate % is a metric that depicts the total number of candidates sourced using a sourcing strategy that has a high probability of reaching underrepresented talent*. This gives an indication of the % of time each of our recruiters spend focused on sourcing underrepresented talent, while also ensuring we are not making any assumptions on how someone may identify. When a recruiter runs a search that is designed to have a greater chance of identifying candidates who are underrepresented at GitLab, they will utilize tags within Greenhouse to enable this metric for us to goal to as a team. Each quarter, we will set team and individual sourcing rate % goals and measure regularly.

- Sourcing Rate % Calculation: candidates sourced using DIB strategy / divided by the total number of passively sourced candidates.

### The Sourcing Rate % Metric

**What is Sourcing rate %**: Defined as the total number of candidates sourced utilizing a 'diverse sourcing strategy' divided by the total number of candidates (passive, applicants and referrals) in a given pipeline. It is one of our key performance indicators for both sourcers and recruiters on the Talent Acquisition team.

**How does it work**: Per the definition above, we are measuring our sourcing strategy and it's effectiveness in building representation in our pipelines.

## How to Source Candidates

### For Talent Acquisition Team Members

At GitLab, we consider each of our recruiter team members on the Talent Acquisition team 'full life cycle' which means, sourcing is a skill and part of the craft in what we do. In order to ensure we are able to bring a snap shot of the total addressable market for each role that we hire against, cultivating a passive pipeline of talent is an essential part of that process. It is also our opportunity to get very intentional when it comes to building representation into our pipelines.

In accordance with our [values](/handbook/company/culture/inclusion/#values) of Diversity, Inclusion and Belonging, and to build teams as diverse as our users, Talent Acquisition provides a collection of sourcing tools [here](https://docs.google.com/spreadsheets/d/1Hs3UVEpgYOJgvV8Nlyb0Cl5P6_8IlAlxeLQeXz64d8Y/edit#gid=2017610662) to expand our hiring teams' candidate pipelines. If you have any questions on how to implement these resources into your current sourcing strategy or have suggestions for new tools, please reach out to the Talent Acquisition team.

Our strategy to building representative teams is rooted in our top of funnel strategy. At a high level, our approach and expectations for recruiters and sourcers is as follows:

1. At the beginning of every role, recruiters are responsible to build a DIB first approach to their sourcing strategy. We believe healthy pipelines show a balance between source types (applications, referrals, passive talent and internal talent) in order for our hiring teams to have an adequate view of the talent market before making their hiring decision.

- As a best practice, Recruiters will focus on screening internal candidates, referrals, and sourced candidates for the first 5 business days a req is open.

1. Recruiters run targeted searches leveraging some of our internal resources and sourcing tools (ex: LinkedIn Recruiter, SeekOut, our CRM)
1. For each candidate that is sourced in step 2 utilizing a DIB sourcing strategy (ie: leveraging HCBUs in a boolean string, utilizing GraceHopper resume books, etc), apply the appropriate tag.

**IMPORTANT NOTE** These indicators are not assuming or identifying an individual's gender, race, or ethnicity—we cannot be certain of this information from a search and do not want to make any assumptions without self-identification.

Our sourcing rate % is meant to provide a data point to ensure we are taking the appropriate steps, and taking the needed time as a TA team to create a representative top of the funnel. These metrics will not be considered in any hiring decisions. Our sourcing rate % is intended to build more representation into the beginning of the process which we believe will result in more representation at GitLab. We are using coded names in order to further anonymize this information from our hiring teams.

We will set functional sourcing rate % goals that align to the business needs and reach our aspirational hiring rate % goals set quarterly.

#### Our Tags

| Tag      | Description |
| ----------- | ----------- |
| Project Fig      | Searches focused toward candidates that may identify as women globally       |
| Project Maple      | Searches focused toward candidates that may identify as one of our race/ethnicity URGs (Underrepresented Groups: Black or Hispanic/Latino, Indigenous/native Alaskan, Hawaiian/Pacific Islander) in the United States       |

**Calculation of the Metric**: We will measure this throughout the course of the quarter at an individual, team, and functional level. Each quarter, along with our hiring and starts goals, our Talent Acquisition Directors will set sourcing rate % goals for their teams. These goals will be influenced by our aspirational hiring rate % goals per function, health of our pipelines and domain. These goals are a [key performance indicator] (https://internal.gitlab.com/handbook/people-group/talent-acquisition/key-performance-indicators/) for our team members and progress to goal is housed in our Tableau Productivity Dashboard.

### Our Sourcing Tools and Enablement

#### LinkedIn Talent Insights

Our Talent Acquisition team has two seats for LinkedIn's **Talent Insights** product. **Talent Insights** is a platform that is specialized in answering business questions regarding workforce planning, talent pools, competitive hiring analysis, and more from its database that exceeds 705 million members, 50 million companies, 20 million jobs, and 90,000 schools. The use of this tool is helpful in determining the diversity of a talent pool  (LinkedIn's best guess based on provided profile information), regional talent availability, and competitor analysis. To request such insights, please submit an Issue [here](https://gitlab.com/gl-talent-acquisition/operations/-/issues/new?issue%5Bassignee_id%5D=&issue%5Bmilestone_id%5D=#) using the `LinkedIn Talent Insights Request` template.

Once a report has been run, it can be exported in either a `.PDF` or `.CSV` format; the latter allowing you to filter and segment the data. All reports will be uploaded to the [LinkedIn Talent Insights Reports](https://gitlab.com/gitlab-com/people-group/talent-acquisition/-/tree/master/LinkedIn%20Talent%20Insights%20Reports/Talent%20Insights%20Reports) project. If there's a report in that project that you'd like refreshed, please submit a new request Issue.

Our Executive Recruitment team performs research before the start of every Dir+ role which leverages our LI Talent Insights tool. The use throughout the rest of the team is discretionary based on need and sourcing strategy.

#### SeekOut

Each quarter, we allocate SeekOut seats strategically through our recruitment team based on need (volume of roles and alignment to goals), usage and opportunity to drive impact to priority pipelines. Allocations are established during the first two weeks of the quarter. If you are interested in having a seat allocated for the following quarter, be sure to raise the request with your manager for consideration.

#### LinkedIn Sourcing

[View LinkedIn Training slide](https://docs.google.com/presentation/d/1W9PvVp2uGFsWHFTQrAd5ZjgzfAMmS_dQI6R7Lg7XDJc/edit#slide=id.g7ba34d75e8_0_16) to understand the Boolean logic.

#### Greenhouse Sourcing

1. Candidates -> Application Type -> Candidates + Prospects only -> now exclude active people (so you can see also those who haven't been checked yet)
1. Filter by job  -> All reqs
1. Search with specific keywords/skills in the top left search bar. Turn on the "Full Text Search" function to get more results.
1. Search using tags as filters. Profile details -> Candidate Tags
1. Here is the [Video](https://drive.google.com/file/d/1pojTfH5S08T_1mMbbGT682URRO_nW4tm/view?usp=sharing) (internal team members only)!

**How to source our Greenhouse database through LinkedIn**

Simply add all your filters as described above in the LinkedIn Recruiter sourcing section. After setting up your search parameters, add one extra: "In ATS" - here add Greenhouse. This will show you all the people who match your search and are in our database and also have a LinkedIn profile.

**Bonus Greenhouse sourcing tip**

You can download several profiles in bulk in an XLS file and you can run your searches in the spreadsheet. For this, click on the blue "Export" button on the top of your search results in the "All candidates" section of a search result tab.

#### Greenhouse CRM

In today's talent market, a CRM enables us to efficiently and quickly engage with talent that opted into learning and potentially growing at GitLab. Learn more about how to use our Greenhouse CRM [here](https://docs.google.com/document/d/16DzE9bsgeflGiRMntncdhMTc6CpHjE5hlQqOnLBQpwo/edit).

#### DIB Enablement

Examples of searches:

1. Use of SeekOut's gender or race & ethnicity-specific search tools
A list of all HBCUs (Historically Black Colleges and Universities) in the United States
1. A search of all sororities in the United States
1. A LinkedIn search including "she" or "her" pronouns
You cannot search for race or gender on LinkedIn, but you can search for associations. (Examples would be NSBE OR "Black engineer" OR NSMBA OR "Black MBAs" OR AAWIT OR "African American women in technology" OR NAACP OR "Black chamber of commerce" OR "African American chamber")
1. Sourcing Library (available to internal team members only) coming soon

#### Pitch Pages

Pitch Pages are a [Guide]({{< ref "interviewing#guide" >}})-like experience, intended for prospective candidates that have yet to dive into learning about the experience of working at GitLab, or for current candidates who are in the process and interested in learning more. Pitch Pages are a great sourcing tool aimed to help convert a prospect into a true candidate, or to provide more insight about our company for those currently in the process.

To help form a strong and meaningful relationship with both passive and active candidates, Recruiters can leverage a unique Pitch Page built specific to their departments including Sales, Engineering, UX, G&A, Product, or our General Pitch Page. Pitch Pages will highlight GitLab's achievements, life at GitLab, our values, culture, benefits, and working on a specific team! Recruiters may choose to send the Pitch Page via Inmails, LinkedIn messages or use it in any strategy for sourcing by sharing this [link](https://app.guide.co/p/c462b99a-d4a6-4246-9e5c-e4232c7bd958) with candidates.

The Candidate Experience Team will be the DRI for Pitch Pages. If you have any questions or suggestions please reach out to CES at ces@gitlab.com.

### Re-engagement

The recommended process of re-contacting candidates:

1. Re-contacting a candidate for the same/another position if the candidate failed in the previous interview process: we suggest other TA member re-contact them after 6+ months from the time of their last interview. Please consult with the other TA member who contacted/recruited them previously and discuss the case, if needed.
1. Re-contacting the candidate for the same/another position if they haven't responded to the past inmails: the recommended time to contact the candidate again is around 3 months. Please consult with the other TA member who contacted them previously and discuss the case, if needed.

### Rehires

If a former GitLab team member is identified by the Hiring Manager, Recruiter, or a current team member as a potential rehire, the Recruiter should contact People Connect directly via [HelpLab](https://helplab.gitlab.systems/esc?id=emp_taxonomy_topic&topic_id=57e1ad3997804e50a326158de053af3d) using the Greenhouse email template titled `Rehire Eligibility Request` before approaching the candidate. People Connect will conduct a review of possible performance concerns or other factors that may have impacted the candidate's departure from their role at GitLab. People Connect will inform the Recruiter directly if the candidate is eligible for rehire and the recruiter will add a private note of the decision to the candidate's Greenhouse profile (i.e. "eligible for rehire" or "not eligible for rehire"). Note that rehires are not eligible for referral bonuses.

### For GitLab Hiring Managers and Team Members

If you are a Hiring Manager on a open role, your recruiter will partner with you to ensure you have a good action plan for building a passive candidate pool for your role.

Sourcing vs. Referrals: If you **know** a candidate from school, previous companies, seminars... even among your neighbors or family members - the best next step is to submit them as a referral by creating an `Issue` in the [Referrals Project](https://gitlab.com/gl-talent-acquisition/referrals/-/issues/new?issuable_template=Referral%20Submission). More information about the **Referrals** can be found on the [Referral Process]({{< ref "referral-process" >}}) page.

For anyone that you **do not** have a personal relationship with, please add them as a *Prospect* in Greenhouse. Talent Acquisition will be able to engage prospects during the interview process by leveraging information in Greenhouse.

Here's how to do that:

1. Check if the prospect/candidate already exists in our ATS (Applicant Tracking System) by searching for the candidate's name in Greenhouse. Pay attention to the activity history both in Greenhouse (in Activity Feed), LinkedIn (Messages), or any other professional networking sites.
1. Click the **"Add"** button, then click **Add a Candidate**
1. Switch to the **Prospect** tab and complete the intake form
1. **After** receiving confirmation from a *Prospect* about moving forward with a vacancy, you can convert them into a *Candidate*

**Step by Step Example**

I've found someone who might be suitable for our Backend Engineer role, simply use their name or email address to check in Greenhouse to see their status
--> Add them as a *Prospect* in Greenhouse --> Once they replied with interests, please convert them into a *Candidate* in Greenhouse.
You can also check out our [Greenhouse Tips and Tricks](https://docs.google.com/document/d/1BbO5v_IJEq4QR9KpI7T3fSCwdCapVOZCyNgEk6MYO0s/) document to find more information on Greenhouse usage.

**About Sourcing Channels**

The most efficient way to source candidates for any vacancy is to search through a professional network, such as LinkedIn, AngelList, etc.
Professional networks make it easy to scan a person's skill set and professional background quickly and efficiently and are designed to present their best impression to potential employers.

We encourage our team members to think out of the box and source creatively! For some positions, other networks may prove useful as well -
for example, we are looking for someone who has public speaking experience combined with specific tech expertise.
You can go on YouTube and search for candidates who have spoken at seminars or professional conferences, try to search for the person's name and look for suitable ways to contact them.

**About Reaching Out to Candidates**

When you have identified someone as a good potential candidate, send their
profile along with any requested information to the TA member so they can reach out to
the candidate and add them to Greenhouse. You can check the Talent Acquisition alignment
[here]({{< ref "recruiting-alignment" >}}).

If you want to reach out to a sourced candidate directly, you should discuss your communication strategy with your
recruiting partner beforehand in order to avoid duplication and/or poor candidate experience.

Take a look at the [Content library - life at GitLab](/handbook/people-group/employment-branding/content-library) for the latest team member count, employer awards, blog posts, and more facts about working at GitLab. These resources are meant to help guide your outreach to potential candidates.

**Upgrading Your LinkedIn Account to Hiring Manager**

Hiring Managers and hiring team members are able to request a **LinkedIn Hiring Manager Seat.** To upgrade your seat, please add your GitLab email to your LinkedIn profile by following this process: {+ Login to LinkedIn > click Me > Settings & Privacy > Sign in & security > Email addresses > add your GitLab email address and verify it. +} Next, submit an [Access Request Issue](https://gitlab.com/gl-talent-acquisition/operations/issues/new?issuable_template=LinkedIn%20Access%20Request) using the LinkedIn Access Request template within the [Technology and Insights project](https://gitlab.com/gl-talent-acquisition/operations).

- **A Hiring Manager seat** allows a user to collaborate on projects, where they can share and review profiles and provide feedback on prospective candidates.

**New to LinkedIn?** Please reach out to your TA partner for tips.

Please note, we won't be able to reimburse any LinkedIn seats purchased at your own expense.

If you're locked out of your LinkedIn account with no way to confirm your identification via 2 Step Verification, you are able to turn off 2 Step Verification.
