---
title: "Talent Acquisition Process - Candidate Experience Specialist Contract Processes"
description: "This page is an overview of the Candidate Experience Specialist Contract Processes when hiring globally."
---

Assuming that the [hiring process](/handbook/hiring) went smoothly, now it is time to prepare the applicable contracts. Once the verbal offer is made, an issue will be created via the "email team" option in Greenhouse. The CES will send the contract to the applicant, using DocuSign in Greenhouse. On rare occasion, the CES may have to create the contract outside of Greenhouse using Google Docs; if this is the case, the CES needs to have a manager review the contract for accuracy before sending it out for signature.

First, be sure to validate the following:

1. The candidate has been moved to the "offer" stage before sending the contract. CES can adjust this, but it's important to inform the Recruiter because this is a step that should be done when they are ready to make their verbal offer.
1. The start date is not a no-start day, and is more than 10 days from your sent date. People Connect requires at least 5 days to process a new hire, but requests 10 days when possible. Recruiters need to be prepared for the time it takes for both parties to sign the contract as well as reject all remaining candidates and should prepare for this.
1. The candidate lives in a country we are able to hire in. The SSOT for all country hiring is [here](https://comp-calculator.gitlab.net/hiring_status/index).
1. The currency listed in the offer package in Greenhouse should normally be the local currency of the new team member unless approved by Total Rewards. This needs to be confirmed and approved by Total Rewards prior to making the offer, as any changes to the currency will require complete reapproval in Greenhouse, regardless if it is the same amount just in a different currency.
1. Confirm [through which entity the team member would be employed or contracted](/handbook/people-group/employment-solutions#team-member-types-at-gitlab). If the title of the position includes "Public Sector" and they are located in the US, they may need a Federal contract. The Recruiter should confirm with the PBP if there's any questions.
1. If the candidate is located in *Belgium* the CES or Recruiter should be aware of two further things to address: i. there are strict language/translation requirements in Belgium so the CES or Recruiter should confirm which region of Belgium the candidate is located in and let legal know, to ensure the right contract, in the right language is used, and so that a translation can be arranged if necessary; and ii. if the role is *not* Grade 9 or higher, the CES or Recruiter should send a link to the role and the job requisition to the legal team via the #legal Slack channel once the candidate is at offer stage (before anything is sent out!) to determine whether or not the role is a position of trust.
1. The recruiter should select "Email the team" and send the "CES Start Contract Request" email to CES* to initiate the offer letter and background check processes after the verbal offer has been made.

### Entity Contract Signatories

This chart reflects the available signatories for each of GitLab's entities. They are listed in order of preferred signatory first. This chart should only be used for new hire contracts where GitLab has entities. This is not for internal moves such as [contract renewals]({{< ref "contracts-probation-periods#contract-renewals" >}}), [job change letters]({{< ref "contracts-probation-periods#job-change-letter" >}}), or [relocations]({{< ref "relocation" >}}).

| Entity | Signatory |
|-------- | -----|
| GitLab Inc | All Recruiting Leads (Jake Foster, Marissa Farris), Jess Dallmar, Rob Allen, Other People Group Team Members who are employed by Inc. and of the appropriate grade to sign the document. JCLs can be signed by Morgan Wilkins  |
| GitLab Federal LLC    |       Bob Stevens     |
| GitLab BV Belgium, Dutch & English | Marissa Farris, Jake Foster & Pattie Egan|
| GitLab BV, Netherlands | Marissa Farris, Jake Foster & Pattie Egan|
| GitLab Canada Corp | Simon Mundy |
| GitLab France S.A.S. | Jake Foster, Pattie Egan, & Rob Allen |
| GitLab GK, Japan | Jess Dallmar, Rob Allen & Jack Connors Backup: Simon Mundy|
| GitLab GmbH | Marissa Farris, Rob Allen & Pattie Egan|
| GitLab Iberia S.L (Spain) | Jake Foster, Rob Allen, Pattie Egan. Backups: Jim Gladen & Simon Mundy |
| GitLab Ireland LTD | Marissa Farris, Rob Allen, Jake Foster, Jack Connors & Pattie Egan|
| GitLab Israel LTD | Jim Gladen, Simon Mundy|
| GitLab IT BV | Marissa Farris, Pattie Egan, Jake Foster, Jack Connors |
| GitLab PTY Ltd, Australia | Jess Dallmar & Rob Allen, Jack Connors. Backup: Jim Gladen|
| GitLab PTY Ltd, New Zealand | Jess Dallman & Rob Allen, Jack Connors. Backup: Jim Gladen|
| GitLab South Korea | Jess Dallmar, Jack Connors & Rob Allen |
| GitLab Singapore PTE. LTD. | Jess Dallmar, Jack Connors & Rob Allen. Backup: Simon Mundy |
| GitLab UK Ltd | Marissa Farris, Jake Foster, Rob Allen, Pattie Egan|
| JCLs | Choose signatory from the list above. For the US, Morgan Wilkins can also sign. |
| PEOs | The Candidate Experience Specialist processing the offer. For JCLs, choose Morgan Wilkins or Marissa Farris |

### Send the contract through Greenhouse

1. Once the offer package has been approved in Greenhouse and the recruiter has given the verbal offer, go to the candidate's profile in Greenhouse. Verify the address is listed on the details tab. This is required in order to send a contract.
1. If necessary, click Edit Profile to update the candidate's name to their legal name (given on the reference check form). Legal names are required on contracts and for proper export to WorkDay.
1. Ensure the start date is on a Monday, unless Monday is a holiday/[no start date](https://internal.gitlab.com/handbook/people-group/people-operations/people-connect/people_connect_team/#people-connect-availability) or the non-Monday date is legally required.
1. Update signatory and entity, if necessary, by clicking "Update" under Offer Details. Add signatory name and title, as well as entity based on candidate's location.
1. Next you'll need to update the signatory's permissions to ensure we're able to send the DocuSign contract to them.
    - Navigate to `Job Setup` at the top of the page.
    - Click `Hiring Team` on the left handside toolbar.
    - Navigate down to the search bar located underneath `Who can see this job?`
    - Search the signatory's name
    - Click the pencil to trigger the dropdown list of permissions
    - Select `Job Admin: Job Approver`
    - Click `Save`
    - Navigate back to the Offer Details on the candidate profile and continue next steps
1. Scroll to the section "Offer Documents" and click "Generate". Then click in the box and select from the options the appropriate template for the team member's entity, employment/contractor status, full-time or part-time, and any applicable bonuses. An example is `GitLab Inc, with OTE`. Then click "Generate". It will now populate and .docx and .pdf files under the "Offer Documents" section. If there are any token errors (i.e. problems with the information pulling from the candidate's profile and into the contract), Greenhouse will notify you. Most likely, if that happens it is because a field in the candidate profile is not accurately filled in. Once you fix the error, you'll need to "Regenerate" the contract.
    - GitLab BV Belgium contracts are classified as Sales/Non-Sales, With OTE/Without OTE, and Position of Trust/Not a Position of Trust. All roles that are Grade 9 or above should be given the appropriate "Position of Trust" contract. If the role is not Grade 9 or higher, send the job requisition to the legal team via the #legal slack channel to determine which contract should be used.
1. Next, click "Send with DocuSign" right below the offer documents. You will need to have first connected your Greenhouse account with your DocuSign account by going to the integrations tab in Greenhouse. If you receive an error on this step, your integration may have disconnected.
1. Choose the correct template according to country, or if no country template is available select `Offer through DocuSign`. In the "To User" field, choose the GitLab signatory for the contract. In the "CC" field, add the recruiter and the hiring manager. Then click "Preview on DocuSign".
1. You will be redirected to DocuSign.
1. On the top left of the screen, click where it says the candidate's name, then click "Edit Recipients". Change the `2` next to the GitLab signatory's name to a `1`, change the `1` next to the candidate's name to a `2` and change the `1` next to the hiring manager's name to a `2`. This ensures that the contract goes to the GitLab signatory to sign first, as well as the recruiter for a Cc and once signed by them it will go to the candidate and the hiring manager with a Cc. Then click "Done".
1. Scroll throughout the contract and double check that the candidate and GitLab signatory signature and date fields are accurately added.
1. If there is an Exhibit A to the PIAA/List of Included Inventions section of the contract, be sure to add fields to be assigned to the candidate.
    - Navigate to where the PIAA/List of Included Inventions section is on the contract.
    - Make sure you've selected the candidate's name in the upper left hand corner dropdown.
    - On the left side under `Standard Fields`, drag a `Text` field over to underneath the Title, Date, and ID number area of the section. Resize to cover entire area for information.
    - Drag a `Checkbox` from the fields section on the right side to both areas needed (No inventions, improvements area and additional sheets attached area)
    - On click on the Checkbox for `No Inventions` area and navigate to the right hand side of the page. Click `Conditional Logic` and `Create Rule`. Select `Unchecked` in the dropdown and click the Text box (it will grey out) and click `Done`. This will ensure that if the candidate does not click this box indicating they do have exceptions, they will need to fill in the text box before submitting their signature.
        - **You will need to create the conditional logic rule each time you send out contracts**, it does not save for future use.
    - Add a `Signature` field, a `Name` field, and a `Date Signed` field to the correct areas.
1. There may also be other fields you'll need to add a textbox for, so double check if there are any other fields that need to be completed by either the candidate or GitLab signatory. Examples include adding a text box for "Place" on German contracts, or adding text boxes for PIAA at the bottom of most contracts. Once you've verified that all the information is correct and appropriately assigned, click "Send" at the top right corner.
1. You'll now be redirected back to Greenhouse, where you can monitor the progress of the contract and be able to see when each party signs it. Once it is signed by all parties, you and everyone cc'd on the original request will receive a confirmation email that it has been signed.
1. After sending the contract via DocuSign, ping the signatory in the #contracts-to-sign slack channel.
1. If you need to resend the contract, follow the same steps, but be sure to log into your DocuSign account and first delete the original one to avoid confusion.
1. Update the status of your open issue.

### How to add a contract into Greenhouse

1. In the internal GitLab Handbook, you'll navigate to [this link](https://internal.gitlab.com/handbook/people-group/people-operations/people-connect/employment_contracts/) as a SSOT for all contract templates. Only the People Group, Finance, and Legal should have access to this folder.
1. Navigate to the correct entity of the contract you're attempting to update on the handbook page.
1. Click the link to the contract you're wanting to upload and it will open the Google Document.
1. Navigate to `File`, click `Download` and select `Microsoft Word`.
1. Log in to Greenhouse and go to "[Configure](https://app2.greenhouse.io/configure)" by clicking the gear at the top right corner, then choose "[Offer Templates](https://app2.greenhouse.io/account/offer_letter_templates)".
1. Navigate to and click the `Upload New` button (located underneath All Offer Sections).
1. Enter the template name (The convention is typically "GitLab `Entity` `employment-type`, `with/without bonus`", e.g. `GitLab Inc full-time, with variable bonus/commission`).
1. Click `Choose File` and choose the document you've downloaded and click `Save Template`.
1. Greenhouse will upload the document and it will appear at the bottom of the page. There will be a `Test` button next to it; click this, and it will validate that all of the Greenhouse tokens are correctly inputted. If there are any errors, it will notify you. You will then need to go back to the template in Google Docs and correct the errors, redownload it, and reupload it to Greenhouse (after deleting the original one with mistakes). If all of the tokens are functioning properly, there will be green checkmarks, and you're ready to use this template for contracts!
    1. Check all of the token/fields to ensure they are formatted correctly (`{{ }}`). For each of the fields with curly brackets (`{ }`) in the template on Google Drive, find and replace that field (including the curly brackets) with the corresponding Greenhouse tokens (including the curly bracket). For example, `{Contributor Name}` in the Drive template will be replaced with `{{CANDIDATE_NAME}}`.
1. To delete a contract template from Greenhouse, click the three dots `...` to the right of the template name, then click delete and confirm.

The SSOT for the contract templates are on [this handbook page updated by Legal and People Connect](https://internal.gitlab.com/handbook/people-group/people-operations/people-connect/employment_contracts/). Any updates to contracts will be done there first, and then the talent acquisition team needs to be pinged to be made aware of the changes so they can update the corresponding Greenhouse template.

These steps are executed by the **People Connect and Legal teams** when contracts are being updated, but for reference, if any changes need to be made to the templates, these tasks can be referenced below:

   1. Some fields that are not necessarily clear are the compensation fields as there are separate fields for the *vacancy* and for the *candidate*; we want the candidate fields for the contract, so in Greenhouse, the appropriate token for salary is `{{CURRENCY}}`, bonus is `{{BONUS_AMOUNT}}`, and stock options is `{{STOCK_OPTIONS}}`. Another field that is easily confused is the title; the `{{JOB_NAME}}` is the name of the vacancy, which is not always necessarily the same as the title the candidate will have; to make sure it is always correct and includes the appropriate level and specialty for the candidate, use the token `{{FULL_TITLE__INCLUDING_LEVEL_AND_SPECIALTY_}}`.
   1. The one exception to the curly bracket find and replace process is the Belgian contract. The fields that need to be edited are highlighted.
   1. When removing optional clauses, take care that the paragraph / section numbering still makes sense.
   1. Double check that each field that needs to be filled out is replaced with a Greenhouse token. Sometimes it is not always obvious, as the curly bracket might be regular brackets by mistake.
   1. For each signature section, the following tokens **must** be on their own line in the document, with nothing else on the line: `{{CANDIDATE_SIGNATURE}}`, `{{CANDIDATE_SIGNATURE_DATE}}`, `{{COMPANY_SIGNATURE}}`, and `{{COMPANY_SIGNATURE_DATE}}`. Find each signature page, then hit enter to create the new line after the "Signature", "Name", "Title", and "Date" sections, then copy the corresponding Greenhouse tokens. These can be easy to miss, so double check each signature section has the appropriate Greenhouse tokens, each on their own line.
   1. Most contracts will have various versions that need to created, e.g. one that contains bonus language for variable bonus/commission, director/executive bonuses, or signing bonuses. Best practice is to create the contract containing all of the additional information and title it accordingly, then once you are done go to "File" in Google Docs and choose "Make a copy". Then remove the information as needed and rename the new document and continue the steps below. You can view other documents in the Greenhouse Templates folder for examples.
   1. For contract templates with variable bonus/commission plans, replace all paragraphs with the token `{{VARIABLE_BONUS_TYPE_OFFER_SECTION}}` which will tell Greenhouse to automatically choose the correct bonus type based on the offer package created in Greenhouse.
   1. To change or update a contract that has already been created and uploaded into Greenhouse, return to the corresponding Google Drive doc in the "Greenhouse Templates" folder, open the templates that need to be updated (there may be multiple that need to be changed, since there are different varieties of each contract to accommodate bonus structures, full-time/part-time, etc.), then update each accordingly. If you need to add new tokens to accommodate the change, be sure to follow step 5.3 in the above instructions. Once you have finished making any updates, click "File" in Google Docs, then "Download as" and "Microsoft Word (.docx)". Then go back to the "[Offer Templates](https://app2.greenhouse.io/account/offer_letter_templates)" section in Greenhouse. Find the contract that you are replacing, copy the name of it so you can maintain consistency, then click the three dots `...` to the right of the template name, then click delete and confirm. Then click "Upload New", paste the name of the template, and upload the new version. Click "Test" to validate that everything translated correctly (per step 9 above), and you are ready to use the new template.

### How to Send a Family Member Relationship Acknowledgment

Consistent with GitLab's policy governing Hiring Significant Others or Family Members, GitLab is committed to a policy of employment and advancement based on **qualifications and merit** and does not discriminate in favor of or in opposition to the employment of significant others or family members. Any new hire that has a family member relationship that is currently employed at GitLab must sign [this acknowledgment](https://docs.google.com/document/d/1IseZy4zJZMgP0VCAsGqCP3I6sfnavGdD81THnqljaPI/edit?usp=sharing) along with the GitLab team member. This process is done in conjunction with sending out the contract.

1. If you have not been notified by the recruiter that there is a family relationship in play, there is now a field in the 'Offer Details' that will show whether a relationship exists. There should also be a *Family Member* tag on their profile. It, however, will not show who that family member is.
1. The Recruiter will post the name of the family member in the Private Notes within the Greenhouse profile. If not there, the CES will reach out to the recruiter to find out who the current GitLab team member is.
1. Once the family member is identified, you will send the [Family Member Relationship Acknowledgment](https://docs.google.com/document/d/1IseZy4zJZMgP0VCAsGqCP3I6sfnavGdD81THnqljaPI/edit?usp=sharing) via DocuSign to the new hire as well as the GitLab team member for signing.
1. Drag and drop the Family Member Relationship Acknowledgement form on DocuSign.
1. Add recipients using the following order:

- #1 GitLab Team Member (needs to sign)
- #2 New Hire (needs to sign)
- #3 CES (receives a copy)

1. After all parties have signed, upload a copy into the new hire's Workday profile.
1. Upload Family Member Relationship Acknowledgement form into Workday.
   - Sign into Workday
   - Search the new hire's name
   - Click on the Personal Link on left side of screen
   - Select "Documents"
   - Select "Add"
   - Click "Select Files" and choose appropriate saved PDF
   - Select "OK"
   - Under "Document Category" select "Pre-hire documents & Changes"
   - Under "Comment" write "Family Member Relationship Acknowledgement"
   - Upload
   - Repeat same steps above this time finding the GitLab team member in Workday
1. Lastly, please open a General People Team request in HelpLab asking them to upload the acknowledgement into the exisiting family members Workday profile. You will need to attach the acknowledgement in the request and provide them the team members name.

### How to Update a Start Date After the Contract is Signed

To change a start date after a **GitLab entity** contract has been signed and the new team member has been "hired" in GreenHouse the Candidate Experience Specialist will complete the following steps:

1. Confirm the start date via email with the new team member, the recruiter, the hiring manager, and the Candidate Experience Specialist.
1. Save the email as a pdf file for upload into Workday.
1. Update GreenHouse:
   - Offer Details
   - Click the edit pencil next to the start date
   - Select the new Start Date
   - Save
   - In the "Make a Note" section in Greenhouse state the old start date and the new state date, and tag the person on FP&A (typically the second approver) who approved the offer.
   - Save
1. Update Entity Payroll Provider (Netherlands) of any changes to the start date via the email templates in Greenhouse.
1. Update the People Connect Team in Slack Workflow.
    - Open private Slack channel `#peopleops-alerts-private`
    - Click Shortcuts button in the bottom left corner (looks like a lightning bolt)
    - Click "New Start Date        Workflow"
    - Fill in Team Member Name with the New Hire Name
    - Fill in Original Start Date (YYYY-MM-DD)
    - Fill in New Start Date (YYYY-MM-DD)
    - Fill in Reason For Change. This is to inform the People Connect Team of the reason for the new date (i.e. Public Holiday, New Hire request, Hiring Manager request, etc.).
    - Optional: Fill in Any other changes.
    - Click Submit
1. Upload start date change comms into Workday.
   - Sign into Workday
   - Search the new team member's name
   - Click on the Personal Link on left side of screen
   - Select "Documents"
   - Select "Add"
   - Click "Select Files" and choose appropriate saved PDF
   - Select "OK"
   - Under "Document Category" select "Contracts & Changes"
   - Under "Comment" write "Start Date Change"
   - Upload

To change a start date after a **PEO** contract has been signed and the new team member has been "hired" in GreenHouse the Candidate Experience Specialist will complete the following steps:

1. Confirm the start date via email with the new team member, the recruiter, the hiring manager, and the Candidate Experience Specialist.
1. Forward the email to the contact at the PEO.
1. The PEO will generate a new contract and send to the new team member.
   - The Candidate Experience Specialist will need to follow-up with the PEO contact to ensure the new contract is signed.
1. Update GreenHouse:
   - Offer Details
   - Click the edit pencil next to the start date
   - Select the new Start Date
   - Save
   - In the "Make a Note" section in Greenhouse state the old start date and the new state date
   - Save
1. Update the People Connect Team in Slack Workflow.
    - Open private Slack channel `#peopleops-alerts-private`
    - Click Shortcuts button in the bottom left corner (looks like a lightning bolt)
    - Click "New Start Date        Workflow"
    - Fill in Team Member Name with the New Hire Name
    - Fill in Original Start Date (YYYY-MM-DD)
    - Fill in New Start Date (YYYY-MM-DD)
    - Fill in Reason For Change. This is to inform the People Connect Team of the reason for the new date (i.e. Public Holiday, New Hire request, Hiring Manager request, etc.).
1. Upload start date change comms into Workday.
   - Sign into Workday
   - Search the new team member's name
   - Click on the Personal Link on left side of screen
   - Select "Documents"
   - Select "Add"
   - Click "Select Files" and choose appropriate saved PDF
   - Select "OK"
   - Under "Document Category" select "Contracts & Changes"
   - Under "Comment" write "Start Date Change"
   - Upload

### How to Update a Start Date for an internal candidate after the Job Change Letter is Signed

To change a start date after a Job Change Letter (JCL) has been signed and the internal team member has been "hired" in GreenHouse, the Candidate Experience Specialist will complete the following steps:

1. Once the start date change request comes through, CES will advise the recruiter to collaborate with the hiring manager or PBP to raise a HelpLab ticket for the People Connect team to make these changes in Workday.
The hiring manager or PBP should provide confirmation of the new start date via the HelpLab ticket.
1. CES can update GreenHouse:
   - Go to Offer Details
   - Click the edit pencil next to the start date
   - Select the new Start Date
   - Save
   - In the "Make a Note" section in Greenhouse, state the old start date and the new state date, and tag the person on FP&A (typically the second approver) who approved the offer.
   - Save

### How to Update a Start Date After a French or Spain contract has been signed

   Please follow the normal start date change [process](/handbook/hiring/talent-acquisition-framework/ces-contract-processes/#how-to-update-a-start-date-after-the-contract-is-signed), thereafter, please follow the following steps:

   1. Make a copy of this Start Date Amendment [letter](https://docs.google.com/document/d/1qpxTi6nPrT4KXDi87tDAWm49D9NZNvTS/edit)
   1. Edit all the highlighted details and save the document on your desktop
   1. In Docusign, create a new envelope and set the signing order as follows:
      - 1 - GitLab France or Spain Signatory (sign)
      - 2 - The candidate (sign)
      - 3 - Alessio Spaggiari (copy)
   1. Use the TextExpander ‘StartdateFS’ in the body of the email in Docusign
   1. Request the signatory in the contracts Slack Channel `#contracts-to-sign` to sign the letter
   1. Once the document has been signed, load it onto the candidate's profile in WorkDay

### How to Void a Contract Before a Candidate Signs

In rare cases, we may rescind our offer before a candidate signs the contract. Work with the Recruiter, Hiring Manager, People Business Partner, VP of Talent Acquisition, and Contract Employment Counsel on ensuring uniform communication. Once the candidate has been informed verbally and via email by the talent acquisition team, follow these steps:

1. Ensure the email is exported into the Activity Feed in Greenhouse.
1. Void the contract in DocuSign utilizing the same communication that was emailed.
1. Reject the candidate in Greenhouse. Be sure to select 'Reject and Don't Send Email.'

### How to Void a Contract when the candidate declines the offer and not marked as hired in the system

In cases where the candidate has declined the offer verbally or via email to the talent acquisition team or CES, follow these steps once the recruiter confirms it is okay to void the contract:

1. Go to the docusign portal, under the " waiting for others" tab, click on the candidate's name whose contract needs to be voided.
1. Under "More" tab, click "Void". Enter the reason for voiding the contract e.g "Candidate declined offer" then click on Void.
1. Go to the candidate's Greenhouse profile, make a note saying the contract is voided by copying the recruiter. This will prompt the recruiter to reject the candidate in GH if it hasn't been done.

### How to Resend a Contract After Being Marked as Hired

There are certain times when a contract needs to get resent to the candidate after they have been hired into the system, should that happen. Follow the steps below:

1. If the req is already closed, tag the Enablement team in the greenhouse profile explaining the situation and that the req needs to be reopened to resend a contract.
1. Unhire the candidate in Greenhouse. (If the position is Closed, Enablement will need to assist with this step).
1. Resend the correct contract and follow standard steps for doing this.
1. Once you receive the contract back, **before** marking the candidate as hired in Greenhouse - ping the People Connect team in the `#peopleop-alerts-private` slack channel and explain exactly what the change was. The updated details will not update Workday and will need to be manually corrected by the People Connect Team.
1. Upload the new contract to their Workday profile.
1. Ping the People Connect Team and let them know the contract has been updated and the details in Workday can be corrected.

For Talent Acquisition Enablement:

1. Once notified by the CES team, copy the Job Approval Chain and add it to the Approval Details Notes section. Include the names of the approvers, the dates approved, and the reason as to why the requisition is being re-opened. Tag the Finance Business Partner, CES, and Recruiter in this note.
1. From the Approvals page, select 'Edit Job & Openings'
1. Duplicate the Opening that needs to be re-opened.
1. Bypass approvals in the Job Approval section to change the Job Status from Draft to Open.
1. Inform CES once the req is open.
1. When the revised contract is uploaded by the CES, verify if the core fields on the offer remain the same. If it remains the same, bypass offer approvals and inform the CES once completed.
1. Once the CES team marks the candidate as hired in Greenhouse, close the duplicated opening and save changes.

### How to Keep Candidates Informed of Any Delays in the PEO Contract Process

Occasionally, there can be delays between the candidate receiving the PEO New Hire Document issued by the CES team and the official contract from a PEO. This delay can result in a nervous wait for the candidate. We must keep anyone who has not received their full contract from our PEO informed of any delays outside of the PEO SLAs.

The Candidate Experience Specialist who initiated the contract process is expected to follow up with the PEO every 24-48 hours until the contract is sent and will note of follow-up dates in the [PEO Tracker](https://docs.google.com/spreadsheets/d/1gSOVTJ1Yv-YsSaliJwKVf-1H0vBZXxb5NWFiqCwT-uo/edit#gid=0). This communication should be sent in Greenhouse, so that the communication is captured in the activity feed. If there are any extreme circumstances that will result in a contract getting to the candidate outside of the PEO SLA's, the CES will also note those in the PEO Tracker. Recruiter is expected to keep the candidate updated on the progress of their contract every 24-48 hours until the candidate receives their contract. A simple message that explains the delay is all that is necessary. As a Candidate Experience Specialist or Recruiter, you're encouraged to utilize the Greenhouse reminder feature to manage these updates and log the email in Greenhouse.

## Amended Contracts

Contract amendments or modifications are processed by the Candidate Experience Specialist if the team member has not started or by the People Connect Team member if they have.

### Amendments prior to starting with GitLab

If an amendment needs to be made and the previous contract was never active, the Candidate Experience Specialist should:

- Ask People Connect in the `people-exp_ces` Slack channel to delete the previous contract from Workday.
- Upload the updated contract in the Documents section of the team member Workday profile, using the 'Contracts and Changes' document category.

*Note: It is essential that People Connect Team members are informed of all changes, as various fields must be updated in Workday.*

### Amendments to contracts for new hires with planned relocations

1. Candidate Experience Specialist will ensure that there is verbiage clearly stating the terms of the compensation changes for relocation after the new hire's start date and ensure that the Total Rewards team has approved both compensations.
1. If you are unsure about the Total Rewards approval, CES will ping the Total Rewards team in the Approval Notes.
    - Navigate to the bottom of the candidate's GH profile
    - See "Approval Notes"
    - Click "Leave a Note"
    - Tag the Total Rewards team member who approved in a note to confirm that both compensation values have been approved
    - Tag the Recruiter as CC
1. Once Total Rewards has confirmed both have been reviewed and approved, generate the appropriate contract
1. Download the Word version of the contract and upload into Google Drive for editing. Don't click to open the doc, just transfer it into Drive so it doesn't impact formatting.
    - Navigate to Google Drive
    - Click "New" in the upper corner of the left toolbar
    - Select "File Upload"
    - Select the contract
1. Add lines at the top of the document for categories to include Compensation for the relocation
    - Example for relocation from ID to CA:
        - CA Compensation: $ USD
        - ID Compensation: $ USD
1. Update Section 10 Location verbiage:
    - Original
        - 10. Location. Your employment with GitLab is conditioned upon your permanent legal residence being near Boise, ID. If your permanent legal residence changes from that location you must notify the Company prior to any such changes. Changes to your permanent legal residence could result in a change to your compensation, benefits, and in some circumstances, termination of your employment.
    - Updated
        - 10. Location. Your employment with GitLab is conditioned upon your permanent legal residence being near Boise, ID and you've disclosed a planned move to San Francisco, CA on or around January 1st, 2021. If your permanent legal residence changes from those locations you must notify the Company prior to any such changes. Changes to your permanent legal residence could result in a change to your compensation, benefits, and in some circumstances, termination of your employment.
1. Delete out all signature tokens from the document, because they will otherwise show up as text in DocuSign.
1. Save and download the contract as a PDF
1. Upload in GH by selecting "Upload Replacement"
1. Stage contract as normal
1. Add tokens back in after changing signing order
1. Send
1. When the contract is completed, message People Connect to make sure they note the relocation.

### Amendments after starting with GitLab

A contractor requests a modification to their contract due to a name change/company incorporation (Example: The individual recently incorporated a company, and would like to invoice GitLab through their company versus individually)

- The People Connect Team member should log the requested change in the Documents section of the team member Workday profile, using the 'Contracts and Changes' document category.
- The People Connect Team member should draft the new contract using the appropriate template in the [Employment Contracts](https://internal.gitlab.com/handbook/people-group/people-operations/people-connect/employment_contracts/) internal handbook page. ***Please remember to always make a copy of the template before editing.***

*Important: Employment contracts cannot be backdated. If a team member requests to backdate a contract for invoicing purposes, an addendum should be added to the contract stating: "As the Contractor has not invoiced GitLab for payment since their start date on `contractor start date`, GitLab will pay the Contractor for this period of time in accordance with the Contractor's base compensation". The start date on the new contract should always reflect the date the contract is staged for signatures.*

- The People Connect Team member should stage the contract in DocuSign to be signed by both the team member and the Director of People Operations.
- Once siged by both parties, the contract should be uploaded to the Documents section of the team member Workday profile, using the 'Contracts and Changes' document category.

### How to Unhire a Candidate After Contract is Signed

If for some reason a candidate declines an offer after they have been hired into the system, whoever receives that information needs to make sure `@ces` is tagged in the Greenhouse profile and is made aware that the candidate will no longer be starting at GitLab. Please note that the steps below are assuming that the person will not be working for GitLab; if you are hoping to just amend their offer after they've been marked as hired, please view the Resend process above.

If they have been hired in Greenhouse and exported to Workday, the team will need to follow these steps:

1. Unhire the candidate in Greenhouse if the req is still open by clicking the "unhire" button on the candidate's offer. If the req is closed, ask Enablement to unhire.
1. Ask the Recruiter to reject them in Greenhouse; add reasons in notes, you may add the email that was sent by the candidate. Click 'reject and don't send email'.
1. Cancel any scheduled emails in Greenhouse.
1. If they were hired via a PEO, inform the contact person at the PEO of this change immediately, ideally before onboarding starts. If they are in a country that uses outside payroll, we will need to inform the payroll company as well.
1. Message IT, People Connect, and the Sr. Background Check Specialist in the #peopleops-alerts-private channel to let them know to cancel any laptop orders, onboarding issues, background checks, and remove from Workday.
1. If the Recruiter has not already tagged the FP&A approver in the Greenhouse notes, please tag them to let them know that the candidate has withdrawn.
1. If the Recruiter has not done so already, add a candidate tag of `Rescinded Acceptance` to the candidate's profile.

**Enablement steps:**

1. Make a note on the Approvals tab and tag each job approver who approved the job last. Note the date approved and let them know that no action is needed, that you are not adding additional headcount, and that you will be reapproving on their behalf as they have already approved.
1. Open a draft opening through the Approvals tab with "TEMP" in all empty mandatory fields.
1. Approve on behalf of Total Rewards (job approval step 1).
1. Mark the candidate unhired on their candidate profile.
1. Remove the temporary opening on the approvals page. This will happen in two steps: first, you'll need to close the opening (using the same process you used to open it), save, and then go back in again to delete the record of the opening. There is a bug in Greenhouse that impacts pop-ups during this stage, so you may need to resize your browser if you're not seeing confirmation messages.
1. Approve the final approvals on behalf of those who originally approved.
1. Inform any involved parties of the unhiring status who will be taking next steps.

## Job Change Letter

When a team member applies for and receives a new position through Greenhouse, a Job Change Letter is prepared in lieu of a new contract using DocuSign. The Candidate Experience Specialist will prepare the letter. This document is signed by the Director, Total Rewards or the Sr. Director, Global People Operations or the Chief People Officer and the team member through DocuSign. Using the Offer through DocuSign - Job Change Letter template in Greenhouse the letter is cc'd to peopleops@gitlab.com team for processing.

Effective dates for a job change letter should be the first (1st) of the month or the sixteenth (16th). For Sales or Sales Development team members, they can only be the first of the month. These effective dates do not need to be on a business day and should be adhered to payroll purposes.
Please note that JCLs cannot be used if a team member is moving from the Federal, LLC. entity into any other entity **or** any entity that is not Federal, LLC into the Federal, LLC. entity. In those cases, a new contract **must** be issued as there are tax implications to this entity.

If the team member is making a lateral move where there is no change in compensation, then the start date can be any Monday.

When generating a job change letter for a PEO, the steps remains the same as outlined below. However, select the JCL template that does not include RSUs, and send the RSU details via DocuSign email.

The Candidate Experience Specialist needs to merge any additional candidate profiles before marking as hired. If the profiles are not merged, it will create a duplicate and mess with the employment bot sync to Workday. The signed letter is uploaded into Workday under the Contracts and Changes folder on the Documents Tab by the Total Rewards Analyst.

When an internal transition is taking place and the start date for that JCL is amended, please ensure to update the People Connect team via Slack in the `#people-connect_ces` channel of the new start date.

If a team member goes through a promotion through WorkDay versus Greenhouse, a [Job Change Letter]({{< ref "promotions-transfers#job-change-letter" >}}) is prepared by the Total Rewards team as listed on their handbook page.

CES: Follow the instructions below on how to create and send a job change letter.

1. Confirm that the start date is either on the 1st or 16th of the month. For Sales or Sales Development, the start date should be the 1st. This is for payroll purposes and does not need to be on a business day.
1. The signatory matches the appropriate entity. If the candidate is located in the US (including Federal), Morgan Wilkins can be a signatory. If the candidate is employed through a PEO, Morgan Wilkins and Marissa Ferber can be signatories (this process is subject to change)
1. Next, Click Generate
1. Select Job Change Letter template in Greenhouse:
    - Job Change Letter w/ OTE (US ONLY!)
    - Job Change Letter w/ no OTE (US ONLY!)
    - Job Change Letter w/ OTE, no RSU's
    - Job Change Letter, No OTE, No RSU's
    - **Special Note: Please ensure you are using the bottom two templates ONLY for NON US JCLs!**

JCLs should be treated like contracts, where RSUs are only features in US ones and all other countries should have text within the DocuSign email instead.

1. Click on Send through DocuSign
1. You will be redirected to DocuSign.
1. On the top left of the screen, click where it says the candidate's name, then click "Edit Recipients". Change the order of recipients to reflect the following order:
    - #1 is Director, Total Rewards (needs to sign)
    - #1 is Recruiter (receives a copy)
    - #1 Hiring Manager (receives a copy)
    - #2 Candidate (needs to sign)
    - #3 People Ops (receives a copy)
    - #3 Nitin Upadhyay and Julia Demina (receives a copy)
    - This ensures that the contract goes to the GitLab signatory to sign first, as well as the recruiter for a Cc and once signed by them it will go to the People Experience for an update of records.
1. Then click "Done".
1. When the JCL is signed, ensure that you merge profiles before Hiring to avoid creating duplicate profile

## Germany Job Change Letters

1. Confirm that the start date is either on the 1st or 16th of the month. For Sales or Sales Development, the start date should be the 1st. This is for payroll purposes and does not need to be on a business day.
1. CES will send the "German Job Change Letter step 1" template email via Greenhouse.
1. Follow the Job Change Letter process above to send via Docusign.
1. Download a copy of the unsigned JCL on your desktop.
1. Open the saved unsigned contract in Google Drive and replace Signatory's name with "GitLab Signatory". Save the contract as a PDF format.
1. To send the contract out to the German Counsel, CES can follow the below email structure through Gmail:
    - To (recipients) : Thomas.Leister@osborneclarke.com & julia.bauer@osborneclarke.com
    - Subject line : Please Send Physical Job Change Letter for "Name of the team member"
    - Body of the email : Expand the Text expander snippet "GCtogermancounsel"
    - Attachment : CES to attach the unsigned PDF JCL
1. In order to inform the candidate regarding the physical copies sent out via post, go to the Greenhouse profile of the ​​candidate, using the "email the "candidate name" function, select the template "German Job Change Letter already sent to counsel".
1. Once the candidate has confirmed that they have received the physical JCL in mail, CES will send the email template "German Job Change Letter step 2" to the candidate and close out the issue.

## Contractor Conversions

A contractor conversion is when a GitLab contractor is moving into a permanent position. Recruiters should communicate to their CES partner that a candidate is going through a contractor conversion process. You can confirm this by checking that the "source" says Contractor Conversion, which will show up on the requisition. CES team members will follow the same steps as a regular contract, however there are a few nuances to note:

1. **Reference Check Forms:** You will need to ensure the candidate has completed the reference check form. You may need to remind recruiters that this is required when contractors transition to a permanent position. The candidate does not need to provide references again however, they will need to disclose outside work and PIAA.
1. **Start Dates:** You may find that start dates with contractor conversions have quicker turnaround times so there are no gaps between a contract end date and a new hires' start date (i.e. a request to start in less than 10 business days, or to start on a non-start date). Please continue to follow the [Hiring SLA Exception](/handbook/hiring/talent-acquisition-framework/coordinator/#send-contract) workflow to gain People Connect's approval in these instances and indicate that this is a contractor conversion.
1. **Background Checks:** Please check with the Senior Background Check Specialist in the [backgroundchecks-ces](https://gitlab.enterprise.slack.com/archives/C05ATK8B4V9) Slack channel to confirm if you need to initiate a new background check. If there is no gap between the contract and the permanent position, you may not need to initiate a new background check.
1. **Mark as Hired:** After you mark a candidate as hired in Greenhouse, you will need to leave a comment notifying People Connect in the [peopleops-alerts](https://gitlab.enterprise.slack.com/archives/CLTBQ9XC7) Slack channel that it is a contractor conversion.
1. **Laptop/IT:** For all contractor conversions, CES will need to confirm with IT Ops via the [people-connect_CES](https://gitlab.enterprise.slack.com/archives/GJT1K944Q) Slack channel whether the candidate will need a new laptop or not.
    - If they do not need a new laptop, CES will remove the "Ordering your laptop" section from the Welcome email to the candidate.

## Rehires

In the event that a former team member is rehired with the company, they will still go through the normal interviewing process and standard onboarding. Once the contract is signed, CES should ensure that there are no profiles left to merge and that `Former Team Member` is selected as a candidate tag on the right hand side of their profile. They should have their old hire record on their Greenhouse account.

Please let People Connect know in #peopleops-alerts-private if a rehire is happening.

## Process for GitLab team-members in the Netherlands

In this location, a temporary contract (tijdelijk contract) is for 12 months, with a pre-determined end date. A dismissal procedure is not required to terminate a temporary contract at the end of its duration. However communication about the extension of the contract must happen at the latest 1 month before the actual contract end date (aanzegtermijn).

It is common for Dutch employers to offer a second temporary contract when the first expires, but it's not guaranteed. As a Dutch employer, this is standard procedure for GitLab. As of 2015-07-01, employees who have worked with an employer on temporary contracts for at least two years are entitled to an indefinite contract if the work agreement continues, and this is known as the chain rule (ketenregeling).

The process for New Hires is as follows:

1. The offer is made by the recruiter per the [hiring process](/handbook/hiring).
1. If the date of birth is not filled out and cannot be found in a reference check form, the Candidate Experience Specialist can use the emails the email template Contract Info Request - the Netherlands from GreenHouse and send to the candidate.
1. Ensure the start date is on a Monday, unless Monday is a holiday or the non-Monday date is legally required.
1. The Candidate Experience Specialist will update the GreenHouse Offer Details with the Date of Birth when the new team member provides the necessary details and then generates the "IT BV Employee Temporary - the Netherlands" contract out of GreenHouse.
1. The Candidate Experience Specialist will stage the contract for signature via DocuSign, CC the hiring manager, and CC the HRSavvy group email. This will ensure our payroll provider in this location can start their onboarding, well ahead of ours.
1. Please note that you should *not* be running a criminal background check for the Netherlands, because they'll be doing a different process (Certificate of Good Conduct/VoGS) instead. Please select the Netherlands background check package which only includes employment verification and an extended global sanctions search.

The People Operation Specialist are in charge of [contract renewals]({{< ref "contracts-probation-periods#contract-renewals" >}}). The process the **end of the first 12-month GitLab BV Netherlands temporary contract** is listed in their [Netherlands Renewal Process]({{< ref "contracts-probation-periods#netherlands-renewal-process" >}}) section of the [Contracts, Probation Periods & PIAA]({{< ref "contracts-probation-periods" >}}) handbook page.

*GitLab IT BV contracts should only be used for contractors. All Netherlands **employees** should be issued the GitLab BV contract.*

## Process for GitLab Team Members in Australia, New Zealand, or Ireland

GitLab has an entity in this location. All team members in this location are employees. Please note that Northern Ireland is under the United Kingdom, so if you see an address that includes UK you should hold and verify on google maps where the candidate is located and whether a different contract and background check are needed.

Always ensure the start date is on a Monday, unless Monday is a holiday or the non-Monday date is legally required.

## Process for GitLab Team Members in Singapore, South Korea, or France

GitLab has entities in Singapore, South Korea, and France. All team members in this location are employees, but payroll will be processed through Global Upside. Please be sure to select the correct docusign email template so they will be CC'ed as the final step of the offer process.

Reminder: France requires contracts to be individually drafted by the Legal team. There is a [SSOT document](https://docs.google.com/spreadsheets/d/1HQxOwt30v1qffulaZay61aj_A5edQgb_zfBrhoq0CgA/edit#gid=0) where we keep track of these requests.

Always ensure the start date is on a Monday, unless Monday is a holiday or the non-Monday date is legally required.

## Creating a French and Spain Offer

1. You will receive a req to create a French or Spain Offer.
1. In Greenhouse, click on Job setup, then hiring team, then add Sarah Rogers & Darren Burr to the job granting them the Job Admin: FPA and Legal permissions, then save.
1. Ensure the start date is on a Monday, unless Monday is a holiday or the non-Monday date is legally required.
1. Send a Slack message to the Legal Team in [ces_legal_contracts](https://gitlab.slack.com/archives/C05R0R495L6) requesting assistance with the offer. When making the request in the channel, please indicate the candidate's name and include the link to the GH profile
1. One of the Legal Team members will respond with the following information:
    - The GreenHouse Offer Template that you should use
    - The wording that should be added to the template (including information on where the wording should be placed). This wording will be placed as provided by Legal on both the English & French sides in English.
    - If the offer does not include draw language, Legal will confirm which part of the offer template should be removed.

Once this information has been received, please go onto GH and follow the steps below:

1. Click on the settings icon
1. Select 'Offer Templates' on the left-hand side
1. Search for the Template as advised by Legal
1. Click on the three dots on the right-hand side of the template you will be using and select the 'download' tab
1. Open the document in Google Docs
1. Make all the changes as advised by the Legal Team and save the document
1. Go back to the offer templates page on GH
1. Click on 'Upload New' on the right-hand side
1. Upload the amended document
1. Then follow the normal offer creation process in GH and select your uploaded document as the offer template for this offer.
1. Please remember to delete this template once you have completed the process and the offer has been signed by the signatory & the candidate

## CXC (NOTE: HIRING IS CURRENTLY PAUSED HERE: Please speak with Enablement before sending offer letters)

GitLab is working in partnership with [CXC Global](https://www.cxcglobal.com/) to employ GitLab team-members located in **Poland**, **Ukraine**, **Romania**, **Russia**, **Serbia**, & **Slovenia**. The actual employment contracts will be sent and issued by CXC and are in accordance with local labor law. CXC also handles the processing and payment of payroll and associated taxes and compliance in each of the countries on behalf of GitLab. The contracts themselves are between the individual and CXC.

CXC provides a 12 month contract in these locations, and this can be extended. They are only able to support contractors that have an established entity/company in these countries (listed above). The offer details will be provided to CXC by GitLab's hiring team.

To create the contract:

1. Offer is made by the recruiter per the [hiring process](/handbook/hiring).
1. The Candidate Experience Specialist emails the new team member the Contract Info Request - CXC from GreenHouse.
    - Click "Email CANDIDATE NAME"
    - Select "Contract Info Request-CXC" from dropdown.
    - CC Recruiter
    - Click "Send Email"
1. Ensure the start date is on a Monday, unless Monday is a holiday or the non-Monday date is legally required.
1. The Candidate Experience Specialist will check if there is a probationary period.
    - Go to [Probationary Periods for Team Members Employed by a PEO]({{< ref "contracts-probation-periods#probation-periods-of-team-members-employed-through-a-peo-or-an-entity" >}}) and check the candidate's country.
    - Select the duration of the probationary period (if any) in the "Offer Details" dropdown. If there isn't one, select "N/A" in that field.
1. The Candidate Experience Specialist will check if the contract is indefinite or fixed.
    - If the contract is indefinite, select "Indefinite" from the dropdown in "Offer Details".
    - If the contract is fixed, select "Fixed Contract" from the dropdown in "Offer Details" and enter the end date under "End Date".
1. Once the additional information is received, The Candidate Experience Specialist will generate the PEO form out of GreenHouse.
    - Click "Generate"
    - Select "PEO New Hire Template" from the dropdown
    - Click "Generate"
1. The Candidate Experience Specialist will stage the form for their own signature via DocuSign, the new team member and the appropriate CXC contact. Contact details can be found in 1password => People Operations Vault => Entity & Co-employer HR Contacts.
1. The Candidate Experience Specialist should add the candidate to the [PEO Tracking Sheet](https://docs.google.com/spreadsheets/d/1gSOVTJ1Yv-YsSaliJwKVf-1H0vBZXxb5NWFiqCwT-uo/edit#gid=0) and keep track of communication between GitLab.
1. CXC will then prepare the SOW and contract.
1. CXC will then reach out to the candidates directly to coordinate the contract signing and onboarding to CXC's payroll.
1. Kindly allow a duration of one week for CXC to complete their process. This might mean that a two week notice period to start at GitLab, could increase to three weeks, its important to communicate this duration to new hires in this location.
1. CXC will inform the Candidate Experience Specialist when the contract is signed.
1. The Candidate Experience Specialist will mark the candidate as hired.
1. The CES will adjust the 'Accepted' date to match the 'Sent' date.
1. The Candidate Experience Specialist will now [mark the candidate as hired](coordinator/#send-contract). See steps 10-12.

## Preparing Employment Agreements for GitLab team members employed via Global Expansion (GX)

GitLab is working in partnership with Global Expansion to employ GitLab team-members located in:

- Mexico
- Costa Rica
- Kenya
- South Africa
- UAE
- Latvia
- Philippines
- Austria
- Chile

1. The Offer is made by the recruiter per the hiring process
1. If the Nationality field is not filled out and cannot be found in the Reference Check form, CES sends “Contract Info Request-Global Upside” email to the new hire to collect additional details
1. Ensure the start date is on a Monday, unless Monday is a holiday or the non-Monday date is legally required
1. The Candidate Experience Specialist will check if there is a probationary period.
1. Go to Probationary Periods for Team Members Employed by a PEO and check the candidate’s country
1. Select the duration of the probationary period (if any) in the “Offer Details” dropdown. If there isn’t one, select “N/A” in that field
1. The Candidate Experience Specialist will check if the contract is indefinite or fixed
1. If the contract is indefinite, select “Indefinite” from the dropdown in “Offer Details”
1. If the contract is fixed, select “Fixed Contract” from the dropdown in “Offer Details” and enter the end date under “End Date”
1. Once additional details are obtained, update the offer details to reflect all information. The CES should be the signatory
1. Generate “PEO New Hire Template” in Offer Documents to Send through DocuSign
1. Choose template Offer through DocuSign -GX - Global Expansion -To User, Self (CES) -Sign and complete
1. Log in to the GX 1 Platform using the log in credentials (you can find this information in the CES desk repository)
1. Click + New Employee on the landing page
1. Add personal information of new hire
1. Add Position details
1. Add benefits information:
    - Benefits Policy Type: Use Country guide information located in CES Repository
    - Signatory: Name/Email of CES submitting candidate into Portal
    - Expense approver: Leave blank for now
    - Employment Benefits: Use Country guide information located in CES Repository
    - Benefits Policy Duration: Select "auto renew" for contract duration
    - Employment Retirement Insurance: Use Country guide information located in CES Repository
    - If you see three check boxes for Visa & background screening: ONLY FOR UAE - Select YES (Visa only) and ALWAYS Select "No" for the background screenings for all countries
1. GX Compensation
    - Local currency: Per location - portal should auto adjust
    - Enter just the number “1” (You are not expected to calculate this) In the additional notes section, you can copy/paste the Annual Salary figure
1. If you have all the details click Initiate New Employee (or Save and Submit Later if you are missing data)
1. GX will then review the details and compose the employee’s contract. They will then email ces@gitlab.com when it is complete and ask us to review. You will need to log into the GX platform FIRST, and then click the link in the email sent by GX
1. Review all details of the contract to confirm accuracy
    - If there are items missing, you have the ability to write feedback notes and send back to GX. Click the drop down and select “REJECT - the following changes are required” and submit
    - If everything looks good, click the drop down and select “APPROVE - I am happy with this employment contract” and submit
1. GX will also be sending a 1 page docusign to ces@gitlab.com where we need to confirm employment details again. Please review and sign the document if accurate. Docusign will auto populate a signature of “GL CES Team” but you can adjust and add your name in front of that title. Add your title and send
1. GX will then release the employment contract to the candidate and notify us via email as soon as it is signed. We may also receive an email to our desk when they manually upload the contract to their portal, but these can be ignored if you have heard from them already
1. Proceed with sending the correct Welcome Email
1. Before making the candidate as hired in GH, please make sure all other candidates have been rejected. Once that is done, mark the candidate as hired in Greenhouse, adjust the ‘Accepted’ date to match the ‘Sent’ date, and close the req

## Preparing Employment Agreements for GitLab team members employed via Global Upside

GitLab is working in partnership with [Global Upside](https://globalupside.com) for employing GitLab team-members located in:

- India

The process for creating and sending an agreement is as follows:

1. The Offer is made by the recruiter per the [hiring process](/handbook/hiring).
1. If the Nationality field is not filled out and cannot be found in the Reference Check form, CES sends "Contract Info Request-Global Upside" email to the new hire to collect additional details.
1. Ensure the start date is on a Monday, unless Monday is a holiday or the non-Monday date is legally required.
1. The Candidate Experience Specialist will check if there is a probationary period.
    - Go to [Probationary Periods for Team Members Employed by a PEO]({{< ref "contracts-probation-periods#probation-periods-of-team-members-employed-through-a-peo-or-an-entity" >}}) and check the candidate's country.
    - Select the duration of the probationary period (if any) in the "Offer Details" dropdown. If there isn't one, select "N/A" in that field.
1. The Candidate Experience Specialist will check if the contract is indefinite or fixed.
    - If the contract is definite, select "Indefinite" from the dropdown in "Offer Details".
    - If the contract is fixed, select "Fixed Contract" from the dropdown in "Offer Details" and enter the end date under "End Date".
1. Once additional details are obtained, update the offer details to reflect all information. The CES should be the signatory.
1. Generate "PEO New Hire Template" in Offer Documents to Send through DocuSign
1. Choose template *Offer through DocuSign -Global Upside*
    -To User, Self (CES)
    -Sign and complete
1. Download the completed Statement of Work in PDF form to upload it into Egnyte.
    -Make sure the downloaded file is titled with new hire's full name
1. Once in Egnyte, navigate to *"/Shared/GPS/Active Clients/GitLab/IN/HR/Employee Master/Client Upload/New Employee Information"*
1. Click *Upload* to place new hire's statement of work in this folder
1. Inform the Global Upside team (gitlabHR@globalpeoservices.com) of any new hires by sending email template *Email to Global Upside* under "Email the Team" in Greenhouse to let them know that a new SOW was uploaded into Egnyte and the employee's name.
1. The Candidate Experience Specialist should add the candidate to the [PEO Tracking Sheet](https://docs.google.com/spreadsheets/d/1gSOVTJ1Yv-YsSaliJwKVf-1H0vBZXxb5NWFiqCwT-uo/edit#gid=0) and keep track of communication between GitLab.
1. Once Global Upside has drafted up the contract, they will place it in Egnyte and email the CES to review and approve.
    -CES should double-check that the contract reflects all the correct information that we sent to them.
1. Once the contract is signed by the new hire, Global Upside will notify the CES.
1. Proceed with marking them as hired in Greenhouse, adjusting the 'Accepted' date to match the 'Sent' date, sending the welcome email, and making sure all other candidates have been rejected prior to marking as hired and closing the req.

## Remote.com

GitLab has partnered with [Remote.com](https://remote.com/) to hire in Brazil, Denmark, Switzerland, Italy, and Hungary. The actual employment contracts will be sent and issued by Remote and are in accordance with local labor law.  The offer details will be provided to Remote by GitLab's hiring team.

To create the contract:

1. Offer is made by the recruiter per the [hiring process](/handbook/hiring).
1. If the Nationality field is not filled out and cannot be found in the Reference Check form, CES sends "Contract Info Request-Global Upside" email to the new hire to collect additional details.
    - Click "Email CANDIDATE NAME"
    - Select "Contract Info Request-Remote.com" from dropdown.
    - CC Recruiter
    - Click "Send Email"
1. Ensure the start date is on a Monday, unless Monday is a holiday or the non-Monday date is legally required.
1. The Candidate Experience Specialist will check if there is a probationary period.
    - Go to [Probationary Periods for Team Members Employed by a PEO]({{< ref "contracts-probation-periods#probation-periods-of-team-members-employed-through-a-peo-or-an-entity" >}}) and check the candidate's country.
    - Select the duration of the probationary period (if any) in the "Offer Details" dropdown. If there isn't one, select "N/A" in that field.
1. The Candidate Experience Specialist will check if the contract is indefinite or fixed.
    - If the contract is indefinite, select "Indefinite" from the dropdown in "Offer Details".
    - If the contract is fixed, select "Fixed Contract" from the dropdown in "Offer Details" and enter the end date under "End Date".
1. The CES will change the signatory to themselves to stage the offer for their signature.
1. Once the additional information is received, The Candidate Experience Specialist will generate the PEO form out of GreenHouse.
    - Click "Generate"
    - Select "PEO New Hire Template" from the dropdown
    - Click "Generate"
1. The Candidate Experience Specialist will choose template *Offer through DocuSign -Remote.com* and will copy gitlab@remote.com on the email.
1. In DocuSign, the CES will update the signing order to CES/Signatory as number 1 to sign and all other copied individuals as number 2, to receive a copy.
1. CES will send PEO template and sign once it is received in their inbox.
1. Once PEO template is signed, CES can upload candidate into the Remote.com platform (see more details instructions on how to do so, below).
1. Remote will prepare the New Employee Contract and will inform the Candidate Experience Specialist when the contract is sgined.
1. Once  CES receives confirmation that the candidate has signed the Remote.com contract (can be viewed in portal), they will continue steps as normal - send Welcome Email and [mark the candidate as hired](coordinator/#send-contract). See steps 10-12.
1. The CES will adjust the 'Accepted' date to match the 'Sent' date.

## How to add the New Hire to the Remote platform

1. Log into the [Remote](https://employ.remote.com/dashboard) platform
1. Click the onboarding tab on the left side of the page
1. Click 'add new employee' on the top right corner of the page
1. Click 'employee'
1. You be will be on the 'employment eligibility' page - fill in the candidates details and click continue
1. You will now be on the 'basic information' page - fill in the candidates details and click continue
1. You be will be on the 'contract details' page - fill in the contract details

Kindly note the following when filling in this section:

1. Contract Duration: Most contracts will be indefinite, unless specified by the Recruiter
    - Probation Period: Use the default or minimum options specified by Remote. Please utilize the [Probation Section]({{< ref "contracts-probation-periods#probation-periods-of-team-members-employed-through-a-peo-or-an-entity" >}}) of the handbook to determine probation.
    - For Mexico: When adding a team member to the Remote platform you should select 30 days as a Christmas bonus, not 15.
1. Type of employee: Full time
1. Annual Gross salary: as stated in the offer details in GH
1. Annual leave: Is usually the statutory minimum. You can also utilize the [General & Entity Specific Benefits page]({{< ref "remote-com" >}})
   - Mexico you can input 20 days
1. Is this employee approved for outside employment: No
1. Signing bonus: as stated in the offer details in GH
1. Other Bonus: Do not include guaranteed draw. If asked, please loop in Marissa. Remote does not currently have enough of an in-depth understanding of our bonus structure to be able to include this information.
1. Commission: No
1. Equity Compensation: Do not include.
1. Number of paid time off days: Select the statutory minimum recommended days as mentioned by Remote, if there is an option, select the lowest number (this should be the statutory minimum)
1. Role Description: Copy/paste the job description within the job family. Make sure you're only including the specific role they have, and you can skip the fillers at the beginning and end.
1. Training requirement: Leave blank
1. Supervisor Name: as stated in the offer details in GH
1. Experience level: There will be different versions of these choices based on the country you are selecting. Choose the one that most closely matches your position, and ask the recruiter for recommendations if you're unsure.
1. Work Address: Select Yes
1. Benefits - Select the following per country:

| Country | Benefit plan |
|---------|--------------|
| Denmark | Standard |
| Austria | None |
| Hungary | Standard |
| Mexico | Allowance |
| South Africa | Allowance |
| Luxembourg | Premium |
| Brazil | Omint Plan (should be added for you) |
| Italy | Premium |
| Switzerland | None |
| Sweden | None |

1. Life Insurance Coverage - For Mexico Hires, Please select "Life/ADD Insurance of 350 MXN (~18 USD)". For more details on benefits for team members who are contracted through Remote. Click [here]({{< ref "remote-com#brazil" >}}).
If there are any questions, these should be directed to help@remote.com.
1. Click on the benefits acknowledgement and continue
1. You be will be on the 'billing cycle' page.
1. Click on monthly billing cycle and click continue.
1. You will now be able to review all the candidate and contract details, you are able to edit them should you wish.
1. Once you have reviewed, and everything is in order, click 'invite now'.
1. Please select the option to "add this employee to a single employee plan"
1. Your candidate has been submitted successfully. You are able to see the progress on the Remote homepage.

## How to add the New Hire to the Papaya platform

1. Log into the [Papaya](https://gitlab.papayaglobal.com/backoffice/org/1826/dashboard) platform
1. Click the 'add worker' tab on the top right side of the page
1. Click 'create new request' under the EOR worker block
1. Select the candidates country on the drop down
1. Click next
1. You be will be on the 'worker details' page - fill in the candidates details
1. Please ignore the following: Company ID
1. Click next
1. You will now be on the 'employment terms' page - fill in the details
1. Please ignore the following: expected end date in the case of an indefinite contract & the organizational attributes
1. Click continue
1. You will be on the 'contract compensation' page - fill in the contract details
1. Please ignore the following: allowances & miscellaneous
1. Under contract terms, select the mandatory requirements by local law tabs for all
1. Click next
1. You will be on the 'initial employment terms letter' page - fill in the contract details
1. Should papaya send the candidate the initial employment terms letter prior to the contract - click 'yes'
1. Click next
1. You will now be able to review all the candidate and contract details, you are able to edit them should you wish.
1. Select all the term of the consent clause
1. When should papaya contact the worker - select 'as soon as possible'
1. Click submit
1. Your candidate has been submitted successfully. You will be redirected to the papaya homepage
1. Once you submit the candidate, an alert will be sent to Papaya to inform them of the new project
1. Amit Bengal - AmitBe@papayaglobal.com (Customer Success Manager at Papaya who looks after GitLab) will reach out to the CES to confirm that they have received the alert. Amit should ask for permission to contact the candidate directly - please confirm this ASAP. Papaya will validate the information submitted into the platform and reach out to CES or the candidate should there be any immediate questions regarding the contract information shared
1. An offer overview (Offer Template) with the basic offer details will be sent to CES to approve (resembles our PEO Template) - once approved, a welcome email will be sent to the candidate - accompanied by the offer template. The Welcome Email will introduce the PEO to the candidate.
1. At this stage, the candidate is also requested to verify their information and provide documents needed to complete the request.
1. Once the candidate has verified their information and provided the required documents, Papaya sends the offer draft to the Local Team (a contact person in the candidates country) to review the contract against the in-country laws - Duration: 48 hours
1. The Local Team then sends the offer to Papaya's Legal Team once they have done their part. The Legal Team then approves the final offer. - Duration: 24 hours
1. The approved offer will then be uploaded onto the Papaya Platform under hidden documents. CES will be informed to go and approve the final draft before it can be issued to the candidate.
1. Should there be any questions or amendments that need to be made, depending on their complexity, they could have to be directed back to the Local Team (48 hours), then back to the Legal Team  (24 hours), before making its way back to us again.
1. Once CES approves the offer, Papaya will extend it to the candidate.
1. Should there be any questions or amendments that need to be made, depending on their complexity, they could have to be directed to the Local Team (48 hours), then back to the Legal Team (24 hours), before making its way back to us again for reapproval, then issued to the candidate again.
1. Once the candidate accepts, Papaya will inform us.

## Advance Funds process for locations GitLab can not order laptops

There are a handful of countries, listed [here](/handbook/it/end-user-services/onboarding-access-requests/#new-hire-laptop-ordering-process) where new hires will need to procure their own laptop before their start date.

1. The CES team member will identify that the new hire is located in one of these countries, and will send the New Hire Welcome Email - Brazil, Costa Rica, Chile template.
1. This email uses a different Google form than the regular Welcome Email. The new hire will be presented with two options and be asked to select their preference:
    - Purchase and expense for reimbursement through NAVAN on their first day at GitLab
    - Request advanced funds to self-procure
1. IT will receive an issue in their [IT Equipment Order Processing](https://gitlab.com/gitlab-com/it/end-user-services/issues/it-equipment-order-processing/-/issues/?sort=closed_at_desc&state=opened&first_page_size=100) desk with the new hire's selection. If the candidate has requested advanced funds, IT will then tag AP within the issue and provide approval for the laptop purchase. AP will gather the new hire's banking details and release the funds.

**GitLab and New Hire:**

1. Once the verbal offer has been made by the recruiter [hiring process](/handbook/hiring) complete the [Template-GitLab China Employee Offer letter](https://docs.google.com/document/d/1c69dG9TuAB0MgiKj_gLDuHTHpzjocvEAm2okUOKqRIs/edit#) as per How to use this page to prepare a contract.
1. CIIC require a Chinese version of a [Letter of Employment Intent](https://docs.google.com/document/d/1BEHvveYUJkS1xwyd037P_zzitOSotF_68Kbi-c7k8hY/edit).
1. Complete the Letter of Intents with all of the information required/known. This should be completed in [English](https://docs.google.com/document/d/1b3fHqHzXhhoJeskUN-Km9vTLeuszysWPj8PlvXm45ug/edit) first then translated into Chinese using Google Translate.
1. Once this has been done send the GitLab (Chinese & English) versions of the Letter of Employment Intent to the new hire for their review, completion and signature using DocuSign. Ensure that Peopleops and CIIC are copied.
1. Once everything has been signed, print and FedEx the Chinese and English Letter of Intents to CIIC. The address can be found in the PEO China folder > China Employment Options > CIIC in the Google Drive.
1. The Candidate Experience Specialist should add the candidate to the [PEO Tracking Sheet](https://docs.google.com/spreadsheets/d/1gSOVTJ1Yv-YsSaliJwKVf-1H0vBZXxb5NWFiqCwT-uo/edit#gid=0) and keep track of communication between GitLab.
1. The PEO will inform the Candidate Experience Specialist when the contract is signed.
1. The Candidate Experience Specialist will mark the candidate as hired.
1. The CES will adjust the 'Accepted' date to match the 'Sent' date.
1. The Candidate Experience Specialist will now [mark the candidate as hired](coordinator/#send-contract). See steps 10-12.

**GitLab & CIIC:**

1. GitLab has a Secondment Agreement in place with CIIC, this may need to be updated but CIIC will confirm.
1. Once CIIC have received the documents they will prepare a payment notice and send this to GitLab (peopleops) for payment. This must be paid upfront and may need CFO approval.
1. After CIIC receive payment they will reach out to the new hire to complete a Labor Contract.

**CIIC & New Hire**

Once the Labor Contract has been signed by both CIIC and the new hire the individual can now commence their work with GitLab.

## Employment Agreements for GitLab team members in Germany

According to the revised German Contract process, contracts require wet signatures, which means that besides contracts being e-signed in Docusign, GitLab also requires physical copies of the contract to be signed by both parties.

To initiate the process to submit the contract for e-signatures via DocuSign:

1. CES will ensure that the start date is either a Monday, or the 1st or 16th of the month
1. CES will send the German Contract Step 1 template email via Greenhouse
1. The offer can be sent through Greenhouse and DocuSign. Please use the signatories listed against the German Entity as per this [table](/handbook/hiring/talent-acquisition-framework/ces-contract-processes/#entity-contract-signatories)]
1. Download a copy of the unsigned contract onto your desktop from Greenhouse.
1. Initiate the background check. Please use the Germany Package from the drop down in Sterling.

**Once the Contract has been e-signed via DocuSign by both parties, please follow the steps below on how to send the contract in PDF format to the German counsel**

Please follow the outlined steps below before sending the unsigned copy of the Contract to the Counsel:

- Open the saved unsigned contract in Google Drive, remove GitLab signatory from the below fields -
    1. **Summary Key of Terms** - Delete the GitLab Signatory's name and leave the field blank.
    1. **Scroll down to the end of the contract** - replace Signatory's name with "GitLab Signatory". Save the contract as a PDF format.
- To send the contract out to the German Counsel, CES can follow the below email structure through Gmail:
  - **To (recipients)**-  Thomas.Leister@osborneclarke.com & julia.bauer@osborneclarke.com
  - **Subject line**  : Please Send Physical Contract for "Name of the new hire"
  - **Body of the email** : Expand the Text expander snippet "GCtogermancounsel"
  - **Attachment** : CES to attach the unsigned PDF contract
- In order to inform the candidate regarding the physical copies sent out via post, go to the Greenhouse profile of the ​​candidate, using the "email the "candidate name" function, select the template "German Contract already sent to counsel".
- A welcome email should be sent to the candidate, and they should be marked as hired as per the normal hiring process.
- Once the candidate has confirmed that they have received the physical contract in mail. CES will send the email template "German Contract step 2" to the candidate and close out the issue.

## Employment Agreements for GitLab team members in Japan

GitLab has an entity in Japan (GitLab GK) and use the GitLab GK contracts in this location. All team members in this location are employees.

Always ensure the start date is on a Monday, unless Monday is a holiday or the non-Monday date is legally required.

## Intern Employment Contracts

GitLab participates in hiring interns within the INC entity as well as the Code2College program. Code2College is the FIRST and ONLY program that places high school students into paid, technical internships.

The Intern contract template will be used for both C2C interns and all other interns hired into GitLab. However there are some different necessary steps when processing a C2C intern. Processes are described below.

1. When the offer decision is made, Emerging Talent Coordinator/Recruiter will create offer in GH profile and request approvals as normal.
1. Once approved, CES to send the contract using the "INC Intern" template in GH. Some important details needed in the offer details will be the hourly rate of pay and the end date of the contract (since this is not an indefinite contract). Please ensure these details are in the offer before generating.
1. After the offer is sent, CES will initiate the background check by selecting the Comprehensive Criminal Check with Employment. **IMPORTANT NOTE - If this is a C2C (Code2College) intern - you will only need to select the Comprehensive Criminal Check in Sterling. Employment check is not needed as most C2C interns will be minors.**
1. Because most interns from C2C are minors, at the time the BGC is initiated, CES will also need to send the [Parental Consent Form](https://docs.google.com/document/d/1J0xundRL___Hhg0zNkt7KTMMEgTv63U5rseqTlmv8ok/edit) to the interns guardian.

   - This form can be send via DocuSign
   - Please add appropriate tokens
   - Please set up distribution as follows (guardian email can be recieved from Emerging Talent Coordinator):
      1. Guardian - Needs to sign
      1. Emerging Talent Coordinator - receives a copy

1. Once the offers are signed by the candidate, CES will send the GitLab Inc Intern Welcome Email. **Note: GitLab will provide laptops to these interns. The Welcome Email asks them to fill out form ASAP**
1. Once the req is cleared, CES can mark the Intern as hired.
1. CES will ping People Connect in the #peopleops-alerts slack channel to let them know they just hired in an Intern. **please indicate if they are C2C in your messaging to them**
1. Once Intern is hired into the system - they will move to the responsibility of People Connect who will create onboarding issues and communicate information about the TaNewKi call.
1. If you are notified that the C2C intern requires a "youth work permit", please send form over to People Connect. They will be required to fill out the "employer" portion and submit to the intern/guardians.

## Employment Agreements for GitLab team members located everywhere else (IT BV contractor agreements)

1. Review the [Hiring Status](/handbook/people-group/employment-solutions#country-hiring-guidelines) of the location you are working with. If the location has not been evaluated yet, we issue a IT BV contractor agreement.
1. If the candidate would like to use their own entity for the contractor agreement update the offer details with the Contractor Name and Address. You will use the IT BV Contractor Agreement - C2C in these cases.
1. Generate IT BV Contractor Agreement - Independent or the IT BV Contractor Agreement - C2C
1. Select Send with DocuSign
1. Select the "Offer through DocuSign-IT BV" email template
1. Update the "To" field to include the GitLab signatory and include the hiring manager in CC field
1. Select Preview on DocuSign
1. Once in DocuSign, update the signing order as you would with other contracts and hit send

## Adding Relocation Verbiage to Entity Contracts

1. Candidate Experience Specialist will ensure that there is verbiage clearly stating the terms of the compensation changes for relocation after the new hire's start date.
1. CES will ping the Total Rewards team in the Approval Notes.
    - Navigate to the bottom of the candidate's GH profile
    - See "Approval Notes"
    - Click "Leave a Note"
    - Tag Brittany Rohde in a note to confirm that both compensation values have been approved
    - Tag the Recruiter as CC
1. Once Total Rewards has confirmed both have been reviewed, generate the appropriate contract
1. Download the Word version of the contract and upload into Google Drive for editing
    - Navigate to Google Drive
    - Click "New" in the upper corner of the left toolbar
    - Select "File Upload"
    - Select the contract
1. Add lines at the top of the document for categories to include Compensation for the relocation
    - Example for relocation from ID to CA:
        - CA Compensation: $ USD
        - ID Compensation: $ USD
1. Update Section 10 Location verbiage:
    - Original
        - 10. Location. Your employment with GitLab is conditioned upon your permanent legal residence being near Boise, ID. If your permanent legal residence changes from that location you must notify the Company prior to any such changes. Changes to your permanent legal residence could result in a change to your compensation, benefits, and in some circumstances, termination of your employment.
    - Updated
        - 10. Location. Your employment with GitLab is conditioned upon your permanent legal residence being near Boise, ID and you've disclosed a planned move to San Francisco, CA on or around January 1st, 2021. If your permanent legal residence changes from those locations you must notify the Company prior to any such changes. Changes to your permanent legal residence could result in a change to your compensation, benefits, and in some circumstances, termination of your employment.
1. Delete out all Tokens
1. Save and download the contract
1. Upload in GH by selecting "Upload Replacement"
1. Ping the `Contracts-to-sign` channel in Slack and let the recruiter know that you are sending a contract staged for a future relocation
1. Stage contract as normal
1. Add tokens back in after changing signing order
1. Send
