---
title: "Executive Search"
description: "This page provides an overview on the executive search team and process"
---

## Team Mission

The executive search team is responsible for leading the talent acquisition process for director and above leadership positions across GitLab.

## Contact Us

<i class="fa-brands fa-slack"></i> [#executive-search](https://gitlab.slack.com/archives/C052DPP03E0) on Slack (GitLab Team Members only)

## Team Members

- Rich Kahn - Director, Executive Search
- Sruthy Menon - Senior Candidate Experience Specialist

## Executive Search DRIs

During an executive search process, it is imperative that the roles and responsibilities are defined upfront to ensure a positive process and outcome.

For executive level searches, we have a Talent DRI and Hiring DRI.

- Talent DRI: member of the talent acquisition team assigned to lead the search
- Hiring DRI: hiring manager

**Talent DRI Responsibilities**

- Organizes intake meeting
- Defines the core search group, including external partners, if necessary
- Leads all calls, partners with EBA to the Hiring DRI to ensure correct group and attendance
- Defines interview panel and associated competencies
- Ensures interview process is followed and feedback is documented
- Lead for all steps in the recruitment process, including sourcing strategy, candidate engagement, candidate screening, next steps, references, offer negotiation and approvals. These responsibilities may vary if an external search vendor is engaged.

**Hiring DRI Responsibilities**

- Attends intake meeting and approves of direction taken at intake meeting
- Approves list of core group
- Attends all search team calls
- Approves interview panel and associated competencies
- Provides feedback and collaborates with the Talent DRI to move the process forward
- Delegates to Talent DRI to run effective, efficient process as outlined

## Role Identification and Assignment

**Identification of Opportunity**

The Director, Executive Search will be made aware of a job opening in one of two ways:

- Net New Planned Headcount: The role will be defined in the headcount plan received from finance, which includes a target start date.
- Backfill Headcount: The PBP team will make TA leadership aware of the backfill. The Director, Executive Search will then be responsible for confirming headcount approval and target start date with finance.

No role should be assigned to a Talent DRI before headcount approval has been confirmed with finance.

**Role Assignment**

After the role is identified and headcount approval is confirmed, The Director, Executive Search will assign a Talent DRI. The Talent DRI assigned to lead the search will be chosen based on capacity, level of role and functional alignment.

If capacity on the executive search team is lacking, a senior recruiter with functional expertise may be selected as the Talent DRI in close partnership with the Director, Executive Search. Senior TA leadership may also be assigned as the Talent DRI in specific circumstances.

Based on the target start date, the Talent DRI will work backwards by estimating time to fill and determine when to start the recruiting process.

At this stage, The Talent DRI is also responsible for [creating the Greenhouse req]({{< ref "req-creation#requisition-creation-process" >}}).

## Role Qualification and Intake

**Role Qualification and Preparation**

As part of the role qualification process, the Talent DRI and Hiring DRI will:

- Confirm the job family is up to date and accurate
- Select the core search group
- Select the interview panel and associated competencies
- Decide which recruiting strategy is best suited for the open role

In most cases, the role qualification and preparation can be done async. However, in certain situations where an external vendor is involved, the Talent DRI and Hiring DRI may choose to connect in a sync to discuss.

The Talent DRI will then take the lead on next steps in the recruitment process. In the event that a vendor is required (see decision parameters below), the Talent DRI will lead the process. Read more about this in External Vendor Selection(#external-vendors).

**Intake Meeting**

The intake meeting will be subsequently scheduled between the Talent DRI, external search partner (if applicable) Hiring DRI and core search group. EBAs to the Hiring DRI and executive shadows may also be in attendance at the Hiring DRI's discretion.

Ahead of the intake meeting, the Talent DRI will conduct baseline research, to include:

- Talent Insights Reports
- DIB data and directions
- Sample profiles for candidate calibration

The Talent DRI is responsible for generating an intake meeting agenda and driving the meeting. The Director, Executive Search will maintain a meeting intake template to be shared with the Talent DRI.

## External Vendors

**External Vendor Selection**

It may be necessary for GitLab to engage a recruiting/sourcing partner (vendor) for certain executive level searches. It is the responsibility of the Director, Executive Search to maintain a list of approved vendors and work with the Talent DRI and Hiring DRI to select an appropriate partner for the search.

**Criteria for External Vendor Selection**

Engagement of an external executive recruitment vendor can be considered if any of the following is true:

1. The talent pool is best addressed by search firm networks rather than our internal executive search team. Typically this applies to C-Level (E-Group) searches, but may apply elsewhere on occasion.
1. Search is director level or above AND:
    1. Search is not on track after the Hiring DRI spent a minimum of four weeks sourcing a broad diverse set of candidates in collaboration with the executive search team, OR
    1. Search is not on track after the Hiring DRI spent a minimum of two weeks sourcing a broad diverse set of candidates AND there is no internal executive search team capacity to manage the search
1. Search is in a specific geography where GitLab is lacking necessary in-house expertise
1. There is a need for additional confidentiality that will be best handled by an outside party.

**Budget for External Vendors**

If the business chooses to use an external recruitment vendor for an executive search, the expense will come out of their budget.

**Process for External Vendor Engagement**

Once a role has been identified as eligible for an external search vendor and budget has been secured, the process is:

1. The executive search team will obtain vendor references where necessary or applicable. The Hiring DRI should not engage any vendor directly prior to this step.
1. The Director, Executive Search submits the budget request to the VP, Talent and Engagement and VP, Finance for approval.
1. The Talent DRI engages the vendor and involves procurement in the contract discussion. No work should be completed by the vendor before we have a signed agreement.

**Decision Framework for New External Vendors**

If a hiring manager wishes to use an external executive search vendor that is not currently on our approved vendor list, the process is:

1. If after discussion between the Director, Executive Search, Talent DRI and Hiring DRI, it is determined that there is no suitable approved vendor available for the search, a new vendor may be considered.
1. The Director, Executive Search will set up an informational call with the potential vendor, Talent DRI and Hiring DRI to discuss the search and assess the vendor's ability to partner and deliver.
1. If the vendor is chosen to move forward, the Director, Executive Search engages the vendor and involves procurement in the contract discussion. No work should be completed by the vendor before we have a signed agreement.

## Communication Cadences

**Slack Channels**

At the onset of a search, The Talent DRI will set up two Slack channels:

- Core search channel: (#search-job-title). This channel will be the SSoT and communications vehicle for the search and will include the core search group.
- Panel search channel: (#panel-job-title). This channel will be for communication with the interview panel and broader stakeholder group that may include:
  - Core search group
  - Interview panel
  - EBA group
  - CES
  - People Business Partner

**Progress Calls**

- The Talent DRI will recommend communication cadences to the Hiring DRI. After the intake call, it is common to allow the recruiting process 2-3 weeks head-start prior to the first progress call.
- Progress calls are normally weekly (unless otherwise planned) and have the core group in attendance.
  - During the progress calls, the core group will cover:
    - Longlist and shortlist summaries (prospect candidate lists)
    - Interview feedback
    - Next steps for candidates
    - Any special timeline requirements of candidates, if applicable
- In addition, the Talent DRI is also responsible for providing relevant async updates to the search team via Slack channels

**Coordination Work Between Progress Calls**

The Talent DRI (in partnership with CES and the EBA to the hiring manager) will take the lead on any coordination necessary between arranged call cadences. SLA for next steps to be actioned between calls is 24 hours.

**Agenda Maintenance and Progress Updates**

The Talent DRI (in partnership with the vendor) is responsible for maintaining the progress call agendas and surfacing any urgent requirements via email and Slack to the relevant parties when necessary.

**Feedback Calls**

During the final stages of an interview process, it may be necessary for the core search team to meet and discuss feedback in order to make a decision. These calls will be coordinated by the Talent DRI and EBA to the Hiring DRI. The Talent DRI will gather all feedback ahead of the feedback calls and organize an agenda to facilitate the discussion.

## Confidential Searches

Certain executive searches may have the need for additional confidentiality. These may include:

- E-Group level searches
- Strategic roles
- Confidential backfills

These roles will be marked as confidential when opened in Greenhouse, and will be excluded from standard reporting. Special care will be given to limit access permissions to only essential stakeholders.

In certain circumstances when a role is highly confidential, the Hiring DRI and Talent DRI may choose to run the process outside of Greenhouse.

## Interview Process

To ensure a consistent and in-depth process, we employ competency-based interviewing for our executive level hiring. These competencies and the associated interview group have been pre-defined in the initial call.

**Interview Process Overview**

- Screening
- Hiring DRI Interview
- Panel Interview Series
- Values and Leadership Interview
- Board Interviews
- Additional Meetings
- References and Background Check
- Offer Preparation
- Offer Approval
- Offer Delivery

**Interview Stage Details**

**Screening**

A screening call with the candidate will be conducted via Zoom by the Talent DRI or external search partner.

- Within 24 hours of the interview, the Talent DRI provides:
  - Candidate rating (Strong Yes, Yes or No), as well as shorthand feedback in the designated feedback repo.
- The Talent DRI or external search partner will tag the Hiring DRI in the search Slack channel with a link to feedback and a recommendation on next steps. The Hiring DRI will confirm next steps before the Talent DRI moves the process forward.

**Hiring DRI Interview**

- Interview between Hiring DRI and the candidate. The purpose of this interview is to:
  - Discuss the role requirements and responsibilities
  - Discuss the candidate's background
  - Share GitLab pitch and positioning
  - Assess GitLab values fit
- Within 24 hours of the interview, the Hiring DRI provides:
  - Candidate rating (Strong Yes, Yes or No), as well as shorthand feedback in designated feedback repo.
- Within 24 hours of Hiring DRI feedback being received, the Talent DRI will action one of the following next steps:
  - Schedule panel interview series
  - Reject candidate

**Values and Leadership Interview**

- The People Business Partner or CPO will conduct a values and leadership Interview.
- This interview will be scheduled in parallel to the panel interview series
- Within 24 hours of the interview, the values and leadership interviewer provides:
  - Candidate rating (Strong Yes, Yes or No), as well as shorthand feedback in designated feedback repo.

**Panel Interview Series**

- The panel interview series will be scheduled in parallel to the values and leadership interview
- The Talent DRI and Hiring DRI collaborate to assign focus areas upfront, which are to be shared in the (#panel-job-title) Slack channel using this template.
- Within 24 hours of the interview, the panel interviewer provides:
  - Candidate rating (Strong Yes, Yes or No), as well as shorthand feedback in designated feedback repo.
- Within 24 hours of the values and leadership and panel interview series concluding, the Talent DRI will tag the Hiring DRI in the search Slack channel with a summary of feedback and a recommendation on next steps. The Hiring DRI will confirm next steps before the Talent DRI moves the process forward.

**Board Interviews**

For E-Group and other senior level searches, meeting board members may be necessary.

- Post completion of the above, board interviews will then be scheduled.
- The Talent DRI will work with the Hiring DRI, EBA and CES team to schedule board interviews.
- The Talent DRI is responsible for briefing board members with a written briefing incorporating all feedback and recommendations.
- The Talent DRI is responsible for sharing an interview notes document with the board member, following the process in "Interview Documentation" above.
- Within 24 hours of the interview, the board interviewer provides:
  - Candidate rating (Strong Yes, Yes or No), as well as shorthand feedback in designated feedback repo.
- Within 24 hours of the board interviews concluding, the Talent DRI will tag the Hiring DRI in the search Slack channel with a summary of feedback and a recommendation on next steps. The Hiring DRI will confirm next steps before the Talent DRI moves the process forward.

**Additional Meetings**

The interview process should be defined at the onset of the search. However, there may be a need for exceptions to this process. There may be an occasional need for an additional meeting to further assess a specific competency, or to address additional questions from the candidate.

The Talent DRI and Hiring DRI will discuss any additional meetings required, and work with the CES and EBA teams to schedule.

**Candidate Rejection**

After each stage in the interview process, the Talent DRI and Hiring DRI will review feedback and decide on next steps. A candidate can be notified of the decision to not move forward with further steps during any point in the hiring process. The Talent DRI is responsible for communicating the decision to the candidate.

**References**

References will be conducted in accordance with GitLab's standard policies documented [here]({{< ref "hiring-manager#step-7hm-complete-references" >}})

**Background Check**

Background check will be conducted in accordance with GitLab's standard policies documented [here]({{< ref "people-policies#background-screenings" >}})

**Offer Preparation**

Once a hiring decision has been made, the Talent DRI will work together with Hiring DRI, Total Rewards, external compensation partner and People Business Partners to construct the offer.

If necessary, the Talent DRI will create a Slack channel (#offer-job-title) to discuss the offer with this group.

**Offer Approvals**

In addition to the normal [offer approval process]({{< ref "offer-process#offer-approvals" >}}), Director and above offers require approval from the e-group member over the division.

**Offer Delivery**

The offer delivery mechanism will vary by situation, and may be completed by the Talent DRI, Sr. People Leadership, external vendor or Hiring DRI.

## Diversity, Inclusion and Belonging

The Executive Search Team has made a committment to instill inclusive processes in everything we do. In FY24, we documented best practices for conducting our searches in an equitable manner. Our DIB initiatives can be found [here](https://docs.google.com/document/d/1i3gsXskARrJeYaTZsdQyEiKMR-q4_uSwJ64X4HVRJiE/edit) (internal only)
