---
title: "Internal Hiring Process"
description: "This page discusses the Internal Hiring Process"
---

## Team Member Responsibilities

- Meet with your current manager to discuss the internal opportunity you'd like to pursue prior to submitting your application.
- Ensure you have met your department specific eligibility requirements:
  - Guidelines for performance eligibility:
    - Team members who are assessed at a Performing or Exceeding Performance level during Talent Assessment are eligible to be considered for another role
    - Team members whose Performance is assessed as Developing or are actively undergoing written performance management, may not be eligible. These situations require manager and/or PBP approval to proceed.
    - Team members that have not had a Talent Assessment require manager and/or PBP approval to proceed
  - Time in role eligibility will be 6 months in current role. Exceptions to this:
    - Job Family specialty changes
    - Business Impact  (revenue-dependencies, interim role to perm)
    - Business driven transfers (example of realignments)
    - SDR 12 months in role
- Important things to consider when applying:
   1. Ensure the opportunity aligns with your career goals here at GitLab
   1. Ensure you have taken a look at the compensation calculator and assessed if the compensation range for the new role is suitable for you. We encourage you to bring any questions around compensation and leveling to the recruiter and/or hiring manager for the open role you are interested in and applying for.
   1. While you may apply to a role with a higher job grade and title, there may be situations (moving from one job family to another for example) where the higher job grade may not align with your current competencies and skillset that is required for the role. If the hiring team does choose to move forward with an offer, in these cases, it's likely a higher job grade and title will not be given.
- To apply, visit the [internal job openings](https://gitlab.greenhouse.io/internal_job_board). If you are interested in keeping an eye on openings that are posted you can also join the #newvacancy channel in Slack.
- For any questions you have about internal hiring or questions specific to your individual interview process you can either:
  - Create an [issue](https://gitlab.com/gitlab-com/people-group/internal-hiring/-/issues?sort=created_date&state=opened) in the [hiring process repo](https://gitlab.com/gitlab-com/people-group/internal-hiring).
  - If a Recruiter has reached out to you, please feel free to reach out directly to them on status updates of your specific process.

## Recruiter Responsibilities

- Recruiter will post a job internally following the [req creation process]({{< ref "req-creation" >}}), and the [transfer, promotion guidelines]({{< ref "promotions-transfers#greenhouse" >}}).
- Recruiters will set up notifications for internal applications, to ensure they are notified when internal candidates apply to the role
- Once the Recruiter receives an internal team members application, they will proceed with the following:
  - Review the application as you would with an external candidate and determine if they are qualified for the role. If they are not qualified, please ensure you communicate the decision via email (or slack) and provide clear feedback as to why they are not qualified, and add the hiring manager so they are looped in and can add additional feedback if appropriate.
  - Ensure the internal team members GitLab email is associated with their application. If it is not, then update it as such and notify the team member of the change in email address to ensure all the communication throughout the interview process is directed here.
  - If the internal candidate is considered qualified for the role, reach out to People Connect by submitting a request via [HelpLab](https://helplab.gitlab.systems/esc?id=emp_taxonomy_topic&topic_id=2e8c3f81478c069067429ee0026d4380).
    - If they have additional questions, they may reach out to the team member's current PBP.
- For promotions through the internal mobility process (upward movement from one job grade to another), tag the department specific People Business Partner in the notes section of Greenhouse to ensure they are aligned before moving forward with the offer. Additionally, confirm that the offer has been approved by the skip-level leader of the new role.
- Once the Recruiter has confirmed the eligibility status with People Connect, if eligibile, the Recruiter will reach out to the team member to introduce themselves and set expectations around the internal hiring process (which includes ensuring they have notified their current manager). If a team member is not eligible, the Recruiter will send the appropriate decline email template.
- Recruiter will then continue the process as described in the [Talent Acquisition Process Framework]({{< ref "talent-acquisition-framework" >}}) for all candidates. Recruiter will use identified templates in Greenhouse to communicate with candidates, current managers and hiring managers throughout the internal hiring process.
- Once it is confirmed that the internal candidate is moving to the offer stage, the Recruiter will connect the team member's current manager and potential new manager via Slack to:
  - Give formal notice that an offer is being created for the team member.
  - At the same time you should tag the relevant [People Business Partner](/handbook/people-group/people-business-partners/#people-business-partner-alignments) (both the departing and receiving PBP) in a note on Greenhouse so they are notified, can track the internal move and take any necessary action.
  - Facilitate a discussion around a transition date that works for both parties. Please note that TA's involvement is to facilitate this conversation and is not the decision maker. Ultimately, a transition date is something that should be agreed upon between a current manager and hiring manager. A finalized start date will be needed as TA submits an offer for approvals.
  - Some suggestions for transition timelines include:
    - Aiming for between 4-6 weeks for an official transition date to ensure the team with the backfill has lead time on filling the position
    - A one month 50/50 split between teams to ease into a full time transition. For any moves from Sales Development, please be aware the team requests a 45 day transition period from the date of a verbal offer
- Please note the following about this process:
  - TA will only start an official backfill once the role has been approved via the [Backfill Approval process](/handbook/hiring/talent-acquisition-framework/req-creation/#backfill-approvals)
  - It is the [Team Member's responsibility](/handbook/hiring/talent-acquisition-framework/internal-hiring-process/#team-member-responsibilities) to meet with their current manager to discuss the internal opportunity they’d like to pursue prior to submitting their application. Offers at the end of an internal interview process should not come as a surprise to current managers.
  - TA will not discuss any compensation changes with the team member's current manager.
  - TA will not provide updates on interview feedback or progress to a team member's current manager. This should be discussed between managers and team members during 1:1s.

### Template for the Recruiter's slack message

Hi XX and XX,

As you are both aware, XXX has been interviewing for the XXX role and the team is ready to move forward with an offer! I wanted to connect you both as their  current and future managers to cover a few items as we start the offer process:

- What transition date works best for the both of you? The GitLab standard recommendation is between 4-6 weeks (OR 45 days for Sales Development). Please see our handbook page [here](/handbook/people-group/promotions-transfers/#internal-transfer-start-date) for some suggestions on transition timelines.
- Please discuss any outstanding items that may require XX to stay in their current role longer than 6 weeks as we want to ensure they'll be able to have a smooth transition between roles.
- I'd recommend connecting live if you can, but if not, async works and we can use this channel. If you do connect live, please  confirm with me once you've done so and agreed on a start date. Once I have that information, I will proceed with the formal offer approvals.  Once they accept the offer (and sign the Job Change Letter), we will be able to move forward with the [Backfill Approval process](/handbook/hiring/talent-acquisition-framework/req-creation/#backfill-approvals). Thanks!

- If the hiring team would like to move forward with an offer, the Recruiter will align with People Connect on the team member's current compensation. The Recruiter will
  - Reach out to People Connect by submitting a request through HelpLab using the [Internal Movement](https://helplab.gitlab.systems/esc?id=sc_cat_item&sys_id=7b2f4b8d4748069067429ee0026d435f) case template. In your request details please include that you the candidate has been selected to move forward and that you require their current compensation details. People Connect will only confirm the salary details and any confirmation on equity would need to be verified by the Total Rewards team separately.
  - Within 48 hours, the People Connect team will respond and provide annual base compensation details to the Recruiter to utilize for the offer (in partnership with the hiring manager).
- Once an internal candidate verbally accepts an offer, the Recruiter will notify CES to get the Job Change Letter (JCL) to the team member.

## CES Responsibilities

- When scheduling internal team members during the internal hiring process, use the team member's Google calendar. This allows for a consistent and efficient scheduling process. Internal candidates are notified to:
  - Block off any times on their calendar when they would prefer not to interview.
  - Have working hours visible on their internal Google Calendar
- Please follow the scheduling process for executive scheduling
- Recruiters will notify CES via Greenhouse once a [Job Change Letter (JCL)]({{< ref "promotions-transfers#job-change-letter" >}}) is ready to be sent.

## People Connect Responsibilities

- People Connect will handle all eligibility checks for team members applying for an internal opportunity.
  - For eligibility checks for candidates on the People Connect team please reach out directly to the Manager of the People Connect team.
- Engage People Connect by submitting a request via [HelpLab](https://helplab.gitlab.systems/esc?id=emp_taxonomy_topic&topic_id=2e8c3f81478c069067429ee0026d4380). People Connect will notify the Recruiter that the eligibility check is completed by replying to the request submitted via HelpLab. Ensure you have met your department specific eligibility requirements:
  - Guidelines for performance eligibility:
    - Team members who are assessed at a Performing or Exceeding Performance level during Talent Assessment are eligible to be considered for another role
    - Team members whose Performance is assessed as Developing or are actively undergoing written performance management, may not be eligible. These situations require manager and/or PBP approval to proceed.
    - Team members that have not had a Talent Assessment require manager and/or PBP approval to proceed
    - Time in role eligibility will be 6 months in current role. Exceptions to this:
      - Job Family specialty changes
      - Business Impact  (revenue-dependencies, interim role to perm)
      - Business driven transfers (example of realignments)
      - SDR 12 months in role
      - SDR/BDR Team Lead 3 months in role
- For any situations where further discussion may be needed, People Connect Leads will go to the department specific [PBP](/handbook/people-group#people-business-partner-alignment-to-division).
- At the offer stage, the Recruiter will submit a request via HelpLab to attain current compensation information:
  - People Connect checks Workday for current team member base compensation.
  - People Connect will then provide annual base compensation details in the HelpLab request. The Recruiter can then utilize this information while putting an offer together (in partnership with the hiring manager).

## Current Manager Responsibilities

- Once your team member has notified you that they have applied for an internal opportunity (this should happen at the application stage) make sure to check in with them during 1:1s to see how their interviews are progressing.
- If your team member moves to the offer stage, the Recruiter will connect you with the hiring manager via Slack. Please follow the steps outlined by the Recruiter once you receive that confirmation. Until you receive that Slack from TA, the offer is not confirmed.
- Once the transition date is agreed upon, the current manager is responsible for notifying their leadership and to follow the steps outlined in the [Backfill Approval process](/handbook/hiring/talent-acquisition-framework/req-creation/#backfill-approvals) handbook page
- If the team member is not selected for the new role, the current manager should meet with the team member to discuss ongoing career development in their current role.

## Hiring Manager Responsibilities

- Hiring Managers will be notified by Recruiter when an internal team member has applied and has completed the necessary eligibility checks as mentioned above, and they will follow the process outlined in the [Talent Acquisition Process Framework]({{< ref "talent-acquisition-framework" >}}) for all candidates.
- If a team member moves to offer, the Recruiter will connect the Hiring Manager with the team member's current manager. Please follow the steps outlined by the Recruiter in their message via Slack (details above).
- Hiring Manager will be provided the candidates compensation expectations from the Recruiter (in partnership with People Connect). It is up to the hiring manager to propose a compensation aligned with budget, candidate expectations, and internal pay equality.
- If internal candidates need to be declined post interviews, it is required that the hiring manager connect with the team member via Zoom to inform them of the decision and provide constructive feedback (an outline providing feedback can be found below).

### Delivering feedback to declined candidates

At any stage a team member needs to be declined, it is up to the Recruiter and Hiring Manager to connect to determine the best approach to ensure the appropriate [feedback]({{< ref "guidance-on-feedback" >}}) is given by the hiring manager. It is important to deliver transparent and honest feedback to the candidate while remaining constructive and focusing on growth.

If the candidate has made it to the hiring manager screen or beyond, hiring managers can consider this approach:

- Condense the themes from all of the scorecards so that there is a high level, but anonymous summary of what they did well in the interview, and any opportunities for improvement
- Document your key takeaway as a hiring manager in terms of how this candidate does not have the right competencies for the position
- Document your key takeaways on what the candidate did well and should continue doing, along with improving other areas to be ready in the future
- Provide actionable, concrete steps to work on those areas
- Sync with the candidate to review these topics in a synchronous meeting

A guideline template to prepare for this conversation might look like the following:

**What went well**:

- Has good examples of making improvements to the area they were interviewing for in the past

**Opportunities for improvement**:

- In general if experience was missing (such as XYZ) when asked a question, they were not able to answer it based on any lessons/training they have taken in preparation for this role

**Key Takeaways (to be delivered synchronously)**:

- They understand the day-to-day responsibilities of this role in terms of (these job requirements), but are not yet prepared for what this looks like long-term around (these other job requirements and challenges they may face). They may be coachable in these areas and have an exceptional history with GitLab, however this position will be demanding on time which may not allow the candidate to get enough support in the role. I would recommend:
  - Specific actions this candidate can take to get more experience **at GitLab**

If you are not sure what actions they can be taking to be more qualified for your position, you may reference your role's job requirements and/or the [Job Framework](https://docs.google.com/spreadsheets/d/1FX4NBwF099uMBm7mGBtf1orIJZuHEjtiEa3jSbg9jJs/edit#gid=0) for inspiration defining concrete actions.

## Internal Hiring Process Survey

- A survey will be sent out to all team members that have made it through to the team interview stage.
- This survey will measure:
  - Expectations set
  - Recruiter interaction
  - Interviewer experience
  - Timely experience
  - Scheduling
  - Feedback (for declined candidates)
  - Overall experience rating
- Talent Acquisition's goals for this survey will be determined after the base survey data is captured.
