---
title: "Talent Acquisition Job Offer Process"
description: "The Talent Acquisition Job Offer Process provides guidance to Recruiters on how to initiate the offer process and guide a candidate through to completion."
---

There are a series of steps that are taken when preparing a job offer at GitLab to ensure there is consistency and fairness in our hiring process.

These steps outline all of the major stages that Recruiters follow in our job offer process.

## Debrief Stage

Purpose: The purpose of the 'debrief' stage is to drive towards a hire/no hire decision at the end of our interview process. Once all scorecards are submitted and interviews are complete, recruiter is to move candidate to this stage within Greenhouse

**R&D Process Specifics**

There are two specialized notes for the Engineering, Product and Security teams as a part of this process to ensure we are further optimizing for speed and asynchronous decision making given the global distribution of our interview teams.

1. When a candidate is moved to the 'debrief' stage (also known as the 'justification stage') recruiter is to kick off reference checks.
1. Recruiter to review scorecards and ensure candidate is ready for review and all [Engineering Hiring Practices](/handbook/engineering/hiring/#hiring-practices) have been met. Once confirmed, recruiter tags hiring manager in candidate profile to initate 'justification'.
1. Once a 'hire' decision has been made, there is an additional step - the justification. The justification is intended to serve as an asynchronous method to articulate the hiring decision as well as flesh out any nuances in the decision not captured in scorecards. Justifications are reviewed by offer approvers farther along in the process. A hiring manager will need to answer the following questions in the candidate's profile within Greenhouse prior to an offer preparation:

Justification Questions:

- In what specific way(s) does this candidate make the team better?
- What flags were raised during the interview process? Include any past rejections, thumbs-down ratings, or hesitancy from previous interview scorecards (but not resume reviews), as well as your reasons for being comfortable moving forward despite interviewer recommendation.
- How do we intend on setting this candidate up for success?
- Engineering specific: Does the candidate meet a simple majority of nice-to-have requirements (5 of 9) [for the specific role](https://gitlab.com/gitlab-com/www-gitlab-com/-/blob/master/sites/uncategorized/source/job-families)? (please add them to the appropriate scorecard section)

## Reference Check Stage

Once a hiring decision has been reached (note: for all teams outside of R&D) the recruiter is to start the reference check process. For R&D offers, this process is run in tandem with the 'debrief' stage (see above section).

We require references for all external candidates at offer via sending a Reference Check Form in Greenhouse. To use this form:

1. Update notifications on the job for reference check. Navigate to 'Job Setup', select 'Forms' and edit the individual reference form. Add hiring manager to notification so they can initiate the calls once references have been submitted.
1. Click the 'send' button on the location-specific form attached to the Greenhouse reference check stage.
1. Once references are submitted, your Hiring Manager will be responsible for completing reference checks.

The Reference Check Form will request references' contact details as well as candidate details that will help with a future offer. You can view completed forms in the "Application" tab.

- The address, preferred first name/nickname, preferred last name, and PIAA details will auto-populate into the candidates' details. **Any other fields, including their legal name, will not transfer outside of the form and need to be added manually**. If a candidate requests changes to their legal name, you will need to do that manually. As a reminder, middle names are not required as part of legal names.
- Fields that are entered in offers, such as BSN and Date of Birth for the Netherlands, should be added during the Offer stage by the Recruiter.
- CES will be responsible for 3-4 fields in the Reference Check form, depending on location. These include PIAA, Outside Work, TMRG calls, and NYC background check fields. CES instructions can be found [here](coordinator/#reference-check-forms).

Please note that these forms, just like an Offer in Greenhouse, are connected to the specific job you request them for. You cannot transfer forms to another job, so be sure you're hiring into that req before sending a form. If you transfer the candidate, the form **will not transfer**. If no forms are listed, please contact the Enablement team.

For more information about Reference Checks from a Hiring Manager perspective, [click here](hiring-manager/#step-7hm-complete-references).

## Background Check and Offer Stage

After the reference check stage is completed with positive references, candidate is moved to the Background Check and Offer stage

**Offer Fields**

A description on what to input into each Offer field in Greenhouse can be found below.

{{% details summary="Offer Fields and How to Use Them" %}}

- **Opening:** If you have multiple openings, you are typically choosing the one that started the earliest. You can check the approvals tab to confirm this, but you should also be able to tell based on the smallest opening number. Choosing the earliest opening helps ensure an accurate Time to Fill.
- **Start date:** New hires start on Monday, with exceptions made for public holidays for a new hires' location, Family & Friends Day, and other designated [no start dates](https://internal.gitlab.com/handbook/people-group/people-operations/people-connect/people_connect_team/) as chosen by People Connect. Additionally, internal hires with salary changes start on the 1st or 16th only (regardless of the day of the week), and those in Sales can only start on the 1st.
- **Job Title:** It's important that we use the correct title, which should not include a specialty. People Managers have "Manager, " before the rest of their title, whereas individual contributors will have the title followed by Manager. Total Rewards will review this title to ensure it matches with those in Workday. In some cases, such as Area Sales Manager, industry standards indicate that our expected conventions will not work and exceptions are made.
- **Level of Role:** Anything Director+ is considered a "Leader"
- **Division:** This field is synched with Workday and will update as new divisions are created.
- **Department:** This field is synched with Workday and will update as new divisions are created.
- **Employment Type:** Select either 'full time' or 'intern' pending role type.
- **Employment Status:** Select non-exempt for all roles with hourly wages which are paid overtime. For salaried, non-overtime eligible roles, select exempt. This information can be found in the Interlock sheet for comfirmation.
- **Hiring Manager/Hiring Manager Title:** Please provide a full title and prefered name for your hiring manager as seen in Workday.
- **Candidate City:** Choose the actual city where the candidate is located, not their locality.
- **State/Province:** This field is synched with Workday and is only applicable to the US and Canada.
- **Candidate Country:** This field is synched with Workday. If the candidate is currently living in a different country than where their contract is stating (ie they currently live in Germany and are going to be working in Netherlands), please choose the place they will be working, but let CES know so they can order a background check for the place where they are currently working. Please note that Northern Ireland is part of the United Kingdom, so ask Enablement if you're unsure of what country to list.
- **Locality:** Use [this link]({{< ref "compensation-calculator#location-factor" >}}) to help you determine your locality. More details on how to select a specific city can be found [here]({{< ref "compensation-calculator#introduction-2" >}}).
- **Comp Calc Link:** Include a link to the comp calc that you used to determine salary, or outside documentation. If you had an exception, please include a link to that documentation here.
- **Did this offer require a comp exception?** In this field, you can single or multi-select the following options: `No` comp exception required, `Yes - Base`, `Yes - Equity`, `Yes - Bonus` and/or `Yes - Sign-On`.
- **Compensation Package:** Tell us what type of offer this is---whether it has a bonus or signing bonus included. This field is used to populate information within the contract itself, so it's important that you select the correct option.
- **Currency and Annual Salary:** Candidates are paid in local currency. [Click here]({{< ref "compensation#paid-in-your-local-currency" >}}) for a current list of any locations where exceptions can be made if a candidate asks. Annual and monthly salaries should be rounded up or down to the nearest whole currency unit and should always end with a zero (e.g., "50,110.00" or "23,500.00"). Hourly rates should be rounded to the nearest quarter-currency unit (e.g., 11.25/hr.).
- **Base Salary and Equity Compa-Ratio:** These mandatory fields are used to report back to the business (except when recording equity compa-ratio for internal offers). Please use the format `0.00` meaning an offer at 85% of median would be inputted as `0.85`.
- **Are they paid yearly or hourly?:** If the salary is an annual salary, rather than an hourly rate, choose yearly.
- **Variable Bonus Type:** Choosing this field will add a designated paragraph to your candidate's contract that explains how a commission or director bonus works.
- **Variable bonus frequency:** This details whether the variable bonus shown is per year, not how it is paid out. All bonus information is calculated per year.
- **Bonus Currency & Amount:** This is calculated per year, in the same currency as their salary.
- **Signing Currency & Amount:** This is a one-time payment in the same currency as their salary.
- **Bonus/Variable Percent:** This is a bonus field that specifies what percent of the total salary is bonus. This field will not be used in contracts and is only used for Workday.
- **References Checked:** This verifies for record whether you have already completed references, or if you've told the candidate that the offer is contingent on positive references as they're still in progress.
- **Family Relationship:** Use this field to let CES know if there's a family relationship that will require a [Family Member Acknowledgement form]({{< ref "ces-contract-processes#how-to-send-a-family-member-relationship-acknowledgment" >}}).
- **Signatory Name & Signatory Title:** See [this chart]({{< ref "ces-contract-processes#entity-contract-signatories" >}}) for a list of signatories per country.
- **Clearances:** If you will be sending a Federal contract, please use these fields to designate if clearances are required in order to complete the job, and what bonus would be given if that is the case.
- **End Date:** Use for Inc (USA) contractors and interns only.
- **Entity:** [This]({{< ref "general-and-entity-benefits#entity-benefits" >}}) is a great place to see which entities are currently associated with different countries. If your candidate has a position that includes "Federal" or PubSec" in the title, or you believe they'll be working in government contracts, please discuss with your Hiring Manager if they belong in the Federal entity. If you're not sure, discuss with Legal before CES sends a contract. If the candidate is internal and is moving from a different entity to Federal, or from Federal to a different entity, please send a note to CES that the candidate requires a full contract rather than an LOA.
- **Total Rewards:** Skip these fields, Total Rewards will add them during their approval stage.
- **Candidate BSN:** These fields are for Netherlands candidates only, and answers can be found in your completed Reference Check form.
- **Nationality & Country of Citizenship:** Please fill these out for any PEO contracts. The answer will be in your completed Reference Check form.
- **Indefinite or Fixed Contract:** Netherlands hires will receive a fixed contract for their first year, as will any contractors or interns. Other than these, you can select "no" or leave this field blank.
{{% /details %}}

Note:The Reference Check Form does not automatically update a candidates' legal name, so that will need to be updated manually in the Details tab.

**Internal Candidates**: recruiter is to wait until after offer has been presented, but before the candidate is marked as hired, to merge the applicants' profiles. All other candidates should have profiles merged as early as possible. Please visit the [Enablement handbook page](https://internal.gitlab.com/handbook/people-group/talent-acquisition/enablement-team/#greenhouse-admin-instructions) for instructions.

**Constructing an Offer:**

Talent Acqusition partners with hiring managers in order to advise on best practice in constructing a total compensation package (the offer). Offers are constructed of base pay, bonus (when applicable) and equity. Base pay is based off of proficiency and performance, and recruiters will advise to take the following into account when positioning a candidate within range for the job (also known as compensation-ratio):

1. salary range
1. candidate interview performance (competency)
1. job information
1. team member parity

***Special Considerations***

1. Relocations need to be called out in Compensation Details should include originating location and salary, as well as the new location and new salary details to ensure it is communicated as part of the approval and the correct entity is selected. Ensure the People Connect team is informed about any known relocations within the first 90 days of employment. Recruiters should also communicate if the candidate is moving between countries, because CES will need to request a background check in the country where they are currently living. The CES will [initiate the background check](coordinator/#initiate-background-check) during the verbal offer stage.
1. Internal Candidates need to include inputs in the 'Approval Notes' section. Recruiter to include candidate's current level and position, as well as their compensation package. If the comp has a variable component, please include base, on target earnings (OTE), and split in this section.

**Additional Process for Engineering**
Recruiters advise and partner with hiring manager to construct compensation package for candidates. Once details are confirmed, there are a few additional steps specifically for Engineering offers starting in FY25 Q3 as follows:

1. For any offers above 0.85 compa ratio, recruiter and hiring manager will partner with TA Director and Engineering VP to confirm candidate position in range. To provide the VP with a snapshot of the proposed base and equity and how this compares to the average internal salary, the recruiter will be required to complete the [0.85+ VP Approval Template](https://docs.google.com/document/d/1VuunhZFT40d86iOPzsq9PtbobBTelCiKgZyJDepyf-M/edit) and share with the TA Director. Please make sure you add the relevant Finance Business Partner and PBP to the document for visibility. Once approved, recruiter to move through next steps - offer approval process.
    - When creating the offer in Greenhouse, add a link to the 0.85+ VP Approval Template in the `Comp Calc Link & Additional Context` section
1. Recruiter to add compa-ratio information in [Pod Squad](https://docs.google.com/spreadsheets/d/1zGKpr_JUYpW_PrDKF8FVsJtvlCGpCBaFHmUuU48zVRw/edit#gid=2102749819)
1. For any offers at or below 0.85 compa ratio, recruiter to move through next steps - offer approval process.

### Offer Approval Process

For all offers within range (ie: no exceptions) they will route through the following approval path:

1. Total Rewards
1. FP&A Partner
1. Business Leader (department head/ VP)

Total Rewards reviews:

- Compensation in range
- Ensure the bonus percentage, if applicable, matches bonus percent amount. For bonus/commission, this will be a percent of OTE. For Director level bonus, this will be a percent of base.
- Audit stock options, department, division, etc.
- Add entity, job code, job grade, sales geo differential
- Ensure the title is added to Workday.

FP&A reviews:

- Compensation package to budget

**Common approval challenges:**

- Out of Office: If the offer is stuck in the approvals chain because someone is out of office, the Recruiter to proactively reach out to the approver's manager about an appropriate temporary adjustment. Recruiter to work with Enablement team to update approval path.
- Incorrect Offer Approver: Recruiter to work with Enablement team to correct.

**Counter offer details:**

Information in the offer package for counter offers should include the following in the "Approval Notes" section:

- New offer:
- Original offer:
- Justification for adjustment:

### Verbal Job Offer

Once the offer is fully approved in Greenhouse, an offer will be verbalized to the candidate by the Recruiter.

**Please note:** Japan offers are contingent on a cleared background check. Recruiter is to let the candidate know that they would like to make an offer, but it is contingent upon their background checking coming back clear.

Offer details usually include:

- [Start Date](https://internal.gitlab.com/handbook/people-group/people-operations/people-connect/people_connect_team/) - ensure that the candidates start date is not a no-start date (unless needed for legal reasons) and is at least 10 buisness days from offer acceptance. For PEOs, partner with CES to build in appropriate leadtime.
- Job Title
- Salary
- General and specific [benefits]({{< ref "benefits" >}})
- Contract type and [employment type](/handbook/people-group/employment-solutions#team-member-types-at-gitlab)
- [Onboarding process]({{< ref "general-onboarding#onboarding-at-gitlab" >}})
- [Asynchronous communication](/handbook/company/culture/all-remote/asynchronous/)
- [Stock options](/handbook/total-rewards/stock-options/)
- [Unlimited paid-time-off]({{< ref "paid-time-off" >}})
- [Incentives]({{< ref "incentives" >}})
- [Office equipment/reimbursements](/handbook/finance/spending-company-money/)
- [Configuring your new laptop](/handbook/it/end-user-services/onboarding-access-requests/#configuring-new-laptops--apple-ids)
- [Employment Assistance Program]({{< ref "benefits" >}})

### Sending the Employment Contract/Offer Letter

Once a verbal offer is made to a candidate...

1. Recruiter will notify `@ces` to [send a contract](coordinator/#send-contract) to the candidate via Greenhouse email. The Talent Acquisition team will sometimes refer to an Offer Letter and Employment Contract interchangeably, because they are called Offer Letters in the US and Employment Contracts outside of the US.
1. Any special circumstances regarding relocation communicated in the notification to CES to ensure it is added to the contract.
1. Once a candidate signs a contract, the CES will send welcome email with instructions on hardware ordering and next steps.

### Declined Offers

Offer acceptance rates are a key metric for Talent Acquisition, and unfortunately, offer declines will happen. In order to ensure we are measuring our offer accpetance rate appropriately, recruiters need to move candidates within Greenhouse at the appropriate times.

1. When a decision has been made at debrief to move forward with an offer, candidate is moved to Offer and Background Check stage. If candidate declines a verbal or written offer, this will then be caught in our offer acceptance rate.
1. Recruiter notifies [Finance Business Partner](/handbook/finance/#finance-business-partner-alignment) via the candidates notes section in GH that the candidate has declined the offer
1. FP&A will make appropriate changes in Adaptive
1. If contract has been generated, recruiter notifies CES via the candidate notes section in GH that the candidate has declined offer and the contract needs to be voided. CES will then follow their own decline process.
1. Recruiter to then disposition the candidate with the appropriate offer decline reasoning so we can measure/monitor rationale for declined offers and partner cross functionally around themes as they present. Please ensure you add relevant notes about why the candidate rejected our offer in the 'Rejection Notes' section. Any details about compensation and numbers should be added as a private note.

## Hired

**Accepted Offers** After the employment contract has been signed by both a GitLab signatory and the candidate:

1. Recruiter to disposition all remaining candidates on position within 24 hours of offer acceptance. Recruiter to manage any active candidates in pipeline appropriately.
1. CES will send a welcome email and mark the candidate as Hired in Greenhouse.
1. Once the candidate has been marked as Hired, this will trigger a sync with Workday and initiate the pre-onboarding process with the People Connect team.
