---
title: "Talent Acquisition Process Framework for REQs"
description: "The Talent Acquisition Process Framework provides guidance on the talent acquisition process for the talent acquisition team, hiring manager, and hiring team to efficiently hire."
---

**Purpose**: The Talent Acquisition Process Framework provides guidance on the hiring process for the talent acquisition team, hiring manager, and hiring team to efficiently hire top talent and create a positive candidate experience when it comes to hiring to a REQ.

**Variations**: It's understood that variations to the process may occur given particular situations that make sense to a specified hiring team or need.

The communicated Talent Acquisition Process Framework specifically focuses on approved REQs and candidates who are moving forward. It is understood that candidates who will be [declined will be done so in a timely and respectful manner]({{< ref "interviewing#rejecting-candidates" >}}).

## Search Team

- **[Hiring Manager](hiring-manager/):** The Hiring Manager is the individual who is hiring for the particular REQ. In most situations, the person hired into this REQ will report into this individual.
- **Hiring Team:** The Hiring Team is a group of people the Hiring Manager asks to be involved in the interview process. The Hiring Team will assess candidates for a given req based on what is defined in the [REQ Kick-off Issue](https://gitlab.com//gl-talent-acquisition/req-intake/-/issues) and the [Hiring Repo](https://gitlab.com/gitlab-com/people-group/hiring-processes/-/tree/master).
- **Recruiter:** The Recruiter is the main point of contact for the Hiring Manager, Hiring Team, and all candidates associated with the REQ. The Recruiter will directly source for prospects as well as partner with their Sourcer and Candidate Experience Specialist throught the process. For more information on what role a Recruiter may play, please visit the Recruiter Job Family.
- **[Candidate Experience Specialist (CES)](coordinator/):** The CES partners with the Recruiter and Sourcer on all scheduling, background check, references and offer needs. For more information on what role a CES may play, please visit the [CES Job Family](/job-families/people-group/candidate-experience).

### **Step 1: Identify hiring need**

The Hiring Manager will determine the need for an opening and ensure it is an approved headcount (confirm with your [finance business partner](/handbook/finance/#finance-business-partner-alignment) if you are not sure). Once confirmed, the Hiring Manager will notify the [Talent Acquisition Manager/Lead specific to their org]({{< ref "recruiting-alignment" >}}) utilizing the steps provided on the [req creation process]({{< ref "req-creation#requisition-creation-process" >}}).

### **Step 2: Create opening in Greenhouse**

The Recruiter will create the opening in Greenhouse following the [req creation]({{< ref "req-creation#opening-vacancies-in-greenhouse" >}}) guidelines. The assigned Recruiter, CES, and Sourcer should receive an email notification from Greenhouse when the req is approved.

### **Step 3: Complete kick-off session, agree on priority level, & complete a sourcing session**

The **kick-off session** provides an opportunity to gain alignment on the requirements, hiring process and, perhaps most importantly, the expectations and responsibilities of the Recruiter, Sourcer, CES, Hiring Team, and Hiring Manager. Recruiters should come prepared for the kick-off session with insights - such as the size and geographic distribution of the talent pool - and should act as a talent advisor. Such information can be pulled from *LinkedIn Talent Insights*. To request this report, please submit an Issue [here](https://gitlab.com/gl-talent-acquisition/operations/-/issues/new?issuable_template=LinkedIn%20Talent%20Insights%20Request.md#) using the `LinkedIn Talent Insights Request` template.

The Recruiter will schedule the kick-off session and must open a [**REQ Kick-off Issue**](https://gitlab.com/gl-talent-acquisition/req-intake/issues/new) ahead of the kick-off session so the Recruiter and Hiring Manager can contribute to it ahead of time. A link to the [**REQ Kick-off Issue**](https://gitlab.com/gl-talent-acquisition/req-intake/issues/new) should be included in the invite.  The Recruiter should include the Hiring Manager, Internal Recruiter, and CES team on the kick-off session invite.  Everyone involved in hiring for the REQ should be tagged into the issue so everyone understands the requirements, process, and individual accountabilities. To ensure that Recruiting haas complete details regarding role, skillset, and interview panel, Hiring Managers must complete the Kick-Off Issue within 5 business days of a job being approved in Greenhouse and posted to the [GitLab jobs page](https://about.gitlab.com/jobs/all-jobs/).

Recruiters may schedule a **Sourcing Session** after the kick-off session to help support identifying passive talent.

- The Recruiter will discuss with Hiring Manager who should participate in the Sourcing session.
- The Sourcing Session is focused on finding outbound candidates outside of our Talent Community.
- Our recommendation is to have at least the Hiring Manager and Interviewers participate in a Sourcing Session.
- The Sourcing Session should be scheduled within 5 business days after the kick-off call. (For the "evergreen" and "volume" roles we recommend having regular Sourcing Sessions every month.)
- All Sourcing sessions that include team members outside of the Talent Acquisition team should be set up for 30 minutes by default and could be done
live or in an async way.
- We don't require a specific number of profiles to be added by every participant, however, the Recruiter should aim to identify 20 qualified profiles for the role.

### **Step 4: Identify & Engage Top Talent (Prospects)**

**4.1 - Source prospects**

The Recuiter and Hiring Manager will partner in finding top talent using different sourcing avenues to find candidates, with LinkedIn and GitLab Talent Community being the most used and efficient ones. *(It is possible that other Recruiters, and/or members of the CES Team will provide additional [sourcing support]({{< ref "talent-acquisition-framework#sourcing-support" >}})*.

**4.2 - Add prospects to Greenhouse**

All approached prospects should be added in Greenhouse as prospects.**Greenhouse is the source of truth.**  Every sourced prospect should have the name of the person who sourced them in the Source field. If a Prospect was sourced by a Talent Acquisition Team Member from the Talent Community, that user will need to [manually update the candidate's source]({{< ref "greenhouse#high-level-workflow" >}}) information.

There are multiple ways to add the candidates, as follows:

- [LinkedIn](https://support.greenhouse.io/hc/en-us/articles/204110135-Add-Prospects-to-Greenhouse-via-LinkedIn-RSC-Integration)
- [Greenhouse plugin](https://support.greenhouse.io/hc/en-us/articles/4947637389083-Greenhouse-Recruiting-Chrome-extension-overview)
- [Maildrop](https://support.greenhouse.io/hc/en-us/articles/201990630)
- [Enable LinkedIn Recruiter System Connect (RSC)](https://support.greenhouse.io/hc/en-us/articles/115005678103-Enable-LinkedIn-Recruiter-System-Connect-RSC-) so you can export candidates in one click as prospects

Keep in mind, a candidate could have the source, `Applied through your website's jobs page` or `Jobs page on your website`, if they signed-up to the **Talent Community** prior to the correct tracking link being associated with the in-take form. In that situation, please change their source to `Talent Community`.

If a candidate is moved from one requisition to another by a *Talent Acquisition Team Member* and the candidate **did not** apply recently, then please update their source to  `Greenhouse Sourcing`.

How to add prospects to REQs:

- [From Greenhouse Talent Community Video Walkthrough](https://drive.google.com/file/d/1if4lWdmQPy7K6sw_sHFf5XIGijQHfbIP/view)
- [From LinkedIn Video Walkthrough](https://drive.google.com/file/d/1ESbhDVsRou81xNcKLhU9SqW2ObjuenAx/view)

**4.3 - Reach Out**

Use our [reach out templates](https://docs.google.com/presentation/d/1ySqgLoYnFUGtb7hdywav6iSb_NBPRhfIs6WZlGne6Ww/edit?usp=sharing) or create your own messaging for reaching out to candidates

#### **Sourcing Support**

Anyone on the Recruitment Team can provide sourcing support for priority REQs.  The focus should be P0 and P1 REQs.  If you want to help with a specific REQ, please engage with the Recruiter directly to verify the REQ is in fact a priority. If the REQ is a priority, use the [REQ kick-off Issue](https://gitlab.com/gl-talent-acquisition/req-intake/-/issues) and the [Hiring Repo](https://gitlab.com/gitlab-com/people-group/hiring-processes/-/tree/master) to learn more about the REQ.

If you are helping a Recruiter source for an open REQ please verify the prospects you find are best qualified *before* reaching out to them. Share added prospects in bulk with the Recruiter vs. sending multiple one-off pings to the Recruiter.  This can be done by  sending the Recruiter a Greenhouse link to the candidate pool using filters (applied on DATE, source NAME, role title).

- The Recruiter has a *7 day SLA* to review the prospects you share
  - If the prospect is not qualified, the Recruiter will select the option to "stop considering as a prospect"
  - If the prospect is qualified the Recruiter will ask you to engage the prospect
    - If the prospect responds and is NOT interested, select the option to "stop considering as a prospect" in Greenhouse
    - If the prospect does not respond before the REQ is filled, the Recruiter should reject all prospects in bulk and select the option to not send an email.
    - If the prospect responds with interest, the person who found them will select the option to "convert to candidate" in Greenhouse and will work to schedule a screen between the candidate and the Recruiter.

#### **Assists**

**What is an Assist?**

- An Assist is hiring credit given to a Recruiter who sourced or otherwise advanced a candidate through an interview process, and then handed off to another Recruiter resulting in a Hire.

**Characteristics of an Assist:**

- You have sourced a passive candidate and/or completed a Recruiter Screen with a candidate
- You have made an introduction between the candidate and the hiring Recruiter
- Candidate is Hired to GitLab

**What is *not* an Assist?**

- Applicants from other pipelines that have not yet been screened

**How to record:**

- Greenhouse:
  - Navigate to `Job Setup` -> `Hiring Team`
  - Locate `Recruiter` field -> **add** the Recruiter receiving the Assist after your own name -> `save`
    - Note: The person with `Recruiting Tasks` next to their name will be the Primary Recruiter.
- Record the Assist in your team’s hiring tracker document (ie. PodSquad for Engineering)

**FAQs:**  
</details>
<details><summary>Click to expand</summary>

What is the purpose of an Assist?

- Assists are a great way to maintain activity during times of reduced hiring in your own business unit. They also provide an avenue to be rewarded for sourcing and interview activity if your own role fills or closes.

Who is responsible for documenting the Assist?

- The Closing Recruiter is expected to document the Assist when closing the role in Greenhouse, once the candidate has signed and all other candidates have been dispositioned. As a best practice, keep a record of candidates that have been handed off to you to maintain data integrity and proper credit. Assisting Recruiters may also [follow](https://support.greenhouse.io/hc/en-us/articles/203800369-Follow-Email-notifications-about-candidate-or-prospect) candidates in GH after the handoff to keep notified of their status.

Will my hiring goals be affected as a result of this change?

- No, hiring goals will remain the same. Any Assists will contribute to your overall performance.

Will the Recruiter responsible for hiring the candidate also get credit?

- Yes, both the Recruiter who made the introduction and the Recruiter who closed the candidate will receive credit for this hire. This is similar to a Sourcer/Recruiter dynamic.</details>

**Reporting:**

- Run: Greenhouse -> Reports -> Essentials Library -> Reports -> All Jobs Summary -> customize filter fields as desired -> Apply
- Result: Primary Recruiter = Closing Recruiter, Secondary Recruiter = Assist

#### **Use Greenhouse to track prospects**

- Use the [Follow](https://support.greenhouse.io/hc/en-us/articles/203800369-Follow-Email-Notifications-About-Candidate-or-Prospect) button to get timely updates on the candidate's status.
- [Follow-up Reminders](https://support.greenhouse.io/hc/en-us/articles/360017456592-Follow-up-Reminders) to resend the assessment, availability or for any other important updates.
- [Tags](https://support.greenhouse.io/hc/en-us/articles/360027904392-Assign-Candidate-Tag-): The most common tags used are "Location sourcing" and "diversity sourcing". You can also create your [auto tags](https://support.greenhouse.io/hc/en-us/articles/360000060551)
- [Greenhouse Candidates Filter](https://support.greenhouse.io/hc/en-us/articles/360004175751-Best-Practices-Sourcing-Strategies): Similar to LinkedIn, Greenhouse has filters to track your pipeline. Under the candidates section, you can check any team members and your candidates tagged under a specific job, interview stage, location and so on. The most commonly used are Source, Profile details, Jobs and Location. Example - [Filter Candidates by Custom Job Fields](https://support.greenhouse.io/hc/en-us/articles/360003493951-Filter-Candidates-by-Custom-Job-Fields)

For more information about Greenhouse and it's tips & tricks, please refer to this [document](https://docs.google.com/document/d/1BbO5v_IJEq4QR9KpI7T3fSCwdCapVOZCyNgEk6MYO0s/edit)

### **Step 5: Interview Stages**

- When the prospect responds with interest and we have a matching requisition, select the option to "convert to candidate" in Greenhouse.

#### EEOC Questionnaire

- All candidates that are evaluated for a requisition in the United States or globally (including the United States) **must** be sent the **EEOC Questionnaire**. Candidates evaluated for requisitions outside of the United States will **not** be sent the EEOC Questionnaire. For requisitions that are posted externally, where a candidate would apply, the candidate will automatically be presented with the *optional* survey in the application. If a candidate comes from a source where they **wouldn't** have necessarily applied (e.g. via an *Agency* or were *Sourced* or *Referred*), then the candidate will receive an automated email from Greenhouse when they reach the `Assessment` milestone. In the case of the requisition **not** being posted externally, then the **EEOC Questionnaire** will need to be sent **manually**. Information about checking the status of that questionnaire and how-to send it can be found [here]({{< ref "greenhouse#eeoc-questionnaire" >}}).

#### Screening

During the screening stage, it is important we capture the following information in Greenhouse and be able to pull data from this information when required. Please refer to the following check list when conducting a screening call:

1. **Locality**
     - Instructions: Navigate to the `Details` tab in the candidate's profile > Navigate to the `Additional Details` section > Select the candidate's location in the `Locality` drop down menu. *Please note this is mapped to the location factors as provided by the Total Rewards Team and may not be their specific location.*
1. **Do you have a significant other or family member that is currently a GitLab team member?**
     - Instructions: Navigate to the `Details` tab in the candidate's profile > Navigate to the `Additional Details` section > Select an option in the `Family Relationship` drop down menu. Select *N/A* if the candidate answers no. Add the 'family member' tag to their Greenhouse profile if there is a relationship to be aware of. The CES will need this to process a disclosure in conjunction with the contract at the time of offer.
1. **Notice period (if the candidate is currently employed)**
     - Instructions: This information is captured in the Screening call Scorecard.
1. **Salary expectations**
     - Instructions: This information is captured in the Screening call Scorecard as a *Private Note*.
If at any time during the interview process a candidate is declined due to compensation, you must add compensation information to the profile as this is used for reporting purposes. To do so, navigate to the `Private` tab in the candidate's profile > Navigate to the `Other Details` section > Fill out the `Currency` and `Compensation Expectations` fields.
1. **It is the Recruiter's obligation to check the candidates right to work in the country they are applying to before going further in the process**
     - Instructions: This information is captured in the Screening call Scorecard.If a candidate requires any form of visa sponsorship, the Recruiter will let the candidate know that we are not able to move forward in the process per our [Visa policy](/handbook/people-group/visas/).
1. **Are you subject to any employment agreements and/or post-employment restrictions with your current employer or a past employer?**
     - Instructions: This information is captured in the Screening call Scorecard.

#### Assessment

- As determined previously in the kick off session with the hiring manager, if there is an assessment involved in the initial interview process, send candidates the assessment through the provided Greenhouse template. The assessment grader is to be added to the appropriate location on the template email to ensure a notification will be sent to them once the applicant has completed the assessment.

#### Team Interview

- Once a screening call is completed and a candidate is still determined as top talent, team interviews will be scheduled. To do this, the recruiter will send an "Email the Team" template called `CES Scheduling Request Form` through Greenhouse to CES* with specific communication on what interview(s) need to be scheduled. The CES team member will then [schedule team interviews](coordinator/#schedule-team-interviews).
- The number of team interviews and order will vary from opening to opening. An example of what a Team Interview may look like is:
  - Round 1: 50 minute interview with Hiring Manager
  - If applicable, Round 2A: 25 minute interview with a Hiring Team member
  - If applicable, Round 2B: 25 minute interview with a Hiring Team member
  - If applicable, Round 3: 50 minute Executive Interview
- The Recruiter should confirm focus areas have been assigned to the interview team. This should have been taken care of in the [REQ kick-off Issue](https://gitlab.com/gl-talent acquisition/req-intake/-/issues)
- Interviewing is only available to full time GitLab team members. Under no circumstances should a contractor or outside third party be invited to interview a candidate or to shadow an interview.
- The candidate should be provided clear expectations of the process, location of interviewers, timeline to hire, etc.
- When Team Interviews have completed, follow up with the hiring manager on next steps. Depending on the level of the role and outcome of interviews, next steps may include additional interviews including an executive interview or moving to reference checks.

**If you have a candidate who's interested in multiple openings please follow these guidelines:**

1. Inform the candidate they will need to go through a full interview process for each role and outline the time commitment that may entail (for example, if a candidate is in process for 2 roles they may need to make time for 10+ interviews).
1. There is no limit on the amount of roles a candidate can apply to but due to recruiter capacity we will only process 3 applications at a time, and will ask the candidate to choose the 3 that are highest priority.
1. We want to avoid a situation where we have competing offers from multiple teams within GitLab. In order to prevent this, there will be an added step after the final interview stage where the recruiter discusses with the candidate which role they're most interested in. Only one offer will be sent to the candidate after the final interviews.

### **Step 6: References**

Once a Hiring Manager has determined they want to move forward with a candidate, the Recruiter will send the appropriate form to the candidate that is found in the Reference Check stage. If no forms are listed, please contact the Enablement team to get them added. The form will request their references' contact details as well as details that will help with an offer letter such as Legal name and background check.

If you would like the Hiring Manager to receive an email when the form has been received, you can go to the job setup for that req, select 'Forms' and edit the individual form you plan to send. The Recruiter, individual CES assigned to the candidate, and CES@gitlab.com will all automatically receive an email when the form is completed.

During this time, you will also submit your offer for approvals.

If the candidate for the position is internal, you should wait until you've presented an offer to merge the applicants' profiles. Please visit the [Candidate Hygiene Instructions](/handbook/hiring#interview-stages) for details.

If there are any special circumstances regarding a known relocation for the candidate, this information should be included in the Compensation Details. Details should include originating location and salary, as well as the new location and new salary details to ensure it is communicated as part of the approval.

### **Step 7: Verbal Offer & Contract**

Once references are completed or are in progress, and the offer has been approved, the Recruiter will move the candidate to offer stage to show that they are ready to present a verbal offer.

For details about these final stages, please visit the [Job Offer Process]({{< ref "offer-process" >}}) page.
