---
title: "1-1"
---

Maintaining an effective and efficient agenda is important to get the best out of the 1-1 (read as: one *to* one) meetings you have with your team members. Furthermore this page will take you through other tips and tricks to conduct an effective 1-1 meeting.

## The 1-1 Agenda

1. Make sure you use a consistent agenda format for each 1-1.
1. Both parties add items to the agenda. Preferably, the majority added by the team member. If the manager puts more than half of the items on the agenda this is an indication that something is wrong.
1. Reference the [suggested format for leadership]({{< ref "suggested-agenda-format" >}}) as necessary.

## Conducting a 1-1

We recorded a training about 1-1s which you can find here:

{{< youtube "KUxxjGJv1dQ" >}}

1. It's advisable to schedule 1-1's at least once a week.  The choice of synchronous or asynchronous meetings can be made by the manager and their direct report, depending on their preferences and needs. To avoid prolonged periods without face-to-face communication, it is preferable for the manager and their direct report to have a minimum of two regularly scheduled synchronous 1-1s every month, barring any PTO or leave from work.
   1. For example, some managers schedule 1-1s on alternating weeks, with one week for synchronous meetings and the next week for asynchronous meetings. This approach allows for more dedicated focus time and aligns with our priority of emphasizing asynchronous communication.
1. Create a Google doc as the [agenda](#the-1-1-agenda) and set the sharing settings exclusively between you and the team member. This should not be a public document because performance feedback should be as private as possible.
1. From [High Output Management](https://getlighthouse.com/blog/high-output-management/) (edited sightly for language):
    1. "A key point about a one-on-one: it should be regarded as the reports's meeting, with its agenda and tone set by them ... issues that preoccupy and nag the individual contributor."
    1. How often you should have 1-1 meetings: "The answer is the job- or task-relevant maturity of each of your individual contributors. In other words, how much experience does a given report have with the specific task at hand?...the most effective management style instance varies from very close to very loose supervision as a report's task maturity increases."
1. Bill Campbell, executive coach to top executives at Google, had a [suggested approach to the 1-1](https://alearningaday.blog/2015/11/29/bill-campbell-style-1-1/). Instead of leaving the conversation open, he required both the manager and the team member to bring a list of 5 things to discuss. At the start of the meeting, they would match lists and talk about whatever is on both lists first. After that, they would spend time on 4 topics – performance on job requirements, relationships with peer teams, leadership and innovation.
1. If you have negative or positive feedback give it right away rather than waiting for the 1-1. However, make sure bi-directional feedback is given *at least* as often as the 1-1 meeting. The face to face 1-1 is also useful for feedback that the person may be especially sensitive too, or is being given for the second time and needs to be taken more seriously.
1. It's important not to push times of the 1-1's for "more important" tasks. Book them and ensure you always are on time. Similarly, canceling a 1-1 should be a last resort. The exception to this is talent acquisition interviews. If participating in an interview schedule, reschedule the 1:1 with as much advance notice as possible, but prioritize the interview.
1. One communication style does not fit all. Some need very direct feedback. Others work better with FYI style information to then come to the conclusion you want them to come to on their own. Others work well with clear goals, but without a clear prescription as to how to reach the goal. Great managers can adapt their style to the report.
1. It is common to start with a bit of small talk. You can also consider starting with asking how are you as a person?
1. The end of the meeting is a good time to ask questions people might be hesitant to answer. [People will often reveal their important information at the end of a conversation.](https://leadingstrategicinitiatives.com/2011/07/19/use-the-columbo-question-to-get-strategic-information/) Use this to get information about things that are bothering them about other people in the company, including you as a manager. Ask a question like 'How can I make your life better?' or 'How's the team and the work with other people?'. Don't put this question on the agenda in advance. Since it is the end of the meeting it might be needed to add it to the agenda to discuss in the next meeting.
1. Setting and managing expectations is maybe your most important task. Both the managers expectations of the work done by the report and the reports expectations about the work and company.
1. Reports tend to assume that they must do everything added by the manager, make it clear that they can push back (not a good idea, not worth the time), and redirect (please handle it directly with this person, can you arrange for this). You want to prevent the agenda piling up. The manager will put items on the agenda because it is in the functional area of the report and the manager doesn't want to bypass them. But in case the manager cares about something and the report doesn't it might be preferable for the manager (or an executive assistant) to do the work.
1. Actively listen to identify what the direct report is saying. The manager should strive to do 20% of the talking while the direct report does 80%.
1. If you have few items on the agenda from the report try the following questions:

   - Is there anything that needs clarity?
   - What are you most proud of/excited about?
   - What can I (your manager) improve on?
   - Anything you think important that happened since the last 1-1
   - What are potential troubles you see for the team
   - What are potential troubles you see for the company
   - What went well since last week?
   - What went not so well since last week?
   - Is there anything I can do to help?
   - Anything non-work related worth mentioning?
   - When x happened, what will you do differently next time?
   - Have you identified any career development opportunities that I can help you with? For example: [Internship for Learning](/handbook/people-group/learning-and-development/internship-for-learning/)
   - Other great questions to consider can be found in the [Culture Amp Blog: 24 great one-on-one meeting questions](https://www.cultureamp.com/blog/one-on-one-meeting-questions) or in 15Five's [The Great eBook of Employee Questions](https://www.15five.com/ebook/employee-questions/).

1. Consider encouraging direct reports to keep their 1:1 document open in their browser throughout the week. As items come up, they can add them in real time instead of waiting until 30 minutes before the meeting to scramble to fill in the [agenda](/handbook/leadership/1-1/suggested-agenda-format/).
1. Asking open ended questions is important. "You doing alright?" is a yes/no question. There is no room for an answer unless you dig and prod to get more. Instead asking things like "Tell me how you've been doing since we last talked" leave more room for discussion and result in something both more actionable and results driven. Your goal is not just to know how they are doing, but why they feel that way.
1. Consider populating the agenda to the 1-1 meeting at least 24 hours in advance of the meeting. This will enable the direct report and manager mental space to think more critically about each topic.

## Learning From the CEO on Conducting a 1-1

The Learning & Development team and the CEO, discuss conducting a 1-to-1 in more detail during a handbook learning session.

{{< youtube "TAcfRjqGzOs" >}}

## Career Development Discussion at the 1-1

We recorded a training about career mapping which you can find here:

{{< youtube "YoZH5Hhygc4" >}}

These discussions should take place once a month and after the [360 Feedback](/handbook/people-group/360-feedback/) meeting has taken place. As a manager of people you play a crucial part in developing careers for your reports. This is for them but you should be able to support this process and help them achieve their goals. This is a join collaboration so prior to the meeting think about what questions to ask, specifically identifying **competencies(c)**, **skill gaps(sg)** and **career objectives (co)**. Adrienne Smith who wrote [increase employee retention with career pathing](https://www.geteverwise.com/human-resources/increase-employee-retention-with-career-pathing/) suggests the following:

1. Which projects are you most proud of that you've finished here? (c)
1. What is your favorite part of your job? (c)
1. Which projects have you struggled with most in this role? (sg)
1. What's your least favorite part of your day-to-day? (sg)
1. When do you ask for help most often? (sg)
1. What parts of your role do you want to do more of? Less of? (co)
1. What don't you do in your current role that you'd like to? (co)
1. What would you like to learn next? (co)

Once you have established the goals you can then create a [career development plan](/handbook/people-group/learning-and-development/#career-mapping-and-development)

### Why career development for team members is key to being a great leader

Providing team members with a clear path of advancement within the group, department or division that includes career development opportunities is a win-win-win for team members, managers and GitLab.  Team members who are challenged, engaged and who are actively contributing relevant solutions stay with organizations. An engaged workforce allows the department and divisions to meet their current and future needs for talent and skills and increases performance and decreases regrettable attrition.

Please make sure as a manager you have reviewed the [Career Development Section in the handbook](/handbook/people-group/learning-and-development/career-development/)

There are many reasons that career development conversations are important. Below are a few examples though there are many more reasons.

### Increase team productivity and performance

For managers, having career development conversations offers them a chance to help develop team members which then has an impact on the overall organization.  It's a critical skill for those serious about increasing their teams' productivity and performance.  Development conversations will help the group, department, division and GitLab retain great team members, which at the end of the day also contributes to the manager's own success.

### Build a bench of high contributors

On top of increasing performance, these career development conversations allow managers to build a bench of top talent contributor and create a succession pipeline.  This will help reduce worries about losing top talent and who the team can turn to for critical tasks.  Good managers know that if you have a strong bench, you have a lot less to worry about.

### Be a great leader

When it comes down to, it the best managers or leaders — the ones that team members want to have and are happy continue being part of the team.  These are the managers that take an interest in their team members lives and career.  By learning about what your team members wants, what they strive for and by being able to help them drive to their goals, you will build credibility, trust and respect.  This in turns also contributes to your overall success as a manager.

### Attract, engage and retain top talent

A managers's job is not to just drive to OKRs and performance.  It is also to attract, engage and retain top talent team members and maximize their contribution to the group, department or division.  If you are interested in your team members aspirations, success and what motivates them, you will attract top talent because people will want to work for you.  Once you get great team members on board, you will need a plan to get them and keep them engaged. Career development can be and should be one of the ways you as a manager invest your time and energy to help drive engagement, performance and results.

### Preparing for a team member's performance and development conversation

#### Career conversations do not have to be intimidating

Career development conversations are vital for the team members, managers and GitLab's success.  However, not all managers are prepared to address career development due to either lack of experience in having these conversations or a fear that the conversation will be difficult or unpleasant.  Here are a few other reasons that managers may avoid having these conversations:

- Career development conversations will take up time they do not have and create more work
- Team members will want different roles or opportunities on an unrealistic timeframe
- Team members will have aspirations that do not match their current skill level
- Team members will take conversations about their career as a promise of a promotion
- Team members will leave after they have developed new skills

Not discounting these concerns, but as a manager it is your job to engage team members in meaningful career development conversations.

If a team members expectations or timeframe is unrealistic, you can explore having them use their time to find opportunities that will engage and prepare them for when their opportunities arise. If they are ready for promotion but the opportunity is not in scope or plan for the business it is best to be transparent with the team member. Discuss any timeline of if/when a position may be available or if there is no plan currently to add that role. You can also work with the team member to look for internal opportunities like internship or cross collaborative projects to help keep the team member engaged while continuing in their role.

If a team members expresses career ambitions that are beyond their current skill set, then that is an opportunity to talk about the next level skills and experience that might help prepare them to get them where they want to go. If your department or division has job matrices or competencies this is a good time to review those with the team member. Technical skills are only one part of the team members ability to continue to grow and succeed. If there are issues with attitude and behaviors this is a good time to also share what the team member needs to work on in regards soft skills as part of their career growth and development.

If you are concerned that your career development conversation could be construed as a promise of a promotion, focus the conversation around skills gap development and opportunities.  Try to focus on the things needed now rather than focusing on a specific time frame.

It is possible that some team members may leave for other opportunities after they acquire a new skill set. However, it is even more possible that they will leave if they believe you or GitLab is not interested in their career aspirations or development. Engaging in meaningful career development conversations show that you as a manager care about them personally and their future development.

### Preparing for the discussion

#### Strengths and wins

As a manager part of your job is to learn more about the team members you manage. What are their skills, interests and career goals? The tone of the career development conversation should be transparent, encouraging, curious and show that you are interested and invested in the team member. Spend some time before you have a conversation to think about the following:

- The team members key strengths, skills and wins
- The team members engagement level
- What are opportunities for their development
- Current level of skills in technical or functional areas
- What are their strong leadership competencies or behaviors

Career development conversations shouldn't be done on a whim or just "winging it," but instead these should be thought out and conversations that you prepare for ahead of time. You should come prepared to offer team members feedback, offer suggestions and to ask pertinent questions.

#### What questions might team members ask?

Team members want feedback on their strengths, performance and their potential within GitLab. Be prepared to answer the following questions:

- What you say are my top strengths or top skill?
- What skills should I build on?
- Are you aware of any development opportunities that would be helpful for me?
- I see this as my career path, what career path do you see based on my skills?
- Should I be gathering career development feedback from others?

Since you are already having regular [1:1s]({{< ref "." >}}) with your team member you may have ideas regarding your team members development aspirations. Plan ahead and take the time to think about what questions they may ask and come prepared to the conversation.

#### Having the discussion

#### Maintain the right frame of mind

Coming to the meeting with an open mind and the willingness to learn more about the team members career development aspirations will set the right tone for the conversation.

A best practice could be having the team member start the meeting by expressing their goals for the conversation. Your job as a manager is to listen and [understand their desires](/handbook/people-group/learning-and-development/career-development/#the-relationship-between-learning-and-development-and-promotion) and help them explore options that may be available for reaching those goals. Try and refrain from interjecting, let the team member finish before you start talking. Try not to be judgemental on what they say, different people will have different career goals and it is important to respect their ideas. However, this can also be a time for you to provide them with feedback, suggestions, recommendations and guidance. It can also be an opportunity for you to connect them with different people within GitLab and additional resource that support their identified career path.

As a manager you should follow up on the goals and activities you both identify. This will show the team member that you do listen and have a vested interest in their future success. Also, career conversations should not be a one-time annual conversation. A best practice is to meet at least quarterly for a check-in. Keep in mind some team members may want to meet more often and some less frequently.

#### Be open about your own career goals and development

If asked, share your career goals with your team members. This transparency shows that you are not only willing to hear their career goals, but you are also willing to share your own career path. That could also include discussing with your team members the areas that you have identified to focus on in the future. Be open about questions regarding your own career path and experiences to date. Your team member may be able to take away some valuable lessons that you have learned in your own journey.

#### Additional resources

Below are several recommended articles regarding career development conversations.

- [5 business reasons to put employee career development at the top of your agenda](https://cezannehr.com/hr-blog/2024/02/five-reasons-to-prioritise-employee-career-development/)
- [Career Development Mentoring Benefits](https://www.people360ai.com/blog/benefits-of-career-development-mentoring)
- [Why Employee Development is Important, Neglected and can Cost You Talent](https://www.forbes.com/sites/victorlipman/2013/01/29/why-development-planning-is-important-neglected-and-can-cost-you-young-talent/#22df1a8a6f63)
- [If You're Not Helping People Develop, You're Not Management Material](https://hbr.org/2014/01/if-youre-not-helping-people-develop-youre-not-management-material)
- [Bolt's Developing Your Team](https://conscious.org/managing-our-team/#developing-your-team) section from their [Managing our team](https://conscious.org/managing-our-team/) playbook.

## Key Points

1. **Actively Listen**. Self-assessment is difficult and people often overestimate or underestimate their skillset. Don't be quick to discount their assessment. Look for common ground and focus on understanding their overall goals.
1. **Control**. Maintain control of the conversation to ensure it stays on track. The focus should be on their current skillset and abilities and how to cultivate those for a career path within the company.
1. **Adaptation**. Adapting your approach to different personality types is key. People that overestimate their skillsets should be given specifics on where they do, and don't, meet expectations. They may need areas of failing to be pointed out more plainly (but always caringly). Those that underestimate their skillset may need more emphasis on what they are doing right as they tend to focus on the negative. Also, not everyone wants to advance. Some are very happy in the role they are in and want to stay there. That should also be supported. Learn more in our [Learning & Development Handbook](/handbook/people-group/learning-and-development/).

## Transitioning 1-1s

When taking over management of an existing team member, consider the following guidelines to ensure the team member experiences a psychologically safe transition.

### Manager Transition Meeting

In an effort to be [transparent](/handbook/values/#transparency), managers should consider ensuring that all of the information provided to the future manager by the current manager is done in full view of the team member. This might not work for all team members. You should ask whether the team member will feel comfortable having this conversation openly, and respect their boundaries. When choosing to remain transparent, schedule a transition meeting and follow the [Manager Transition Meeting Agenda](#manager-transition-meeting-agenda-example).

### 1-1-1 Transition Schedule

The following schedule can ensure a smooth transition:

1. Current Manager: Create a 1-1-1 and invite the team member and the future manager
1. Prior to the meeting get approval from the team member to share the existing 1-1 doc (and other feedback documents) with the future manager. Or, if they request start a new 1-1 document and share it with the team member and the future manager. This will give the future manager an opportunity to review in advance of the meeting.
1. Team Member: If a new 1-1 document was started, transfer any relevant content
1. Group: Continue 1-1-1s for up to a month (if needed)
1. New Manager: Remove the former manager from calendar invites and the 1-1 document

Abrupt 1-1 transitions can threaten a team member's sense of psychological safety and career stability. If this is a concern, consider scheduling follow-on 1-1-1 transition meetings.

### Manager Transition Meeting Agenda (example)

#### Attendees

- Team Member:
- Current Manager:
- Future Manager:

#### Introduction

TEAM MEMBER, in the coming weeks I will transition management support to FUTURE MANAGER. This is an opportunity for you to comment, agree, and disagree with how your performance, feedback, professional goals, growth areas, and 1:1 document content is shared with FUTURE MANAGER. We want to ensure you have a complete picture of the information we share. The goal is to make sure we're transparent in the transition of your career, how you want to grow, and how I can support you.

We understand that this meeting format may feel a bit awkward as we will openly discuss your work performance. This is all in the service of the goal to fully support you.

#### Agenda

- Introductions and reason why this manager transition is happening.
- Review most recent performance evaluations, OKRs, and goals.
- Share any additional feedback since recent reviews.
- Are there any follow-on 1-1-1 transition meetings needed?

## Shadowed 1-1

Shadowing a 1-1 is a scenario in which a GitLab team member attends the 1-1 of their manager and their manager's manager. The intent of this model to provide trust through transparency, build connections between team members and leaders who they may not otherwise interact with regularly, and open opportunities for collaboration be providing a broader knowledge to team members. The shadowed 1-1 is exemplified by Sid by having the CEO Shadows attend 1-1s with his direct reports.

### Agenda

Portions of the agenda will be suitable for sharing and others will not. Care should be taken to separate items that could breach our communication guidelines or potentially reveal confidential information. A suggestion on how to handle this would either be to not share the agenda with the shadow(s) or have a separate agenda for private items, these are just suggestions.

### Attendees

Attendance could be limited to direct reports but could also include other people. A suggestion might be to have a sign up for attendance and, in order to maintain the relationship and support expected to arise from 1-1 meetings, alternate shadow weeks with non-shadowed weeks. Suggest having a separate zoom link for shadowed 1-1s.

### Example

An engineering manager decides to open up their 1-1 meetings to their team. The engineering manager checks with their manager that this is acceptable and determines a plan for review. When a shadow will be present, this should be indicated clearly on the agenda. Utilising a separate zoom link, all 3 people join and walk through the agenda. Participation level of the team member is up to the regular participants of the 1-1 but, consider encouraging engagement. At a point where sensitive topics need to be discussed, the team member will be asked to leave.

### Leadership Engagement Check-Ins

Leadership Engagement Check-Ins, (also known as [Stay Interviews](https://www.forbes.com/sites/billconerly/2018/07/21/retain-more-employees-with-stay-interviews/#659422a2f18c)) are conducted to help leadership improve retention in their teams. It helps them understand why team members stay and what might cause them to leave. In a Leadership Engagement Check-In, people managers ask standard, structured questions in a casual and conversational manner.

#### Process

- **Cadence**: Schedule your Engagement Check-In at least every 6 months with each of you direct reports. People leaders can repurpose a scheduled 1-1 meeting;
- **Format**: Use sync communication via Zoom;
- **Preparation**: Preparation should be done before the meeting by the manager and the team member. The manager should set expectations with their team members prior to the meeting to ensure that the team member feels as comfortable as possible heading into the conversation. Managers can include a copy of this Handbook page so their direct report is fully aware of the specific questions that will be asked during the call. Ask the team member to review the questions and think about them prior to the call. Allow them the opportunity to type responses before the meeting if they wish to do so.
- **Questions**: Have a look at the below questions and take notes during the meeting.
- **Follow up**: At the end of the conversation summarize and follow up on any actions.

#### Structure

##### Opening

Start the conversation by explaining the purpose of the meeting and why it's important to you as a manager. An example is below.

> "Thanks for taking the time to have this check-in conversation. Team member engagement is very important to me, and this talk is a way to better understand how things are going for you and how I can help to improve your experience at GitLab. I would like to talk with you about the reasons you stay with GitLab so I understand what I can do to make this a great place to work for you."

##### Questions

It's important to listen and gather feedback from the team member about how they feel about GitLab in an objective manner:

- What do you like most about your job?
- What do you like least about your job?
- How would you describe a great day at work?
- What motivates you to stay at GitLab?
- What would make you consider leaving GitLab?
- If you could change one thing about your job, team or company, what would it be?
- What can I do to support you?

##### Scenarios (situations and reactions)

1. **Team member has expressed the desire to stay at GitLab and is engaged**
    - I am so pleased to hear GitLab is a great place for you and really value your input going forward.
    - In case there's a change in your feelings I want to make sure you can always speak up, even outside of these engagement check-ins.
1. **Team member expressed both reasons to stay but also reasons for leaving**
    - I really want to thank you for your valuable input and feedback.
    - Summarizing what we have discussed I would love to work on an engagement plan so that we can make sure GitLab is a great place to work for you.
    - Let's follow up in one week and prepare items we can work on to improve your experience at GitLab.
1. **Team member expressed mostly reasons why they consider leaving and isn't engaged**
    - I really want to thank you for your valuable input and feedback.
    - Looking at your concerns I would love to work on an engagement plan so that we can make sure GitLab becomes a great place to work for you.
    - Let's follow up in one week and prepare items we can work on to improve your experience at GitLab.
1. **Other scenarios**
    - If you have a scenario different from the above, and/or you need help with messaging, please work with your manager or [People Business Partner](/handbook/people-group/#how-to-reach-the-right-member-of-the-people-group).

##### Closing

To close the Engagement Check-In, summarize the key points discussed, and work with the team member to develop an engagement plan (if applicable). Be sure to end on a positive note. An example is below.

> "Let me summarize what I heard you say about the reasons you stay at GitLab, as well as reasons you might leave. Then, let's develop a plan to make this a great place for you to work.
I appreciate you sharing your thoughts with me today. I am committed to doing what I can to make this a great place for you to work."

If, during the Engagement Check-In, issues arise around health, performance, compensation, etc. and you need assistance, please work directly with your manager or your [People Business Partner](/handbook/people-group/#how-to-reach-the-right-member-of-the-people-group).

##### Follow Up

After the call has closed, capture some notes about what was discussed and share with the team member to ensure you heard their feedback correctly. It is important to do this for all team members - even if they had positive feedback about their engagement level.

For team members who had positive feedback, you will want to continue to find opportunities that align to things that make for a positive experience for them. For team members that had constructive feedback, you will want to use your notes as a start of an engagement plan.
