---
title: Building Trust
title: "Building Trust at GitLab"
description: "On this page, GitLab details considerations for building trust in remote teams. Learn more!"
twitter_image: "/images/opengraph/all-remote.jpg"
twitter_image_alt: "GitLab remote team graphic"
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

## Introduction

Trust is the cornerstone of how we operate at GitLab. We trust team members to [do the right thing instead of having rigid rules](/handbook/values/#measure-impact-not-activity). Trust at GitLab [increases results](/handbook/people-group/guidance-on-feedback/), [efficiency](/handbook/values/#efficiency), and [collaboration](/handbook/values/#collaboration).

Trust takes time and energy to build. We leverage [informal communication](/handbook/company/culture/all-remote/informal-communication/) to build trust, but there are additional strategies [people leaders](_index.md) and team members can implement on their teams.

Working remotely can be isolating for team members if managers do not take the [necessary steps](/handbook/company/culture/all-remote/being-a-great-remote-manager/) to build trust and social cohesion amongst their teams. In a remote environment, it can take team members longer to get to know each other compared to a colocated office setting. On this page, we've outlined additional strategies people leaders and team members can apply to build trust amongst their teams.

## Ten Dimensions of Trust

Sid Sijbrandij, GitLab's CEO, shared what he has identified as the ten dimensions of trust. He notes that trust allows you to [assume positive intent](/handbook/values/#assume-positive-intent) in support of our [CREDIT values](/handbook/values/#credit). It also helps to [prevent political behavior](/handbook/values/#playing-politics-is-counter-to-gitlab-values) that runs counter to our values.

1. Optimizing [efficiency for the right group](/handbook/values/#efficiency-for-the-right-group)
    1. We versus I optimization
    1. Organization versus individual
    1. Other teams versus your team
    1. Global versus territorial, kingdom building
1. Mindset
    1. Abundance
    1. Positive sum position instead of zero sum
    1. Open-minded
    1. Looking for creative win-win solutions
1. Familiarity
    1. Knowing the person better
    1. Listening (actively)
    1. Spending more time
    1. [Informal communication](/handbook/company/culture/all-remote/informal-communication/)
1. Information
    1. Providing and receiving [feedback](/handbook/people-group/guidance-on-feedback/)
    1. Bad news travels fast
    1. [Transparency](/handbook/values/#transparency) (show your intermediate work)
    1. Wide access to information, meetings, and meeting notes
1. Responsiveness
    1. Availability
    1. Open to suggestions
1. Confidentiality
    1. Respected
    1. Safe space
    1. Negative in a small group, not large forums
    1. Discretion in what can be shared and when
1. Build
    1. Praise in a broader group
    1. Giving credit (for an idea)
    1. Constructively picking arguments ([steel man vs. listening for weak arguments](/handbook/values/#assume-positive-intent))
    1. Make each other better
    1. Explain the why ([Simon Sinek](https://www.youtube.com/watch?v=zP9jpxitfb4))
    1. Celebrate successes
1. Competence
    1. Calibrated to what is required
    1. High standards
    1. Relentlessly resourceful
1. Consistency
    1. Opinion/behavior independent of who is in the room
    1. No backroom conversations
    1. No alliances, other than with all peers
    1. No politics (link to handbook section)
1. History
    1. Keeping commitments
    1. History of success

## Strategies to Build Trust

People Leaders should make every effort to build trust as soon as they mobilize a team, when new team members start, and throughout the year. [Informal communication](/handbook/company/culture/all-remote/informal-communication/) is a great tool to build trust; however, there are additional strategies managers and team members can implement to build trust within the teams they support.

### Personality Assessments

Getting to know your people through personality assessments is a tool to build trust. Personality assessments can help teams understand how they are different and enable managers to better understand their direct reports. The results can shine a light on ways you can adapt your processes in a way that is most effective for different team members. Remember when we use personality assessments, it is essential to not type-cast team members into their assessed personality results. Instead use them as a tool to facilitate more meaningful conversations amongst your team.

An abundance of free personality assessments are available. Several are outlined below:

- [Understanding Social Styles]({{< ref "social-styles" >}})
- [Emotional Intelligence Assessments]({{< ref "emotional-intelligence" >}})
- [Gallup Strengths Finder](https://www.gallup.com/cliftonstrengths/en/252137/home.aspx)
- [16 Personalities](https://www.16personalities.com/) (also known as Myers-Briggs)
- [DISC Personality Test](https://discpersonalitytesting.com/free-disc-test/)
- [HEXACO Personality Inventory](https://hexaco.org/hexaco-online)

**How to apply personality assessments:** People leaders can have all team members take a personality assessment when they first join their team. Managers can examine personality assessment results and have strength-based discussions with their people. However, it is essential to never type-cast team members based on their results. Use personality assessments as a tool to facilitate trust and get to know each other. When we embrace our unique strengths and the unique strengths of our team members, we all feel more engaged, more productive, more valued, and more trusted. They should encourage their team members to share their strengths / styles with the team. In addition, team members can take personality assessment and update their [READMEs]({{< ref "_index.md#your-individual-readme" >}}) accordingly with personality assessment information if they choose to.

### Use a One-Slider Personal Summary

A one-slider personal summary is a tool for remote teams to get to know one another. Consider using the [template and example](https://docs.google.com/presentation/d/1N-fNiIBAc8_HefLyPTi4HEhoFkcCDLW_Ntx8wqmEQ9c/edit#slide=id.g822466666c_0_232) below as a starting point. The one-slider can be adapted to whatever questions or facts you'd like to learn more about. One-sliders allow team members to share fun facts about themselves in a remote setting. You can be creative and ask entertaining questions! When someone joins the team, have them fill out a one-slider and use it to introduce themselves to the team. They are fun, easy, and can help to build trust by getting to know one another in a remote setting.

**How to apply one-sliders:** Before the next team call, ask one or two members of the team to pre-populate a one-slider a day or two in advance of the meeting. Spend the first five to ten minutes of the meeting having the designated team members share their one-slider. Give everyone an equal amount of time and encourage everyone on the call to ask questions about what makes them unique.

<figure class="video_container">
<iframe src="https://docs.google.com/presentation/d/e/2PACX-1vTiYHr_SxtAHAcFr5Y5Lrnk39WMyNIRMqMiezKEHsG_dm_3Jd3a6jM1rDEycpCVVn5ZOZeySKHJeNQM/embed?start=false&loop=false&delayms=3000" frameborder="0" width="960" height="569" allowfullscreen="true" mozallowfullscreen="true" webkitallowfullscreen="true"></iframe>
</figure>

### Optional Weekly Team Social Call

Optional social calls are a strategy to increase trust. Anyone can organize one. They are tools to come together as a team informally. The secret is to make the meeting non-work related. Attendees are able to share photos related to the topic during their time speaking. Example optional social call topics:

- Top three songs of all time (you can play short snippets of a song)
- Favorite foods
- Two truths and a lie
- If you won the lottery tomorrow, what would you do
- Would you rather
- What's the most exciting thing you've done outside of work this week/month
- Most recent or favorite vacation

**How to apply optional weekly team social calls:** Set a regular cadence of optional weekly team social calls (monthly, bi-weekly, weekly). Each social call, have one team member be in charge of managing and facilitating the discussion. They are responsible for proposing the topic and keeping the call moving. Remember to make these fun and try not to talk about work!

To be inclusive of time zones and those who may not prefer these types of social settings, alternate synchronous social calls with [asynchronous](/handbook/company/culture/all-remote/asynchronous/) social standups. You can port the questions to the `Geekbot` Slack app so team members can share at their convenience.

### Zoom Background Ice-Breaker

The Zoom feature to upload [any background image](/handbook/tools-and-tips/zoom#virtual-background) of your choice is a fun tool to use for an ice breaker. Managers can ask their team to come to a meeting with a background of their favorite place to vacation, or a place they hope to visit one day, and much more. It's a great feature that can add some fun to calls and build unity. Spend the first five minutes of a meeting talking about the Zoom background and giving everyone in the meeting a voice.

One of our Managers said this about the Zoom Background Ice-Breaker:

> One of my favorite things that the team and I have done over the last 3-4 months is to update our Zoom background. We all threw out TV shows and then agreed on our favorite, from there; we picked a scene from that show and showed up to a meeting with our background. Not only was it fun to listen to the shows our team members like, but it was also a conversation piece and a lot of fun!

**How to apply Zoom background ice-breakers:** Team members can do this for as many meetings as they like. If it is a team discussion, spend the first five minutes of the meeting doing a round robin of the background. Managers can implement a rotation of DRIs ([directly responsible individuals](/handbook/people-group/directly-responsible-individuals/)) in charge of the ice-breaker by assigning different team members.

### Give Credit to Team Members

Use the '#thanks' [Slack channel]({{< ref "communication" >}}) to give recognition to team members in a public setting. Review team accomplishments weekly, monthly, and quarterly. Meet with each team member to review their accomplishments.

Take a [coaching approach]({{< ref "coaching" >}}) and have the team members talk through what their accomplishments were. Managers should identify opportunities for [executives]({{< ref "structure#executives" >}}) to recognize the team. They should also look for opportunities to recognize the team in front of executives.

**How to apply giving credit to team members:** Managers can set a weekly reminder to review team accomplishments and areas for individual recognition. Scheduling a regular cadence of giving credit will show team members that leaders are playing an active role in their career.

### 1-1 Meetings

[1-1 meetings]({{< ref "1-1" >}}) can serve as an opportunity for managers and team members to get to know each other on a personal and professional level. Nobody is alike, and each person has a different unique background and story. A communication or management approach that works well on one team member might not work on another. By showing vulnerability during 1-1 discussions, team members can build trust.

**How to build trust in 1-1 meetings:** One way to do this is to ensure team members have plenty of time to talk about the weekend or what fun things are going on in their lives. Managers can spend the first 5-10 minutes of the call, letting it be about "them." Before diving straight into "work topics," especially at the beginning of a new working relationship, pause and ask about family, hobbies, the weekend, etc. Try to remember things team members mention about family, pets, hobbies, or other things going on in their life. If they live in a particular part of the world, managers can spend time getting to know what's happening regionally. Follow up with questions related to a team member's home.
For some great tips on how to make small talk and build connection through communication listen to [Rachel Greenwald in Episode 89 of Think Fast, Talk Smart](https://www.youtube.com/watch?v=jLFH9Q3VQsc).

### Leverage the Building High Performing Teams Model

The [Building High Performing Teams model](https://internal.gitlab.com/handbook/company/high-performing-teams/) is one of the most widely used and accepted models for team development. A big component of the model is building trust. To reach high performance, teams need to trust each other and share mutual regard where people are supported and respected. There is a willingness to be forthright, open, and free in working with team members. Review the [high performing teams page](https://internal.gitlab.com/handbook/company/high-performing-teams/) for strategies to build trust.

**How to apply the building higher performing teams model:** Review the strategies to improve [building high performing teams](https://internal.gitlab.com/handbook/company/high-performing-teams/) at GitLab. Managers can conduct an assessment with their teams to see if team members trust one another. Use the resources outlined to facilitate a discussion.

A [curated list of external resources](/handbook/people-group/learning-and-development/manager-development/high-performing-teams/) has also been compiled which may help when adopting this model.

### Ask for Feedback

Managers should be open to [receiving feedback](/handbook/people-group/guidance-on-feedback/) from their team members. Often there is a barrier as employees feel uncomfortable sharing constructive feedback, let alone with their manager. But if managers are open to feedback, they can slowly grow a culture of feedback within their team, thereby increasing trust. Managers can show their openness by asking for feedback, through [1:1 calls]({{< ref "1-1" >}}) with direct reports or our performance management platform.

**How to apply asking for feedback:** It may be difficult to ask for feedback from team members as a manager. However, people leaders should be in the habit of regularly asking for feedback. Every 1-1 can be an opportunity for team members to share feedback on your performance. Managers must establish an environment built on trust with [no ego](/handbook/values/#no-ego) to enable team members to be forthcoming.

### Overcome Unconscious Bias

As people, we have a natural tendency to make assumptions about others, which means that once someone becomes a manager they might unintentionally favor some team members over others. [Unconscious bias](/handbook/company/culture/inclusion/unconscious-bias/) contributes to a major loss in trust between managers and employees.

**How to apply overcoming unconscious bias:** There are a host of free resources available to overcome unconscious bias. Managers and team members should spend time understanding their bias. Take the [implicit-association test (IAT)](https://implicit.harvard.edu/implicit/) as a first step. Block time on your calendar to take [Diversity, Inclusion, and Belonging](/handbook/company/culture/inclusion/) related training every quarter. Apply empathy to discussions amongst your team and put yourself in others shoes to better understand their perspective.

### Take Time Out To Learn

Managers can make it clear that they have a vested stake in team members career development by advocating for their team to take time to learn. Team members look to their managers to provide learning guidance. As a People Leader, send your team interesting articles, thought leadership studies, videos, etc, on the latest trends in your domain. Managers should advocate to take time to learn for reskilling and upskilling on a range of topics relevant to the job. Managers can set an example by fostering a learning culture within the organization by sending a strong message that it is okay to take time out to learn.

**How to apply taking time out to learn:** People leaders can send a clear message to their teams by sending them weekly learning exercises to break up the workweek. Try sending out interesting webinars and articles that are relevant to their job family. Encourage team members to take advantage of our tuition reimbursement policy to grow professionally. Managers can also encourage their team to block a portion of their week for focusing on professional development.

### "No Work Talk" Team Chats

Managers can set up a more relaxed call with their team that is specifically focused on personally getting to know one another as individuals. It helps to remind us all that at the end of the day, we're people and we have unique hobbies, interests, and milestones happening in our lives! **The only rule for this call: no talking about work!**

**How to apply "no work talk" team chats:** People leaders can set up a calendar invite (with all team members marked as optional) weekly or at a desired cadence. Encourage team members to join and get to know each other better in a remote environment. Come prepared with some possible ice breakers if the conversation doesn't immediately flow. An easy one: what are your plans for the weekend? Timezones can be tricky, so if you're team is represented globally and it's not possible to schedule a single time for all team members to join, it is recommended to rotate the time weekly so that everyone can be included.

### Host a "Lunch & Learn"

"Lunch & Learns" can serve as an opportunity for individual team members to drive training of the team on more complex functions. It doesn't have to be lunch for everyone; you can replace "lunch" with "breakfast," "dinner," or "snack" as teams are geographically and time zone diverse at GitLab. Allowing team members to "drive" the topic can help understand how they function and how their minds work. By enabling team members to support group activities, teams can see individual communication styles, and managers can understand where additional support may be needed. Having a clear understanding of learning styles can help team members and managers support individual and group needs.

**How to apply "lunch & learns":** A Manager can have the team pick a topic by quarter, and vote across the team, or a subject can be volunteered. For example, an accounting manager's team selected: complex deal types, ramped deals, and reseller billing as topics. Then have one or a few team members work to build the presentation and schedule the "lunch & learn" for the whole team. Ensure there is enough time for Q&A. They are a great way to understand what data we need to review, how we can present information in a meaningful way to learn, and helping the team recognize where their are knowledge gaps.

### Managers Enable Team Members to Make Decisions

Managers play a unique role at GitLab. When a team member on their team excels in their role, they should be given an opportunity to [make decisions]({{< ref "making-decisions" >}}). Allowing team members to play a role in decision-making can enable trust by catering to the team members' skills and attributes.

### Host a Team Day

Organized team days, like [this example from the Growth team](https://gitlab.com/gitlab-org/growth/team-tasks/-/issues/119) encourage trust and community building. If your team distributed across multiple time zones, enable async participation or have synchronous events across multiple time zones.

Below are potential team day activities:

1. Host a non-work related call, like a social hour or a time to share passion projects.
1. Give a tour to your team of your home town, your favorite place, or a dream vacation spot. Try sharing photos, Google Maps tours, and videos.
1. Play a Zoom pictionary/drawing guessing game. Try using the tool [Drawasaurus](https://www.drawasaurus.org/).
1. Host live or recorded Zoom classes based on team members skills, like cooking, crafts, fitness, or woodworking.
1. Organize a [Walk and talk](/handbook/communication/#walk-and-talk-calls) social chat, a team 5k walk or run, or some other kind challenge to get your body moving.
1. Create Slack social threads to solve riddles, play a trivia game, post GIFs to represent your day, and share photos.

#### More Ideas for Activities

- [Among Us](https://innersloth.com/gameAmongUs.php) - Free on mobile, multiple platforms.
- [Card & board game "table"](https://playingcards.io/) - Free!
- [City Guesser](https://virtualvacation.us/guess) - Free!
- [Drawasaurus](https://www.drawasaurus.org/) - Free!
- [Drawphone](https://rocketcrab.com/game/drawphone) - Free!
- [Escape rooms](https://brainchase.com/escape-rooms-for-parties-events/) - Small fee based on team size.
- [GeoGuessr](https://www.geoguessr.com/) - Free. Guess your location based on what you see in Google Street View.
- [Google Feud](https://googlefeud.com/) - Free. Like Family Feud but you're guessing Google autocomplete.
- [Jackbox](https://www.jackboxgames.com/) - Small fee for each pack. Only the host needs to own the game.
- Online multiplayer jigsaw puzzles ([1](https://jigsawpuzzles.io/), [2](https://www.jigsawexplorer.com/)) - Free!

## Learning Speaker Series - Building Trust with Remote Teams

On 2020-11-19, the L&D team launched our first [learning speaker series](/handbook/people-group/learning-and-development/learning-initiatives/#learning-speaker-series-overview) on Building Trust with Remote Teams. We hosted [Dr. Jeb Hurley](https://medium.com/@jebhurley/building-trust-on-remote-teams-99b937cbd5d0), CEO and Co-Founder of [Xmetryx](https://www.xmetryx.com/) to discuss how strategies and tips on how to build trust in a remote setting. The discussion was a [fireside chat](https://docs.google.com/document/d/17ziw6q-nioyzYGnnIa9LM1G3I4DwYfb2UxwN9XceFxg/edit) format where Dr. Hurley shared what remote team members can do to meaure trust on their teams.

{{< youtube "hHMDY77upAE" >}}

## Summary

Building trust takes time and energy. These are not the only strategies teams can apply to build trust but it is a start. Use this page as a guide to building a cohesive and collaborative team. Trust among teammates is the foundation of almost everything we do at GitLab.

If you have further suggestions on building trust in a remote team, make a merge request to this page and alert our [Learning & Development team](/handbook/people-group/learning-and-development/#how-to-communicate-with-us).
