---
title: Compensation Review Conversations
---

## Compensation Review Conversations

Conversations with regards to compensation are an important part of being a people manager. This page will take you through information and recommendations to effectively manage and guide these conversations. If you're ever in doubt or have a question, don't hesitate to reach out to your aligned [People Business Partner.](/handbook/people-group/#people-business-partner-alignment-to-division)

For more information for managers on the FY25 Annual Compensation Review Cycle, please refer to the [Manager Information Guide](https://docs.google.com/document/d/1ZSC0lVo3di9JFJy4kwy9QSGChrI8F3jdO34iG0yO3Sg/edit)

## Content to Review Prior to Compensation Conversations

Please make sure to review and understand the following content with regards to Compensation at GitLab:

- [GitLab's Guide to Total Rewards](/handbook/total-rewards/)
- [LevelUp Training: GitLab Total Rewards Compensation Fundamentals](https://levelup.gitlab.com/access/saml/login/internal-team-members?returnTo=https://levelup.gitlab.com/courses/total-rewards-compensation-fundamentals-training)
- [Compensation Calculator](https://comp-calculator.gitlab.net/users/sign_in)
- [Annual Compensation Review Cycle](/handbook/total-rewards/compensation/compensation-review-cycle/#determining-cash-compensation-increases)
- [Equity Refresh Program](/handbook/total-rewards/stock-options/)
- [Talent Assessment at GitLab](/handbook/people-group/talent-assessment/)

## Total Compensation Statements

For FY25, Total Rewards will be providing [Total Compensation Statements](/handbook/total-rewards/compensation/compensation-review-cycle/#total-compensation-statement) outlining the total compensation increase (cash and equity) and/or promotion received during Annual Compensation Review. We recommend reviewing this letter before the conversation and using the letter as preparation to communicate the compensation decisions and expected total compensation. It is also recommended that you send the letter to the team member after your conversation with them so they can view the details. You can find instructions on how to pull the Total Compensation Statement in the [job aid](https://docs.google.com/document/d/1zjWqzYKblfzH4fo2OfMzUU3fwWXfdX4ILwwzJqmMrww/edit)

### Compensation Communication Recommendations

- **Communicate the increase face-to-face over [Zoom](/handbook/communication/#zoom).** As a manager, this is an opportunity for you to have a conversation with your team member about their compensation, increase and/or equity refresh grant (if applicable). Having the conversation over Zoom allows for you to have a dialogue with your team member (versus just sharing the number) and allows you to pick up other information like tone and non-verbal cues which can tell you more about how someone is feeling.
- **Prepare for the call ahead of time.** As a manager, you should have awareness of the following facts about GitLab's compensation principles (please review the handbook's [Global Compensation](/handbook/total-rewards/compensation/) page), any recent changes to the compensation calculator/band and personal details about your team member in Workday:
  - Hire date
  - Current compensation (including base salary, variable pay (where applicable), equity etc.)
  - Date of last compensation adjustment
  - Performance Factor
  - Growth Potential Factor
  - Key Talent
  - Location factor changes
  - Benchmark changes
  - % and # increase: This number can be found on the Total Compensation Statement
- Communicate the change at the beginning of the meeting. You want to give the team member time to ask questions and discuss their compensation change. Avoid trying to rush to communicate at the end of a [1:1 meeting]({{< ref "1-1" >}}).
- Try to clearly explain the reasoning behind the compensation change. As Compensation differentials are related to performance, the preparation done for the [Talent Assessment conversation](/handbook/people-group/talent-assessment/#best-practices-for-communicating-performancegrowth-factors) could also be useful in explaining the "why". It is also recommended to review the Annual Compensation review page for [all considerations that go into compensation reviews.](/handbook/total-rewards/compensation/compensation-review-cycle/)
- Protect the confidentiality of other team members by avoiding saying things like "everyone else received less than you" or "you were the only team member to get a discretionary increase."
- Avoid blaming others (For example: "I would have given you more but management didn't approve.")
- Avoid making future promises (For example: "In the next review, I will get you a large adjustment.")

## Compensation Conversations Scenarios

This section provides and overview of potential compensation conversation scenarios with recommendations on how to approach and navigate these conversations.

### Compensation

1. **Receiving a Cash Compensation Increase**:

    Sample Script:

    - "I am so pleased to inform you that you will be receiving a cash compensation adjustment as a result of this year's compensation review. Your compensation increase is based on one or more the following factors (Talent Assessment, Location Factor/Geo Region, Benchmark change and/or Discretionary).
    - Your salary will be increased to (insert $ amount in local currency) which is a (insert %) adjustment effective, February 1st.
1. **Equity Refresh Grant (if applicable)**:

    Sample Script:

    - "I am (also) pleased to inform you that your equity refresh grant is approved at (insert USD). The following factors were considered in determining the equity refresh grant (Talent Assessment, Criticality of Role/Skills, Tenure, Unvested equity holdings). This means your total unvested equity is $XX based on the share price of $X (as listed on the Total Compensation Statement)".
    - "Thank you for your hard work and I look forward to continuing to work with you! Do you have any questions?"
    - **Recommended: If identified as [Key Talent](/handbook/people-group/talent-assessment/#key-talent)**: "Based on the impact you have on the business/ARR/Product/essential processes and your performance within that responsibility, I (or Senior Leadership) have identified you as Key Talent. This means we feel you fulfill a key role within GitLab and we value your skills and what you deliver to the company."
1. **Not receiving an increase or refresh grant:**   A team member is not receiving an adjustment:

    Sample Script:

    - Cash Compensation Sample Script:
    "As you know, GitLab just went through our Annual Compensation Review. I wanted to inform you that you are not be receiving a compensation adjustment at this time. This is due to (examples below)...
    - A team member is new to the team and at the market range for your aligned role.  "You are meeting performance expectations at this time (if applicable), however, we hire new team members at a competitive market rate and considering your recent start at GitLab, we feel that you are compensated accurately for your role at this time compared to peers in the organization.
    - A team member is not receiving because they are above range for their role.   "Your compensation is above the market pay range for your role and therefore you are not receiving an additional increase as a part of the Annual Compensation Review. You are meeting performance expectations at this time (if applicable), so let's discuss what you want to work on in the future and create a [development plan](/handbook/people-group/learning-and-development/career-development/) together."
    - A team member needs to improve performance. For questions on specific situations, please work with your People Business Partner.
    Equity Refresh Sample Scripts:
        - **A team member was eligible, *and was performing at expectations*, but is not receiving refresh grant**
        Not all team members were able to receive refresh grants, despite eligibility, as it is in the program setup/market alignment that we allocate only to a certain portion of our population. Aligned with our [expected distribution](/handbook/people-group/talent-assessment/#expected-distribution-company-wide/), typically organizations have ~25% of team members "exceeding", 60-65% "performing", and 10-15% "developing". Core performers make up the most significant population in organizations, meaning that difficult decisions needed to be made in this group in terms of who was granted a refresh and who was not.

        These were the factors considered that contributed to the decision to not allocate an additional refresh for you this year:

        - ***Not enough improvement on identified performance/growth areas:*** "Aligned with our performance discussion in FY23 we have identified improvement areas, such as [EXAMPLES]. Between that review and this equity review, there was not sufficient improvement in the areas identified. Therefore the decision has been made to not grant you additional equity at this time. I would love for us to further discuss those improvement areas and see how I can support you in meeting all expectations going forward. We review equity grants on an annual basis, and I hope we can work together to reassess your eligibility for next cycle."
        - ***Role or skill based decision:*** "Participation in this program was based on performance and criticality of role/skills. Therefore, not all team members will receive a refresh grant in the annual review cycle. However this is an annual process. You will be eligible to participate in next year's program."
        - ***Not in good standing with the company*** There could be factors that have contributed to the fact that currently the team member is not in good standing with the company. Examples here could be: Code of conduct violations or significant behavioral issues. As a communicating manager please discuss these with [Team Member Relations](/handbook/people-group/team-member-relations/) and your [People Business Partner](/handbook/people-group/#people-business-partner-alignment-to-division).
        - ***Has been with the company for a shorter period of time:*** Team members with less than 6 months tenure were not eligible for a refresh based on our eligibility cut off date. However, aligned with the equity refresh program setup and market alignment, not all team members who are eligible based on start date will receive a grant.  Tenure has relevance when considering overall impact of contributions so far, demonstrated performance and growth potential, and unvested equity levels. Tenure was a factor in considering grant allocations.
        - ***A team member's New hire equity grant was significant***.  "You are meeting performance expectations at this time (if applicable), however, with proposing equity refresh grants we review holdings against hire date and peers for equality. Based on that extensive review, we feel you are well positioned from an equity perspective for your role compared to peers in the organization.
1. ***Team member was hired after the cut-off date:*** "At GitLab we review compensation (cash + equity + benefits) on a yearly basis. Due to your hire date you were not eligible to receive additional compensation at this time. You will be eligible for the next Annual Compensation Review where we will review both your cash and equity compensation."
1. ***Team member is receiving either just a compensation adjustment or just an equity grant*** Please refer to the guidance above to explain to a team member why they may be receiving either just a compensation adjustment or just an equity grant.
1. ***Team member is receiving a (cash compensation increase/equity refresh grant) while on Leave:*** Our recommendation is to send this via email to the team members GitLab email address, but team members are not required to respond.

    Sample Email:

- "I am so pleased to inform you that you will be receiving a (cash compensation adjustment/equity refresh grant) as a result of this year's compensation review. You will see your compensation increase effective on February 1st.  Your (compensation increase/equity refresh grant) is based on one or more the following factors (Talent Assessment, Location Factor/Geo Region, Benchmark change and/or Discretionary).
Details of this will be outlined on the Annual Compensation Statement attached.
  - Your salary will be increased to (insert $ amount in local currency) which is a (insert %) adjustment (and/or)
  - I am (also) pleased to inform you that your equity refresh grant is approved at (insert USD). This means your total unvested equity is $XX based on the share price of $X (as listed on the Total Compensation Statement)".
Thank you for your ongoing commitment to results at GitLab! If you have any questions you can reach out, otherwise this email is for your information only and no reply is required."

1. **Other scenarios:** If you have a scenario different from the above, and/or you need help with messaging, please work with your manager or [People Business Partner](/handbook/people-group/#how-to-reach-the-right-member-of-the-people-group).
    - Although informing a team member that they are not getting a compensation adjustment and/or equity grant is a tough message to deliver, managers should have this direct conversation. This is directly aligned with our transparency value. We want everyone to know why they may not have received an adjustment and give them the space to ask questions.

#### Possible Reactions

1. A team member is not happy with their compensation adjustment (cash and/or equity).
    - Listen to your team member's feedback and allow them to express their concerns.
    - Ask open ended questions to allow for the team member to share more (like what were your expectations for an adjustment this year? Why were those your expectations?)
    - Reiterate GitLab's compensation philosophy. We pay to market based on the compensation calculator and increase compensation annually based on performance.
    - Point your team member to the Compensation Calculator where they can see the range for their role.
    - If your team member is in good standing from a performance perspective, work with them to put together a [development plan](/handbook/people-group/learning-and-development/career-development/) to help them achieve their goals (e.g. skill development or a promotion).
1. A team member is not happy with their performance and/or growth potential rating.
    - Listen to your team member's feedback and allow them to express their concerns.
    - Refer back to the conversation you had with your team member at the time performance/growth potential ratings were determined and reiterate the justification and feedback that you provided at that time.
    - If your team member is in good standing from a performance perspective, work with them to put together a [development plan](/handbook/people-group/learning-and-development/career-development/) to help them continue to grow.

**If you need assistance after reviewing the [handbook](/handbook/total-rewards/compensation/), please work directly with your manager or your [People Business Partner](/handbook/people-group/#people-business-partner-alignment-to-division)**
