---
title: Crucial Conversations
description: "GitLab's strategies for being an effective leader during crucial conversations with team members"
---

Any synchronous or asynchronous engagement with team members may turn into a crucial conversation. At GitLab, we can develop the skills of sensing the tone of an async or sync conversation to uncover potential pain-points, risks, blockers, etc for team members. We need to find a way to create [psychological safety]({{< ref "psychological-safety#introduction" >}}) for our people. Using a 1-1 can be a great way to gain context on a situation a team member is facing and hold a crucial conversation.

Team members can take a [crucial conversations training](/handbook/people-group/learning-and-development/learning-initiatives/crucial-conversations/) led by the Learning and Development team.

What is a Crucial Conversation: According to the [book](https://www.amazon.com/Crucial-Conversations-Talking-Stakes-Second/dp/0071771328/), a conversation to be crucial is that the results of it could have a huge impact on the quality of your life. A conversation involving a promotion, performance, debate between coworkers, etc. In short crucial conversations are discussions between two or more people where:

1. Stakes are high
1. Opinion vary
1. Emotions run strong

Most of us are good at avoiding them because it's human nature to avoid pain and discomfort when addressing a crucial conversation. So what do you do when faced with a crucial conversation?

1. We can avoid them
1. We can face them and handle them poorly
1. We can face them and handle them well

At GitLab, there can be many instances where a crucial conversation is needed. Whether it is addressing the underperformance of a team member, discussing the results of promotion, interviewing, being notified that a high performer is leaving the team, etc. The Crucial Conversations book has strategies laid out that can help master one:

1. **Power of Dialogue:** Gaining information and context on the situation. The free flow of meaning between two or more people.
1. **Shared Meaning:** Each of us enters conversations with our own opinions, feelings, theories, and experiences about the topic at hand. Coming to a shared opinion and entering a pool of a shared meaning helps our synergy with team members in many ways. Adding information to the shared pool of meaning requires each person to take meaningful ownership of their role in the conversation.
1. **Start with the Heart:** If you can't get yourself right, you'll have a hard time getting dialogue right by looking inward first. Apply empathy in the moment by asking questions to yourself that return you to the dialogue:
   - What do I really want for myself?
   - What do I really want for others?
   - What do I really want for the relationship?
   - How would I behave if I really wanted these results?
1. **Learn to Look - How to Notice When Safety is at Risk:** It can be difficult to see what exactly is going on and why during crucial conversations. Watch for these situations to learn to spot one:
   - The moment a conversation turn crucial
   - Signs that people feel safe
   - Your own style under stress
1. **Make It Safe:** Nothing kills dialogue faster than fear. When you make it safe, you can talk about almost anything and people will listen. If you spot safety risks as they happen, you can step out of the conversation, build safety, and then find a way to dialogue about almost anything.
1. **Master Your Stories:** Learn to exert influence over your feelings by slowing down the storytelling process, take a step back, and retrace your path to action one element at a time.

These are just a few strategies outlined in the Crucial Conversation book. We [highly recommend reading it](/handbook/leadership/#books) for leading teams at GitLab. Team members can also sign up to take our in-house [Crucial Conversations training](/handbook/people-group/learning-and-development/learning-initiatives/crucial-conversations/).

## How Crucial Conversations align with GitLab Values

| GitLab Value | Crucial Conversation Connection |
| ----- | ----- |
| [Collaboration](/handbook/values/#collaboration) | Crucial conversations are introduced not just by people leaders but by all GitLab team members. We are all managers of one and should feel enabled to open crucial conversations whenever necessary. Building a shared pool of meaning in a discussion requires everyone in the conversation to share to be successful. |
| [Results](/handbook/values/#results) | Crucial conversations are results-oriented. Conversations should focus on action that will improve the situation or problem for all members involved in the conversation. |
| [Efficient](/handbook/values/#efficiency) | Crucial conversations can be evaluated via the CPR (Content, Pattern, Relationship) method to determine the root cause of the conflict or problem. This method allows for efficiency in approaching crucial conversations with specific tools depending on the context. |
| [Diversity, Inclusion, and Belonging](/handbook/values/#diversity-inclusion) | Everyone has a shared voice in a crucial conversation. The goal is to fill a shared pool of knowledge with facts and stories from all points of view. Hosts of crucial conversations should be open to having their stories challenged. |
| [Iteration](/handbook/values/#iteration) | Crucial conversations should happen early and often. The CPR (Content, Pattern, Relationship) encourages conversation early and often in the `content` category before something becomes a `pattern` |
| [Transparency](/handbook/values/#transparency)| Results, goals, and stories about crucial conversations are shared throughout teams to encourage more crucial conversations. While the content of specific conversations isn't always shared to maintain a safe space, the discussion about practicing crucial conversations keeps us accountable. |

## Strategies for Successful Crucial Conversations

### 9 Influencing Strategies

The ability to influence is an essential leadership skill. To influence is to have an impact on the behaviors, attitudes, opinions and choices of your team members and others across GitLab and externally. Influence should not be confused with power or control. It is also not about manipulating others to get your own way. It is about noticing what motivates team members commitment and using that knowledge to leverage performance and results.

[Leadership]({{< ref "leadership" >}}) has sometimes been described as the ability to influence others. An effective leader does not move team members into action by coercion. An effective leader will articulate the overall vision and goals for the organization. By doing such this can motivate and move team members to action by tapping into their desires and need for success. Positive influence that is properly channeled can also bring about transformation and change for team members, department, division and the company. A leader that exhibits and exerts positive influence in others will build trust and become a true driving force towards transparency, iteration, collaboration and results.

There are many different influencing strategies and in this section we are going to review 9 that leaders can review. Each strategy below will include a definition, example and ways for leaders to develop this strategy.

1. **Empowerment**: Making others feel valued by involving them in decision making and giving them recognition.
    - Example: Manager invites their team members to a meeting in order to take their inputs on how to improve product quality.
    - Develop: Finding win-win situations, not taking people for granted, not providing unsolicited advice to people and having confidence in the ability of others.
1. **Interpersonal Awareness**: Being able to recognize and address the concerns of key stakeholders.
    - Example: A manager/leaders offers support to team members by identifying a list of questions that may be asked in meetings with senior leadership.
    - Develop: Awareness of verbal and non verbal cues, putting yourself in another person's shoes and testing your own understanding of the message.
1. **Negotiating**: Gaining support from others by mutually agreeing on a common set of goals or outcomes.
    - Example: A vendor who is trying to land a big deal may offer their client incentives or a discount provided the size of the order large enough.
    - Develop: Understand the other person's requirements, identify your non-negotiable, role-play with a colleague, practive in a low risk real life situation.
1. **Networking**: Establish and maintain a network of contacts who you may need to influence going forward.
    - Example: A manager spends time with their peers or cross functional partners in different activities (either work or non work related) in order to develop a better bond/relationship with their network.
    - Develop: Take interest in other peoples lives, find common ground, leverage existing relationships and take advantage of existing opportunities.
1. **Stakeholder awareness**: Identifying the key stakeholder and the ability to gain support when needed.
    - Example: A manager identifies the key stakeholder and decision maker within a supporting organization and regularly meets with them to collaborate.
    - Develop: Keep your ear to the ground to understand what is happening around you, learn by example, identify the decision makers, appreciate other's points of view.
1. **Shared vision**: Showing others how your ideas support the broader organizational vision.
    - Example: A manager communicates their vision to their team by helping them understand what they can become and the steps needed to achieve the goal.
    - Develop: Always keep the outcomes in sight, speak about the benefits of the approach and get others to participate.
1. **Impact and Influence**: Choosing the most appropriate time and manner to present your point, always keeping in mind your audience.
    - Example: A manager understands the landscape or demographics of their audience and is thoughtful in their presentation approach.
    - Develop: Study prominent influencers, try different approaches each time, take formal training, model good influencers within the organization.
1. **Analytical reasoning**: Using analytical reasoning to convince others about your point of view.
    - Example: A team member uses data and market insights to convince their manager about their ideas.
    - Develop: Have more than 1 reason for your idea, clearly lay out the pros and cons, show clarity of thought and structure, spend time on research and case studies.
1. **Coercion**: Using threats or pressure tactics to get other to agree to your point or to comply to rules.
    - Example: A manager makes a decision with no or little input from team and informs team members of actions or consequences if they do not comply.
    - Develop: Use it sparingly and not as the first resort, leave no room for ambiguity and do not use as a way to surpress your team member or others.

### Having crucial conversations on an all-remote team

Having crucial conversations via a Zoom call might be more difficult than having the conversation in person. These strategies are meant to identify what makes having crucial conversations in an all-remote environment challenging and things we can try to make the conversations more effective.

1. Pre-populate your [1:1 meeting agenda]({{< ref "1-1" >}}) so that everyone can come prepared to have meaningful conversations. The ability to prepare ensures that everyone in the conversation knows the topics that will be discussed and can prepare in advance.
1. In a video call, we might miss out on key body language markers that are more apparent when having conversations in person. Focus on the body language queues we can see. Does someone who typically uses video have their video off, or does someone turn their video off suddenly? Does the person seem to be looking away or looking down, avoiding the screen?
1. If an async conversation is starting to get heated and is veering away from productive dialogue, move to a synchronous call to increase safety.
1. Async conversations make it easier for us to hold off a response until emotions cool off, preventing a fight or flight response. This can be helpful in some cases but watch out for its detriments. It's important to speak up about projects or conversations that make you feel upset or unheard.
1. It's easy to assign tone to text-based communication. The tone we assign can influence the story we tell ourselves. We can avoid this by [assuming positive intent](/handbook/values/#assume-positive-intent). Emoji can help to add context to text-based commuication.
1. Make space for pause. Silent pauses on a phone call might feel awkward or uncomfortable. These pauses are necessary for people to process feelings and stress and craft thoughtful responses during crucial conversations. Try using these phrases if you need to create a space for silence:
     - `Can we wait one second before moving on to that topic?`
     - `I need a minute to think through this one.`
     - `Can we take a pause for a minute?`
     - `I need a few extra seconds/minutes to think through my response here`
     - `I think I got defensive there - let me take a second to regroup`
1. If you're in a crucial conversation and a team member uses one of these phrases to indicate they need a pause, remember to respect their need for time by:
     - Don't try to fill the space with more talking. Let there be a minute or two of quiet on the line.
     - Let your eyes gaze around the room, down, or at your notes if you need something else to focus on
     - Wait until the person you're speaking with initiates conversation again before speaking
1. Asking questions lets everyone determine what facts and stories are present in the conversation. They can be can asked in a synchrounous and async formats. Example questions include
     - `What do you think?`
     - `Can I get your perspective/a different perspective on this?`
     - `How do you feel?`
     - `Can I get your feedback on...`
1. During a crucial conversation, different priorities might come up from members in the conversation. It's important to determine what conversation people are prepared to participate in and what topics are most important and efficient to address. Determining the root cause of the conversation is important here. Think about questions like:
     - `Is this turning into a performance discussion?`
     - `Do we need to reschedule so we can all prepare?`
     - `Is this conversation about a specific problem?`
     - `Has this problem happened before?`
     - `What is the most pressing issue to address?`
     - `Is what is pressing for me the same thing that is pressing for others in the discussion?`
1. Historical messages in tools like GitLab and Slack might help you gather information about the tone and communication patterns of people you're having crucial conversations with.
1. Transparency in GitLab projects, Slack statuses, and Google Calendar gives us a picture into what projects our remote team members are working on. We can use this as a tool to help fill our own pool of meaning and have a deeper understanding for the workload that our peers have.
1. Give team members who are uncomfortable verbalizing in a group on call the option to ask someone to `please verbalize`. While GitLab issues and Slack may be more comfortable areas for them to contribute, decisions do get made on Zoom calls. Encourage team members to add their input in the agenda doc or Zoom comments section with `please verbalize` in parentheses. The lead for the call should then verbalize their input to the larger group, so it becomes part of the discussion. This can help create a safe space for their ideas to be shared.

## What GitLab Managers Say about Crucial Conversations

During the Manager Challenge Program, we asked GitLab Managers what they had to say about holding crucial conversations

1. "As noted in Crucial Conversations finding that shared goal and relying on the trust in the conversation ensures the dialogue will be non-threatening."
1. "The hardest conversations are with those who are not performing and helping them understand what they need to work on or improve upon.  The joy is when they do respond and approve, which happens more than not.  The other conversations is mentoring and seeing the growth from it. The joy is to see them prosperous and I've had many work for me again.  Those to me are both sides of the equation."
1. "One thing that I can add to my list, letting someone go due to budget cuts. I find that difficult to inform a great performer and team player that they are being let go. Because it is human to feel that it is tied to performance. Luckily, in the end, they do find a new role quickly."
1. "We are so lucky with working async that we have the benefit of time to reflect before responding (part of "master your stories"). I took a moment to think about where things went awry and where I was responsible, so that I could own it and apologise first. The next step was to realign – we actually have the same goals overall, just different ideas about how we would get there. I reaffirmed what we had in common and asked them to contribute how they would go about things, which turned the conversation back to working towards a solution together."
1. "Something that I'd like to practice where applicable is to step out of a heated conversation and continue another time if possible. This is not to avoid the issue, and also, this won't suit every scenario but can help to reset the mind."
1. "One that has come up is with a team member that may want to branch out to another area within the company. This was a big deal for them to talk to me about, so I wanted to make sure they knew it was a safe space for them to do it. I never want to stand in someone's way of improving themselves or trying new challenges.  I think my reaction of being enthusiastic as opposed to negative was very helpful in keeping the conversation flowing."
1. "Performance reviews can easily turn into crucial conversations. This is one reason why it is so important to make performance and career development a consistent topic throughout the year, and not a one-off conversation that happens cyclically."
1. "Product strategy. Sometimes you have to make the unpopular/hard call to say no to continue investing in a product area. The people involved tend to be passionate about their positions, and the outcome affects not only the people working on execution, but also the company's position in the market and the bottom line."
1. "I'm a new manager, and I started my role by doing performance reviews with the team. These very crucial conversations since I haven't been their manager for long, and I had to provide them with performance feedback and career development guidance."

### Additional resources

Below are additional resources on influencing and leadership for you to review.

- [Team Members: Take the Crucial Conversations Training at GitLab](/handbook/people-group/learning-and-development/learning-initiatives/crucial-conversations/)
- [What Great Leaders Know about Influence](https://www.forbes.com/sites/rebeccanewton/2016/07/27/six-steps-to-increase-your-influence/#5609705a1edd)
- [Influencing Skills: A Key to Leadership Success!](https://www.linkedin.com/pulse/influencing-skills-key-leadership-success-marcia-zidle-ms-bcc/)
- [Influencing Others: A Key Leadership Skill](https://www.ginaabudi.com/influencing-others-a-key-leadership-skill/)
- [The 5 Key Skills of Influential Leaders Within Every Organization](https://www.inspirationaldevelopment.com/5-key-skills-influential-leaders-every-organisation/)
- [Influence and Leadership](https://www.deeelliottconsulting.com/leadership-and-influencing/)
- [5 Leadership Strategies Proven to Improve Performance on Your Team](https://crestcom.com/blog/2016/12/01/5-leadership-strategies-to-improve-performance-in-your-company/)
- [The 7 Best Books to Improve Influencing Skills](https://www.roffeypark.com/articles/the-7-best-books-to-improve-influencing-skills/)
- [7 Ways to Build Influence in the Workplace](https://www.inc.com/jayson-demers/7-ways-to-build-influence-in-the-workplace.html)
- [The Power of Vulnerability](https://www.youtube.com/watch?v=iCvmsMzlF7o)
