---
title: Effective Delegation
---

## Effective Delegation

The purpose of this section is to give you the following:

- An appreciation for the importance of delegation to others as a way to manage workload and prioritize action items.
- Face any fears that you may have regarding delegating to others.
- Help you adopt an appropriate strategy to delegate the right tasks to the right people at the right time and in the right way.
- Help you develop a systematic step-by-step approach to brief team members on what you want to delegate to others.

### What is delegation?

Delegation is the assignment of responsibilities to another person for the purpose of carrying out specific job-related activities.  Delegation is a shift of decision-making authority from one team member to another.

### Considerations when delegating

Before further diving into delegation, it's important for you as a leader to consider whether delegation is the right thing to do. In this [Situational Leadership Strategy](https://about.gitlab.com/blog/2021/11/19/situational-leadership-strategy/) article, GitLab's co-founder and CEO Sid Sijbrandij gives an overview of 4 leadership styles discussed in Situational Leadership Theory and the factors he considers when determining whether to delegate.

### Benefits of Delegation

**Manager/Leader Benefits**

- Reduced stress
- Improve time management
- Increased trust

**Team Member Benefits**

- Professional knowledge and skills development
- Enhanced self-esteem and confidence
- Sense of achievement

**GitLab Benefits**

- Increased teamwork and collaboration
- Increased productivity and efficiency

### So why do managers struggle with delegation?

As a Manager, we have to delegate tasks and activities to achieve results. Delegation only works when both the team member and manager share a common understanding of the problem set and how to go about solving them. If a Manager doesn't understand fully what they are delegating, achieving results could be slowed down. Delegation without follow-through by the manager is abandonment. When delegating tasks, consider monitoring the team member's progress based on their level of competence/skills with the tasks.

**Additional reasons why managers struggle with delegation:**

- It is too hard
- It takes too much time
- Nobody can do it as well as I can
- Nobody else has the time
- They are scared things will fail
- They lack trust in their team members
- Leaders get caught up in all the details
- Leaders feel the sense of a loss of control
- Leaders "worry" about quality

**Knowing when and to whom you should delegate to**

Delegating can be especially helpful in the following situations:

- When the task offers a valuable training opportunity for a team member
- When a team member has more knowledge or experience related to the task than you
- When the task is recurring and all team members should be trained
- When the task is of low priority and you have higher priority tasks that require your immediate attention

When deciding who to select for the task, you must consider:

- The team members current work load
- The strengths and weaknesses of the team member
- The experience and skill level of the team member

**IDEAL** - Six steps of delegations.  In this section we will review the 6 different steps and approaches for enhancing your delegation skills.

**I** - Introduce the task
**D** - Demonstrate clearly what needs to be done
**E** - Ensure understanding
**A** - Allocate authority, information and resources
**L** - Let go
**S** - Support and monitor

**Introduce the task**

- Determine the tasks to be delegated
- Determine the tasks to retain
- Select who you will delegate the task to

When you introduce the task use "What-Why" statements like "I want you to do ... because you ..."

**Demonstrate Clearly**

- Show examples of previous work
- Explain objectives
- Discuss timelines, expected outcomes and then set a deadline

**Ensuring Understanding**

- Provide clear communication
- Ask the team member if they need additional clarification
- Secure commitment that the team member can achieve the objective
- Collaboratively determine methods for follow up

**Allocate authority, information and resources**

- Grant authority to determine process, not desired outcomes
- Provide access to all the information sources
- Refer team members to specific resources and other team members that have been assisting with the task in the past or present
- Provide any appropriate training necessary to ensure success

**Let go**

- Communicate to the broader audience the team members authority and ownership of task
- Step back, let the team member get to work
- Don't allow yourself to engage in reverse delegation or step in take over (unless the task is completely going off the track or potentially going to miss the deadline by a significant amount of time) Reverse delegation is a term that describes a situation whereby a manager delegates a task to their direct reports, but only to take it back, for one reason or another, to work on it sometime later.  There are two ways, forced and unforced, that reverse delegation may take place.

**Support and Monitor**

- Schedule follow-up meetings
- Review progress
- Assist, when requested
- Avoid interference
- Publicly praise progress and completion
- Encourage problem-solving

## Delegation Stressors

**"Why do Managers...?"**

- Loss of control - If you train your team members to apply the same criteria as you would yourself, then they will be exercising your control on your behalf.
- Too much time spent on explaining the tasks: The amount of time you spent up front is, in fact, great.  But, continued use of the team member may free you up to complete more complex tasks and/or gain you some time for yourself.
- Compromising your own value - By successfully delegating to team members, your value to the department, division and GitLab will grow at a faster rate as you will have more time to do more things.

**Delegation Obstacles**

- Lack of support - Manager and team members must be fully supportive of the delegation efforts in order to be successful
- Failure to plan - Taking the time to follow the steps for delegation can avoid any pitfalls that might otherwise be overlooked
- Lack of communication - Communicating the plan in a clear and precise manner prevents errors caused by miscommunication
- Fear of relinquishing control - Management may be resistant to delegating at first, but delegation can build trust and morale among managers and team members
- Micromanagement - Micromanagement prevents team members from completing their assigned tasks and defeats the purpose of delegation
- Interruptions - Managing our time is a key attribute to increasing the managerial output of the teams we lead. Interruptions can occur a lot. Ask yourself how you can strive toward regularity and prevent stops and starts in your day.

**Signs of Micromanagement**

Micromanaging occurs when a manager assigns a task to a team member, but prevents the team member from successfully completing the task on their own.  Micromanagers usually:

- Resist delegating
- Prevent team members from making decisions
- Revoke tasks after they have been assigned
- Avoid letting team members work independently

**How to avoid Micromanagement**

- Clearly define the roles and responsibilities of managers and team members
- Create a written plan and timeline
- Include scheduled meetings and evaluations rather than frequent "check ins'" that can be viewed as micromanaging
- Allow team members and managers to openly communicate any concerns or questions they may have

**Consequences of poor delegation**

- Information and decision-making is not shared by the group
- Leaders become tired our or burnt out
- If a leader leaves the group, no one has the experience needed to carry on
- Team or group morale becomes low and people become frustrated and feel powerless
- The skills and knowledge of the group/division/department are concentrated in a few people
- New team members do not find any meaningful ways to contribute to the work or growth of the group

**Conclusion**

Practice makes perfect.  It gets easier the more you do it!  Below are a few useful articles for managers regarding the importance of delegation.

- [Managers Must Delegate Effectively to Develop Employees](https://www.shrm.org/resourcesandtools/hr-topics/organizational-and-employee-development/pages/delegateeffectively.aspx)
- [Why Aren't You Delegating](https://hbr.org/2012/07/why-arent-you-delegating)
- [Management Tips: 10 Reasons To Delegate](https://www.bakercommunications.com/archive/apr13/management04013.html)
- [The Benefits of Delegation and Why Most Leaders Under-Delegate](https://www.yourthoughtpartner.com/blog/the-benefits-of-delegation-and-why-most-leaders-under-delegate)
- [How to Delegate Tasks Effectively and Why it is Important](https://www.meistertask.com/blog/delegate-tasks-effectively/)

**Books to consider reading**

- [If You Want It Done Right, You Don't Have to Do It Yourself! The Power of Effective Delegation](https://www.amazon.com/Want-Done-Right-Dont-Yourself/dp/1884956327)
- [The Busy Manager's Guide to Delegation](https://www.amazon.com/Busy-Managers-Guide-Delegation-Worksmart/dp/0814414745)
- [The Art of Delegation: Maximize Your Time, Leverage Others, and Instantly Increase Profits](https://www.amazon.com/Art-Delegation-Maximize-Leverage-Instantly/dp/1508606463/)
- [How to Delegate - Essential Managers series](https://www.amazon.com/Delegate-Essential-Managers-Robert-Heller/dp/0789428903/)
