---
title: Emotional Intelligence
---

## Introduction

At GitLab, we place a high level of importance on interpersonal skills for workplace effectiveness. Employee interpersonal skills have an impact on productivity, morale, engagement, performance, and help us [live up to our values](/handbook/values/). Whether you are a People Manager or an Individual Contributor, being skilled in "emotional intelligence" (also referred to as EQ) is a key attribute to interpersonal effectiveness.

One of the most important factors in people's decisions to stay or leave a job is the quality of the relationship they have with their immediate boss and their coworkers. There are practical ways to learn and apply interpersonal skills in a remote environment. In this section of the handbook we review the key characteristics of emotional intelligence (EQ) and how to improve your interpersonal skills professionally and personally. You'll learn how to work more effectively with others.

## What is emotional intelligence?

![ven diagram explanining elements of emotional intelligence.](eq-diagram.jpg)
{.shadow.medium.center}

EQ is defined as the ability to understand and manage your own emotions, as well as recognize and influence the emotions of those around you, according to [Harvard Business review](https://online.hbs.edu/blog/post/emotional-intelligence-in-leadership). At GitLab, we operate in an [all-remote environment](/handbook/company/culture/all-remote/guide/) where [team members communicate](/handbook/communication/) virtually across the globe. By fostering EQ, we can establish a level of connection in an all-remote environment.

Better EQ provides better relations with remote teams. EQ plays an important role in helping maintain order between teams that consist of [diverse cultures and backgrounds](/handbook/company/culture/inclusion/). At GitLab, we rely on [low-context communications](/handbook/company/culture/all-remote/effective-communication/), [Slack channels](/handbook/communication/chat), email, and [video calls](/handbook/communication/#video-calls) to get our message across. There are less opportunities to practice our EQ.

Considering that these communication channels do not always express our true feelings, developing our EQ will be a tool for us to pick up on emotional cues and help us read between the lines to better understand the message.

Learn more about emotional intelligence by watching this session titled Being Human with Claire Doody, hosted by the GitLab L&D team in September, 2022. Hear from more experts in conversations hosted by GitLab with [Reini Chipman on Diversity in Emotional Intelligence](https://youtu.be/DErrcLrw-ag) and [Christopher Connors on EQ for Modern Leaders.](https://youtu.be/6gwPV6Y5YUQ)

{{< youtube "ai6DbsNIOF4" >}}

## Building an inclusive environment with EQ

EQ is a major factor in developing and maintaining [cultural awareness](/handbook/company/culture/all-remote/building-culture/). By fostering emotional intelligence, you are able to promote understanding, respect, and good relationships across all teams, regardless of their locations.

It is a tool that is helping GitLab build an [inclusive environment for everyone](/handbook/company/culture/inclusion/building-diversity-and-inclusion/). By understanding that others might have different responses and customs based on their upbringing, you can develop social and emotional intelligence.

## Components of EQ

There are five main components of EQ:

| What it's called | What it means | Competencies to measure |
| ----- | ----- | ----- |
| **Self Awareness.**  | The ability to identify and understand your own emotions and the impact we have on others. | Emotional Self-Awareness, Accurate Self-Assessment, and Self-Confidence |
| **Social Skills.** | The ability to understand the emotions of others through empathy by identifying what others feel and sharing emotion. | Empathy, Organizational Awareness, and Service |
| **Self Regulation.** | The ability to manage emotions and behaviors. When we are aware of our emotions we can begin to manage them. | Emotional Self-Control, Transparency, and Adaptability & Initiative |
| **Relationship Management.** | The ability to build and maintain healthy relationships through conflict management, teamwork, and to inspire others. | Inspirational Leadership, Influence, Developing Others & Teamwork, and Conflict Management |
| **Motivation.** | The ability to pursue goals with energy and persistence and a passion to work for reasons that go beyond money or status. | Optimism , Organizational Committment, and Achievement  |

The components of EQ were developed by psychologist and writer Daniel Goleman and his colleagues. They documented how people with high EQ outperform others in terms of success as managers and executives, yearly sales, and lower turnover rates. Furthermore, they have shown the increasing importance that EQ plays as professionals progress in their careers and reach higher levels of management.

Pure technical skills and intellectual ability are prerequisites for top positions, but they do not differentiate top performers from the rest as well as interpersonal abilities do.

## How to develop your EQ in a remote environment

*Click the numbers in the interactive image below to learn more.*

<div style="width: 100%;"><div style="position: relative; padding-bottom: 99.45%; padding-top: 0; height: 0;"><iframe frameborder="0" width="1083" height="1077" style="position: absolute; top: 0; left: 0; width: 100%; height: 100%;" src="https://view.genial.ly/630fb3c75f08a40011b7201c" type="text/html" allowscriptaccess="always" allowfullscreen="true" scrolling="yes" allownetworking="all"></iframe> </div> </div>

1. **Control your self-expression and perceptions.** At GitLab, we rely on [written communication](/handbook/company/culture/all-remote/effective-communication/) and [virtual calls](/handbook/communication/#video-calls) as opposed to working in an office where we can rely on [in-person interactions](/handbook/company/culture/all-remote/in-person/). As remote workers, we not only have to collaborate on projects but we are also responsible for building relationships, trust, and rapport with other colleagues through a screen. To build trust with a team, we need to understand how we express emotions to others through various communication methods.
1. **Understand how your actions can impact others.** At GitLab, our default form of [communication is asynchronous](/handbook/company/culture/all-remote/asynchronous/) through text. Written communication among remote teams can lead to misinterpretations. Be aware of what actions you need to take in delivering a message. Put yourself in the reader's shoes when [crafting a message through text](/handbook/company/culture/all-remote/effective-communication/). Empathize with them and view the message from multiple audiences.
1. **Self-awareness (know yourself).** Understanding yourself means being aware of your own emotions, strengths and weaknesses, your values, and what motivates you. There are strategies we will detail below on gaining a better understanding of your own EQ and how it impacts others, but improving your interactions with others begins with self-awareness.
1. **Know your stressors (self-regulation).** Managing your emotion in stressful situations requires an understanding of how you can adapt to changing situations. Identify what stresses you out and take proactive steps to mitigate them. Keeping your cool and accepting the fact that you can't control everything. An emotionally intelligent person thinks how their emotional expressions affect others.
1. **Strengthen your social skills.** Team members with strong social skills are able to communicate their thoughts and ideas effectively in a remote setting. At GitLab, we are intentional about using [informal communication](/handbook/company/culture/all-remote/informal-communication/) to strengthen social relationships. Set up a [coffee chat](/handbook/company/culture/all-remote/informal-communication/#coffee-chats) or join a [team social call](/handbook/company/culture/all-remote/informal-communication/#team-social-calls) to get started. Strengthen your own social skills by actively listening and providing [feedback](/handbook/company/culture/all-remote/effective-communication/#feedback-is-a-gift) during virtual discussions.
1. **Build your motivation.** A key component of EQ is having intrinsic motivation to achieve goals. At GitLab, every team member is a [manager of one](/handbook/values/#managers-of-one). Being self-motivated (by adopting a [self-service and self-learning mentality](/handbook/company/culture/all-remote/self-service/)) should be paramount in defining what you can accomplish in a remote setting. Focus on the aspects of the job you really enjoy and use those to drive your personal and team success forward.

## Emotional Intelligence Manager Competency

Emotional intelligence is a key skillset for all team members at GitLab. For Managers, it is an essential attribute that can help enable team dynamics and ensure your people are receiving the right level of professional development as they progress in their careers.

Skills and behavior of the emotional intelligence [manager competency](/handbook/people-group/competencies/#list):

- Actively displays self-awareness and self-regulation through the use of empathy
- Models high level of emotional intelligence while balancing with hard and soft skills
- Applies emotional intelligence to personalize their management approach with each team member that focuses on the whole person approach to management
- Drives an organizational strategy and culture that ensures courtesy and politeness in all interactions
- Recognizes pressures/problems faced by team members and provides sympathy and understanding

## How to understand your EQ

In order to develop your EQ, you need to understand your current baseline of how developed the skill is. Take one or more of the many free EQ assessments below to gain a better understanding of where you stand. Share the results with your team. If you are a [manager]({{< ref "leadership" >}}), encourage your team to take one of the assessments. Use the results to tailor discussions and interactions with them. The more you know about your team personally and professionally, the more you can strengthen your EQ.

### Emotional intelligence (EQ) assessments

1. [Color Code Personality Test](https://www.colorcode.com/free_personality_test/?timestamp=1588009250.89&hash=667424d7d32a031b41b6896af6ab1ad7)
1. [Global Leadership Foundation EQ Test](https://globalleadershipfoundation.com/geit/eitest.html)
1. [Mind Tools EQ Quiz](https://www.mindtools.com/pages/article/ei-quiz.htm)
1. [University of California at Berkley EQ Assessment](https://greatergood.berkeley.edu/quizzes/ei_quiz/take_quiz)
1. [Psychology Today EQ Test](https://www.psychologytoday.com/us/tests/personality/emotional-intelligence-test)
1. [Growth versus Fixed Mindset Assessment](https://blog.mindsetworks.com/what-s-my-mindset)

## Related pages on emotional intelligence (EQ)

- [Understanding SOCIAL STYLES](/handbook/leadership/emotional-intelligence/social-styles/)
