---
title: Psychological Safety Short Course
---

## Introduction

Welcome to Psychological Safety: Understanding, Empowerment & Self-Reflection

This is a short course designed to help with your understanding of psychological safety, provide pragmatic steps to cultivate a culture of psychological safety within in your team, and reflect on some of your behaviours that may appear psychologically safe or unsafe.

We are doing this to ensure we create an environment where everyone is able to thrive, as well as easily embody our values of Collaboration, Results, Efficiency, DIB, Iteration and Transparency, and the operating principles that accompany this. In this course you will see how certain actions can quickly lead to erosion of these values and the erosion of trust amongst team members.

There are two ways to take the course. You can:

- Watch the [videos](https://levelup.gitlab.com/access/saml/login/internal-team-members?returnTo=https://levelup.gitlab.com/learn/course/psychological-safety-understanding-empowerment-and-self-reflection) on Level Up.
- Read the content, which can be done on Level Up where you achieve your badge.

You are free to do both of course, but the content is duplicated across the two mediums.

## Introduction to Psychological Safety

1. [Review the Psychological Safety Handbook Page]({{< ref "psychological-safety" >}})
1. **Welcome to Psychological Safety: Understanding, Empowerment & Self-Reflection**

### First, what is psychological safety?

*Psychological safety* was defined by Amy Edmondson as a "shared belief held by members of a team that the team is safe for interpersonal risk taking". It's not about being warm and fuzzy and sharing your feelings. It's about being comfortable admitting when you are wrong or have made a mistake as well as challenging each other for the better. You can view a great video of Susan David explaining this further in the handbook.

Here is an illustration of what a psychologically safe team and what a psychologically unsafe team would look like:

[Psychological Fear and Psychological Safe](https://docs.google.com/presentation/d/18kMSpBQBbJ0qvpviYxfegwP7_UXEG0zjMX3E_51srHY/edit#slide=id.g8c87dcb54b_0_0)

As you can see, the opportunity to live our values in the red zone is very difficult. Collaboration, Iteration, Transparency, and Diversity of thought would disappear. This will ultimately lead to poor results. We want to ensure we create a green environment where everyone is given the freedom to thrive at GitLab.

Creating a Psychological safe environment is much harder in a diverse group of people. The risks to psychological safety is much higher, therefore we have to operate with a much higher intent, and work together, as well as individually, to learn and grow our ability to cultivate these environments.

Cultivating these environments is an ongoing process as team members leave and new ones start. You need to always be operating with psychological safety intentions.

## What Impacts Psychological Safety

In this section we will address 5 key things that effect Psychological Safety, but this is certainly not exhaustive. This section does focus on what negatively impacts Psychological Safety, while in the next section of the course we will address how to tackle some of these issues and how we can cultivate a culture where these things do not arise.

- **Punishment culture** - If we don't allow reasonable failures to happen, risk taking diminishes, iteration stops, and creativity is stifled. This is a sure fire way to create a culture of "we have always done it this way".
- **Not allowing conflict** - Disagree and commit is a subvalue at GitLab and is very important in creating an environment where everyone is heard, but still able to move forward. This generates ideas, ensures many perspectives are taken into consideration when building processes and products, and avoids missing considerations which could have diversity implications.
- **Not understanding communication styles** - Not recognizing others communication styles means you cannot effectively facilitate conversations and meetings, can miss other points of views, and potentially isolate individuals. This is a great exercise you can do with your team to help understand each others communication style better.
- **Blame culture** - After we begin a culture of blaming individuals, much like punishment culture you reduce trust in team members developing creative solutions.
- **Leaders & Team Members not embracing feedback** - If leaders do not take on feedback from team members, trust erodes, messages are not delivered correctly, and misunderstandings happen.

You may be thinking that these are obvious, but in scenarios later in the course you will see how these things can subtly happen and erode psychological safety. Next you will learn what you can do to cultivate psychological safety.

## What can you do to promote and cultivate psychological safety as Team members and Leaders?

### Three Practices to Cultivate Psychological Safety

These three great practices will help you really make that push into ensuring that everyone feels psychologically safe.

1. **Perception vs Intent** - Ensuring that you are being mindful of this on both sides is very important. How could your actions be perceived against what you mean or how you perceived someone's actions, and what their actual intent was? Understanding your team members' communication styles and work styles will go a long way towards avoiding this. We will talk more about awareness of this later in the course.
1. **Operate with a high intent** - We assume positive intent, including on most occasions when mistakes are made that were not intended. A way to avoid these mistakes is to operate with higher intent.

   Higher intent is the practice of recognizing, reevaluating, and reiterating on inclusive practices.

   For example, you are an extrovert and enjoy participating in conversations in meetings, but you recognize that you are not the only voice in the meeting and some haven't been heard. You use your confidence to encourage and provide space for other ideas.

   This also means acknowledging and apologizing when you get it wrong. People who operate at a higher intent do not use positive intent as a defense but as a learning opportunity.
1. **Have moral courage** - This is the practice of being brave for ethical and moral reasons, even when it is a risk or inconvenient for you.

**Scenario:** Someone is consistently using the wrong pronouns for a team member who identifies as non-binary. They use the pronouns They/Them. The person doing this is at the Director level and you have a great relationship with them. After an incident of seeing the director doing this, you ask for a zoom chat and explain the issue.

**Risks:**

- The person is higher in the hierarchy
- You may not know their conservative or liberal views
- Risking the friendship you have with the person

### Nurturing Psychological Safety for All Team Members

It is important that there are consistent things that we can do to ensure that we nurture and cultivate psychological safety.

Everyone at GitLab can follow these key practices to create and continue the culture we desire:

- **Embrace a culture of respectable debate:** We have our operating principle of "Disagree, Commit, Disagree" - to help embrace this practice. It allows us to have those conversations that spark creativity, iterations, and gather viewpoints that we may have missed. Our value ensures that we still progress and move forward.
- **Encourage and Share personal stories:** This is a great way of ensuring that as team members we build relationships and, ultimately, trust at work. Coffee chats are a great avenue for this so that you are more comfortable bringing up pertinent issues.
- **Practice self-reflection:** We will have a task later in the course to help you practice this, but it is important that you are evaluating how you react and engage in conversations at work under different stress responses.
- **Allow for experimentation and failure:** Again, this is something that sparks creativity, allows some freedom for projects to not work out, and provides space for our iteration and efficiency values to prosper. We don't want to be stuck in a culture of "we have always done it this way."
- **Build a culture of curiosity:** Ask questions not only about people's lives (as above), but also about shared personal stories. Be genuinely curious about processes, practices, products, and other things at work. Be curious and respectful.
- **Be open to feedback:** Always be open to both good and constructive feedback. Receiving constructive feedback should not be psychologically unsafe. Leaders, ensure you understand not only how to give feedback effectively, but also how a team member likes to receive constructive feedback.
- **Encourage creative collaboration and collaborative learning:** Collaboration is a core value here and we encourage learning. Allow for these things to happen together. For example, someone in your team may have a unique skill. Ask if it is possible for other team members to shadow them when they perform that skill.
- **Seek diverse perspectives:** To avoid confirmation bias, ask team members from underrepresented groups for their views. It is so important that a diverse set of voices are considered in our day to day work, so actively seek those voices.

### Nurturing Psychological Safety for Leaders

These are specific practices and actions for leaders and future leaders. While nurturing and cultivating psychological safety is everyone's job, leaders are in a unique position and have a disproportionate effect on this.

- **Foster a pro diversity mindset and build diverse teams:** Try not to build teams where all members look and act the same. Leverage your power to hire and promote from underrepresented groups (URGs), regions, and skills while still ensuring this is based on merit.
- **Highlight competencies of team members:** Much like collaborative learning, ensure you are letting team members know who within the team are subject matter experts. People can learn from them, but it also help elevate their voices on certain issues. Get to know your team members.
- **Try to remove biases such as contrast and compare:** Each team member is unique and was hired based on their strengths, try to avoid contrasting and comparing when evaluating performance, etc.
- **Participative management:** Try to dismantle perceptions of hierarchy by ensuring you are part of the team and not just the leader of the team.
- **Avoid blame & keep negative feedback 1-1**

## Self Reflection Exercise

- What are your stress responses (when you are excited, angry, stressed, etc)? For example:
  - "When I am excited I am animated with my hands."
  - "When I am stressed with work I am less transparent and tend to shut off."
  - "When I am stressed in my personal life I can get distracted."
  - "When I am excited I tend to interrupt people."
  - "When something stressful happens I tend to panic."
  - "When something stressful happens I tend to be defensive."
- What are your actions when you are passionate and excited?
- How do you react to frustrated team members?
- Can your actions and responses be considered psychologically safe? For example:
  - "I am animated with my hands which can cause sensory overload for someone who is neurodivergent." Still, on most occasions it is safe.
  - "I interrupt people often when I am excited which can cause frustration and make people feel as though their voice is not heard." This **can be unsafe**.
- Have you provided your intent? For example:
  - "I want everyone to be aware that when stressful things happen I can shut off and just put my head down. If you notice this and feel I am not being transparent about activities please let me know."
  - "I am aware that when I am excited I tend to cut people off. Please call me out on this behavior when it happens as I often don't realize I am doing it."
- What are your unconscious biases and have you challenged them?
- Do you consciously evaluate your unconscious biases when communicating?
- How do you like to receive feedback? Do you give feedback the same way? Does your team know how *you* like to receive feedback, and do you know how *they* prefer feedback?
- What constitutes psychologically unsafe behavior? Leaders and team members can provide feedback that, for example, isn't itself psychologically unsafe, but someone may feel that *any* feedback makes them feel unsafe. Challenge your assumptions on whether it is truly unsafe or part of the work.

## Psychological Safety Manager 1:1

This is a guide on how to conduct a 1:1 with your direct reports after they have completed the Psychological Safety Short Course.

1. If your direct reports are taking the course ensure you have completed the course too here
1. Create a safe space to share.
    - No need to keep notes
    - Be conversational
    - Share scenarios or anecdotes
1. Be vulnerable, share your learnings from the course and your commitments to psychological safety after taking the course.
1. Challenge team members to share authentically and ask follow up questions to help team members share.

**Example Agenda**

- What are one or two things that you learnt from the course, was there anything that surprised you?
- What were some of the learnings that came out of the self reflection exercise and how do you plan to use those learnings moving forward?
- How can I support you as a manager or anything I can do to make our relationship more psychologically safe and for the team at large?
- What is one personal commitment that you will make moving forward to psychological safety?

## Scenarios & Quiz

[You can view scenarios here](https://docs.google.com/presentation/d/1T9VEOGl0ppfwKhp9_9ikoGdDiC3UTEoZElK9SdRsfWg/edit#slide=id.g29a70c6c35_0_68) and take the quiz via Level Up.
