---
title: Psychological Safety
---

## Introduction

On this page we are going to review psychological safety and its importance for successful teams.

## What is Psychological Safety

Psychological safety is [defined by Amy Edmondson](https://www.jstor.org/stable/2666999?seq=1) as a "shared belief held by members of a team that the team is safe for interpersonal risk taking".

It's not about being warm and fuzzy and sharing your feelings. It's about being comfortable admitting when you are wrong or have made a mistake as well as challenging each other for the better.

Watch the video below where Susan David explains psychological safety.

{{< youtube "O0kAMpRp2hU" >}}

## How it Works

The following information was summarized from an [article on Psychological Safety](https://peopletalking.com.au/project/psychological-safety/) by PeopleTalking.

**Psychological Safety** has primary importance when it comes to significant impact on a team's performance.

The other factors that have an impact on a team's performance are: Dependability, Structure, Meaning & Clarity, Impact.

In addition, the factors of Accountability, Open Communication & Motivation, Dialogue Practices, and Shared Assumptions are only valuable when the team is already psychologically safe. In the diagram, those lie on the arrows between each of the circles.

Why is psychological safety important? When you have psychological safety in the workplace, the following things increase:

- Collaboration
- Innovation
- Inclusion
- Well-being
- Culture

![Psychological Safety How it Works](/images/handbook/leadership/psych-safety-how-it-works.png)

Amy Edmondson uses David Kantor's model to show the [relationship between Psychological Safety and Accountability & Motivation](https://peopletalking.com.au/project/psychological-safety/). When there is an environment where psychological safety is low or non-existent, it can be very stress or anxiety filled. When there is high psychological safety, it can make people more comfortable. You can get a better picture of this from the diagram below.

![Psychological Safety Model](/images/handbook/leadership/psych-safety-model.png)

## Psychological Safety vs Danger

When you have psychological safety people become more motivated because they feel more able to take risks. When people feel psychologically safe, they will learn from their failure rather than feeling the need to blame others.

![Psychological Safety vs Danger](/images/handbook/leadership/psych-safety-vs-danger.png)

## Diversity and Inclusion

Psychological safety has impacts on diversity and inclusion in organizations. Even if an organization has diversity, it doesn't mean that inclusion is present as well.

## Strategies for Cultivating a Culture of Psychological Safety

1. Embrace a culture of respectful debate.
1. Encourage personal storytelling.
1. Ask questions.
1. Allow for experimentation and failure.
1. Dismantle perceptions of hierarchy.
1. Model openness to feedback.
1. Set clear goals and key performance indicators.
1. Offer development opportunities.
1. Build a speak-up culture.
1. Highlight competencies.

The above list is from a [Grant Thornton article](https://web.archive.org/web/20220528223316/https://www.grantthornton.com/library/articles/advisory/2020/psychological-safety-speak-up-culture.aspx).

It is important to enable a human-to-human approach and realize the other party is more like you than different. The reflection activity called "Just Like Me", [developed by Paul Santagata](https://hbr.org/2017/08/high-performing-teams-need-psychological-safety-heres-how-to-create-it), asks you to consider:

- This person has beliefs, perspectives, and opinions, just like me.
- This person has hopes, anxieties, and vulnerabilities, just like me.
- This person has friends, family, and perhaps children who love them, just like me.
- This person wants to feel respected, appreciated, and competent, just like me.
- This person wishes for peace, joy, and happiness, just like me.

## Psychological Safety Learning & Development

{{% alert %}}
[Psychological Safety Short Course](/handbook/leadership/emotional-intelligence/psychological-safety-short-course/)
{.h4}
{{% /alert %}}

If you want to learn more about how you can impact psychological safety, you can take the Psychological Safety Short Course which takes approximately 30-45mins. This will guide you things that impact psychological safety, how you can cultivate psychological safety as well as run through scenarios to reaffirm your learning.

You can:

- Access the [Psychological Safety Short Course here](https://levelup.gitlab.com/access/saml/login/internal-team-members?returnTo=https://levelup.gitlab.com/learn/course/psychological-safety-understanding-empowerment-and-self-reflection).
- Read the [content of the course here](/handbook/leadership/emotional-intelligence/psychological-safety-short-course/).

## Live Learning Session

During Week 3 of our Manager Challenge Pilot, we had a course covering Building an Inclusive & Belonging Environment. The [slide deck](https://docs.google.com/presentation/d/1eBr33VeYePGck9K5Q5WGqrhqKmKT8zLgkO3kNNRCew0/edit?usp=sharing) and [meeting agenda](https://docs.google.com/document/d/13BofXLCDC2fafHlYij7sZetBidB2cycuz1BeJSSDsMo/edit?usp=sharing) follow along with the session.

A recording of the second of two sessions can be found here:

{{< youtube "pdB-WWeXNjg" >}}

## One Week Challenge

We rolled out a One week challenge in November 2020. All details relating to the challenge can be found here on this page.

The [One Week Challenge](/handbook/people-group/learning-and-development/#gitlab-mini-and-extended-challenges) is a blended learning approach that incorporates self-paced daily challenges and live learning sessions to build knowledge and skills around Psychological Safety.

The challenge was organized in [an Epic](https://gitlab.com/groups/gitlab-com/people-group/learning-development/-/epics/19). Each day of the challenge was an issue within the epic with specific tasks for each day. Participation was tracked based on engagement in the issues, attending and participating in one of the live learning sessions, and completing the self reflection and evaluation forms.

### Program Overview

- 3 Daily Challenges (20 minutes)
- 1 Live Learning Sessions (1 hour)
- 1 Weekly Self Reflection and Evaluation (10 minutes)
- Certification Upon Completion

### Learning Objectives

1. Define Psychological Safety
1. Identify the importance of Psychological Safety
1. Demonstrate how to increase Psychological Safety

### Program Outline

| Day | Challenge | Time | Format | Activity | Competency |
| ------ | ------ | ------ | ------ | ------ | ------ |
| Day 1 | Introduction to Psychological Safety | 20 minutes | Self-paced Daily Challenge | Read the [Psychological Safety Handbook Page](/handbook/leadership/emotional-intelligence/psychological-safety/) <br> Comment on the daily issue in response to: What does psychological safety mean to you? | <ul><li>Diversity, Inclusion, & Belonging</li><li>Emotional Intelligence</li></ul> |
| Day 2 | Importance of Psychological Safety | 20 minutes | Self-paced Daily Challenge | Watch [The importance of psychological safety: Amy Edmondson](https://www.youtube.com/watch?v=eP6guvRt0U0) <br> Comment on the daily issue in response to: Throughout your career, what zone(s) (Comfort, Apathy, Learning, or Anxiety - outlined here) have you found yourself in? | <ul><li>Diversity, Inclusion, & Belonging</li><li>Emotional Intelligence</li></ul> |
| Day 3 | Increasing Psychological Safety | 20 minutes | Self-paced Daily Challenge | Read [7 ways to create psychological safety in your workplace](https://blog.jostle.me/blog/psychological-safety-at-work) <br> Comment on the daily issue in response to: What can you do to increase psychological safety within the teams you are a part of at GitLab? Have you tried or experienced any of these things in the past? | <ul><li>Diversity, Inclusion, & Belonging</li><li>Emotional Intelligence</li></ul> |
| Day 4 | Attend Live Learning | 50 minutes | Live Learning - Psychological Safety in the Workplace | Participate in the live learning | <ul><li>Diversity, Inclusion, & Belonging</li><li>Emotional Intelligence</li></ul> |
| Day 5 | Eval + Self Reflection Forms | 20 minutes | Self-Reflection & Evaluation Forms | Complete the Self-reflection and Evaluation | <ul><li>Diversity, Inclusion, & Belonging</li><li>Emotional Intelligence</li></ul> |

## Trust and Psychological Safety Team Survey and Feedback Template

As a part of the Elevate training, an initial iteration for a trust and psychological safety [team survey](https://docs.google.com/forms/d/1g8jXdTBItJW9JIWUU9XssUxgvXt2mwwShKWBTh4T6nk/edit?ts=64e679c9) along with a team tracking [issue template](https://gitlab.com/gitlab-com/www-gitlab-com/-/edit/master/.gitlab/issue_templates/psych-trust-safety.md) were created to help teams manage the process of measuring and discussing their teams trust and psychological safety. The goal is to better understand how each team member feels about psychological safety within their own team and share those feelings in a discussion. Each manager is encouraged to make copies of the survey and issue template to use when conducting this trust and psychological safety exercise with their team.

Once survey results have been collected and reviewed by each manager, it's suggested that these anonymous results are shared with the team in a sync meeting, in a tracking [issue (template)](https://gitlab.com/gitlab-com/www-gitlab-com/-/edit/master/.gitlab/issue_templates/psych-trust-safety.md), or both to discuss trends and identify action items in the data collected for each question. The intention is to provide transparency around how each team is feeling and also decide as a team what action items can be taken away from the results and applied in the future.

## Additional Resources

- Read: [The Role of Psychological Safety in Diversity and Inclusion](https://www.psychologytoday.com/us/blog/the-fearless-organization/202006/the-role-psychological-safety-in-diversity-and-inclusion) - Psychology Today
- Read: [The Fearless Organization by Amy C. Edmondson](https://www.amazon.com/Fearless-Organization-Psychological-Workplace-Innovation/dp/1119477247/)
- Read: [7 ways to create psychological safety in your workplace](https://blog.jostle.me/blog/7-ways-to-create-psychological-safety-in-your-workplace)
- Read: [What Google Learned from it's Quest to Build the Perfect Team](https://www.nytimes.com/2016/02/28/magazine/what-google-learned-from-its-quest-to-build-the-perfect-team.html)
- Read: [How To Build An Environment Of Psychological Safety](https://trainingindustry.com/articles/compliance/how-to-build-an-environment-of-psychological-safety/)
- Read: [How Psychological Safety Actually Works](https://www.forbes.com/sites/shanesnow/2020/05/04/how-psychological-safety-actually-works/#c5be718f864c)
- Read: [High-Performing Teams Need Psychological Safety. Here's How to Create It](https://hbr.org/2017/08/high-performing-teams-need-psychological-safety-heres-how-to-create-it)
- Listen: [Creating Psychological Safety in the Workplace](https://hbr.org/podcast/2019/01/creating-psychological-safety-in-the-workplace) - HBR
- Watch: [Why good leaders make you feel safe - Simon Sinek](https://www.youtube.com/watch?v=lmyZMtPVodo&list=PLhVoCCkYxQDcdcU7j7H_w0-0BdOqIIYxa) - TED
- Watch: [The importance of psychological safety: Amy Edmondson](https://www.youtube.com/watch?v=eP6guvRt0U0)

The SSOT for the slides on this page can be found in [this folder](https://drive.google.com/drive/folders/1RLXcBUM1IKx8KmgQSR-dPDwvkso6bVJL).
