---
title: GitLab Onsites - Getting your team together in person
decsription: "This page outlines resources for managers who organize in person time with their team."
---

## GitLab Onsites

> **GitLab Onsites**
>
> *noun*
>
> Dedicated time for all-remote teams to come together in person to build trust

As a leader in all-remote work, it's important that we recognize the value and impact of time spent in the same location. Meaningful time spent together influences the trust and results our teams build. Co-located companies often gather for `offsites` to connect in a new location. In our all-remote environment, we call in-person team meetings `onsites`.

This page is an `onsite` planning resource for people managers at GitLab. Use these suggestions to guide the way you plan in-person time for your team. Our additional [considerations for in person time](/handbook/company/culture/all-remote/in-person/) advise the wider GitLab community on how to make the most of time spent at conferences, in person meetings, and other types of meetups.

Leading an `onsite` for your team might be outside your comfort zone. The resources on this page will equip you to feel confident organizing an in-person team event. Lean into the skills that make you a great manager as you plan.

After your team `onsite`, we hope you'll feel:

1. United on common team goals
1. Motivated to achieve results
1. Connected with shared understanding and trust
1. Trusting and connected with those with whom you work most closely

### Let us help you plan your onsite

The GitLab Talent Engagement team is here to support your onsite planning. We can help you plan activities and make suggestions on how you can best spend this time together in person. To request this custom support, please [open an issue here using the `onsite-support` template](https://gitlab.com/gitlab-com/people-group/learning-development/custom-ld-engagement/-/issues/new).

Please note this does not include support for booking or scheduling onsite events and locations.

## Prepare

Consider the following as you start planning your `onsite`:

### Set a goal

What do you want your team to get out of this time spent together? As a manager, setting an intention for this time is vital. You need to develop a shared understanding of why the team is traveling to be together and have a clear way to measure success of the `onsite`.

Use these sample goals to get started. Personalize your final goal based on your team in this current moment. What is going on for the next fiscal year? Has your team struggled in the past with microagressions, difficulty working together, or transitioning to new leadership? If you tailor your goal to exactly what your team is needing most, you'll see greater engagement and results.

Sample goals:

1. Build trust and get to know each other so our team can work more efficiently together when we're all remote.
1. Develop a 3 year vision and clarify individual opportunity for contribution and growth within that vision.
1. Collaborate on a solution for a challenging and persistent issue our team faces.

### Plan transparently

Be transparent in your planning to maximize both attendance and engagement:

1. **Ask for input from your team early and often:** What do folks on your team want to do during their time together? What are they not interested in?
1. **Set expectations:** Leave nothing as a suprise. Build psychological safety by planning out in the open so folks know what to expect.
1. **Share resources:** Share resources like our [expense handbook](/handbook/finance/expenses/), [travel handbook](/handbook/finance/travel/), [support for nursing mothers](/handbook/finance/expenses/#supporting-nursing-mothers), and [considerations for working while traveling](/handbook/company/culture/all-remote/working-while-traveling/).
1. **Plan in advance:** Some functions and roles at GitLab are accustomed to work travel - others are not. Give time to plan and organize scheules to maximize attendance and presence.

### Develop a shared reality

Spending time during a team meeting to set norms for your `onsite` will begin to develop shared expectations for your time together.

1. **Assign prework:** Depending on the goals you've set and the activities you've planned, assign prework to help your team prepare. This might be a video, article, or activity to complete prior to meeting in person.
1. **Clarify expectations around attendance:** Make it clear that remote participation will be offered, but in person attendance is preferred whenever possible.

## Activity Planning

The all-remote structure at GitLab is efficient and collaborative. It works really well for problem solving, independent work, and all forms of collaboration - not to mention things like getting up to date on GitLab to-dos and Slack messages.

Time spent together in person has its own benefits, too. It's great for building trust, getting to know members of your team, and creative brainstorm discussions.

Review the resources below for guidance on what to prioritize when your team is together in person, and what you might save for when you're back in your home office.

### Team Building

Make the most of `onsites` with intentional time to get to know one another.

1. **Set and iterate group norms:** Spend 5-10 minutes at the start of each day to set and review group norms. Decide together things like work you're going to set aside, if/when you'll take breaks as a group, and how you'll communicate during each activity. These might be similar to norms your team follows on all-remote team meetings, but recognize that it might be different - like making sure everyone knows where the restroom is and that everyone has a comfortable seat or space to work.
1. **Personality assessments:** Increased awareness of our own strengths and working styles helps us work more collaboratively with others. Use a framework like [social styles]({{< ref "social-styles" >}}), [Clifton Strengths Assessment](https://www.gallup.com/cliftonstrengths/en/), or the [Enneagram Assessment](https://www.enneagraminstitute.com/type-descriptions). Assign the assessment as prework then have a discussion to share results.
1. **Ice Breakers:** Don't cringe - ice breakers don't have to be super cheesy or put people on the spot. A great ice breaker gets authentic conversation started. Here are a few ideas to get you started. Be mindful of how underrepresented groups and neurodiverse team members might feel during these activities.
     - Conversation Deck: Purchase a deck like [The Teamwork Game](https://www.theschooloflife.com/shop/teamwork-game/) or this [Best Self Question Deck](https://www.amazon.com/Conversation-Starter-Icebreaker-Deck-BestSelf/dp/B07RRQWHN9?th=1). Pick a card to start a conversation in small groups, then share.
     - Temperature Check: ask folks to share how they are feeling to start the day on a color or number scale. Give space to elaborate if comfortable.
1. **Incorproate flexible social time:** Plan team lunch or dinner, exercise classes, group walks, cooking classes, or tours to explore the city where you're meeting. Be mindful of mobility limitations and your team members' individual needs.
1. **Balance team building with independent time:** We all need space to recharge. Avoid booking each day solid with activities. Ensure there is time for folks to return to their hotel room or spend time alone to feel ready for each day's activities.

### Consider Utilizing Design Thinking Exercises

Design thinking is a non-linear, iterative process that teams use to understand users, challenge assumptions, redefine problems and create innovative solutions to prototype and test. (Source: [Interaction Design](https://www.interaction-design.org/literature/topics/design-thinking)). What makes design thinking unique is that it's a user-centric, solution-based approach to problem solving. The focus is on the solution, rather than the problem. Design thinking gives opportunity for [everyone to contribute]({{< ref "mission#mission" >}}) and can help develop a [growth mindset](/handbook/values/#growth-mindset).

Design thinking directly supports our GitLab values of Results, Collaboration, and  Efficiency. We balance being [ambitious](/handbook/values/#ambitious) along with a focus on [boring solutions]({{< ref "#boring-solutions" >}}) - both of which are solutions-oriented.

Listen to [Tim Brown speak about the Design Thinking process in this TedTalk](https://www.ted.com/talks/tim_brown_designers_think_big/transcript).

{{< youtube UAinLaT42xY >}}

Regardless of what your team is working on during time in person - whether it be long term planning, high stakes problem solving, or new idea generation - you can apply design thinking activities to achieve results. Here are some suggested activities you can explore:

1. [Roses, Buds, Thorns activity](https://easyretro.io/templates/rose-bud-thorn/): Gather feedback on what is and isn't working, then identify new opportunities.
1. [Eisenhower Matrix](https://asana.com/resources/eisenhower-matrix): Map top priorities to set realistic goals.
1. [Empathy Map](https://www.accenture.com/us-en/blogs/software-engineering-blog/what-is-an-empathy-map): Apply [emotional intelligence]({{< ref "emotional-intelligence" >}}) skills to understand the root cause of a problem.
1. [Structured Brainstorming](https://www.innovationtraining.org/online-templates-for-brainstorming/): Focus discussion on a specific topic or problem to solve. Set [brainstorming norms](https://www.innovationtraining.org/brainstorming-rules/) to stay efficient.

## Logistics

### Inclusion and remote participation

It's inevitable that some team members won't make it to an `onsite`. It's critical to think about how you'll include remote participation to ensure that folks aren't missing out on key conversations and team building.

1. Find out in advance who cannot attend. It's important to know this information early so you can plan a successful event.
1. Plan key team discussions in timezones where remote participants can call in.
1. Engaged remote participants in discussion - don't just ask them to listen.
1. Use technology to set yourself up for success - tools like Mural can mimic whiteboards and allow multiple ways to contribute.
1. Ask for consistent feedback. Ensure the structure is working for remote participants and adapt as needed.
1. Set clear boundaries so remote participants don't feel like they need to 'cover' for everyone who is in person.

### Outdoor events

It's challenging to include remote participants in team building, especially in an outdoor space. Here are a few special considerations for this:

1. Plan team building that allows for remote participation. For example, in a cooking or painting class, you could accommodate with a Zoom set up so remote participants can follow along. [WithConfetti](https://www.withconfetti.com/) is a great resource for sessions and ideas.
1. Encourage, and provide budget, for remote participants to get together with other remote participants. This could look like a Zoom happy hour, or a shared meal for all remote participants.

## Ready to get planning?

The content and suggestions from this page are neatly captured in 2 planning templates. Simply open the template, make a copy, and use this resource to plan your event!

Customize the templates as needed. We suggestion you start with the `Onsite Planning Guide` to plan, then use the `Onsite Attendee Guide` to communicate plans to your team.

[Onsite Planning Guide](https://docs.google.com/spreadsheets/d/1WawNa6Xjg30Ev_lzFv5a1rre3f962sWaI45lQdNk1F4/edit#gid=1554266865)
{.btn .btn-light}
[Onsite Attendee Guide - Know Before you Go](https://docs.google.com/spreadsheets/d/1ZV7bI9lSuGPsNOMlfLpnHEq8awT4kh0C6syiYU260d0/edit#gid=0)
{.btn .btn-light}

## Additional Resources

1. [Travel Guidelines](/handbook/finance/travel/)
1. [Travel support for nursing mothers](/handbook/finance/expenses/#supporting-nursing-mothers)
1. [Expense Guidelines](/handbook/finance/expenses/)
1. [Considerations for working while traveling](/handbook/company/culture/all-remote/working-while-traveling/)

## Contribute

Our team member community is the expert on what works for time spent together - so contribute! Open a Merge Request to update this page with your favorite (and least favorite!) ways to spend in person time with your team.
