---
title: Identifying & Addressing Burnout
---

## Manager Guide: Identifying & Addressing Burnout

With GitLab's results-driven culture, the demands of product innovation around AI, the fast-paced and ever-evolving business environment, our organization recognizes the crucial balance between **achieving ambitious goals** *and* **maintaining the well-being of our team members**.

### Defining Burnout

The World Health Organization defines Burnout as "a syndrome conceptualized as resulting from chronic workplace stress that has not been successfully managed. It is characterized by three dimensions: feelings of energy depletion or exhaustion; increased mental distance from one's job, or feelings of negativism or cynicism related to one's job"

### Goal

The primary objective of this resource is to set expectations of leaders when it comes to managing burnout and to provide practical strategies to proactively identify and address signs of burnout. People leaders play a key role in ensuring a healthy, productive, and engaged workforce.

This guide serves as a toolkit for fostering a supportive work culture where team members feel recognized for high performance and motivated to excel, *without* compromising on their mental and physical health. We encourage managers to utilize these insights in their regular interactions and decision-making processes, adapting them to their team's unique dynamics and needs. By doing so, we aim not only to enhance our team's overall well-being but also to sustain GitLab's innovative momentum and long-term success.

#### Resource

🏁 Modern Health provides an interactive walkthrough centered on burnout prevention and designed for people managers. [Preventing Burnout in Team Members](https://my.joinmodernhealth.com/program/preventing-burnout-in-team-members) (10 min) is included for all GitLab team members. If this is your first time using GitLab's Modern Health benefit, you can follow guidance for [team member registration](/handbook/total-rewards/benefits/modern-health/#team-member--family-registration).

- Reflect: What are other ways "burnout" might show up beyond "fatigue"?

### Understanding Burnout

Here are some  team member considerations inspired by GitLab's culture, values, and ways of working. You'll see some tips, but we'll share more advice and talking points below:

- **On & Offline:**-  When working in a remote, heavily asynchronous, collaborative team environment you may not always see and hear early signs of fatigue or burnout. Make it a point to reserve time in regular connections to see how team members are managing workload and boundaries. Even asking directly in a Slack message can be helpful.
- **Flexibility:** GitLab encourages team members to be directly involved in when, where, and how they get their best work done. Managers still play a key role in allowing space while also remaining dialed into progress, output, and managing capacity.
- **Results-driven:** Burnout has a direct impact on deliverables and overall results. Managers must continuously strive to improve workload management, output, and their team's well being. This is, in itself, a result of a manager's leadership capability and there should be a sense of ownership of the work for which their team is responsible.
- **Common Pitfall:**  "*Taking time away resolves any issues related to burnout.*" While taking time away is a great way to set boundaries and strike a healthy balance between work and personal time; it's not a catch-all solution. Time away should be supported and modeled by leaders, but leaders also need to recognize that addressing a team member's potential burnout can come from a variety of approaches. This might include coaching on time management, additional targeted feedback, more effective delegation, or goal clarification. Note: Time Away is CRUCIAL to well-being and quality work. This is part of GitLab's culture around work beyond combating burnout.
- **Sense of "urgency":**  Some team members may read this excerpt from GitLab Values…
    > "*At an exponentially-scaling startup, time gained or lost has compounding effects. Try to get the results as fast as possible, but without compromising our other values and ways we communicate, so the compounding of results can begin and we can focus on the next improvement.*"

     ...and only hear the "urgency" without recognizing the emphasis GitLab puts on effectively managing work, agency, and family + friends first.
- **Ask around:** Managers may hear about burnout and workload issues directly from team members, but there may be a need to *appropriately* source information from cross-functional partners or People Business partners to help understand how team members are feeling around workload.

#### Resource

🦊 GitLab Handbook: "[Recognizing Burnout](/handbook/people-group/paid-time-off/#recognizing-burnout)" (5 min)

### Addressing Burnout

- **Again, Rest and Time Off are PRODUCTIVE!:** With GitLab's recent [updates to the paid time off policy](https://gitlab.slack.com/archives/C010XFJFTHN/p1701277010756539), prioritizing time away remains top of mind.
- **Workload Management:** Managers are expected to delegate work effectively. Doing this effectively means strategically distributing workload and creating space for team members to express support or push back when needed.

  - [ ] Encourage open dialogue whenever possible
  - [ ] Transparently share workload management strategies and systems
  - [ ] Discuss how workload and demand informs delegation
- **Growth & Development:** There are several ways to improve/enhance capabilities for managers and team members when it comes to combating burnout through professional development opportunities centered around stress management, time management, and professional counseling.
  - [ ] Preventative training for the whole team
- **Creating a Supportive Work Environment:** Foster an environment of open communication and support, encouraging team members to speak up about their challenges.
- **Longer-Term Solutions:** Encourage participation in wellness programs, explicitly communicate with teams about GitLabs culture of flexible work, and review job/role descriptions for potential stressors and opportunities to address scope.
- **Dogfood:** Managers must model healthy/balanced working behaviors! Taking time away, sharing challenges and success around effectively managing workload, storytelling centered on output as a result of effective workload management.

#### Resource to share with team members

[Combating burnout, isolation, and anxiety in the remote workplace](/handbook/company/culture/all-remote/mental-health/)
Burnout Index: [Yerbo's Risk Check](https://web.archive.org/web/20240121220209/https://burnoutindex.yerbo.co/)

---

### Where to ask questions

You can direct questions to [#people-managers-and-above](https://gitlab.slack.com/archives/C01SFG8EDGA) Slack channel.

#### Resource Repository

Below, you can access all the referenced in this guide:

| Reference | Notes |
| :------ | :------ |
|[GitLab team members share how to recognize burnout (and how to prevent it)](https://about.gitlab.com/blog/2018/03/08/preventing-burnout/)        |Audience: All team members        |
|[Recognizing Burnout](/handbook/people-group/paid-time-off/#recognizing-burnout)        |Audience: All team members        |
|[Combating burnout, isolation, and anxiety in the remote workplace](/handbook/company/culture/all-remote/mental-health/)        |Audience: All team members        |
|[Yerbo's Risk Check](https://web.archive.org/web/20240121220209/https://burnoutindex.yerbo.co/)        |Managers can share this with their teams. It's recommended that managers go through this for themselves as well.        |
|[Mental_Health_Aware](https://gitlab.enterprise.slack.com/archives/C834CM4HW)        |Audience: All team members        |

#### Additional Resources

[Modern Health](/handbook/total-rewards/benefits/modern-health/#mental-wellness-services): Burnout at work can also be influenced by a multitude of experiences happening inside and outside of work. EAP offers benefits the serve a variety of needs.
