---
title: Managing Conflict
---

## Managing conflict

In this section, we will review the definition of conflict, the different causes of conflict, different methods for addressing conflict, steps in the conflict process, and some do's and don'ts of workplace conflict. Conflict in the workplace is inevitable when you have team members of various backgrounds and different work styles all working towards the same goals and [OKRs](/handbook/company/okrs) (Objectives and Key Results). Conflict should never just be avoided, conflict should be managed and resolved. The first step is for the team members who experience conflict to work to address the situation to work towards a resolution. If a resolution is not possible, the manager should work with the team members and their assigned [People Business Partner](/handbook/people-group/) to help foster a resolution.

## What is conflict?

Conflict is any situation where your concerns, desires, perceptions, goals, or values differ and clash with other team members. Here are a few examples of potential causes of workplace conflict:

- Personality differences
- Team member behavior is regarded by some as irritating or annoying
- Perceived unfairness or inequities of resources, training or project work
- Unclear role expectations
- Poor communication skills
- Differences in work methods or goals

## Different methods or approaches to managing conflict

### Competing method

This method involves managing conflict through unilateral decision making.

- Primarily used for: Situations that require a quick decision, instances where there is no compromise or debate on making a hard decision.
- Competing styles: Win-Lose approach, Assertive & Uncooperative and You try to satisfy your concerns at the other team members' expense.
- Examples:
  - Imposing or dictating a decision - "Sorry X, but that's my decision as your manager"
  - Arguing for a conclusion that fits your data - "Our customer survey shows a steady decline.  We need to design the route"
  - Hard bargaining (making no concessions) - I won't take less than X - Take it or leave it.

### Avoiding method

Actively deciding not to manage a conflict.

- Primarily used for: Unimportant, non-work issues, buying time until a resolution can be reached, and recognizing issues as symptoms.
- Avoiding styles: "Lose-Lose" approach, unassertive and uncooperative, evading conflict without trying to satisfy either person's concerns, and effective in emotionally charged circumstances.
- Examples:
  - Avoiding people you find troublesome - "This doesn't seem to be a good time to discuss this issue with X".
  - Avoiding issues that are unimportant, complex, or perceived threatening - "Maybe. We'll see. Let's move along to the next topic."
  - Postponing the discussion until later - "Let me check on that and get back to you next week."

### Accommodating method

Allowing the other side to "win."

- Primarily used for: Maintaining perspective in a conflict situation, making active decisions on what can be "let go", maintaining peace, and creating goodwill.
- Accommodating styles: Unassertive & cooperative and you attempt to satisfy the other team members' concerns at the expense of your own concerns.
- Examples:
  - Doing a favor to help someone - "I can see this is important to you, OK."
  - Being persuaded - "I didn't think of that, you are right."
  - Obeying an authority - "I'd do it differently, but it is your call."
  - Deferring to another's expertise - "You are the experts, I'll trust your judgment."
  - Appeasing someone who is threatening - "Ok, ok, please calm down."

### Compromising method

Reaching a resolution with a "win" on both sides.

- Primarily used for: Resolving issues of moderate to high importance, finding a solution that involves equal power and strong commitment on both sides, situations where a temporary "fix" may be needed, and backing up a decision that's been made via the competing or collaborating method.
- Compromising style: In the middle and you try to find an acceptable settlement that only partially satisfies both team members' concerns.
- Examples:
  - Soft bargaining or exchanging concessions - "Let's split the difference and settle for X".
  - Taking turns - "Suppose I do X this time and then you do Y next time."
  - Moderating your conclusions - "You think X will solve the problem but I think Y will, so perhaps we say X&Y are possible solutions?"

### Collaborating method

Managing conflict through team input.

- Primarily used for: Gaining support from the team, using different perspectives as an opportunity to learn and improve relationships through collaboration.
- Collaborating style: Assertive and cooperative and finding a "win-win."
- Examples:
  - Reconciling interest through a "win-win" solution - "You need to fund project X but I need to project Y, how can we do both?"
  - Combining insights into a richer understanding - "You are praising X's technical skills, however, I have concerns about their iteration and collaboration skills.  Both are true, aren't they?  They have high potential if they can improve on their interpersonal skills."

## 8 tips for managing conflict

1. **Management/leadership sets the tone**
    - A workplace built on mutual respect
    - Managers/leaders' behavior and actions provide team members with a model to follow
1. **Hire the right people**
    - Look for team members who demonstrate the ability to address conflict in a positive and productive way
1. **Train team members**
    - Provide learning and development opportunities on how to engage in positive conflict
1. **Reward meaningful conflict**
    - Recognize team members who participate in positive conflict, and acknowledge those whose actions result in successful outcomes for the department, division, and GitLab.
1. **Encourage team members to support their position**
    - Team members should be expected to be able to support their positions with data.  This will take the conflict from emotional to rational.
1. **Encourage your team members to be respectful**
    - Team members in meaningful conflict situations must be respectful of others and should not be allowed to make personal attacks.
1. **Encourage transparency and inclusion**
    - All team members must feel free to express their opinions in a non-judgmental environment.
1. **Serve as a resource**
    - Serve as a resource in business decisions to [coach through conflict](#balancing-conflict) and understand a path forward to support [GitLab's Vision](https://about.gitlab.com/direction/#vision).

## Balancing conflict

Managers and leaders need to find the right balance depending on the team members involved and the situation. Remember conflict is a *problem* when it:

- Hampers productivity and increases tensions
- Lowers morale
- Causes more and continued conflict
- Causes inappropriate behavior
- Leads to team member absenteeism.

Conflict is *constructive* when it:

- Opens up issues of importance resulting in issue clarification
- Helps build cohesiveness as team members learn more about each other
- Causes team members to reassess processes or actions
- Increases team member involvement.

If at any time a manager feels the conflict situation has violated our [values](/handbook/values/) or code of conduct they should [reach out to the PBP](/handbook/people-group/#how-to-reach-the-right-member-of-the-people-group) (People Business Partner). Also, if a manager would like to talk through different conflict situations and approaches your PBP is willing to help you work through the best strategies.

## Conflict Resolution Competency

Managers need to be well-versed in managing and facilitating conflict resolution between team members. They can do this by surfacing and clarifying areas of disagreement and by creating an environment where resolution is possible. Conflict resolution is a key component to enabling team members to be successful and reach their potential.

**Skills and behavior of the conflict resolution [manager competency](/handbook/people-group/competencies/#list):**

- Facilitates conflict resolution between co-workers by surfacing and clarifying areas of disagreement
- Creates an environment where resolution is possible
- Works to resolve conflict by engaging in open, productive dialogue that clarifies differences, identifies common ground, and works towards agreement or acceptance
- Provides guidance to team members on conflict management as needed
- Advises team or others on conflict management strategies, especially for difficult or complex situations

## Additional resources

If you are interested in learning about conflict and your role as a manager please review the following articles.

- [Do You Handle Conflict like a Rhinoceros or an Ostrich](https://keithrosen.com/2015/04/14/do-you-handle-conflict-like-a-rhinoceros-or-an-ostrich/)
- [How to deal with employees who do not get along](https://www.insperity.com/blog/employees-who-dont-get-along/)
  [How managers should deal with conflict between two employees](https://www.theladders.com/career-advice/how-managers-should-deal-with-conflict-between-two-employees)
- [5 Conflict Management Skills For Every Manager](https://lattice.com/library/conflict-management-skills-for-every-manager)
- [5 Conflict Management Styles for Every Personality type](https://blog.hubspot.com/service/conflict-management-styles)
- [The Science of Productive Conflict: Podcast Transcript](https://www.ted.com/podcasts/worklife/the-science-of-productive-conflict-transcript)
