---
title: "GitLab API Terms of Use"
description: "Understand your rights and obligations when using GitLab's publicly-available APIs"
---

A. These API Terms of Use ("**API Terms**") form a binding contract between you and GitLab and explain your rights and obligations when using GitLab's publicly-available application programming interfaces (the "**GitLab APIs**").

B. "**We**", "**our**" **and** "**us**" refers to GitLab Inc. and "**you**" and "**your**" refers to the individual, or company or other legal entity, on behalf of which the GitLab APIs are used.

C. If you are using the GitLab APIs on behalf of a company or other legal entity, you represent that you have the authority to bind such entity to these API Terms. If you do not have such authority, or do not agree with these API Terms, you must not use the GitLab APIs.

D. These API Terms do not apply to your use of the software, and other products and services, made available by GitLab (the "**GitLab Software**"), including without limitation, the self-managed and SaaS versions of GitLab's DevOps Lifecycle Application Platform. Your use of the GitLab Software is subject to a separate written agreement between you and GitLab or one of its affiliates entered into prior to such use.

E. We may revise these API Terms from time to time at our sole discretion. All changes are effective immediately when posted. Your continued use of the GitLab APIs following the posting of revised API Terms signifies your acceptance of the revised API Terms.

F. In the event of an inconsistency between these API Terms and those of an agreement governing (i) your use of the GitLab Software; or (ii) your partnership with GitLab, the provisions of such other agreement(s) will prevail to the extent of such inconsistency.

## 1. License and Use

1.1. Provided that you comply with these API Terms, all documentation relating to the GitLab APIs at [docs.gitlab.com](https://docs.gitlab.com/) and [developer.gitlab.com](https://developer.gitlab.com), and all applicable laws, we grant you a non-exclusive, non-transferable, non-sublicensable, revocable, limited right to access and use the GitLab APIs to:

&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;1.1.1. Develop, test and support any application or integration developed by you which interacts with the GitLab APIs (each, an "**Integration**") and;

&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;1.1.2. Distribute, or allow third parties to access, your Integration.

1.2. You acknowledge that there are no implied licenses granted under these API Terms, and we reserve all rights not expressly granted.

1.3. When using, or attempting to use, the GitLab APIs, you agree:

&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;1.3.1. To adhere to the applicable access requirements set out in the GitLab API Documentation;

&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;1.3.2. Not to share any API keys or authentication tokens for the GitLab APIs with any third party, and to keep these secure at all times;

&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;1.3.3. Not to misrepresent or mask either your identity or your systems' identity;

&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;1.3.4. Not to remove any proprietary notices from the GitLab APIs;

&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;1.3.5. That to protect the security, integrity, and operability of the GitLab APIs, GitLab may place limits on your use of the GitLab APIs (like limits on call volumes or requests that can be sent and received by the GitLab APIs during a defined period of time). You accept that:

&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;1.3.5.1. GitLab, in its sole discretion, will determine what constitutes abuse or excessive usage of the GitLab APIs;

&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;1.3.5.2. You will not use, or attempt to use, the GitLab APIs in a manner that exceeds such limitations, including rate limits, or in a manner that constitutes excessive or abusive usage; and

&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;1.3.5.3. GitLab may monitor the volume of requests sent to the GitLab APIs for compliance with these API Terms;

&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;1.3.6. Not to use the GitLab APIs in any manner that poses a security risk to other users of the GitLab APIs or GitLab Software, or tests the vulnerability of our systems or networks or those of any third party;

&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;1.3.7. Not to use the GitLab APIs for competitive analysis, or to disseminate performance information (including uptime, response time, and benchmarks), relating to the GitLab APIs or the GitLab Software;

&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;1.3.8. Not to use the GitLab APIs in any manner or for any purpose that infringes, misappropriates, or otherwise violates the rights of any third party;

&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;1.3.9. Not to use the GitLab APIs for the bulk collection or scraping of information.

1.4. We reserve the right to terminate your access to the GitLab APIs at any time and at our discretion, if you are, or are suspected of being, in violation of these API Terms.

## 2. Intellectual Property

2.1. We own all rights, title, and interest in the GitLab APIs and the GitLab Software. By using the GitLab APIs, you do not acquire ownership of any rights in them, or the content that is accessed through them.

2.2. Subject to section 2.1, you own all rights, title, and interest in any Integrations.

2.3. GitLab will retain all intellectual property rights relating to any suggestions, ideas, enhancement requests, feedback, or other recommendations you provide relating to the GitLab APIs and GitLab Software ("**Feedback Materials**"), which are hereby assigned to GitLab. Feedback Materials will not include any intellectual property owned by you.

2.4. Your use of any registered or unregistered GitLab trademarks is subject to the GitLab [Trademark Guidelines](/handbook/marketing/brand-and-product-marketing/brand/brand-activation/trademark-guidelines) and [Branding Standards](https://design.gitlab.com/brand-overview/resources), as updated from time to time.

## 3. Processing of Personal Data

Any personal data processed related to your use of the GitLab APIs will be processed in accordance with GitLab's [Privacy Policy](https://about.gitlab.com/privacy/).

## 4. Export

The GitLab APIs are subject to US global trade control laws and regulations, including the U.S. Export Administration Regulations and various sanctions programs administered by the U.S. Office of Foreign Assets Control. You will not, directly or indirectly, export, re-export, release, or make the APIs available for use, in contravention with these laws and regulations.

## 5. Warranty and Indemnification

5.1. EXCEPT AS EXPRESSLY STATED HEREIN, ANYTHING PROVIDED IN CONNECTION WITH THESE API TERMS, INCLUDING, WITHOUT LIMITATION, THE GITLAB APIS, IS PROVIDED "AS-IS", WITHOUT ANY WARRANTIES OF ANY KIND. EACH PARTY DISCLAIMS ANY IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, ANY IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.

5.2. You will indemnify, defend (at GitLab's request) and hold harmless GitLab and its affiliates and their respective directors, officers, employees, agents, contractors, end users, and licensees from and against any claims, losses, costs, expenses (including reasonable attorneys' fees), damages or liabilities based on or arising from (a) your Integration and any derivatives / combination of your Integration with the GitLab APIs (b) your relationships or  interactions with any end users, or third-party distributors, of your Integration, or (c) your infringement of GitLab's or any third party's intellectual property rights. GitLab may at its own expense participate in the defense and settlement of any claim with its own counsel, and you may not settle a claim without GitLab's prior written consent (not to be unreasonably withheld).

## 6. Limitation of Liability

6.1. WITH THE EXCEPTION OF YOUR (A) INDEMNIFICATION OBLIGATIONS UNDER SECTION 5.2; AND (B) OBLIGATIONS UNDER SECTION 4 (EXPORT), TO THE MAXIMUM EXTENT PERMITTED BY LAW:

&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;6.1.1. IN NO EVENT SHALL EITHER PARTY BE LIABLE TO THE OTHER FOR LOST PROFITS OR REVENUE OR LOSS OF USE OR DATA, COSTS OF COVER OR SUBSTITUTE GOODS OR SERVICES, OR FOR INCIDENTAL, CONSEQUENTIAL, PUNITIVE, SPECIAL OR EXEMPLARY DAMAGES, OR INDIRECT DAMAGES OF ANY TYPE OR KIND, HOWEVER CAUSED, RELATED TO OR ARISING OUT OF THESE API TERMS OR THE RIGHTS, LICENSES, PRODUCTS OR SERVICES PROVIDED UNDER THESE API TERMS WHETHER BY BREACH OF WARRANTY, BREACH OF CONTRACT, NEGLIGENCE, TORT, OR ANY OTHER LEGAL THEORY, AND WHETHER OR NOT THE PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES; AND

&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;6.1.2. THE TOTAL, CUMULATIVE LIABILITY OF EACH PARTY ARISING OUT OF OR RELATED TO THESE API TERMS OR THE RIGHTS, LICENSES, PRODUCTS OR SERVICES PROVIDED UNDER THESE API TERMS, WHETHER BASED ON CONTRACT, TORT (INCLUDING NEGLIGENCE), OR ANY OTHER LEGAL THEORY, SHALL BE LIMITED TO FIVE HUNDRED U.S. DOLLARS ($500.00).

## 7. Term and Termination

7.1. These API Terms shall remain in effect until terminated.

7.2. You may terminate these API Terms at any time by ceasing all use of the GitLab APIs and any relevant credentials.

7.3. GitLab reserves the right to terminate these API Terms or your use of the GitLab APIs with immediate effect for any reason and at any time without liability or other obligation to you.

7.4. Upon termination:

&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;7.4.1. All licenses granted herein immediately expire and you must cease use of the GitLab APIs;

&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;7.4.2. The terms of these API Terms that by their nature are intended to continue indefinitely will continue to apply.

## 8. Governing Law

These API Terms shall be construed and enforced in accordance with the laws of California, U.S.A., and you and GitLab submit to the jurisdiction of the State and Federal courts in San Francisco, California, without giving effect to any conflicts of laws principles.
