---
title: "Employment Law at GitLab"
---

Employment law refers to the law that governs the relationship between employer and employee, so the Employment section of GitLab Legal interacts with the People Group on a regular basis to provide information and legal advice related to the entire arc of our team members' relationship with GitLab.  **So what does that mean?**

- It means we work closely with the Finance and People teams to determine scalable employment solutions for the Company as it hires across the globe, using a collaborative process for gathering and assessing relevant information on any particular country.
- It means we support the Talent Acquisition department in meeting its goals and ensuring compliance with all local laws and regulations as they source, recruit, and hire new team members.
- It means we help the People Connect team onboard new team members and get them the information they need that applies both to their location and to their job responsibilities.
- It means we support the Total Rewards team, People Operations team, and People Business Partners in developing policies that meet GitLab's needs, our team members' needs, and local requirements.
- It means we support our Team Member Relations team, People Business Partners, and Total Rewards as they manage team member relations, requests for [reasonable accommodation](/handbook/people-policies/inc-usa/#reasonable-accommodation) or adjustments, performance, promotions, transfers, and any other types of issues that pop up during the course of the relationship.
- It means we support our Diversity, Inclusion, and Belonging team in ensuring that decisions across the entire arc of the relationship match our mission statement.
- And it means we provide support when it comes to end of employment decisions,  offboarding, and any follow-up matters that can occur.

Based on the outcome of its global expansion process for gathering and assessing relevant details on any particular country (which include local employment legislation and statutory requirements, potential PEO/EOR service agreements or limitations, branch or entity incorporation options, product and privacy considerations, etc), GitLab's employment team provides information regarding legal risk and compliance requirements based on particular jurisdictions and particular job types. Often, it is up to the others within the organization whether or not to continue down a certain path once the risks and requirements are known.

## Working with the Legal Employment Team on Sensitive Matters

In any situation(s) that relates to specific team members or otherwise requires any team member personal information remain confidential, the People Group (and any other GitLab Team Members) should email legal-employment@gitlab.com. This respects team member privacy and may, where applicable, retain attorney-client privilege.

If the Legal Employment team requires support from the People Connect team for communicating a country specific legal requirement to team members, to consult with team members in an entity country if necessary, or to arrange legally required contract amendments, to name just a few examples, which may relate to individual team members or groups of team members, assistance can be requested using the confidential process and template referenced [here](/handbook/people-group/#when-support-from-the-people-connect-team-is-required-by-the-legal-employment-team).

## Working with Legal on Employment Issues

When individual team members have questions about their employment at GitLab, they should interact with the People Group rather than reaching out directly to the Legal Employment team. Visit the [People Group Handbook](/handbook/people-group/) to determine who to work with for your particular needs.

If People Group needs to engage with Legal Employment on a particular question, they will apply the `legal-employment::to-do` label on the issue that requires attention. This will update the [Legal Employment Issue Board](https://gitlab.com/groups/gitlab-com/-/boards/4585701) and allow the team to triage appropriately. When the Legal Employment team has finished their portion of the issue, they will update the label to `legal-employment::done`.

Below are some common employment topics where Legal is asked to provide input. The paragraphs below are intended to assist People Group to know when to reach out to Legal.

**Note: GitLab team members should *always* obtain approval from the Senior Director of Legal, Employment prior to speaking with outside counsel regarding employment-related matters.**

## Before Hire

Legal supports the Talent Acquisition team to develop sourcing processes, candidate tracking processes, and job posting processes that meet applicable compliance requirements.

### Talent Acquisition

Legal reviews sourcing and talent acquisition strategy for compliance and advises about requirements for applicant tracking in the various countries in which we hire.

### Background Check

Legal reviews overall background check policy and procedure in place, helps develop background check adjudication process, and serves as escalation point when the Senior Background Check Specialist has questions or concerns about specific results.

## During Hire

### Contract Review

Legal should be asked to review negotiated contracts that seek to change standard terms.

- Standard contract terms are audited on an annual basis. A contract audit issue will be opened to review the terms and gather input from appropriate teams across the organization. To suggest a change to an entity contract template, please leave a comment in the current contract audit issue found in the `People Operations` project and titled  Semi-Annual `Global Employment Contract Review YYYY-January or June`.

### Compliance with Onboarding Issues

As different countries have different requirements for hiring and disclosures, Legal will assist People Operations to ensure that onboarding issues are compliant for specific locales.

## During Employment

### Total Rewards

Total Rewards is responsible for determining what benefits should be provided. Legal is available for advice when determining whether those benefits comply with local law.

### Relocation Request Reviews

[Relocation](/handbook/people-group/relocation/) requests are handled by People Connect, which has a very thorough explanation of the process and requirements. After People Connect team members have worked through their workflow, Legal is available to assist with specific unresolved questions.

### Conflicts of Interest

If a GitLab team member engages People Operations about a possible conflict of interest, the People Operations team should encourage discussion between the team member and their manager, as many conflict of interest determinations are business decisions, rather than legal decisions. If the team member and manager agree that there is no conflict then the applicable Functional Leader can provide written approval, which is maintained in Workday.  Legal is involved in managing the process to ensure that decisions regarding what is or is not a conflict remain consistent across departments and so that the manager and team member can understand the potential risks and implications in order to make an informed decision.

## General Business Needs involving Employment Issues

### Scalable Employment Solutions

As GitLab scales, global expansion efforts require support from a dedicated cross-functional team with multidisciplinary background: Sales, Engineering, Talent Acquisition, Tax, People Ops, Total Rewards, Payroll, Legal, and Finance, with strategic decisions on which countries to prioritize expansion in being made at E-group level. There are challenges related to global expansion, including economic impact, legal exposure, tax exposure, and accounting impact. The GitLab Employment Team coordinates the 'global expansion legal process' for each proposed or potential country, as required, collaborating with each of the other GitLab legal teams to gather and review relevant information on any particular country to assess, including whether GitLab already has team members there, and if so, what employment model is currently in use and whether it can be scaled. If there are no team members in a country, the team considers (with input from all of GitLab Legal) what employment options there might be, whether there are any limitations or restrictions on hiring and what the best solution might be for now and for into the future.

### Legal Global Expansion Process

- The GitLab Employment Legal Team creates a repository (in Google Drive) for the requested country;
- The GitLab Employment Legal Team completes a Country Expansion Issue using an Issue Template. This Issue is submitted and operates to (a) inform each legal team stakeholder; (b) review the current employment status of the country (for example, does GitLab have team members in that location?); (c) engage external counsel (as applicable); and (d) review and gather additional information related to the country and individual(s) which may play a role with regards to employment, employment contract(s), costs of employing in the country, and other material elements.
- Based upon the information from the Country Expansion Issue, the cross-functional team will determine and recommend next steps;
- If expansion is determined by the cross-functional team, a second Issue will be opened by the Employment Legal Team to manage the next step(s), which may include (a)supporting the creation of the new employment solution, (b) converting current team members to the new solution, (c) supporting Corporate, Finance, and Tax (as applicable) if a new entity is formed, (d) creating or reviewing employment contracts, (e) reviewing equity compliance, and (f) developing jurisdiction-specific employment and privacy policies where applicable.

### Policy Development

The GitLab Employment Legal Team are available to collaborate with the People Teams if or when a new employment policy is required or an update or review of a current policy is undertaken and, if not involved at an earlier stage, should still be asked to perform a final review when policies are updated or created. The Employment Legal Team can be engaged to assist with policy creation, updates or review by using this [issue template](https://gitlab.com/gitlab-com/legal-and-compliance/-/issues/new#). By adding the `legal-employment::to-do` label on the issue that requires attention, the issue will update the [Legal Employment Issue Board](https://gitlab.com/groups/gitlab-com/-/boards/4585701) and allow the team to triage appropriately.

### Contract Negotiations

In the event that a customer or vendor has questions regarding terms that affect our team members (such as drug tests or more intensive background checks), the procurement team will reach out to the Employment team.
