---
title: "Team Member Sustainability Guide"
description: "GitLab's Team Member Sustainability Guide for Remote Work"
---
Please contribute your ideas to this guide [here.](https://gitlab.com/gitlab-com/legal-and-compliance/-/issues/2072)

## Introduction

Welcome to the first iteration of GitLab's Team Member Sustainability Guide. As a fully remote workforce without daily commutes or physical offices, we don't have the typical environmental footprint that many other companies have, but that doesn't mean we don't have an environmental impact.

[Climate Action and Greenhouse Gas (GHG) Emissions](/handbook/legal/esg/#esg-materiality-matrix) are key focus areas identified in GitLab's ESG Materiality Assessment. Through our [annual GHG inventory](/handbook/company/esg/#climate-action-and-greenhouse-ghg-emissions), we measure four emissions sources from our business; purchased goods and services (our suppliers), cloud services, business travel, investments, and **emissions associated with remote work**.

Working remotely comes with its own sustainability challenges and opportunities. For example, our laptops, monitors and lamps use energy that generates carbon emissions. The meals we eat during our work day generate waste that may end up in a landfill. The purpose of this guide is to provide actionable steps for team members to take at home to reduce individual environmental impact.

We know that part of doing responsible business means minimizing our environmental footprint. That's why we're committed to analyzing and publishing our emissions along with any steps we're taking to reduce our footprint in our annual [ESG report](/handbook/company/esg/#gitlab-fiscal-year-2023-fy23-esg-report).

We are a global team, and we know there are sustainability initiatives and offerings specific to where you live. Many of you have developed sustainable practices at home, and we would love to know more about them! Please [contribute here](https://gitlab.com/gitlab-com/legal-and-compliance/-/issues/2072) and help us crowdsource ideas for other team members in your area! Please share any feedback or questions in the issue or in slack #ESG.

## Electronics

1. Unplug devices at the end of the day. You can save anywhere between $100 and $200 each year by unplugging devices not in use.<sup>1</sup>
2. Use sleep mode instead of a screensaver. Screensavers might actually use more energy than not using one.<sup>2</sup>
3. Repair devices instead of replacing. [ifixit](https://www.ifixit.com/) provides manuals for how to fix a variety of electronic and other household items. For GitLab laptop repairs, follow the [steps listed in the handbook](/handbook/it/end-user-services/onboarding-access-requests/#laptop-repair).

## Lighting

1. Switch to LED lights. LED lights use up to 90% less energy and last up to 25 times longer than incandescent bulbs.<sup>3</sup>
2. Take advantage of daylight - if you can, place your desk near a window and turn off overhead lights as much as possible during your work day.

## Heating & Cooling

1. Conduct an energy audit - hire a professional or [DIY](https://www.energy.gov/energysaver/do-it-yourself-home-energy-assessments). Energy audits are helpful for better understanding where your home is losing energy and where you should prioritize upgrades/fixes. In the U.S., take advantage of the new [Home Energy Audit Tax Credit](https://www.energystar.gov/about/federal-tax-credits/home-energy-audit), introduced as part of the Inflation Reduction Act. Check out the [full list](https://www.irs.gov/credits-deductions/energy-efficient-home-improvement-credit) of energy efficiency home improvements that qualify for a tax credit in the U.S. If you aren't based in the U.S., check to see if your municipality offers financial incentives/support related to energy efficiency improvements in your home.
2. Replace traditional heating systems, such as furnaces, boilers and baseboards with a heat pump. [Heat pumps](https://www.energy.gov/energysaver/heat-pump-systems) are 2-3x more efficient than traditional heating systems.<sup>4</sup>
3. Turn your thermostat down. You can save as much as 10% a year on heating and cooling by simply turning your thermostat back 7°-10°F for 8 hours a day from its normal setting.<sup>5</sup>
4. Insulate your home. A leaky home is expensive! You can cut your utility bills by $500 - $1,000 just by sealing leaky windows and doors.<sup>6</sup> One easy way to do this is to use weather strips to seal windows and doors to prevent energy leakage. Check out [this guide](https://energysavingtrust.org.uk/energy-at-home/reducing-home-heat-loss/) from Energy Savings Trust for more information on other ways to insulate your home.
5. Consider switching to a [tankless water heater](https://carbonswitch.com/tankless-water-heater-buyers-guide/). Consult a professional to understand your options for a tankless water heater based on your house size, hot water needs, and energy source. <sup>7</sup>

## Waste

1. Reuse. Before throwing something away, consider if you can reuse it at least one more time.
2. Reduce single use plastics. For example, opt for a reusable water bottle instead of a plastic water bottle. Bring a reusable bag to the grocery store. Swap out plastic food storage bags for reusable ones, like [these](https://www.stasherbag.com/).
3. Reduce food waste. When food waste ends up in landfills and rots, it generates methane, a greenhouse gas 28x more potent than carbon dioxide.<sup>8</sup>
4. Compost your food waste instead of throwing it away. Use a countertop compost bin to make it easy to collect food scraps. Take advantage of curbside composting programs if your municipality offers one. If not, research options for compost pick up in your area (this will likely include a fee) or check to see if there's a local composting facility where you can drop off your food scraps. Alternatively, set up your own [composting system at home](https://www.epa.gov/recycle/composting-home). If you don't have access to space for traditional composting, explore alternatives like vermiculture.
5. Recycle. Recycling reduces the amount of waste sent to landfills and reduces greenhouse gas emissions generated by landfill. Before throwing something away, check to see if it's recyclable. Take advantage of curbside recycling programs if your municipality offers one. If not, research options for recycling curbside pick up in your area or check to see if there's a local recycling facility where you can drop off your recyclable materials.

## Water

1. Reduce your water consumption by making small changes to your daily routine, such as turning off the tap while you brush your teeth or shortening your shower.
2. Upgrade to low flow appliances, such as aerated shower heads and dual-flush toilets.

## Food

1. Choose plant-based foods to reduce your meat and dairy consumption. Animal-based foods have a significantly higher carbon footprint than plant-based foods. For example, producing one kilogram of beef emits 60 kilograms of greenhouse gasses. In contrast, peas emit just 1 kilogram per kilogram produced.<sup>9</sup> Check out [this visualization](https://ourworldindata.org/food-choice-vs-eating-local) that shows GHG emissions from 29 food products — from beef at the top to nuts at the bottom.

## Transportation

1. Use public transit instead of driving or using ride hailing services like Uber or Lyft. If you're part of the GitLab, Inc. entity, check out [Commuter Benefits](../../../total-rewards/benefits/general-and-entity-benefits/inc-benefits-us/#commuter-benefits) to learn how to use pre-tax dollars for transit passes.
2. For inter-city trips, use train or bus transportation instead of flying in order to reduce carbon emissions.<sup>10</sup>

## Renewable Energy

1. Consider installing solar panels on your roof. Check out this [Step by Step Guide](https://www.energy.gov/eere/solar/articles/walk-me-through-it-step-step-guide-consumers-going-solar) for homeowners considering solar. Assess your roof's solar potential using [Project Sunroof](https://sunroof.withgoogle.com/).  Don't own a home? Here are [some ideas](https://greenerideal.com/guides/solar-for-renters-a-guide-on-using-solar-energy-without-owning-a-home/#:~:text=Renters%20can%20take%20advantage%20of%20solar%20energy%20without%20owning%20a,contribute%20to%20a%20cleaner%20environment.) for how renters can benefit from solar power.
2. Check to see if your local utility offers a 'green power' or 'green tariffs' program. Many utilities make it easy for customers to support green energy. Here's a U.S. example for reference: [Seattle City Light Green Up Program](https://www.seattle.gov/city-light/residential-services/home-energy-solutions/renewable-energy-credits).

## Calculate Your Personal Carbon Footprint

1. If you're curious about your personal carbon footprint, check out [The Nature Conservancy's carbon footprint calculator](https://www.nature.org/en-us/get-involved/how-to-help/carbon-footprint-calculator/).

## Get Involved

1. Join the [Great Global Cleanup](https://www.earthday.org/campaign/cleanup/) and find a volunteer event near you.
2. Take a look at EarthDay.org's [individual action toolkit](https://www.earthday.org/individual-action-toolkit/).

## Additional Resources

- [Carbon Switch](https://carbonswitch.com/): guides for how to reduce household carbon emissions
- [Energy Star](https://www.energystar.gov/?s=mega) (US gov't): Find energy efficient household appliances
- [Energy Saving Trust](https://energysavingtrust.org.uk/) (UK-based): an independent organization that provides resource for how to reduce energy use
- [Project Drawdown](https://drawdown.org/): the world's leading resource for climate solutions
- [Water's Worth Saving](https://web.archive.org/web/20240717112301/https://watersworthsaving.org.uk/): (UK-based): tips for saving water at home

**Footnotes**

1. https://www.energy.gov/energysaver/articles/how-stop-energy-vampires-attacking-your-home
2. https://www.energy.gov/energysaver/energy-efficient-computers-home-office-equipment-and-electronics
3. https://www.eia.gov/todayinenergy/detail.php?id=49816
4. https://carbonswitch.com/what-is-a-heat-pump/
5. https://www.energy.gov/energysaver/programmable-thermostats#:~:text=You%20can%20save%20as%20much,those%20in%20more%20severe%20climates
6. https://carbonswitch.com/insulation-and-sealing/
7. https://www.energy.gov/energysaver/tankless-or-demand-type-water-heaters
8. https://www.epa.gov/gmi/importance-methane
9. https://ourworldindata.org/food-choice-vs-eating-local
10. https://ourworldindata.org/travel-carbon-footprint
