---
title: "GitLab's Ethics and Compliance Program"
layout: single
---

## Mission

GitLab Inc. (collectively with its subsidiaries,***"GitLab"***, ***"we"***, ***"our"***) is committed to lawful and ethical behavior in all we do and expects members of GitLab's Board of Directors (***"Board"***) and officers, employees, and contractors (collectively, ***"Team Members"***) to conduct business ethically, with integrity, and in accordance with all applicable laws and regulations.

GitLab's culture is based on our [VALUES](/handbook/values/), which are reflected in and reinforced by our Code of Business Conduct and Ethics and various supporting policies, such as our Anti-Fraud Policy and Anti-Retaliation Policy (collectively, ***"Compliance Standards"***). Because GitLab is made up of individuals who are aligned with our VALUES and who are accountable to our customers, shareholders, and each other, we have designed this Ethics and Compliance Program (the ***"Program"***) as an operational framework for our team members. This Program is dedicated to (among other things) making sure GitLab's Compliance Standards are current, complete, and readily accessible. Team Members are educated on these Compliance Standards, through continuous training, awareness campaigns, required annual reviews and acknowledgments, and additional resources, including #compliance-legal.

While compliance is certainly a company-wide effort, it is as importantly the individual responsibility of each and every GitLab team member. By embracing our Compliance Standards, together we will maintain our good standing and instill our customers and the wider community with confidence when they place their trust in GitLab.

## Compliance Standards, Guidelines & Other Resources

### Policies

Listed below are GitLab's policies and procedures, as well as guidance and other resources. This list will be updated, as needed, in order for GitLab to address the constantly evolving worldwide regulatory landscape, and partner with GitLab customers to allow them to meet their own regulatory requirements.

- [Acceptable Use Policy](/handbook/legal/acceptable-use-policy/)
- [Anti-Corruption Policy](/handbook/legal/anti-corruption-policy/)
- [Anti-Fraud Policy](/handbook/legal/anti-fraud-policy/)
- [Anti-Harassment Policy](/handbook/people-group/anti-harassment/)
- [Anti-Retaliation Policy](/handbook/legal/anti-retaliation-policy/)
- [Authorization Matrix](/handbook/finance/authorization-matrix/)
- [Code of Business Conduct and Ethics](https://s204.q4cdn.com/984476563/files/doc_downloads/govdoc/GitLab-Code-of-Business-Conduct-Ethics-2024-06-25.pdf)
- [Corporate Communication Policy](/handbook/legal/corporate-communications/)
- [Data Privacy Impact Assessment (DPIA) Policy](/handbook/legal/privacy/dpia-policy)
- [Employee Privacy Policy](/handbook/legal/privacy/employee-privacy-policy/)
- [Entity-Specific Employment Policies](/handbook/people-policies/#entity-specific-employment-policies)
- [Events Code of Conduct](https://about.gitlab.com/company/culture/ecoc/)
- [Gifts & Entertainment, Political Activities & Contributions, and Charitable Contributions](/handbook/legal/policies/gifts-contributions/#)
- [GitLab Federal Code of Ethics](https://drive.google.com/file/d/1whEuxvIwy3M33N3vbUUkGrOKvkow5LAw/view)
- [Insider Trading Policy](https://drive.google.com/file/d/184tkDZaPmZAxwQRQ5BwBv2JpfTWbWmBW/view)
- [Internal Acceptable Use Policy](/handbook/people-group/acceptable-use-policy/)
- [Partner Code of Ethics](/handbook/legal/partner-code-of-ethics/)
- [Privacy Statement](https://about.gitlab.com/privacy/)
- [Record Retention Policy](/handbook/legal/record-retention-policy/)
- [Record Retention and Disposal Standards](/handbook/security/records-retention-deletion/)
- [Related Party Transactions](/handbook/legal/gitlab-related-party-transactions-policy/)
- [SAFE Framework](/handbook/legal/safe-framework/)
- [Social Media Policy](/handbook/marketing/team-member-social-media-policy/)
- [Third-Party Risk Management Process](/handbook/finance/procurement/#-third-party-risk-management)
- [UK Modern Slavery Act Transparency Statement](https://drive.google.com/file/d/11Yne51yOV5_9EBnGbfvMIrq06Z_OxUEM/view?usp=sharing)
- [Whistleblower Policies](/handbook/legal/whistleblowing/#whistleblowing-at-gitlab)

### Policy Translations

Certain policies are now available [here](/handbook/people-policies/#translations) in Dutch, French, and German.

### Guidelines and Other Resources

- [AI Ethics Principles for Product Development](/handbook/legal/ethics-compliance-program/ai-ethics-principles/)
- [Data Classification Standards](/handbook/security/data-classification-standard/)
- [Designated Insider Pre-Clearance Process and FAQs](https://docs.google.com/document/d/1mcBtnfGbv4jSsJUklMQYyj2052MBHe4Lf9RkE-B9yvA/edit#heading=h.b3pm8ljoip1y)
- [External Materials Compliance Checklist](/handbook/legal/external-materials-compliance-checklist/)
- [Insider Trading Policy FAQs](https://docs.google.com/document/d/1vKFiYuieDQtKmrak-aAB2dTT3B3Q-aU4DtbcRm27X4U/edit)
- [IP Public Materials Guidelines](/handbook/legal/ip-public-materials-guidelines/)
- [Learning Content Accessibility Guidelines](/handbook/legal/ethics-compliance-program/learning-content-accessibility-guidelines/)
- [Materials Legal Review Process](/handbook/legal/materials-legal-review-process/)
- [Trade Controls relating to Russia, Belarus, and Ukraine - Sales](https://docs.google.com/document/d/1oT8fj0z313iYcaVxFBo3MtDm5R2KECYmYbWcGFODHKE/edit)
- [FAQ](https://docs.google.com/document/d/1oT8fj0z313iYcaVxFBo3MtDm5R2KECYmYbWcGFODHKE/edit)

### Policy Change Management

We anticipate the need for policy amendments and new policies and procedures, as GitLab continues to respond to the ever-evolving laws and regulations that our policies are designed to address. Team members who wish to implement new policies and/or amendments to policies identified [here](https://docs.google.com/spreadsheets/d/1p5_02x6nBy1ftLYwhzTvm1lk47ijVdhlGVEJvU7M4xI/edit?usp=sharing) must document all necessary approvals (including DRI and Board, when necessary) using this [issue template](https://gitlab.com/gitlab-com/legal-and-compliance/-/blob/master/.gitlab/issue_templates/policy-requests.md?ref_type=heads) prior to that policy's implementation. Using this process allows GitLab to drive consistency across our policies and procedures and maintain approvals in one central location.

## Training

Compliance training is critical to GitLab's success and the success of its team members. Effective training helps team members achieve a more meaningful understanding of what our Compliance Standards require and puts them in a better position to recognize and escalate (as required) unethical and unlawful behavior when they see it.

All team members are required, as part of their onboarding, to complete compliance training within 30 days of starting at GitLab. This training addresses key compliance topics such as anti-harassment, security, data privacy, and insider training, and must read and acknowledge GitLab's Code of Business Conduct and Ethics. Laws and regulations are constantly evolving, which is why GitLab also provides annual and refresher training as appropriate. Currently, training is provided through either [NavexEngage](https://lms.navexglobal.com/topclass5/) and [WILL Interactive](https://learning.willinteractive.com/). GitLab's [General Security Awareness Training](/handbook/security/security-assurance/governance/sec-training.html) is provided through [Proof Point](https://gitlab.ws01-securityeducation.com/my-training). Additional information about Navex and the courses available there can be found [here](/handbook/legal/legalops/navex/).

We recognize that some team members are subject to additional or heightened compliance requirements as a result of their roles and responsibilities or the geographies in which they operate. Depending on these factors, those team members may receive additional training. As an example, team members employed by or working closely with GitLab Federal, our United States public sector entity, must complete a training course titled Government Contracting: Gifts, Gratuities, and Bribery.

## Reporting

We recognize that unlawful and unethical behavior could happen despite our best efforts. We encourage and require team members to promptly report unlawful and unethical behavior, potential or suspected violations of GitLab's Code of Business Conduct and Ethics or supporting policies, and any other violations described in GitLab's [Whistleblower Policy](https://drive.google.com/drive/folders/1kB3k5FRnR3OUBP0Eyo3SxxyPKeiRFfUk) or any applicable [country-specific whistleblower policy](/handbook/legal/whistleblowing/#country-specific-whistleblower-policies), and any concerns involving team member relations. GitLab offers several different ways for team members to report these concerns:

### Reporting Misconduct (Anonymously OR Non-Anonymously)

Team members should use [EthicsPoint](https://secure.ethicspoint.com/domain/media/en/gui/74686/index.html) to report unethical and unlawful behavior, and violations of the Business Code of Conduct and Ethics and policies in support of the Code. Reports can be **anonymous** or **non-anonymous**. Reports can be made using the platform [online](https://gitlab.ethicspoint.com/.) or by using EthicsPoint's hotline, which is available 24 hours a day, 365 days a year. The toll-free hotline number for the USA is 1-833-756-0853. Direct access phone numbers for other locations can be viewed on the EthicsPoint website by using the country location drop-down menu.  In the alternative, misconduct may be reported in any manner described in GitLab's [Whistleblower Policy](https://drive.google.com/drive/folders/1kB3k5) or applicable [country-specific whistleblower policies](/handbook/legal/whistleblowing/#country-specific-whistleblower-policies).

### Reporting Workplace Harassment (Non-Anonymous Only)

Team members who are comfortable doing so may report workplace harassment concerns, **non-anonymously**, using GitLab's [Harassment Complaint Form](https://docs.google.com/document/d/1Xk5SXvh2kpO-w-TdykiczjhXNrEBjbMwDQHEt6lMhIk/edit?usp=sharing). Simply complete and send it to our Team Member Relations Specialists at <teammemberrelations@gitlab.com>. Read our [Anti-Harassment Policy](/handbook/people-group/anti-harassment/#types-of-harassment) to understand the different shapes that harassment may take and to understand the alternative reporting avenues that are available, such as [GitLab's Chief People Officer](mailto:wbarnes@gitlab.com), [GitLab's Chief Legal Officer](mailto:CLO@gitlab.com), the [Team Member Relations Team](/handbook/people-group/team-member-relations/#discussing-private-concerns), or a [Business People Partner](/handbook/people-group/#people-business-partner-alignment-to-division).

### Reporting Concerns about Team Member Relations (Anonymously OR Non-Anonymously)

Team members who would like to **anonymously** report workplace harassment concerns or who would like to, **anonymously** or **non-anonymously**, report other concerns involving team member relations should use [Lighthouse Services](https://www.lighthouse-services.com/gitlab). Topics may vary but could include, for example, wrongful discharge or disciplinary action, discrimination, alcohol and substance abuse, or threats.

Reports can be made using the platform or through the following avenues, which are available 24 hours a day, 365 days a year.

- A toll-free hotline number for the USA and Canada: 833-480-0010.
- Direct access phone numbers for other locations, available [here](/handbook/people-group/#how-to-report-violations).
- E-mail: <reports@lighthouse-services.com> (must include company name with report)
- Fax: (215) 689-3885 (must include company name with report)

Team members may, in the alternative, report concerns about team member relations, including violations of GitLab's Anti-Harassment Policy, to GitLab's [Chief Legal Officer](mailto:rschulman@gitlab.com), [Chief People Officer](mailto:wbarnes@gitlab.com), the [Team Member Relations Team](/handbook/people-group/team-member-relations/#discussing-private-concerns), or a [Business People Partner](/handbook/people-group/#people-business-partner-alignment-to-division).

### Manager Roles and Responsibilities

Team members should report misconduct, workplace harassment, and other concerns about team member relations to their manager if they are comfortable doing so. Managers who receive a report (verbal or written) or otherwise become aware of misconduct, workplace harassment, or other concerns, must ensure that the misconduct is immediately reported to the relevant People Business Partner or through one of the reporting avenues described above.

### Investigations

GitLab takes allegations of misconduct very seriously and want an opportunity to resolve them. Reports submitted through any avenue described above will be reviewed promptly and addressed in accordance with GitLab's [Whistleblower Policy](https://drive.google.com/drive/folders/1kB3k5FRnR3OUBP0Eyo3SxxyPKeiRFfUk) and [Anti-Retaliation Policy](/handbook/legal/anti-retaliation-policy/#reporting-procedure). Potential instances of non-compliance are taken seriously, and unethical behavior and/or violations of GitLab policies may lead to termination of employment.

## Ethics and Compliance Program Charter

### Purpose

The Ethics and Compliance Program is intended to help GitLab team members achieve and maintain a culture of compliance with GitLab's Code of Business Conduct and Ethics and supporting policies, and all applicable laws and regulations. To accomplish that goal, the Program strives to:

- Promote a culture of compliance and ethical decision-making, consistent with GitLab's values;
- Ensure that Compliance Standards and avenues for reporting potential instances of non-compliance are widely available to team members and are effectively communicated through training and awareness programs; and,
- Encourage and facilitate appropriate risk assessment, due diligence, and remediation, to deter, detect, and address unlawful, unethical, and discriminatory conduct.

### Program Governance and Responsibilities

#### Board of Directors

The GitLab Inc.'s [Board of Directors](/handbook/board-meetings/), through its Audit Committee, is responsible for administering the Code of Conduct and for addressing material issues and risks concerning Compliance Standards and applicable laws and regulations.

#### Chief Legal Officer

The Audit Committee has delegated day-to-day responsibility for administering and interpreting the Code of Conduct to GitLab's Chief Legal Officer (***"CLO"***). The CLO shall reasonably administer the Program and, among other things, will:

- Allocate resources to the Program and delegate authority to its key stakeholders as needed to implement, maintain, and strengthen the Program;
- Ensure that reasonable steps are taken to respond to potentially unlawful behavior and criminal misconduct;
- Ensure that GitLab's Compliance Standards are reasonably designed to prevent and detect misconduct, are widely available and accessible to team members, and are regularly assessed for potential updates and improvements;
- Maintain awareness and encourage the use of mechanisms for reporting potential instances of non-compliance;
- Collaborate with GitLab's Internal Audit team and key stakeholders to ensure that the Program is implemented across GitLab, is monitored and assessed periodically for effectiveness, and that findings and observations are used to promote continuous improvement; and,
- Consider recommendations to the Program itself or which are proposed in response to significant risk assessment or audit findings, instances of non-compliance with laws and regulations, or weaknesses in the Program, and shall advise the Audit Committee as needed.
