---
title: "External Materials Compliance Checklist"
description: "Checklist for use when developing materials for external use"
---

When developing materials for external use, follow the [SAFE Framework](/handbook/legal/safe-framework/) and the [Guidelines for Use of Third-party IP in External Materials](/handbook/legal/ip-public-materials-guidelines/) (the "**IP Guidelines**"). If you have any questions, reach out to the Legal & Corporate Affairs Team via the [#safe Slack channel](https://app.slack.com/client/T02592416/C01UZQ63WFQ).

In addition to following the SAFE Framework and the IP Guidelines, review the following Checklist before publishing or using materials you've created. This Checklist serves as a quick-reference guide, and should not be used as a substitute for reviewing and following the SAFE Framework and the IP Guidelines in full.

- All facts and statements included in the materials are true and correct, and not misleading or deceptive in any way.
- All statements of fact and assumptions are clearly referenced (giving the source name and date) from a reputable source within the collateral (e.g., Gartner, SEC filings, GitLab partner, mainstream technology publications).
- As of dates to indicate the date the information was accurate are included. (e.g., `Over 1700 team members as of April 31, 2022`).
- Backup materials and data verifying any express or implied claims in the materials are saved and accessible.
- There are no guarantees regarding outcomes or that the product will meet any individual's, company's, or customer's specific needs.
- Materials do not contain any unqualified superlatives or overpromotion (e.g. replace `the best` with `among the best`).
- There are no defamatory statements made about other companies, products, services, or people.
- Case studies included are accurate, not misleading, and necessary approvals for publication from the customer or partner featured are in place and documented.
- If indicated by the [Required Disclaimers guidance](/handbook/product/product-processes/product-safe-guidance/#required-disclaimers/), the [appropriate roadmap disclaimer](https://docs.google.com/presentation/d/1hbf9AnFj_E5Y_Yg_WWoy_R0WJXZZLV0zWpMUHqnIs3c/edit#slide=id.ge2b39964d2_0_144) is included.
- All audio and visual content (including images, video, sounds, and music) is obtained from a permissively-licensed source, or is subject to a license permitting the proposed use.
- All content is appropriate for a professional setting and neither offensive nor misleading.
- Where [necessary](/handbook/legal/publicity-waiver-release), signed Publicity Waiver and Release agreements are in place with named individuals, and individuals appearing in audio or visual content.

## Examples - is Legal Review Necessary?

| Nature of Materials | Legal Review Necessary? |
|:--------------------|:------------------------|
|Materials related entirely to company culture (e.g., All-Remote)|No|
|Materials solely relying on and citing data from prior public <p> (i.e., SEC) filings|No|
|Materials based on pre-existing material previously reviewed by <p> Legal & Corporate Affairs without substantive changes|No|
|Materials  about the tech industry or DevOps generally|No|
|Materials which quote, or are in the name of, a Section 16 Officer <p> (i.e., Board Members, Sid, Brian, Robin, McB, and Eric J.) and VP, IR (Jack Andrews)|Yes|
|Materials which include financial data that has not been previously <p> disclosed publicly, or a variation of previously disclosed financial data|Yes|
|Materials with which a Team Member has concerns related to SAFE or <p> third-party IP|Yes|
|Materials related to mergers or acquisitions, including spin out, <p> investment or acqui-hires|Yes|
|Materials related to executive or other material organizational changes|Yes|
|Materials related to quarterly earnings, including future results <p> and dates of earnings release|Yes|
|Materials related to roll out of products material to the business|Yes|
|Crisis communications|Yes|
