---
title: "GitLab Related Party Transactions Policy"
description: "Overview of the Related Party Transactions Policy at GitLab."
---
{{% alert title="This is a Controlled Document" color="danger" %}}
Inline with GitLab's regulatory obligations, changes to [controlled documents]({{< ref "controlled-document-procedure" >}}) must be approved or merged by a code owner. All contributions are welcome and encouraged.
{{% /alert %}}

GITLAB INC. RELATED PARTY TRANSACTIONS POLICY
{.h1}

***THIS POLICY WAS AMENDED AND RESTATED BY THE BOARD ON SEPTEMBER 14, 2021***

### PURPOSE

At GitLab Inc. (the "***Company***"), we aim to lead by example. We set high standards for our team members at all levels and strive to meet them consistently. Our sound business principles and practices foster our commitment to ethical behavior, accountability and transparency. We expect our directors, officers and team members to avoid conflicts of interest, that is, any activity that interferes with the performance of their duties or that might deprive us of their undivided loyalty in business dealings. Conflicts of interest can come up in various ways, even in situations where the transaction may benefit the Company and our stockholders. This Related Party Transactions Policy (the "***Policy***") deals specifically with those situations where the Company (including any of our subsidiaries) is a party to a transaction with a Related Party. Although our Code of Business Conduct and Ethics addresses this issue generally, we have adopted this Policy to formalize our procedures for the identification, review, and consideration and approval of the Audit Committee of our Board of Directors (the "***Audit Committee***") of any transactions involving the Company and a Related Party. This Policy has been approved by our Board of Directors ("***Board***").

### PERSONS COVERED BY THIS POLICY

This Policy applies to all of our executive officers, any person the Company knows to be the beneficial owner of more than 5% of any class of our voting securities (a "***significant stockholder***"), and members of our Board.

### APPROVAL AUTHORITY

Our "***Approval Authority***" will be our Audit Committee. In a situation where a member of our Audit Committee is a Related Party in the proposed transaction, our Nominating and Corporate Governance Committee will be the Approval Authority.

### WHO IS A RELATED PARTY?

You are a Related Party if you are:

1. a person who is, or at any time since the begining of our last fiscal year was, a director or executive officer of the Company or a nominee to become a director;
1. a significant stockholder, or an immediate family member of a director, director nominee, executive officer or significant stockholder. This includes any child stepchild, parent, stepparent, spouse, sibling, in-law (mother, father, son, daughter, brother, sister) of such person, and any person (other than a tenant or employee) sharing the household of such person.

### WHAT TYPES OF TRANSACTIONS ARE COVERED BY THIS POLICY?

Any transaction, arrangement or relationship (including any indebtedness or guarantee of indebtedness) or any series of similar transactions, arrangements or relationships, in which:

1. the Company (including any of our subsidiaries) was, is or will be a participant;
1. the aggregate amount involved will or may be expected to exceed $120,000 in any fiscal year; and
1. any Related Party had, has or will have a direct or indirect material interest.

Any transaction that meets the above criteria is referred to as a "***Related Party Transaction***."

### IDENTIFYING RELATED PARTIES

We have established a process to identify any Related Party to assist us in enforcing this Policy.

**Directors and Executive Officers**
Our Legal Team will collect, at least annually, the following information from each of our directors and executive officers:

1. A list of all entities in which they serve as a director or executive officer, or in which they have 5% or greater beneficial ownership interest.
1. A list of all their immediate family members, and for each immediate family member listed:
    - whether they are (a) an executive officer of any entity, or (b) employed by the Company's independent auditor (or an affiliate, member firm or other entity associated with our independent auditor), and if so, the name of their employer and job title or a brief job description; and
    - all entities in which they serve as a director or in which they are a significant stockholder.

This list also will include the name of each charitable or non-profit organization for which each director, executive officer and any immediate family member is a major fundraiser or otherwise serves as a director or trustee or in a similar capacity.

Directors and executive officers are expected to notify our Legal Team of any updates to the list of Related Parties, including updates to their employment and relationships with charitable organizations.

**Significant Stockholders**

When the Company learns that a person has become a significant stockholder, our Legal Team will examine relevant filings with the U.S. Securities and Exchange Commission ("***SEC***") (to the extent such information is available) to determine (a) if the person is an individual, the same information requested of directors and executive officers under this Policy, and (b) if the person is a firm, corporation or other entity, a list of principals or executive officers of such firm, corporation or entity.

### APPROVAL PROCESS

**Advance Approval**

Any transaction the Company intends to undertake with a Related Party, irrespective of the amounts involved (unless the transaction is subject to standing pre-approval as provided in this policy or pursuant to a resolution adopted by the Approval Authority), must be submitted to the Chief Legal Officer (the "***CLO***") for their determination of the approvals required under this Policy. The CLO will refer to the Approval Authority any Related Party Transaction, and any other transaction that the CLO otherwise determines should be considered for evaluation by the Approval Authority consistent with the purpose of this Policy. The CLO may do so irrespective of any pre-approval or other technical exemption from this Policy.

The Legal Team will provide the Approval Authority with all relevant information available about the proposed transaction, including:

1. the Related Party's relationship to the Company and interest in the transaction;
1. the material facts of the proposed transaction, including the anticipated aggregate dollar value of the transaction or, in the case of indebtedness, the largest amount of principal outstanding at any time during the current fiscal year plus all amounts of interest payable on it during the fiscal year;
1. the rationale for the proposed transaction; and
1. any other relevant information with respect to the proposed transaction.

In deciding whether to approve a proposed transaction, the Approval Authority may take into account any relevant information and considerations, including the impact on a director's independence if the Related Party is a director. The Approval Authority may impose such conditions as it deems appropriate on the Company or on the Related Party in connection with approving the proposed transaction.

The Approval Authority will convey the decision, including any conditions imposed on the transaction, to our CLO, who then will convey the decision to the appropriate people within the Company.

**Review of Ongoing Transactions**

At least annually, the Approval Authority will review any previously approved or ratified transactions with Related Parties that remain ongoing and that have a remaining term of more than six months and remaining amounts payable to or receivable from us of more than $120,000 during the fiscal year. Based on all relevant facts and circumstances, the Approval Authority will determine whether it is in the best interests of the Company and its stockholders to continue, modify or terminate the transaction.

**Ratification**

Members of our finance team will produce quarterly reports of any amounts paid or payable to, or received or receivable from, any Related Party. These reports will be provided (a) to our legal department and used to determine whether there are any Related Party Transactions or other transactions with Related Parties that were not previously approved or previously ratified under this Policy and (b) to our CLO for appropriate reporting in our periodic reports.

If the CLO learns of a transaction with a Related Party that required but did not receive approval or ratification under this Policy, the CLO will promptly submit the transaction to the Approval Authority. The Approval Authority will undertake the review described above. Based on the conclusions reached, the Approval Authority will evaluate all options, including but not limited to ratification, amendment or termination of the transaction with the Related Party, and determine whether disciplinary action is appropriate.

A transaction with a Related Party entered into without pre-approval of the Approval Authority will not be deemed to violate this Policy, or be invalid or unenforceable, provided that the transaction is brought to the Approval Authority as promptly as reasonably practical after it is entered into or after it becomes reasonably apparent that the transaction is covered by this Policy.

**Standing Pre-Approval for Certain Related Party Transactions**

Unless there are special or unusual benefits to the Related Party in a proposed transaction, the following categories of Related Party Transactions do not need to be presented to the Approval Authority for review and approval under this Policy:

1. *Employment of executive officers*: Any employment by us of an executive officer if:
    - the compensation arising from such employment is reported in our proxy statement; or
    - the executive officer is not an immediate family member of another Company executive officer or director, the related compensation would have been reported in our proxy statement if the executive officer were a "named executive officer," and the Company's Compensation and Leadership Development Committee approved (or recommended that the Board approve) such compensation;
1. *Director compensation*: Any compensation paid to a director (in such capacity) if the compensation is required to be reported in our proxy statement;
1. *Transactions where all stockholders receive proportional benefits*: Any transaction in which the Related Party's interest arises solely from the ownership of our capital stock and all holders of our capital stock receive the same benefit on a pro rata basis (e.g., dividends);
1. *Certain transactions with other companies*: Any transaction with another company where a Related Party's only relationship is as an employee (other than an executive officer), director or beneficial owner, together with their immediate family members, of less than 10% of that company's outstanding equity or as a limited partner, together with their immediate family members, holding interests of less than 10% in the limited partnership (or similar interests in an alternative form of entity), if the aggregate amount involved does not exceed the greater of $200,000, or 5% of that other company's consolidated gross revenues;
1. *Certain charitable contributions*: Any charitable contribution, grant or endowment by us to a charitable organization, foundation or university at which a Related Party's only relationship is as an employee (other than an executive officer) or a director, if the aggregate amount involved does not exceed the greater of $200,000, or 5% of the consolidated gross revenues of such charitable organization, foundation or university;
1. *Ordinary course expenses, advances and reimbursements*: Ordinary course business travel and expenses, advances and reimbursements;
1. *Indemnification*: Indemnification payments and other payments made pursuant to
1. (a) directors and officers insurance policies, (b) our amended and restated Certificate of Incorporation or Bylaws, and/or (c) any other policy or agreement approved by the Board; and
1. *Other transactions*: Any transaction with a Related Party (i) where the rates or charges involved are determined by competitive bids; (ii) involving the rendering of services as a common or contract carrier or public utility, at rates or charges fixed in conformity with law or governmental authority; or (iii) involving services as a bank depositary of funds, transfer agent, registrar, trustee under a trust indenture or similar services.

### CHANGES TO THIS POLICY

The Audit Committee may recommend future amendments to this Policy for consideration by our Board. Our Board reserves the right in its sole discretion to modify or grant waivers to this Policy. Any amendments or waiver may be publicly disclosed if required by applicable laws, rules and regulations.
