---
title: "Guidelines for Use of Third-party IP in External Materials"
description: "Guidelines for the use of third-party content in external materials"
---

## Scope and purpose

These guidelines apply to the use of third-party content in all [external](/handbook/legal/materials-legal-review-process/#external-vs-internal-use) materials, including:

- Pitch decks;
- Presentations and talk tracks (including those delivered at conferences and marketing events);
- Marketing collateral, including emails, blog posts, release posts, social media posts on GitLab accounts, and videos; and
- Advertisements.

If you're unsure, reach out to [#legal](https://app.slack.com/client/T02592416/C78E74A6L) to confirm.

These guidelines do not apply to the use of trademarks in the GitLab product itself. Refer to the guidelines of the [Use of Third-party Trademarks in GitLab](/handbook/legal/policies/product-third-party-trademarks-guidelines/#dos--donts-for-use-of-third-party-trademarks-in-gitlab) instead.

When used in these guidelines:

"**external materials**" has the meaning given in the [Materials Legal Review Process](/handbook/legal/materials-legal-review-process/#external-vs-internal-use).

"**third-party content**" means any content, including trademarks, visual content, and written content, created or owned by a third party.

## Note about use of content obtained from the internet

Just because something is available for free on the internet (including on Google Images, Google Maps, YouTube, blogs, social media, and news websites) does not mean it can be freely used. The vast majority of internet content is subject to copyright and/or trademark rights, and GitLab's use of that content could constitute infringement.

## Trademarks - logos and wordmarks

"**Logo**" means a symbol used to identify a company, product, or service, like the [GitLab Tanuki logo](https://about.gitlab.com/images/press/logo/png/gitlab-icon-rgb.png).

"**Wordmark**" means unstylized words or letters used to identify a company, product, or service, like *GitLab*.

### Do

- When using the **logo** or **wordmark** of a customer, partner, or other third party with which GitLab has a commercial relationship, for customers, refer to the [Customer Reference Program handbook page](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/customer-advocacy/). Discuss with [#customer_references](https://app.slack.com/client/T02592416/CLFCPMF8E) if unsure. For use of a partner's logo, discuss with [#channel-marketing](https://app.slack.com/client/T02592416/C013DF4A7QV) to confirm that rights and approvals are in place for your proposed use under the Partner Agreement. For use of an ISV technology partner's logo, discuss with [#partner-program-ops](https://app.slack.com/client/E03N1RJJX7C/CTM4T5BPF).

- Use **wordmarks** referentially: refer to the wordmark owner, or the owner's products and services associated with the mark, when the company, product or service in question cannot be easily identified without using the mark. For example, it's much easier to refer to *GitLab* using the wordmark *GitLab* than to *the company behind the DevOps platform delivered as a single application*.

### Don't

- Use a **logo** when referring to third-party companies, or their products or services. Trademark fair use applies to logos only in very exceptional circumstances; use the wordmark instead.
- Remove, distort, alter, or otherwise modify a **logo**.
- Use a **logo** or **wordmark** in any way that implies an untrue relationship or affiliation with, or sponsorship or endorsement by, the owner.
- Use a **logo** or **wordmark** in any way that denigrates or discredits the owner or their products or services.
- Use a well-known wordmark in a general manner. For example, use `photo` rather than `Polaroid` unless refering to an actual Polaroid.

## Visual content including videos, GIFs, photographs, illustrations, graphics, and artwork

### Do

- Obtain visual content from permissively-licensed sources, like [unsplash.com*](https://unsplash.com/) for images, or use content created by GitLab. If you're unsure, reach out to [#legal](https://app.slack.com/client/T02592416/C78E74A6L) to review the license covering the content you want to use.
- If required by the applicable license, provide attribution, ensuring you follow any attribution guidelines which apply.
- For visual content containing identifiable individuals (including GitLab team members), review and follow the [Publicity Waiver and Release Guidelines and Process](/handbook/legal/publicity-waiver-release).
- For stock house visual content that includes identifiable individuals, ensure the stock house has obtained a model release covering all individuals who appear.

*For Unsplash images, it's good practice to credit Unsplash as the source and photographer. This helps team members repurposing materials determine if images can be used, and is courteous to the photographer.

{{% details summary="Expand for Unsplash attribution instructions" %}}

1. Create a small text box at the bottom right of the relevant slide.
1. Locate the image on [unsplash.com](https://unsplash.com).
1. Click on `Download free` but ignore the downloaded file.
1. Copy the `Say thanks 🙌` attribution text to the clipboard.
1. Insert the attribution text into the text box, and apply formatting: Font `Inter`, Size `8`, `Italic`.

[Example Unsplash attribution](https://docs.google.com/presentation/d/1k4PWKJR9O1jEGxKblSQtjDsloQ95uvu6Ty9Pjpmin7E/edit#slide=id.g129bb425d32_0_273)
{{% /details %}}

### Don't

- Use visual content if you cannot confirm the source of the content.
- Use visual content depicting children.
- Use images which prominently feature a logo, famous building or structure, or well-known person, even if obtained from Unsplash or a stock house. Such images are likely subject to restrictions by virtue of their subject, irrespective of the license covering the content itself.
- Use GIFs from GIPHY.com, as the content on that site is solely for personal and non-commercial purposes.

## AI-generated images

The legal environment surrounding AI-generated creative works, including images, is evolving rapidly. In view of this, this section remains subject to change to take account of changes in the legal environment.

### **General Requirements**

- When using AI-generated images, do not misrepresent the nature of the work, i.e., do not claim or imply that the image was human-generated.
- Don't use prompts that reference an artist by name. For example, don't use `in the style of [artist name]`. You can, however, use a prompt like `in the impressionist style`.
- Use only written prompts -- don't use an existing image as a prompt.
- Use of any text-to-image model besides those listed under `Model-Specific Requirements` below is not permitted without prior legal review of the model's license and any applicable restrictions.
- Don't use AI image generation to create logos.

### **Model-Specific Requirements**

#### ***Stable Diffusion***

- Use of the [Stable Diffusion](https://huggingface.co/spaces/stabilityai/stable-diffusion) text-to-image model to generate images for external use is permitted, subject to the restrictions in this section and the `General Requirements` section above.
- Images generated by Stable Diffusion are subject to Use Restrictions in Attachment A of the [License Agreement](https://huggingface.co/spaces/CompVis/stable-diffusion-license). Before using images generated by Stable Diffusion, review these restrictions to ensure your proposed use is compliant.

### **Written content** including books, papers, blog posts, and news articles

#### Do

- Use excerpts from written content for the purpose of criticism or comment.
- Use as short an excerpt of the original content as possible for your given purpose. Fair use is more likely to be established when a small portion of the original content is copied.
- Provide attribution, ensuring that you follow any attribution guidelines which apply to the content you're using.

#### Don't

- Use the entirety, or a large portion, of an article, paper or blog post.
- Use excerpts, quotes or headlines of print and online news articles without following Corporate Communications' [Sharing Media Coverage guidelines](/handbook/marketing/corporate-communications/#sharing-media-coverage).

## Industry Analyst Content Use

- Any use of industry analyst content from firms such as Forrester Research, Gartner, and International Data Corporation (IDC) must be submitted for review and approval to Analyst Relations by filling out this [issue template](https://gitlab.com/gitlab-com/marketing/strategic-marketing/product-marketing/-/issues/new?issuable_template=AR-CitationReview).

If you aren't sure if the author of the content you're quoting is an industry analyst, or if you have any other questions, contact [`@Ryan Ragozzine`](gitlab.com/rragozzine) or [`@Gaby Berkman`](gitlab.com/gberkman).

## Quotes

### Do

- If using an unsolicited quote from a company or person not affiliated with GitLab, use the quote verbatim.
- If desired when using an unsolicited quote, hyperlink the quote's source.
- If using a quote that references a GitLab customer or partner by name, confirm with [#customer_references](https://app.slack.com/client/T02592416/CLFCPMF8E) (for customers) or [#channel-marketing](https://app.slack.com/client/T02592416/C013DF4A7QV) (for partners) that sufficient rights and approvals are in place for the proposed use.

### Don't

- Reference the company or person by name if using a non-solicited quote.
- Change the sense of the quoted material, whether by quoting out of context, altering the quote itself, or inaccurately paraphrasing.

## Audio content including music, sounds, and sound effects

### Do

- Obtain audio content from permissively-licensed sources which allow **commercial** use of the content without payment of royalties or obtaining a separate license, or use content created by GitLab. If you're unsure, reach out to [#legal](https://app.slack.com/client/T02592416/C78E74A6L) to review the license covering the content you want to use.

### Don't

- Assume that a re-recording or cover of a popular song can be used. The recording, melody, and lyrics of a song are each distinct works protected by independent copyrights; a midi rendition composed by a GitLab team member on GarageBand of [The Eagles' *Hotel California*](https://www.youtube.com/watch?v=dQw4w9WgXcQ&ab_channel=RickAstley) would likely infringe the copyright in the melody of the original song.
