---
title: "Patents"
description: "Learn about Patents and GitLab's Patent Program"
---

## Why patents?

Seeking patent protection for inventions offers several benefits. For individual team members, appearing as a named inventor on a published patent is a significant achievement and something that provides tangible evidence of team members' creative contributions to GitLab and emphasizes GitLab's [focus on results](/handbook/values/#results).

For GitLab, building a portfolio of patents helps increase our profile as innovators in the DevOps space. Moreover, patents are valuable assets, and an investment in building a patent portfolio can increase value for shareholders. In some regions, obtaining patent protection for inventions renders the related research and development costs tax deductible.

Patents can also be used as a defensive tool in the event the owner of another patent seeks to assert their patent rights against GitLab.

## Patents and Open Source

GitLab's stewardship of open source informs how we exercise patent rights, but not whether GitLab applies for a patent. Whether covering open source, open core, or proprietary technology, patents play an important role in managing the risk of third-party patent suits. GitLab emphasizes the defensive use of its patent rights as necessary to protect the GitLab project.

All GitLab-created open source software is distributed under the MIT license which includes a well-established implied grant of patent rights; the rights granted under the MIT license are not undermined by a patent covering an element of the distributed software. Moreover, although patents are a proprietary right, the mandatory public disclosure of the covered invention required to obtain patent protection is consistent with GitLab's open core business model and aligns with GitLab's transparency value.

## GitLab patents

GitLab holds the following registered patents:

- US patent [11,983,091](https://image-ppubs.uspto.gov/dirsearch-public/print/downloadPdf/11983091) covering *adaptively generated program model*
- US patent [2023/0104814](https://image-ppubs.uspto.gov/dirsearch-public/print/downloadPdf/20230104814) covering *vulnerability tracing using scope and offset*
- US patent [9,910,766](https://image-ppubs.uspto.gov/dirsearch-public/print/downloadPdf/9910766) covering *whitebox network fuzzing*
- US patents [9,767,005](https://image-ppubs.uspto.gov/dirsearch-public/print/downloadPdf/9767005) and [9,098,352](https://image-ppubs.uspto.gov/dirsearch-public/print/downloadPdf/9098352), along with Chinese patent 104346277A, and European patent EP2827253A1 covering *metaphor based language fuzzing of computer code*
- US patent [9,323,597](https://image-ppubs.uspto.gov/dirsearch-public/print/downloadPdf/9323597) covering *flow based fault testing*.

## GitLab's Patent Program

Innovation is key to GitLab's success. The GitLab Patent Program seeks to maximize the competitive and commercial value of GitLab's intellectual property rights and capitalize on the time and effort invested by team members in developing patentable inventions. The Program establishes a process to systematically identify valuable inventions, assess their patentability and, where appropriate, enable successful prosecution and registration of a patent covering the invention.

### Patent Awards

As a recognition of the efforts of team members who develop inventions for GitLab, named inventors who contribute patentable inventions under the Patent Program may be eligible for Patent Awards totalling $1,750 U.S. dollars, as follows:

- Level One Patent Award: $250 for each named inventor on each patent application submission accepted for filing by GitLab, payable after acceptance.
- Level Two Patent Award: $500 for each named inventor on each patent application filed by GitLab, payable after filing. No Level Two Patent Award is payable for the filing of a *provisional* patent application.
- Level Three Patent Award: $1,000 for each named inventor on each patent issued to GitLab, payable after patent issue.

### How to participate

To disclose an invention, complete an [Invention Disclosure Form](https://docs.google.com/document/d/1BndxggJyA3aMdYav-ghNwpTdNcfgJcrHFRlT6u8KFD8/copy) and email it to [intellectualproperty@gitlab.com](mailto:intellectualproperty@gitlab.com).

- To disclose an improvement to an invention, complete an [Invention Improvement Disclosure Form](https://docs.google.com/document/d/10D49F21I-G0V9rnyStgD0EwEfLxi8KzNS_ShCA64br8/copy) and email it to [intellectualproperty@gitlab.com](mailto:intellectualproperty@gitlab.com).

The Invention Disclosure and Invention Improvement Disclosure forms  must not be shared outside GitLab, even to former GitLab team members. If the input of a former GitLab team member is required to complete either form, contact [intellectualproperty@gitlab.com](mailto:intellectualproperty@gitlab.com) to discuss before proceeding.

You should submit an **Invention Disclosure Form** any time you think you may have created a new, inventive process, product, or product feature. Since you may be overly conservative in determining what constitutes an invention, or an improvement to an invention, you should submit the applicable Form even if you aren't sure that your work is sufficiently novel to be an invention or improvement.

You should submit an **Invention Improvement Disclosure Form** anytime you think you have made a novel improvement to a previously disclosed invention.

The sooner you submit the applicable Form, the better. Always err on the side of disclosing, leaving it to the Legal and Corporate Affairs Team, and our external patent specialists, to decide whether to file, retain as a trade secret, or publish to preempt.

### Discussion of inventions and improvements to inventions

Follow the guidelines below related to the discussion of inventions, treatment of underlying source code, and software licensing throughout the stages of patent prosecution:

| Patent Process Stage                                                                                                                                     | Default Treatment of Underlying Software Code   | Public discussion of the Invention?                                                                                                                        | Underlying Software Code License                                                                                            |
|----------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------|
| Discovery: Team member has identified a potential invention and has completed or plans to complete an Invention Disclosure Form                          | Closed source.                                  | All discussions and code related to an invention in the Discovery phase should be kept [internal](/handbook/communication/confidentiality-levels/#internal) (only accessible to team members).                                  | Software should not be released until the application is filed.                                                             |
| Patent application has been filed                                                                                                                        | Open source or source available as appropriate. | The invention may be discussed publicly. Do not discuss the patent application itself, including statements about what the application seeks to protect.   | Software can be licensed under the EE or MIT license with no additional considerations required from a patent perspective.  |
| Granted patent                                                                                                                                           | Open source or source available as appropriate. | The invention may be discussed publicly. Do not discuss the patent itself, including statements about what the patent protects.                            | Software can be licensed under the EE or MIT license with no additional considerations required from a patent perspective.  |
| Improvement to existing or pending patents                                                                                                               | Closed source.                                  | All discussions and code related to the improvements of existing or pending patents should be kept [internal](/handbook/communication/confidentiality-levels/#internal) (only accessible to team members).                      | Software should not be released until the application is filed.                                                             |
| Rejected patents. This includes disclosed inventions and improvements that are determined to not qualify for patent protection as communicated by LACA.  | Open source or source available as appropriate. | The rejected patent may be discussed publicly.                                                                                                             | Software can be licensed under the EE or MIT license with no additional considerations required from a patent perspective.  |

If you have any questions or concerns, reach out to #legal.
For guidance on how to review third-party patent functionality, visit the [Guidelines for reviewing third-party patents](https://internal.gitlab.com/handbook/legal-and-corporate-affairs/legal-and-compliance/productguidance/#guidelines-on-reviewing-third-party-patents) (accessible to GitLab team members only).

### Conditions of participation

- Inventors must be current GitLab Team Members to participate in the GitLab Patent Program and be eligible for the receipt of Patent Awards.
- GitLab may change or terminate the Program at any time.
- GitLab reserves the right in its sole discretion to decide whether to file for a patent on submissions or retain submissions as a trade secret or publish to preempt.
- Participation in the GitLab Patent Program is subject to local employment and intellectual property laws.
