---
title: "UX Research Pilot Program for Promotional Games"
description: "Pilot Program for Promotional Games"
---

## Overview

A pilot program has been launched by Legal to test an automated process for the UX Research Team to conduct a prize draw in connection with routine SUS Surveys and other ad hoc surveys which are intended to collect feedback from GitLab users regarding features, navigation, and other items related to improving the user experience. This pilot has been launched based on a request from the UX Research team to be able to have standard rules and be able to launch a new promotional game quickly.

Legal reviewed a requested list of countries for inclusion in the territory of eligibile participants in promotional games. That list was compared against the top 20 markets by country from late 2021. Legal conducted extensive research on 46 countries and determined which countries must be excluded from any promotional game sponsored by GitLab and which countries may be included based on several factors (prize value and type, how the promotional game is administered, relevant tax obligations, translation requirements, and registration requirements). Based on the research, 8 countries were identified for inclusion in the pilot with an additional 2 countries that may be included when and where translation requirements can be met.

The pilot program features an automated workflow for the UX Research Team to generate rules. This is accomplished through a Google Form and not through a GitLab issue. Provided that the request satisfies certain pre-determined requirements, the requestor will receive a set of Abbreviated Rules almost immediately (minutes to an hour). If the request does not satisfy the pre-determined requirements use of the [Promotional Games Legal Template](https://gitlab.com/gitlab-com/marketing/marketing-operations/-/issues/new?issuable_template=promotional_games_legal_template) will be required.

As part of launching this pilot, Legal has updated the definitions and wording used in association with promotional games.  Please review [this section](/handbook/legal/marketing-collaboration/#promotional-games) of the handbook to learn about the three types of promotional games which are generally permitted at GitLab.

Benefits of the pilot program:

- Prize draws are able to be launched very quickly in connection with a survey opportunity.
- Rules can be generated within minutes.
- No need to create new pages to host the Official Rules each time.
- No need to involve Legal.

## Pilot Program Workflow

1. Review the [Eligibility Requirements](#eligibility-requirements-for-pilot-program) for the Pilot Program. Promotional Games which do not meet the Eligibility Requirements **in full* cannot proceed under the Pilot Program. Refer to the [mainstream review and approval process](/handbook/legal/marketing-collaboration/#promotional-games) for Promotional Games that do not meet the Eligibility Requirements.
1. Complete the [Request Rules for a Promotional Game](https://docs.google.com/forms/d/e/1FAIpQLSdVxpGQDt-lPKPIEuGaUnrR2F8F_wS43dVkmVs4ugoaGSNVqA/viewform?usp=sf_link) Google form.
1. You will receive an email with the Abbreviated Rules as an attachment. Please review the [Standard Promotional Rules and Abbreviated Rules](#standard-promotional-rules-and-abbreviated-rules) section for details on how the Abbreviated Rules work in connection with the standard set of rules created for this pilot.
1. Create a separate screen/page within the survey where the participant can select to be entered into the Prize Draw and view the Abbreviated Rules. Follow the [guidelines for the proper administration of the Prize Draw](#proper-administration-of-the-prize-draw) when creating this screen/page.
1. Determine eligibility of all entries prior to the selection of the winner(s) as described in the [administrative responsibilities](#administrative-responsibilities).
1. Validate and verify the proposed winner(s) prior to distributing prizes. Instructions for this are located in the [administrative responsibilities](#administrative-responsibilities).

## Eligibility Requirements for Pilot Program

1. The only type of promotional game permitted in the pilot is a Prize Draw.
1. The prize value of each individual prize must be under $600 USD.
1. The total value of all prizes must be under $2,100 USD.
1. Eligible countries for inclusion:
    1. Australia, Canada, Ireland, Japan, Switzerland, United Kingdom and the United States.
    1. France and Germany can be included provided that translastion requirements are possible. Legal does not provide translation services.
    1. Denmark can be included if the individual prize value is under $30 USD.
1. Participants in the Prize Draw must:
    1. Be legal residents of the included countries;
    1. Be at least 18 years of age on the date of entry;
    1. Not be an employee of GitLab; and
    1. Not be a family member or living in the same household as a GitLab team member.

## Proper Administration of the Prize Draw

1. Within your survey you will need to add a separate screen/page where the participant can select to be entered into the Prize Draw. A suggested way to do this is to have the participant tick a box yes/no to enter the prize draw, and if they tick "yes" then capture the required information (no boxes should be pre-ticked). To enter collect the name, email, country and zip/postal code. If someone attempts to enter with a country that is not within the promotional territory, the system collecting entries should automatically flag that entry as ineligible.  You are not required to notify the entrant that they are ineligible.
1. On the screen/page where the prize draw is discussed, certain information must appear prior to any tick box or text field to enter.  The participant must be presented with the Abbreviated Rules (not a link to the Abbreviated Rules) after a one sentence summary inviting them to enter. By way of example, it can read as follows:

   ```plain
           Thank you for completing the survey. Please indicate if you wish to enter the Prize Draw described below.

            [insert the Abbreviated Rules as generated from the request]

            [ ] Yes, I want to enter the Prize Draw after reading and accepting the terms described and linked above.

            [ ] No, I do not want to enter the Prize Draw.

            Please provide the following information to be entered into the Prize Draw:

                Name:

                Email:

                Country of Residence:

                Zip/Postal Code:
   ```

1. You may not advertise the prize draw outside of the email distribution. If you are advertising the prize draw at an in-person event, the abbreviated rules should be a part of the same visual space as the remainder of the advertising message and should not be made available to any person not attending the in-person event. If you are advertising the prize draw at a virtual event, we recommend an approach similar to the survey screen language described above. The prize draw should not be advertised to attendees of an in-person or virtual event ahead of time or after the event has ended.
1. No changes are permitted to the prize draw, the abbreviated rules, or the plan for advertising after the time period to enter has begun. The reason for this is that the countries designated as eligible in this pilot program were selected in part on the basis that the prize draw is a closed audience, meaning it is not advertised to the general public. If you wish to advertise to additional persons or a broader audience to raise interest in your study or survey using the prize draw as an incentive, then you should not use the pilot program workflow and instead use the [regular channel of seeking legal approval for a promotional game](/handbook/legal/marketing-collaboration/#promotional-games).

## Administrative Responsibilities

1. The DRI for each prize draw is responsible for determining the eligibility of entries prior to selecting a winner. This may be done manually or through an automated process and should include the rejection of all entries by an individual who submits more than 1 entry, the rejection of any entries where the participant is not a resident of a country within the promotional territory, and the rejection of any entries which do not meet eligibility requirements.
1. The DRI for each prize draw is also responsible for qualifying every proposed winner prior to distributing prizes. This is accomplished through the use of a [Declaration of Eligibility and Release](https://drive.google.com/file/d/1LsYGszz9B8RYq-oCG46e6ubz9XTvDNk2/view?usp=sharing) which should be emailed to the proposed winner when they are initially notified. There is a defined window of time for the Declaration to be returned by the proposed winner and failure to do so will result in forfeiture of the Prize. Should a proposed Winner fail to return the Declaration, the DRI may select an alternate winner from the remaining pool of eligible entries, but you are not required to do so. The Declaration of Eligibility and Release will contain personal data of the winner and therefore must be treated in accordance with GitLab standards for the security and protection of personal data. It must also be retained for 24 months after the winner is confirmed.
    - *[Google Drive folder](https://drive.google.com/drive/folders/0AAQKT2RtdwgLUk9PVA) to store the full executed Declarations*

## Standard Promotional Rules and Abbreviated Rules

There is a set of Official Rules which applies for every Promotional Game offered and is permanently hosted [here](/handbook/legal/promotional-game-standard-rules/). The Official Rules are structured and formatted so that they apply to every prize draw. The details which apply to a specific prize draw are outlined in the Abbreviated Rules - generated through the automated workflow of the Google form.

Abbreviated Rules will generate upon submission of the Google Form and will look similar to this:

![GitLab Promotion Rules](q4-fy22-sus-sweepstakes.png)
