---
title: "Marketing"
description: "GitLab Marketing Handbook: Brand and Product Marketing, Integrated Marketing, Sales Development, Marketing Strategy and Platforms, Enterprise Data, Developer Relations, and Corporate Communications"
twitter_image: '/images/tweets/handbook-marketing.png'
---

<i class="fas fa-bullhorn fa-fw color-orange font-awesome"></i> Welcome to the GitLab Marketing Handbook
{.h2}

The GitLab Marketing team operates as one team and is organized by the following departments: [Integrated Marketing](/handbook/marketing/#integrated-marketing), [Brand and Product Marketing](/handbook/marketing/#brand-and-product-marketing), [Marketing Operations and Analytics](/handbook/marketing/#marketing-operations-and-analytics), [Sales Development](/handbook/marketing/#sales-development), [Enterprise Data](/handbook/marketing/#enterprise-data), [Corporate Communications](/handbook/marketing/#corporate-communications), and [Developer Relations](/handbook/marketing/#developer-relations). This page documents our shared team philosophy and processes, while the individual department handbooks contain more detailed information.

## Marketing Purpose

GitLab is the leading DevSecOps Platform that empowers organizations to deliver quality software faster and more efficiently while strengthening security and compliance. The marketing team's purpose is to amplify the value of the GitLab platform, authentically and transparently, by putting customers and the community at the center of everything we do.

## Marketing Alignment

As the GitLab Marketing team puts customers at the center of everything we do, the marketing strategy aligns with the customer journey. The journey's purpose is to provide a clear and cohesive experience to a prospect/customer from the minute they become **Aware** of GitLab, to **Considering** the platform and **Converting** into a happy customer, and then of course **Expanding** over time and becoming an **Evangelist**.

![marketing customer journey](mktgcustomerjourney.png)

Each stage has a purpose which is the guiding indicator for the marketing team to measure our success. Everything the team plans and executes in the short and long term will revolve around the customer journey, and we will also measure our success along each step to hold ourselves accountable.

![marketing customer journey stages](mktgcustomerjourneystages1.png)

## Marketing Strategy

Our FY25 Marketing Strategy and Plan can be found in [the internal handbook](https://internal.gitlab.com/handbook/marketing/fy25-strategy/).

## Marketing OKRs

Each quarter, the Marketing team creates OKRs (Objectives and Key Results) that cascade from the [CEO's OKRs](/handbook/company/okrs/#most-recent-okrs).

Each department within the Marketing team manages their own cascading OKRs. Team members can access the [filtered OKR search](https://gitlab.com/gitlab-com/gitlab-OKRs/-/issues/?sort=created_date&state=opened&label_name%5B%5D=division%3A%3AMarketing&label_name%5B%5D=OKR&search=marketing&search=okr&first_page_size=20).

## <i class="fas fa-users fa-fw color-orange font-awesome"></i> How we work

Value-driven Marketing Team
{.h3}

How we work as one team aligns with the [GitLab Values](/handbook/values/).

**Results** - The team measures success together along the customer journey. Each quarter, we align CMO OKRs based on company goals set in the company OKRs. This helps us stay aligned with company-level goals while also understanding if what we are doing quarter over quarter is moving the needle on our marquee metrics along the customer journey. Being data-driven as a team is essential for team success.

**Iteration** - Like the rest of the company, we aspire to be agile and experimental where possible.  In every area possible, we roll out campaigns, brand updates, messaging, etc. in small iterations, measure the success, and take next steps accordingly.

**Transparency** - We strive to be as transparent as possible in all areas of marketing. We welcome thoughts and feedback from each other, other GitLab team members, and the community at all times.

**Collaboration** - A major key to success is operating as one team. Leveraging the different backgrounds, cultures and, skill sets of an entire company and community, the marketing team operates in a way where everyone can contribute. Collaboration is key to taking Marketing to the next level.

**Diversity, Inclusion and Belonging (DIB)** - With GitLab team members being located across the world, we strive to always keep DIB at the core of everything we do. Like the rest of GitLab, we follow asynchronous meeting principles, welcome diverse perspectives, and as marketers, foster an environment where quirkiness is welcomed.

**Efficiency** - We keep efficiency at the forefront of everything we do. Whether it is bringing in marketing technology to automate menial tasks and foster collaboration, finding ways to save cost, or simply doing the right things to be respectful of others' time, efficiency drives faster results for marketing.

<a id="meetings"></a>

## Team Meeting Cadence

Monthly Marketing All Hands (All Marketing team members)
{.h3}

**Goal**: Align all Marketing team members on activities in progress to achieve our goals, and update the team on cross-functional items.

The meeting is 50 minutes and runs as follows:

1. Always begin by welcoming our newest GitLab Marketing Team Members
1. Celebrate well-deserved promotions
1. CMO Top of Mind (5 items per month)
1. ~20 minutes of CMO Leadership sharing updates
1. ~20 of either marketing team member updates (to be added during the call for items announcement prior) or special guest from another GitLab org
1. The remaining time for Q&A and most importantly…recognition!

All team members are encouraged to bring forward discussion topics that they want to share with the team or to have covered during the call.

Quarterly CMO Q&A (one session for each department)
{.h3}

**Goal**: Provide the team a smaller forum to ask any questions they may have, offer feedback, and brainstorm ideas directly with the CMO

Weekly CMO Leadership Direct Reports Team Meetings (Each manager with their direct team)
{.h3}

**Goal**: Foster an environment to empower managers overseeing different functions to collaborate and share ideas and feedback.

Weekly Direct Reports Meetings (Each manager with their direct reports)
{.h3}

**Goal**: For managers to work with direct reports on removing roadblocks, brainstorming, coaching, and providing/receiving feedback.

## <i class="fas fa-paper-plane fa-fw color-orange font-awesome"></i> Contacting Marketing

<a id="contact-marketing"></a>

### Getting Help by Common Topics

| Topic | Where to reach out | Sub-Team |
| ------ | ------ | ------ |
| Blog posts, webcasts, the newsletter or other marketing content | `#content`  | [Content](/handbook/marketing/brand-and-product-marketing/content/) |
| Swag | `#swag` | [Brand](/handbook/marketing/brand-and-product-marketing/brand/) |
| Design requests, logo usage questions | `#marketing-design` | [Brand](/handbook/marketing/brand-and-product-marketing/brand/) |
| External PR (public relations) agency, discuss GitLab media mentions, and evaluate speaking/podcasting/commentary opportunities | `#external-comms` | [Corporate Communications](/handbook/marketing/corporate-communications/) |
| Anything regarding the marketing website and website development | `#digital-experience-team` | [Digital experience](/handbook/marketing/digital-experience/) |
| Questions about tools in the [marketing tech stack](/handbook/marketing/marketing-operations/), evaluating new marketing tools, marketing system process improvement | `#mktgops` | Marketing Operations |
| Salesforce | `#sfdc-users` | Sales Operations (not marketing) |

A complete list of marketing slack channels can be found [here](/handbook/marketing/#marketing-slack-channels).

### General Questions and Feedback

- [**GitLab Marketing public issue tracker**](https://gitlab.com/gitlab-com/marketing); please use confidential issues for topics that should only be visible to team members at GitLab
- [**Slack channel**](https://gitlab.slack.com/archives/marketing); please use the `#marketing` Slack channel for questions that don't seem appropriate to use the issue tracker

### CMO Requests

Please follow the [CMO handbook](/handbook/marketing/cmo/) for review request workflows, and communication guidelines.

### Social Requests

All teams are responsible for requesting social posts themselves. If you are not the DRI on a specific category or campaign and want to request a social post, please reach out to the teams' point person identified below as a first step. Team Members in these roles reserve the right to say no to your request. If they say yes, coordinate with them to [create a new social request issue](/handbook/marketing/integrated-marketing/digital-strategy/social-marketing/) so that the social team can process the request and schedule the post(s). The point person on the team or a member of the marketing or social teams may adjust copy to ensure consistency in brand voice.

- Events: Jr. Content Editor
- Release & technical posts/product updates: [Technical writing](/handbook/product/ux/technical-writing/)
- User questions/comments on Twitter/X: [Social Marketing](/handbook/marketing/integrated-marketing/digital-strategy/social-marketing/) or [Developer Relations](/handbook/marketing/developer-relations/) team
- Leadgen campaigns: [Content](/handbook/marketing/brand-and-product-marketing/content/) team
- UX Design: UX Lead
- Press/media coverage: Post in `#external-comms` for assistance from the [Corporate Communications](/handbook/marketing/corporate-communications/) team
- Social media, reshares of mentions, CEO Statements/posts: Post in `#social_media_action` for assistance

### Company Spokesperson

Speaking on behalf of GitLab at a conference, to media or on a podcast as a GitLab team member is a significant responsibility. Please see the [Corporate Communications Handbook Page](/handbook/marketing/corporate-communications/) for guidelines and trainings.

### Blog post editing

- Product release posts: [Product team](/handbook/product/)
- Technical community posts/tutorials: [Developer Advocacy](/handbook/marketing/developer-relations/developer-advocacy/) and [Blog editorial](/handbook/marketing/brand-and-product-marketing/content/) team
- CEO statements/updates: [CMO](/handbook/marketing/cmo/)
- All other blog posts: [Blog editorial team](/handbook/marketing/brand-and-product-marketing/content/)

Guidelines for how to pitch and submit a blog, including templates and formatting, can be found in the [Blog Handbook](/handbook/marketing/blog/).

### Newsletter

**Marketing Newsletter**

Marketing and the Editorial team send out a monthly developer newsletter, called "DevSecOps Download", to our [newsletter subscribers](/handbook/marketing/marketing-operations/email-management/#types-of-email). The newsletter always includes information about the latest release post, links to our latest blogs, plus additional content for DevSecOps teams. The goal for this newsletter is thought leadership and awareness.

To add a content suggestion, please create an issue with "DevSecOps Download Content: [subject]" in the title (no template necessary) and tag @sgittlen (Sandra Gittlen, Blog Managing Editor). Anyone in the company can add suggestions, but the Blog Managing Editor will determine the final content.

**Other Newsletter**

To request a newsletter to be sent to an audience outside the [newsletter subscribers](/handbook/marketing/marketing-operations/email-management/#types-of-email), please create an issue in the [Campaigns project](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues), using the `request_email_newsletter` issue template.

Newsletter requests should be submitted no less than 5 business days before the intended send date to ensure there is enough time for Content and Marketing Programs Manager's (MPM) review and set up workflow.

**Community Newsletter**

The community newsletter is managed by the [Developer Relations](/handbook/marketing/developer-relations/) team, dedicated to sharing relevant developer content, highlighting contribution opportunities, and updating community members on upcoming events. We aim to keep our contributors involved and connected with the wider community. This newsletter will not be used to drive or generate leads.

To submit to the newsletter, please follow the [handbook instructions](/handbook/marketing/developer-relations/developer-advocacy/community-newsletter/#submissions).

### Sponsorship

We are happy to sponsor events and meet-ups where a marketing benefit exists, subject to approval by [Field Marketing](/handbook/marketing/field-marketing/) Managers. These sponsorships may be in cash or in kind, depending on individual circumstances.

Organizational or project sponsorships may also be considered where a marketing benefit exists. Typically, these sponsorships will be in kind - e.g., developer time commitments, or [subsidized / free GitLab licenses](https://about.gitlab.com/blog/2018/06/05/gitlab-ultimate-and-gold-free-for-education-and-open-source/).

Cash sponsorship of projects or organizations may be considered only in exceptional cases - for example, if a project or organization that GitLab depends on is struggling to survive financially.

### Marketing Slack Channels

<a id="slack"></a>

We use Slack internally as a communication tool. The Marketing channels are as follows:

- `#marketing`: General marketing channel. Don't know where to ask a question? Start here.
- `marketing-team-internal`: (Private) Read-Only channel for marketing team members, with the ability to post comments. CMO staff has the ability to post. Should a team member want to make a post, please reach out to our Marketing EBA with your written statement and as much as possible, provide an issue or MR with more details.
- `#brand`: Connect with Brand Strategy, Brand Marketing, and Brand Design here.
- `#brand_video`: Video production and marketing support.
- `#cfp`: All event call for papers will be posted here. Learn more in the [speaking resources](/handbook/marketing/corporate-communications/speaking-resources/) handbook.
- `#cmo`: [CMO review requests](/job-families/chief-marketing-officer/) and content shares.
- `cmo-staff`: (Private) CMO's private staff discussion room
- `#content`: Questions about blog posts, webcasts, the newsletter or other [marketing content](/handbook/marketing/brand-and-product-marketing/content/)? This is the place to ask.
- `#developer-relations`: A channel for the [developer relations](/handbook/marketing/developer-relations/) team to collaborate.
- `#dev-advocacy-team`: Discuss the latest tech in DevSecOps and Cloud-Native with the [Developer Advocacy](/handbook/marketing/developer-relations/developer-advocacy/) team. You can request speakers, customer consultancy and technical content collaboration and guidance.
- `#digital-experience-team`: Channel for connecting with the [website development and design teams](/handbook/marketing/digital-experience/)
- `#digital-marketing`: Channel for all advertising, website analytic and general digital programs.
- `#external-comms`: To collaborate with our external PR (public relations) agency, discuss GitLab media mentions, and evaluate speaking/podcasting/commentary opportunities.
- `#fieldmarketing`: Discuss, ask questions, stay up-to-date on events that are being organized by Field Marketing
- `#marketing-design`: Discuss, feedback, and share ideas on [Marketing Design](/handbook/marketing/brand-and-product-marketing/design/) here.
- `#marketing-campaigns`: Discuss, ask questions, stay up-to-date on [campaigns](/handbook/marketing/demand-generation/campaigns/) and events that are being organized by the Marketing Program Managers
- `#mktgops`: [Marketing Ops](/handbook/marketing/marketing-operations/) communication channel for questions and project updates
- `mktg-budget-holders`: (Private) Discussion among all Marketing team members with budget responsibility
- `#product-marketing`: Discuss, feedback related to product news, features and vision
- `#remote`: Discuss and share impressions on remote work experience, playbook and strategy.
- `#sales_dev_global`: Place for the sales development team to brainstorm amd share ideas. Please refer to the [regional Slack channel list](/handbook/marketing/sales-development/#reaching-the-sales-development-organization-internally) to reach SDR/BDR teams in AMER, EMEA, APAC.
- `#sfdc-users`: Having issues with SFDC? Ask here first.
- `#social_media_action`: Use this channel to communicate and coordinate with the [Social Marketing](/handbook/marketing/integrated-marketing/digital-strategy/social-marketing/) team. You can ask for amplification help and share cool tweets, posts, etc.
- `#swag`: Request or question regarding swag.
- `#website`: Discuss topics related to website redesign project

Automated channels with feeds from different sources:

- `#developer-advocacy-updates`: [Zapier workflows](/handbook/marketing/developer-relations/workflows-tools/zapier/) automatically post GitLab blog posts, Developer Relations social shares, competitive insights, Common Room updates, etc.
- `hn-mentions`: Hacker News post feed, automated with [Zapier](/handbook/marketing/developer-relations/workflows-tools/zapier/) and maintained by the Developer Relations team.
- `social_media_posts`: Automated social media post feed.

### Marketing email alias list

<a id="email"></a>

- Analysts@ company domain: external email address for contacting Analyst Relations at GitLab. Replies are forwarded to Analyst Relations manager and VP Product and Product Marketing
- Community@ company domain: external email address for sending confirmation emails related to GitLab products. Replies are forwarded to Zen Desk support
- Content@ company domain: external email address associated with management of our SlideShare account. Replies are forwarded to Content Marketing team and Marketing OPS Manager
- Events@ company domain: external email address for sending live, VIP & in-person training related emails. Replies go to Field Marketing Managers and Marketing OPS Manager
- Fieldmarketing@ company domain: external email address for requests to the worldwide Field Marketing team
- Giveaways@ company domain: external email address for receiving content & social media related promotional giveaways. Replies go to Content Marketing Team and Marketing OPS Manager
- Leads@ company domain: external email address for internal Lead alerts. Replies go to Marketing OPS Manager
- News@ company domain: external email address used to send newsletter. Replies go to Marketing OPS Manager and Manager, Content Marketing
- MPM@ company domain: external email address used to send direct generic requests to the Marketing Program Managers
- MarketingOPS@ company domain: external email address used to direct generic operational requests to Marketing OPS Manager
- MarketingSFDC@ company domain: external email address associated with management of Salesforce. Replies forward to Manager, Digital Marketing Programs; Field Marketing Manager; Product Marketing Manager; and Manager, Content Marketing
- SecurityAlerts@ company domain: external email address used to send security alerts. Replies go to Marketing OPS Manager
- Sponsorships@ company domain: external email address used to manage sponsor requests from community. Replies forward to Developer Relations Team
- Support@ company domain: external email address for sending Breaking Change and/or support related customer communications. Replies go to Zen Desk support
- Surveys@ company domain: external email address for sending the Developer Survey and/or related surveys. Replies go to Content Team and Product Marketing Manager
- Webcasts@ company domain: external email address for sending webcast related emails. Replies go to Marketing OPS Manager and Marketing Program Managers
- on24questions@ company domain: external email address used for collecting privately asked questions in On24 webinars

## <i class="fas fa-users fa-fw color-orange font-awesome"></i> Get to Know the Marketing Team

### Marketing Team READMEs

<a id="readme"></a>

Get to know the people who work in GitLab's marketing team by visiting our [READMEs](/handbook/marketing/readmes/).

### Learn about the Marketing Departments

Marketing Functional Conversations are modeled after Group conversations. While Group Conversations offer high-level insights, Marketing Functional Conversations are meant to drill deeper into the various functions within the Marketing Department. The goal of Marketing Functional Conversations is to create increased awareness and mutual understanding of the functions within Marketing. Awareness and understanding is an essential building block for effective collaboration.

Recordings of the Marketing Functional Conversations can be found on the [GitLab Unfilitered YouTube Channel](https://www.youtube.com/playlist?list=PL05JrBw4t0Kq5aqfL8RmkCMlbk7lWy4Yi)

### Brand and Product Marketing

Product and Brand Marketing represents the GitLab story at the brand, solution, product, and technical levels. We accelerate GitLab's path to market by developing market insights, leadership positioning, messaging, and narratives that elevate our brand, show value in our solution, and fuel demand for our platform. We activate brand ambassadors and customer advocates to show momentum and trust in the market. The team includes Solutions & Product Marketing, Brand Marketing, Design, and Content.

<a href="/handbook/marketing/brand-and-product-marketing/" class="btn btn-primary">Handbook</a>

Handbook Links
{.h4}

- [Brand](/handbook/marketing/brand-and-product-marketing/brand/)
  - [Merchandise Handling (Swag)](/handbook/marketing/brand-and-product-marketing/brand/merchandise-handling/)
- [Product and Solution Marketing](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/)
  - [Core Product Marketing](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/core-product-marketing/)
  - [Competitive Intelligence](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/competitive-intelligence/)
  - [Analyst Relations](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/analyst-relations/)
  - [Customer Advocacy](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/customer-advocacy/)
- [Design](/handbook/marketing/brand-and-product-marketing/design/)
- [Content](/handbook/marketing/brand-and-product-marketing/content/)

### Integrated Marketing

The Integrated Marketing team is focused on creating awareness, generating demand and collaborating with the broader ecosystem globally, through a co-ordinated and unified approach.  We connect the dots and bring content and messaging to life by leveraging various channels as our levers to communicate across segments, regions and personas.

The team includes [Field Marketing](/handbook/marketing/field-marketing/), [Global Channel Marketing](/handbook/marketing/channel-marketing/), [Corporate Events](/handbook/marketing/integrated-marketing/corporate-events/), [Account Based Marketing](/handbook/marketing/account-based-marketing/), [Integrated Campaigns](/handbook/marketing/campaigns/), [Lifecycle Marketing](/handbook/marketing/lifecycle-marketing/), [Digital Strategy](/handbook/marketing/integrated-marketing/digital-strategy/) and [Digital Experience](/handbook/marketing/digital-experience/).

<a href="/handbook/marketing/integrated-marketing/" class="btn btn-primary">Handbook</a>

Handbook Links
{.h4}

- [Field Marketing](/handbook/marketing/field-marketing/)
- [Channel Marketing](/handbook/marketing/channel-marketing/)
- [Corporate Events](/handbook/marketing/integrated-marketing/corporate-events/)
- [Account Based Marketing](/handbook/marketing/account-based-marketing/)
- [Integrated Campaigns](/handbook/marketing/campaigns/)
- [Lifecycle Marketing](/handbook/marketing/lifecycle-marketing/)
- [Digital Strategy](/handbook/marketing/integrated-marketing/digital-strategy/)
- [Digital Experience](/handbook/marketing/digital-experience/)
  - [Marketing Website](https://about.gitlab.com)

### Sales Development

The [Sales Development](/handbook/marketing/sales-development/) organization is focused on serving the needs of prospective customers during the beginning of their buying process.

The Sales Development department is composed of 2 groups: the SDR team who handles all the inbound interest and the BDR team who specializes in outreach of prospective customers.

When prospective customers have questions about GitLab, the SDRs assist them or connect them to a technical team member as needed. During the initial exploration, if the prospective customer is interested in continuing their exploration of GitLab, SDRs will connect them to an Account Executive (AE) or Strategic Account Executive (SAE).

BDRs contact people who work at large organizations to uncover or create early-stage sales opportunities for GitLab SAEs. The BDR team will plan with their paired Sales counterpart to approach interesting accounts and develop a plan for prospecting including contact discovery, understanding enterprise-wide initiatives that GitLab could assist with, and ensuring accurate data quality of accounts and contact in salesforce.com.

<a href="/handbook/marketing/sales-development/" class="btn btn-primary">Handbook</a>

### Marketing Operations and Analytics

[Marketing Operations and Analytics](/handbook/marketing/marketing-strategy-and-platforms/) includes Marketing Operations, Marketing Analytics, and Globalization and Localization. The team focuses on enabling efficient operations and actionable analytics insights, working across all Marketing teams. The team also owns the MarTech stack used by Marketing.

<a href="/handbook/marketing/marketing-strategy-and-platforms/" class="btn btn-primary">Handbook</a>

Handbook Links
{.h4}

- [Marketing Operations](/handbook/marketing/marketing-operations/)
- [Marketing Strategy & Analytics](/handbook/marketing/strategy-performance/)
- [Globalization & Localization](/handbook/marketing/localization/)

### Enterprise Data

The GitLab Enterprise Data Team is responsible for empowering every GitLab team member to contribute to the data program and generate business value from our data assets.

<a href="/handbook/enterprise-data/" class="btn btn-primary">Handbook</a>

### Developer Relations

Developer Relations drives platform awareness and adoption by reaching deep into wider communities and engaging developers where they are. GitLab currently engages with more than 3000 developers every month on GitLab.com alone, and receives more than 250 contributions every month, giving us a unique level of influence in the DevSecOps space and helping accelerate our innovation. Our ultimate goal is to raise awareness of GitLab and drive customer success by winning the hearts & minds of developers through best-in-class technical enablement and an active community of contributors.

<a href="/handbook/marketing/developer-relations/" class="btn btn-primary">Handbook</a>

Handbook Links
{.h4}

- [Contributor Success](/handbook/marketing/developer-relations/contributor-success/)
- [Developer Advocacy](/handbook/marketing/developer-relations/developer-advocacy/)
- [Community Programs](/handbook/marketing/developer-relations/community-programs/)
  - [Education Program](/handbook/marketing/developer-relations/community-programs/education-program/)
  - [Open Source Program](/handbook/marketing/developer-relations/community-programs/open-source-program/)

### Corporate Communications

The mission of GitLab's Corporate Communications team is to amplify GitLab's product, people and partnerships in the media, via social media channels and through award wins. This team is responsible for global public relations (PR), social media, and executive communications (speaking).

<a href="/handbook/marketing/corporate-communications/" class="btn btn-primary">Handbook</a>

Handbook Links
{.h4}

- [Social Marketing](/handbook/marketing/integrated-marketing/digital-strategy/social-marketing/)
- [Speaking Resources](/handbook/marketing/corporate-communications/speaking-resources/)
- [Incident Communications Plan](/handbook/marketing/corporate-communications/incident-communications-plan/)

## <i class="fas fa-calendar-check fa-fw color-orange font-awesome"></i> Marketing Calendar

<a id="marketing-calendar"></a>
<!-- DO NOT CHANGE ANCHOR -->

FY25 All-Marketing SSoT Calendar
{.h3}

<a id="fy25-calendar"></a>
<!-- DO NOT CHANGE ANCHOR -->

The marketing team utilizes a [single all-marketing calendar](https://internal.gitlab.com/handbook/marketing/#fy25-ssot-marketing-calendar) where everyone can contribute, and we can answer key questions (using pre-set filter views) related to upcoming marketing plans. Note: this calendar links to our internal handbook page.

Please do not filter the entire doc. Instead, you may use pre-set filter views (click down arrow selector next to the filter icon on the bookmark bar) to see activities grouped by GTM Motion, segment, region, team, language, and more.

*If there are other views you would find helpful, please feel free to duplicate an existing filter view, and include some sort of categorization (i.e. team, segment, etc.). You can do this by going to a similar filter view, and clicking on the top right gear icon, then selecting `Duplicate`.*

For more information about adding events to All-Marketing SSoT Calendar, please [click here](/handbook/marketing/marketing-team-processes/#marketing-calendar-inputs).

## Marketing Team Processes

This front page of the Marketing Handbook is intended to serve as the external face of the marketing team. We've created a dedicated [Team Processes page](/handbook/marketing/marketing-team-processes/) that is intended to house our internal processes, workflows, and guidances relevant internally to the marketing team.

<a href="/handbook/marketing/marketing-team-processes/" class="btn btn-primary">Visit the Page</a>
