---
title: "The GitLab Content Style Guide"
twitter_image: '/images/tweets/handbook-marketing.png'
---

The GitLab content style guide is for everyone who creates content on behalf of GitLab. It governs the way we write — including our voice, tone, vocabulary, grammar, punctuation, and formatting — and ensures consistency across all of our content.

## Brand voice

GitLab's brand voice represents and expresses who we are as a brand. It is a core part of our brand identity, informed by our brand values. Our brand voice should come through clearly and consistently in all of our communications.

Maintaining a consistent brand voice helps us:

1. Increase awareness, recognition, and trust in our brand
1. Communicate our unique value
1. Differentiate from our competitors
1. Express our personality

---

Our brand voice comprises the following personality traits:

**1. Visionary**

We are confident, sophisticated technical experts and category creators. We are committed to enabling and empowering our customers and community. We embrace new challenges, energizing our customers to navigate their own journeys with confidence. We lead by example through continuous innovation and a bias for action. We believe we are most successful when everyone can contribute.

> _Example: We created the category._

**2. Empathetic**

We are thoughtful, collaborative, and considerate, as well as approachable and inclusive on a global scale. We are dedicated to understanding and supporting the diverse needs of our team and customers and crafting solutions to help them succeed.

> _Example: The GitLab Community; our mission enabling everyone to contribute_

**3. Intentional**

We are purposeful, direct, and transparent. We communicate with clarity and focus to create a reliable experience for our customers.

> _Example: Our monthly release post_

### How our brand voice comes to life

These guidelines will help you incorporate the GitLab brand voice into your writing while also allowing your individuality and creativity to shine through.

#### Visionary

| We are... | But we are **not...** |
| ------ | ------ |
|    ✅ Inspirational    |    ❌ Sensationalistic    |
|    ✅ Technical experts    |    ❌ Inaccessible    |
|    ✅ Sophisticated    |    ❌ Arrogant    |
|    ✅ Innovative   |    ❌ Impractical    |

**Tips for creating _visionary_ content:**

- Share your expertise in a way that brings value.
- Give clear examples and provide data where possible.
- Ensure your recommendations are accurate, provable, and helpful for your audience.

**Examples:**

> - Blog: [GitLab's 2023 predictions: What's next for DevSecOps?](https://about.gitlab.com/blog/2023/01/26/whats-next-for-devsecops/)
> - Blog: [What the ML is up with DevSecOps and AI?](https://about.gitlab.com/blog/2023/03/16/what-the-ml-ai/)
> - Blog: [Building GitLab with GitLab: How GitLab.com inspired Dedicated](https://about.gitlab.com/blog/2023/08/03/building-gitlab-with-gitlabcom-how-gitlab-inspired-dedicated/)
> - Website: [10 reasons why enterprises choose GitLab](https://about.gitlab.com/why-gitlab/)
> - Website: [Global DevSecOps Survey](https://about.gitlab.com/developer-survey/)

#### Empathetic

| We are... | But we are **not...** |
| ------ | ------ |
|    ✅ Collaborative    |    ❌ Deferential    |
|    ✅ Approachable    |    ❌ Overeager    |
|    ✅ Inclusive    |    ❌ Patronizing    |
|    ✅ Thoughtful   |    ❌ Insensitive    |

**Tips for creating _empathetic_ content:**

- Meet readers where they are — don't assume they know the technology or topics you're covering.
- Explain but don't patronize.
- Be [inclusive](/handbook/marketing/blog/#diversity-inclusion-and-belonging-dib-checklist-for-blog-writers) in your writing.

**Examples:**

> - Blog: [Quickstart guide for GitLab Workspaces](https://about.gitlab.com/blog/2023/06/26/quick-start-guide-for-gitlab-workspaces/)
> - Blog: [The ultimate guide to SBoMs](https://about.gitlab.com/blog/2022/10/25/the-ultimate-guide-to-sboms/)
> - Handbook: [CEO handbook page](/handbook/ceo/)
> - Handbook: [Communication handbook page](/handbook/communication/)
> - Handbook: [Values handbook page](/handbook/values/)

#### Intentional

| We are... | But we are **not...** |
| ------ | ------ |
|    ✅ Clear    |    ❌ Pushy    |
|    ✅ Focused    |    ❌ Inflexible    |
|    ✅ Reliable    |    ❌ Rigid    |
|    ✅ Transparent   |    ❌ Reckless    |

**Tips for creating _intentional_ content:**

- Give your audience the information they need.
- Offer opportunities for readers to provide feedback.
- Use plain language and be honest, even if it means sharing limitations.

**Examples:**

> - Blog: [New pricing for GitLab Premium](https://about.gitlab.com/blog/2023/03/02/gitlab-premium-update/)
> - Blog: [Upcoming changes to user limits on Free tier of GitLab.com](https://about.gitlab.com/blog/2022/03/24/efficient-free-tier/)
> - Blog: [GitLab's first ESG and DIB reports: Here's what to know](https://about.gitlab.com/blog/2023/07/26/gitlab-first-esg-and-dib-reports/)
> - Website: [GitLab Duo solution page](https://about.gitlab.com/gitlab-duo/)

## Style and formatting

For any style questions not directly addressed below, refer to the [Associated Press Stylebook](https://www.apstylebook.com/). Where the guidance below conflicts with AP style, the guidance below takes priority. For guidance on how to use specific terms, refer to the [recommended word list in the documentation](https://docs.gitlab.com/ee/development/documentation/styleguide/word_list.html).

### Style

#### Acronyms and initialisms

When using [acronyms or initialisms](https://www.dailywritingtips.com/acronym-vs-initialism/), ensure that your first mention uses the full term and includes the shortened version in parentheses directly afterwards. From then on you may use the acronym or initialism instead.

If you only use an acronym or initialism once in a piece of content, you probably don't need it and can simply use the full term instead.

Only capitalize the words that make up an acronym or initialism if it's a proper noun.

> ✅ _Dynamic application security testing (DAST)_ examines applications for vulnerabilities like these in deployed environments.
>
> ✅ _GitLab Dynamic Application Security Testing (DAST)_ includes the following analyzers.

#### Contractions

We favor contractions (_can't, didn't, it's, we're_) to sound more human and less formal.

#### Lists

If a numbered or bulleted list reads as a continuous sentence, don't capitalize the first letter of each item in the list, and don't include punctuation at the end of each item.

> ✅ GitLab Duo is unique because we:
>
> - do not use your content to train models
> - are transparent about all AI models used by GitLab Duo
> - use the right AI model for each task, ensuring you always stay ahead of the curve

If each item in the list reads as its own sentence, capitalize and punctuate as you would free-standing sentences.

> ✅ Here are three reasons GitLab Duo is unique:
>
> - GitLab Duo features do not use your content to train models.
> - Our publicly available documentation describes all AI models used by GitLab Duo.
> - We use the right AI model for each task, ensuring you always stay ahead of the curve.

#### Pronouns

Unless referring to someone in particular, use gender-neutral pronouns (_they, them_).

> ✅ With GitLab, a developer can integrate security into _their_ workflow.
>
> ❌ With GitLab, a developer can integrate security into _his/her_ workflow.

#### Quotations

Use double quotation marks (" ") for direct quotes, and single quotation marks (' ') for a quote within a quote.

Include periods and commas inside ending quotation marks.

Any punctuation that is part of the quotation should be included inside of the quotation marks. Any punctuation that is not part of the quotation (aside from periods and commas, as noted above) should be outside of the quotation marks.

> ✅ Recently, an article was published stating, "Software is eating the world."
>
> ✅ What do you think of the claim, "Software is eating the world"?
>
> ✅ "Do you agree that software is eating the world?" wrote the author.

When including direct quotations from interviewees in blog posts, use present tense for verbs such as _says_ and _explains_.

> ✅ "Ruby was optimized for the developer, not for running it in production," says Sid.

The exception would be when quoting from an event that was obviously in the past; in that case use the past tense so the reader is not confused or misled.

#### Spelling

We use American English by default on the GitLab blog and marketing site. Please refer to [this list of spelling differences](https://www.oxfordinternationalenglish.com/differences-in-british-and-american-spelling/). In content specifically created for a particular region, use the variant of English that is most appropriate for that region.

#### Voice

Generally, use [active voice](https://www.grammarly.com/blog/sentences/active-vs-passive-voice/) where possible. Using active voice ensures that your sentence includes a clear subject and verb.

> ✅ The GitLab community submitted 1 million merge requests in March 2019
>
> ❌ One million merge requests were submitted in March 2019.

There may be limited cases where passive voice is the better option. Use your best judgment in each case, and if you decide to use passive voice, try to be aware of why you're making that choice.

### Capitalization

#### Brand and publication names

Ensure you style brand names according to the company's brand guidelines.

> ✅ WiFi Tribe, DigitalOcean

If the word the forms part of a brand or publication's name, capitalize it. Omit _The_ if including it would make the sentence awkward.

> ✅ We spoke to a reporter from _The Wall Street Journal_.
>
> ✅ We spoke to a _Wall Street Journal_ reporter.

#### GitLab feature names

Generally, GitLab feature names are lowercase, but there are exceptions. Refer to the [recommended word list in the documentation](https://docs.gitlab.com/ee/development/documentation/styleguide/word_list.html) if you're unsure.

#### GitLab functions, departments, and teams

Capitalize the name of the element, but not the word after (_team, department_, etc.).

> ✅ Engineering team, Security department
>
> ❌ Engineering Team, security department

#### Job titles

Use lowercase for job titles in sentences, regardless of whether they appear before or after a person's name.

> ✅ John Smith, director of engineering, led the project.
>
> ❌ John Smith, Director of Engineering, led the project.

Capitalize the title when the person's name and title appear as a standalone (such as in the lower third of a video, a nametag, or attribution on a pull quote).

> ✅ John Smith, Director of Engineering, XYZ Corporation
>
> ❌ John Smith, director of engineering, XYZ Corporation

#### Titles and headers

Generally, use sentence case (capitalize only the first word and any proper nouns) for all headlines, titles, and subheads. There may be exceptions where title case is preferred from a design standpoint.

> ✅ Remediating vulnerabilities with GitLab's security insights and AI
>
> ❌ Remediating Vulnerabilities with GitLab's Security Insights and AI

### Dates and times

#### Date formatting

For external-facing content, spell out the month and use a comma before the year. If the sentence continues after the year, also include a comma after the year. When you are only stating the month and the year, you don't need a comma after the month.

> ✅ Release date: November 16, 2023
>
> ✅ On November 16, 2023, we released GitLab 16.6.
>
> ✅ We released GitLab 16.6 in November 2023.

For internal content, use ISO format (_2023-11-16_). In content geared toward a specific region, use the format preferred in that region.

Don't use rd/st/th after the date, unless the date appears independently from the month (_See you on the 16th_).

#### Time formatting

Abbreviate _ante meridiem_ and _post meridiem_ using **a.m.** and **p.m.** (lowercase, with periods between the letters and a space before it to separate it from the time: _6:00 a.m._).

We default to the 12-hour clock (_9:00 p.m._). However, in content geared toward a specific region, use the format used in that region.

When writing about physical events, use the time zone where the event is taking place. Don't abbreviate time zones. For virtual events, use UTC.

### Punctuation and symbols

#### Ampersands

Use ampersands only where they are part of a company's name or the title of a publication or official name.

Do not use an ampersand as a substitute for _and_ in body copy.

Ampersands may be used sparingly where character counts are very tight, such as a headline in a display ad.

#### Colons

If a colon is used to introduce a complete sentence (including a question), capitalize the first word after the colon.

> ✅ AI isn't just another fad: It's seeing real adoption among practitioners.
>
> ❌ AI isn't just another fad: it's seeing real adoption among practitioners.
>
> ✅ We aimed to explore several topics: Where are things improving, and where are teams still running into roadblocks?
>
> ❌ We aimed to explore several topics: where are things improving, and where are teams still running into roadblocks?
>
> ✅ One thing stood out in the survey responses: the importance of security.
>
> ❌ One thing stood out in the survey responses: The importance of security.

Always capitalize the first word after a colon in a title, even if it's not a complete sentence.

#### Commas

Our default is to use serial (Oxford) commas. In content geared towards a specific region, feel free to use what is most common in that region.

> ✅ AI can help DevSecOps teams write code, resolve security vulnerabilities, accelerate code review, and improve collaboration.
>
> ❌ AI can help DevSecOps teams write code, resolve security vulnerabilities, accelerate code review and improve collaboration.

#### Dashes

Use an em dash (—) instead of two dashes (--) to set off a distinct thought within a sentence. Place one space on each side of an em dash.

Use an en dash (–) when communicating numeric ranges not preceded by the words _from_ or _between_ (_Join us October 20–25 in San Francisco_). Don't include a space on either side of the en dash.

#### Ellipses

Include one space before and after an ellipsis ( … ).

#### Hyphens

Use a hyphen to connect two or more words that jointly modify another word (_built-in security_).

Do not hyphenate the adverb very or adverbs ending in _-ly_ (_fully integrated platform_).

Generally, don't hyphenate prefixes such as _semi, pre, non, un, sub_, or _multi_ (_multitenant, subtask_). The exception is when the last letter of the prefix is the same as the first letter of the root word (_sub-bucket_).

Do use a hyphen after a prefix followed by a proper noun and for words beginning with the prefixes _all-, mid-, ex-_ (meaning "former"), and _self-_ (_mid-July, self-managed_).

Refer to the [recommended word list](https://docs.gitlab.com/ee/development/documentation/styleguide/word_list.html) for guidance on how to hyphenate specific words.

#### Spacing

Use only one space (not two) after a period.

Use a space between a number and a unit of measurement (_128 GB_).

### Numbers

#### Small numbers

Generally, spell out numbers zero through nine. Exceptions include:

- Percentages: Generally, use numerals and a percent sign (%) for percentages, unless starting a sentence.
- Callout boxes and lists of stats: Use numerals for numbers less than 10 in instances where character counts are limited or when you'd like to emphasize the numbers, such as in a bulleted list of stats, or stat callouts at the top of a case study.

Use numerals for 10 and above unless starting a sentence.

Always use numerals when putting a number at the start of a headline (_5 ways AI can help developers_).

#### Large numbers

Numbers with four or more digits should include a comma (_2,000; 100,000_). If you're writing in a specific context where this might cause confusion (such as for regions that use commas as a decimal separator instead), do what makes the most sense for your audience.

Generally, avoid abbreviations for large numbers, such as _k_ (meaning "thousand") and _M_ or _mil_. Use these abbreviations only where space is very limited, such as a callout box with a tight character limit.

#### Currencies

In contexts where currencies are mentioned, be sure to denote them in the format <NUMBER> <CURRENCY_CODE> by using the code from the [ISO 4217 standard](https://en.wikipedia.org/wiki/ISO_4217#Active_codes_(list_one)) (e.g. 10 USD, 15 EUR, 30 CAD, 30,000 JPY, 29.99 CHF).

#### Percentages

Use % instead of _percent_ at all times, unless the number is spelled out, in which case also spell out _percent_.
