---
title: "Content Marketing"
description: "The content marketing team is responsible for strategic and resourceful content creation."
---

The Global Content team is responsible for showcasing GitLab's expertise and leadership in DevOps through easy-to-find content that is educational, thought-provoking, and market-defining. As part of Global Content, the Content Marketing team works with stakeholders across GitLab to provide readers with end-to-end content experiences that garner trust, create source credibility, and generate customer engagement.

## Meet the Content Marketing team

**[Chandler Gibbons](https://gitlab.com/chandlergibb)**

- **Title**: Manager, Content Marketing
- **GitLab handle**: @chandlergibb
- **Slack handle**: @Chandler Gibbons

**[Sharon Gaudin](https://gitlab.com/sgaudin)**

- **Title**: Sr. Content Marketing Manager
- **Area of focus**: DevOps platform
- **GitLab handle**: @sgaudin
- **Slack handle**: @Sharon Gaudin

**[Kristina Weis](https://gitlab.com/KristinaWeis)**

- **Title**: Sr. Content Marketing Manager
- **Area of focus**: Automated software delivery
- **GitLab handle**: @KristinaWeis
- **Slack handle**: @Kristina Weis

## Working with Content Marketing

### What we can help with

We're here to help with your content, writing, and editing needs! Ask us for help with:

- Writing content for GTM campaigns (mostly awareness- and consideration-level eBooks, landing pages, nurture emails, related blog posts and/or articles)
- Writing blog posts to support strategic [Editorial team](/handbook/marketing/brand-and-product-marketing/content/editorial-team/) needs
- Writing [topic pages and subtopic pages](https://about.gitlab.com/topics/)
- Writing and reviewing [customer case studies](https://about.gitlab.com/customers/), in collaboration with the [Customer Reference team](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/customer-advocacy/)
- Reviewing content for web pages, emails, or other marketing assets
- Reviewing customer-facing emails and other communications

### How to request help from Content Marketing

The team will review all incoming requests in the [Content Marketing project](https://gitlab.com/gitlab-com/marketing/inbound-marketing/global-content/content-marketing) and will schedule accordingly based on current workload and priorities.

**Requesting content creation for campaigns**

- For assets that will have multiple associated tasks or steps, such as a campaign eBook, create an epic for the asset itself and then create issues within the epic that correspond to each step that needs to be completed by a separate owner. Content creation should be one of those issues.
- Create the content creation issue in the [Content Marketing project](https://gitlab.com/gitlab-com/marketing/inbound-marketing/global-content/content-marketing). Be sure to label the issue with the Content Marketing label and assign the Content Marketing team member who is working on the campaign.
- The Content Marketing team will use the content creation issue to manage the content creation process end to end, from drafting the content through peer review, technical review, and final proofreading.

**Requesting content creation for other projects**

- Create an issue in the [Content Marketing project](https://gitlab.com/gitlab-com/marketing/inbound-marketing/global-content/content-marketing) using the most relevant issue template. Please include as much background information about the request as possible, including the deadline for the final deliverable, how it will be used and promoted, goals, and target audience. Feel free to link to other relevant issues and epics, and/or attach the request to an existing epic, if appropriate.

**Requesting content editing and review**

- Create an issue in the [Content Marketing project](https://gitlab.com/gitlab-com/marketing/inbound-marketing/global-content/content-marketing) using the most relevant issue template. Please include as much background information about the request as possible, including a deadline for review. Feel free to link to other relevant issues and epics, and/or attach the request to an existing epic, if appropriate.

### Typical content creation process: Campaign ebook or whitepaper

| Task | DRI |
| ------ | ------ |
| Define general campaign theme and target audience/segment for asset in collaboration with Product Marketing, campaign leads, and Global Content | Campaign manager |
| Provide input on search keywords and topic/angle | Search marketer |
| Write first draft | Writer (Content Marketing) |
| Complete peer review (looking at flow, clarity, consistency, story) | Editor (Content Marketing) |
| Complete campaign review (checking for alignment with campaign objectives) | Campaign manager |
| Complete SME review (looking at messaging and positioning) | Product marketing manager |
| Copy edit | Editor (Content Marketing) |
| Proofread/prepare for Design (cleaning up and resolving edits) | Writer (Content Marketing) |
| Put content into layout | Brand designer |
| Stakeholder review (checking for typos, errors, broken/incorrect links, the look of the design, proof infographics, double check that index links lead to the right pages) | Writer (Content Marketing), Editor (Content Marketing), Product marketing manager |
| Implement final edits | Brand designer |
| Final proofread (checking that all edits are implemented, confirming links) | Writer (Content Marketing), Editor (Content Marketing) |
| Publish | Campaigns team |

*Note: Each role should be assigned at the project outset; for example "Editor (Content Marketing)" would be a single person who would be identified in the relevant project issues/epics and would review the draft at all of the designated times to keep things consistent.*

### Current projects (Q3 FY23)

#### Campaigns and lightning strikes

- [Capability Campaign: DevOps Platform](/handbook/marketing/campaigns/#devops-platform)
- [Solution Campaign: Automated Software Delivery](/handbook/marketing/campaigns/#cicd)
- [Solution Campaign: Security & Compliance](/handbook/marketing/campaigns/#-security--compliance-solution-campaign)

### Content types: Definitions and workflows

Content is most effective when it has the right message, to the right audience, at the right time, in the right medium. That's why the content marketing team produces a variety of content types designed to reach different people at different stages of the buyer journey.

At GitLab, everyone can contribute. While the content marketing team produces a large amount of content, they are by no means the only content creators at GitLab. If you would like to contribute content such as blog posts, eBooks, whitepapers, etc, read more about these content types and how to submit them.

#### Blog post

A post on the GitLab blog is used during the Awareness or Consideration stage of the buyer's journey. A blog post can educate, entertain, tell a story, take an opinionated stance, etc. A blog post is dated, so it only reflects thoughts, ideas, and processes from a specific period of time. For communicating long-term/evergreen ideas or processes, consider using a [topic page](/handbook/marketing/brand-and-product-marketing/content/content-marketing/#topic-page) or [web article](/handbook/marketing/brand-and-product-marketing/content/content-marketing/#web-article) instead.

Visit the blog handbook to learn more about the [blog publishing process](/handbook/marketing/blog/).

#### Blog repurpose

A blog can and should be repurposed as a web article/cluster page if the content is evergreen and Awareness stage. The blog should also be older than six months and not GitLab-centric.

**Blog repurpose workflow**

1. Work with the SEO team to identify existing, older blogs that are the best options for repurposing.
1. Ensure that the editorial team is aware of the intention and has approved the redirect.
1. In a Google doc, copy and paste the existing blog. From there, use the keyword spreadsheets to identify the best possible updates -- this can include changing the title to a better keyword phrase, identifying areas of copyediting improvements, adding links, adding a 'More On' section, and elaborating on longtail keywords throughout the content.
1. Create a merge request on the `www-gitlab-com` project.
1. Once the web article is edited and merged, open an [issue to redirect](https://gitlab.com/gitlab-com/marketing/inbound-marketing/growth/-/issues/new#set-up-a-new-redirect) the blog URL to the new web article. Add the new URL and old URL in the issue. The labels are included in the issue, do not assign.
1. After the web article is merged and the blog redirected, add the web article link to the associated Topics page in the sidebar.

#### Whitepaper

A whitepaper is a technical and focused topic study intended to educate a prospective buyer during the Consideration or Purchase stages of a campaign. The whitepaper offers a problem and solution instance in a granular, technical tone. The content team member should collaborate closely with their product marketing counterpart when researching and writing the asset so that the content reaches appropriate technical standards for the intended audience.

Any technical GitLab team member is welcome to write a whitepaper and collaborate with the content team. If you're interested in writing a whitepaper, open an issue in the [Content Marketing project](https://gitlab.com/gitlab-com/marketing/inbound-marketing/global-content/content-marketing) and describe your idea, or post in the [#content](https://gitlab.slack.com/archives/C2R1NED61) Slack channel. Whitepapers should be related to specific use cases and support campaigns, when possible.

**Examples:**

1. [A seismic shift in application security](https://about.gitlab.com/resources/whitepaper-seismic-shift-application-security/)
1. [How to deploy on AWS from GitLab](https://about.gitlab.com/resources/whitepaper-deploy-aws-gitlab/)

#### eBook

An eBook tends to be broader in scope than a whitepaper and provides a clear definition of the topic, along with various industry standard best practices. eBooks typically provide awareness-level content, but can dive deeper into GitLab if it's intended for late-stage consumption. eBooks should be related to specific use cases and support campaigns, when possible.

**Content Marketer workflow**: A Content Marketing team member develops eBook content with input and review from their product marketing counterpart. More technical or instructive eBooks may require more collaboration with product marketing. eBooks follow the [internal gated content](/handbook/marketing/demand-generation/campaigns/content-in-campaigns/) asset workflow.

Follow the instructions for creating an internal gated asset and start the eBook process by creating an epic using the [epic template](/handbook/marketing/demand-generation/campaigns/content-in-campaigns/).

**For other GitLab team members:** To request an eBook from the content team, feel free to open a [content request](https://gitlab.com/gitlab-com/marketing/inbound-marketing/global-content/content-marketing/-/issues/new?issue%5Bassignee_id%5D=&issue%5Bmilestone_id%5D=#) issue. If you would like to write an eBook, we have an [eBook google doc template](https://docs.google.com/document/d/1V944SVbjBxUVMtZiWIS-Baoxc7Ui-gjq3fCYf8tK0D4/edit?usp=sharing) available for GitLab team members to use with general best practices.

**Examples:**

1. [An intermediate guide to GitOps, Kubernetes, and GitLab](https://page.gitlab.com/resources-ebook-gitops-kubernetes-gitlab.html)
1. [The GitLab Remote Playbook](/handbook/company/culture/all-remote/)
1. [The benefits of single application CI/CD](https://about.gitlab.com/resources/ebook-single-app-cicd/)

#### Infographic

An infographic is an illustrated overview of a topic or process, and is typically an ungated asset. Infographics should tell a story using data, diagrams, and text. It can be used to discuss industry trends, relate insights, or explain different stages of a project. Open a [design request issue](https://gitlab.com/gitlab-com/marketing/corporate_marketing/corporate-marketing/-/issues/new?issuable_template=request-design-general) when planning an infographic to figure out a structure for the graphic, and ask the design DRI for recommended copy lengths.

**Example:**

1. [Git cheat sheet](/images/press/git-cheat-sheet.pdf)
1. [How GitLab accelerates workload deployments on AWS](https://gitlab.com/gitlab-com/marketing/inbound-marketing/growth/uploads/59d1390557bb304e7401443c4e710c0f/gitlab-aws-ci_t-campaign-infographic-01.pdf)

#### Topic page

A topic page is a high-level explanatory "pillar" page dedicated to a specific topic, such as [version control](https://about.gitlab.com/topics/version-control/), [DevSecOps](https://about.gitlab.com/topics/devsecops/), or [continuous integration](https://about.gitlab.com/topics/ci-cd/). Topic pages should explain what the subject is, why it is important, and explain the basic concepts of the subject. Topic pages should include links to additional related resources, such as blogs, web articles, videos, and case studies, as well as at least one CTA to a gated asset.

#### Web article

Web articles are educational, informational content, designed to support topic pages using keywords and search terms. They are similar to blogs in length, but differ in that they are not dated and the content is evergreen (see [more about blog posts](#blog-post)). Web articles should be linked on one or more topic pages, and should serve as a deep-dive into a specific sub-topic. Web articles are created in accordance with SEO research and campaign goals that are listed in the topics clusters spreadsheets. Complete the [SEO web article template](https://docs.google.com/document/d/1ON2CZ7uufl9gtqh-P67AxU5Y42ctQ3mRtPsgJRlep7Y/edit?usp=sharing) when creating a new piece of content.

**Examples:**

1. [How to choose the right continuous integration tool](https://about.gitlab.com/topics/ci-cd/choose-continuous-integration-tool/)
1. [What are Git version control best practices?](https://about.gitlab.com/topics/version-control/version-control-best-practices/)
1. [What is developer-first security?](https://about.gitlab.com/topics/devsecops/what-is-developer-first-security/)

#### Case study

Case studies are in-depth customer stories that provide insight as to how GitLab has resolved significant software workflow problems for a company. The case study tells the story using quotes from customer interviews and straightforward metrics that broadly show the impact of adopting GitLab.

[Case studies](https://about.gitlab.com/customers/) are created in partnership with the customer reference team. The customer reference team has a process in place for how they add new references and provide a list of [customer value drivers](/handbook/marketing/product-marketing/customer-reference-program/customer-insight/#command-of-message-questions). The content team is responsible for writing the case study asset using [this template](https://docs.google.com/document/d/1UbhW2AEP7BfEZJGcp7w4LS6-W-xSeGET4K4NDr7bP0E/edit?usp=sharing), [publishing the case study](/handbook/marketing/product-marketing/customer-reference-program/customer-insight/#publishing-to-the-website) to the website, [adding the customer logo](/handbook/marketing/product-marketing/customer-reference-program/customer-insight/#adding-customer-logo-and-case-study-to-customers-grid) to the customer logo grid, and ensuring that the case study goes through proper social media and newsletter steps.

**Examples:**

1. [How Hotjar deploys 50% faster with GitLab](https://about.gitlab.com/customers/hotjar/)
1. [Security provider KnowBe4 keeps code in-house and speeds up deployment](https://about.gitlab.com/customers/knowbe4/)

## Recommended Slack channels

Anyone at GitLab can reach out to the content team in the #content channel on Slack.

Here are a few other Slack channels to check out if you'd like to learn more about marketing content:

- **`#content-team-lounge`**: Where the content team can hang out. This is a public channel.
- **`#content`**: A general discussion channel for all things content, including blog posts, case studies, videos, webcasts, newsletter content, interesting articles, etc
- **`#content-updates`**: A rolling log of new, published content. Once an article, blog post, case study, webinar, video, landing page, etc. is public, add it to this channel with a TL;DR description of the content.
- **`#marketing`**: The main channel for the entire marketing group.
