---
title: "GitLab TV"
description: "Handbook page for GitLab TV"
twitter_image: '/images/tweets/handbook-marketing.png'
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

## Introduction

This is a public-facing document that outlines the GitLab.tv MVC strategy and contribution guidelines.

GitLab.tv is GitLab's video-first content platform focused on generating valuable and viral content by enabling and encouraging contribution and distribution of GitLab video content. We currently use the GitLab Branded YouTube channel as our video-first platform.

## GitLab.tv Goals

1. **Grow brand awareness and business.**
GitLab.tv is focused on growing our business and brand in measurable ways. Content is strategically focused on attracting, converting, nurturing, or closing leads. We want to provide valuable content and then invite viewers to continue their DevOps adoption and GitLab journey through conversion paths and calls to action (CTA).
1. **Encourage contribution of customer-centric and shareable content.**
GitLab.TV is a group effort. We encourage contribution by providing streamlined paths and guidelines for creating video content. We enable contributors to create customer-centric content that is easy to find and consume and is aligned to audience needs.
1. **Increase video content distribution.**
GitLab.tv video content is distributed across owned, earned and paid content channels. All GitLab.tv video content contributions that are approved are first posted to their respective GitLab.tv Video Channels on YouTube. GitLab.tv video content can also be cross-promoted via GitLab websites, blog, social, and third party platforms as determined by GitLab.tv Video Channel Distribution plans. Top content may be promoted more than standard content. The goal is to make GitLab accessible to audiences, especially top content.

### Success metrics

1. See an average of 300 views for new videos +30 days after publishing
1. Increase number of GitLab website pages with video content
1. Grow YouTube subscribers
1. Increase traffic from YouTube to about.gitlab.com and subpages

## Audience

Like all online audiences, the GitLab.tv audience is short on patience and long on content options, so they may not have a high tolerance for brands or content platforms that do not quickly meet or exceed their needs and expectations. Once they feel a brand or platform is aligned to their needs, their loyalty and patience increases. The GitLab.tv audience likes to share content they feel is valuable to others on their team.

The primary GitLab.tv audience is made up of developers and DevOps practitioners. They are individual contributors and managers who are deep in the weeds of day-to-day execution of development and operations tasks. They are most interested in content that answers a specific question or goes into specifics on a single topic. They look for content that is straightforward, concise, and has clear learning objectives. This audience is willing to watch a 40+ minute video if it offers clear takeaways and/or new information that they can directly apply to their day-to-day work. However, GitLab.tv aims to provide short, digestible video content and oftentimes, longer videos will be broken into smaller, topic-based videos as part of a series. These smaller videos are also known as micro-video content.

## Creating content for GitLab.tv

GitLab.tv strives to create valuable and viral content. In order to do that we need to make sure every video is customer-centric, from the script to the meta tags we add in YouTube to ensure it's discoverable. Here are some goals to keep in mind when creating GitLab.tv content:

### Content guidelines

1. **Audience-centric:** Before creating your video, ask yourself how does this content help our audience achieve their goals? Are there clear takeaways? What is the next step someone should take after watching this video? Make sure that CTA is clear.
1. **Optimize for search:** The majority of our video content is found organically. Make sure you are optimizing your videos for search by using descriptive titles and descriptions. For example, if you are publishing a video on how to use GitLab Issue Boards for project management, use the title "How to use GitLab Issue Boards for project management" over "Senior Developer David Smith explains Issue Boards."
1. **Engaging, clear, and concise:** GitLab.tv video content is clear and concise, but also enjoyable to consume and share. We should avoid internal jargon and follow other communication best practices laid out in our handbook. The videos should be easy to play, hear, and so on.
1. **Micro-content:** GitLab.tv values micro-content over long-form content. Contributors can develop a series of micro-content pieces that allow each video to be played as stand-alone sequentially as part of a content series.
1. **Accessible:** GitLab.tv content should be easy for relevant audiences to find on GitLab.tv as well as in their preferred content channels.

For more specific information on video content types, refer to the [video playbook handbook](/handbook/communication/video-playbook/).

### Video assets

Supplementary video assets, such as logos, bumpers, photos, graphics, animations, etc. can be found [here](https://drive.google.com/drive/folders/0B6i7Xg1yiB8tZWhKbzlsOFpfVDg?usp=sharing).

### Conversion paths & CTAs

All GitLab.tv video content should include a call to action (CTA). The goal is to provide frictionless conversion paths that are relevant to the viewer and easy to follow. Here's how you can integrate CTAs in video content:

1. **End screen CTA:** Add a closing slide to your video with a call to action and link.
1. **Spoken CTA:** Call out the action you want the viewer to take in your video. For example, "check our eBook on XYZ topic to dive deeper" or "if you liked this video, make sure to subscribe for more."
1. **On-screen graphics CTA:** Add graphics, like lower thirds or banners, to your video encouraging viewers to check out additional links.
1. **Text-based CTA:** Add text-based links to your video description.

### Add UTM codes to all video descriptions

Please be sure to add a UTM code to your CTA in the video description when uploading your videos to YouTube. This **required** action is needed to track your video's performance.

The UTM code should follow this sequence: `?&utm_medium=social&utm_source=youtube&utm_campaign={{playbook}}&utm_content={{video}}`

1. Right before the question mark at the start of the UTM code, please put the URL to the campaign/landing page to which your CTA is driving, i,e. if this is a video that drives to the top-level community page, the URL added before the question mark should take you to the Community landing page. For example: `https://about.gitlab.com/community/?&utm_medium=social&utm_source=youtube&utm_campaign={{playbook}}&utm_content={{video}}`
2. Please use a URL shortener, like [bit.ly](https://bitly.com/), once you add the campaign URL to the top of the UTM code sequence in order to avoid posting a clunky web address for your CTA.

## Distribution and promotion of GitLab.tv content

1. GitLab website
1. GitLab blog
1. PathFactory

**How to have your video considered for promotion:**

1. Submit to GitLab social team for consideration (DRI must create issue to enable this step)
2. Submit to GitLab editorial team for consideration on the blog and/or bi-weekly newsletter (DRI must create issue to enable this step)
3. Third-party content platforms (e.g. like ITPro.tv, industry blogs, etc.)
4. Highlighted on GitLab's weekly "This Week at GitLab" video series (DRI must create issue to enable this step)
5. Consideration for featuring on the GitLab home page or associated channel page video band (DRI must create issue to enable this step)
6. Featured in GitLab event follow up email/s, if applicable (DRI must create issue to enable this step)

## GitLab.tv Channels

A GitLab.tv Video Channel is a content track focused on a specific audience and specific business goals. Each channel has a lead who is responsible for:

- Building their channel team
- Curating their channels video content
- Distributing their content and promoting top content
- Reporting on channel and content success metrics

GitLab.tv channels can take many forms as long as they satisfy the GitLab.tv overall strategy, goals, and deliver ROI. Channel leads have the flexibility to define and experiment with channels of all types. The GitLab.tv team doesn't know which channels will be successful, and none of us are as smart as all of us, so we've intentionally given GitLab.tv video channel leads flexibility to create and try channels of all kinds. Channels and their content are measured to gauge success, inform continual improvement and justify further investment. If a channel is not providing ROI, the GitLab.tv team may ask that it be retired.

### Contribute to an existing channel

To contribute to an existing channel, visit the channel playbook for more information on contribution guidelines.

1. [All-Remote](/handbook/marketing/brand-and-product-marketing/content/digital-production/gitlab-tv/all-remote-channel-playbook/)
1. [Events](/handbook/marketing/brand-and-product-marketing/content/digital-production/events-channel-playbook/)
1. [Community](/handbook/marketing/brand-and-product-marketing/content/digital-production/gitlab-tv/community-video-playbook/)

### Create a new channel

GitLab.tv Video Channel Playbooks define the channel audience, measurable goals, content types, content distribution plan, and contribution paths. To create a GitLab.tv Video Channel Playbook, use this [template](https://docs.google.com/document/d/1YEMzrvmo9g2ukDTsOlmMatzELu0FhmkaBil_DRVGv6Q/edit?usp=sharing) and reach out to the GitLab.tv team.

---

Return to the main [Inbound Marketing Handbook](/handbook/marketing/inbound-marketing/).
