---
description: "Describes how we do Product Marketing at GitLab."

title: Product Marketing Team
description: "Product Marketing communicates GitLab business value internally and externally to position GitLab as a DevOps partner and solution."
---

## Product marketing at GitLab

Product Marketing communicates GitLab business value internally and externally to position GitLab as a DevOps partner and solution. The team is responsible for product positioning, value messaging, and go-to-market strategy to support sales and outbound messaging with analysts, press, and prospects. Product Marketing also facilitates market feedback as key inputs into the GitLab product roadmap.

### PMM Stable Counterparts

- The PMM Team
- PM:PMM stable counterparts are listed on the [Product Sections page](/handbook/product/categories/).
- Solution DRIs are listed on the [Solutions GTM page](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/).

### Core Competencies

PMMs require a broad set of skills, knowledge, and expertise. This lists core competencies.

- Narrative, Messaging, and Positioning
- Writing/editing
- End-to-end buyers journey
  - All stages of the marketing funnel - TOFU, MOFU, BOFU
  - All stages of the sales cycle
  - Customer marketing
- Product knowledge
- Market knowledge
  - Competitors
  - Partners
  - Peers (Other tech products and companies that aren't partners or competitors, but exist as part of the ecosystem)
  - Trends
- Buyer and user personas

### Onboarding

- <b>[Go to the PMM onboarding page](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/core-product-marketing/onboarding)</b> and check out our onboarding guide.

### Product Marketing Collaboration

In general, product marketing supports three main groups:

1. **Enables sales** with positioning, messaging, content, and collateral.
    1. Create decks, messaging, and collateral
    1. Support and deliver sales enablement
    1. Actively engage in the sales cycle
1. Supports **campaigns, content, and field marketing teams** with content, webinars, presentations, and strategic input.
    1. Drafts content, whitepapers, webinars, and presentations
1. Partners with the **Product teams** on vision, roadmaps, and new features to improve our differentiation.
    1. Feedback and input into vision and roadmap
    1. Drafting the Release Post Headline and Introduction
    1. Reviewing and updating feature descriptions

#### Sales Collaboration

In additional to enabling sales, PMMs should partner with sales and actively engage with the sales proecess by listening to call recordings and joining customer calls with reps. There are several outcomes that result from this process:

1. Improved Messaging - test messaging directly on end customers to gauge their reaction and get feedback. Understand their pain points and values in order to use them to fuel your messaging.
2. Know the buyers journey end-to-end - understand the stages of the buyer process by actively engaging with them.
3. Assist sales on key deals - PMM can serve as product and market SMEs who can tell the story of thier solutions in a compelling way to help move key deals forward.
4. PM triage/assist/feedback -As part of the PM <> PMM partnership PMMs can recommend customers they've talked to their PMs to enage with and assist in the gathering of product feedback during customer calls to share with the PM. Similarly, PMs can share messaging feedback, buyer persona info, and sales process insights they gather on calls with customers with their PMMs.

### Metrics and Measures

1. ARR per solution: Product Marketing Managers are the "Product Managers of Marketing". In the same way a Product Manager is responsible for the product research & development, the Prouct Marketing Manager is responsible for the product go-to-market. In the same way PMs don't have direct authority over engineering, but they collaborate and lead by influence, PMMs don't have direct autority over sales and marketing execution but they collaborate and lead by influence.
    - At GitLab, PMs are [measured on usage](https://internal.gitlab.com/handbook/company/performance-indicators/product/) of their product area even though they don't have complete control over all of the factors that drive usage, it is a good proxy to help them make decisions that best impact the user.
    - At GitLab, PMMs are measure on ARR of their solution(s) even though they don't have complete control over all of the factors that drive ARR, it is a good proxy to help them make decisions that best impact the buyer at every stage of the funnel/buyer journey.

### Solutions Go To Market

[Solutions GTM Page](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/)

### Project Management

1. Every project should have a top-level Epic, Issue, doc that outlines the plan and links to all supporting issues and docs.
1. The plan chart should include columns for
    1. Deliverable or Milestone
    1. [DRI](/handbook/people-group/directly-responsible-individuals/)
    1. Due Date is ISO format ([point 7](/handbook/communication/#writing-style-guidelines))
    1. Status: [On track, Needs Attention, At risk, or DONE](#health-status-definitions)
    1. Note/Next step (optional)
1. You can use a google sheet, markdown table (in an issue or epic description), or Epic issue list for the plan
1. If you use an Epic issue list follow these constraints:
    1. Every deliverable should have an issue attanched the epic.
    1. The issue title must be the name of the deliverable .
    1. The deliverable draft, and when completed final version, should be linked at the top of the issue description.
    1. Every issue should have only 1 assignee - the DRI for the deliverable.
    1. Every issue should have a due date.
    1. Every issue should have a health status is that is checked/updated weekly. (Close the issue for deliverables that are complete/done.)

#### Health Status Definitions

- **On Track**: We are confident this issue will be completed by the due date.
- **Needs Attention**: There are concerns, new complexity, or unanswered questions that if left unattended will result in the issue missing its targeted completion date. Collaboration needed to get back On Track.
- At Risk: The issue in its current state will not make the targeted completion date and immediate action is needed to rectify the situation.
- DONE: The deliverable is completed and linked. A closed issue represents a status of "DONE".

### Key links

- [Messaging](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/messaging/)
- [GitLab positioning](/handbook/marketing/positioning-faq/)
- [Hidden IT Groups](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/it-groups/)
- [Defining GitLab roles and personas](/handbook/product/personas/)
- [GitLab tiers](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/tiers/)
- [Market segmentation - Industry verticals](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/market-segmentation/)
- [Use Case - Go to market](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm)

### PMM Talk Inventory

<iframe width="950" height="900" src="https://docs.google.com/spreadsheets/d/e/2PACX-1vSvkbjALQnaEu_vg0i_UEfFStZttVxMP0WCzTaDIGS31ZL_ndVvBgaEWn_OkrRYRPYQtj6g9bJV2J0C/pubhtml?gid=0&amp;single=true&amp;widget=true&amp;headers=false&amp;rm=minimal&amp;range=published_talks"></iframe>

### Release vs. launch

A [product release, and a marketing launch are two separate activities](https://www.startuplessonslearned.com/2009/03/dont-launch.html). The canonical example of this is Apple. They launch the iPhone at their yearly event and then release it months later. At GitLab we do it the other way: Release features as soon as they are ready letting customers use them right away, and then, do a marketing launch later when we have market validation.

| Release | Launch |
| ------- | ------ |
| PM Led | PMM Led |
| New features can ship with or without marketing support | Launch timing need not be tied to the proximity of when a feature was released |
