---
title: "Improve Cycle Time"
description: "Faster time to market and shorter cycle times are a major challenge that is faced by development teams in every industry."
---
## Overview

Faster time to market and shorter cycle times are a major challenge that is faced by development teams in every industry.

### 1- Cycle Time - Improve IT responsiveness to business demand

1. What challenges do I (VP Apps) face?
   1. **Meeting the demand from the business to deliver new capabilities**, enhancements, bug fixes, and patches needed to remain competitive.  We lack the capacity to do all the work and always have to prioritize which thing we will work on.   The business thinks we're too slow and can't respond fast enough.  **They want it all, and they want it now.** They think our projects are simply too expensive.
   1. We have **constraints and bottlenecks** that create project conflicts, causing project flows to stop and wait for key resources (environments, SMEs, etc.)
   1. **Bureaucracy (manual handoffs and processes between teams) slows us down** and prevents us from doing the 'real work' of shipping code.
   1. **Quality - we're swamped fixing defects, dealing with incidents** (support), and can't pay down our technical debt.

1. What does it look like today (problems faced)?
   1. **Unhappy business leaders, unhappy customers**
   1. **Rework and loss of productivity** because teams cannot collaborate with each other
   1. The **backlog of high priority business features** waiting to be implemented

1. What are the negative consequences to the business?
   1. **Lost revenue and opportunities** - inability to react fast to changing market needs
   1. **Cost and schedule overruns**
   1. **Build up of technical debt** - example: unresolved vulnerabilities and defects

1. What does it look like if a magic wand were to solve it today?
   1. **Business demand to meet customer needs quickly delivered**
   1. Teams collaborate and deliver **without conflicts**
   1. The **backlog of business demand is both manageable and acceptable** for our business partners/customers.

1. What would be the positive outcomes for the business?
   1. **Faster response time** and **ability to deliver to changing market** needs
   1. Projects delivered **on time and budget**
   1. Developers spend more time delivering **new functionality** than fixing defects

1. What capabilities are required to make this happen?
   1. Development projects/teams have **capacity** to pick up new requirements, code, test and deliver, meeting the business demand without adding to the backlog.
   1. The ability for **all teams (dev, test, security, ops) to work together on same project deliverables** at the same time with a common view
   1. All SDLC capabilities work together - no need to stitch together different tools freeing up developers time to focus on delivering features

1. How would you measure success (metrics)
   1. **Cycle time**  (the time from when a new feature is requested to when it is delivered)
   1. Reduction in number of projects delayed/stalled
   1. Number of engineer **hours spent on new features versus** the integration and maintenance of toolchain

1. How does GitLab help solve the problem?
   1. **Integrated project management, SCM and robust automation** enable development teams to rapidly move from issue to code to test.   GitLab's CI/CD enables teams to rapidly test each of their changes and then move those changes into testing environments using containers and Kubernetes.
   1. **Integrated collaboration and built-in workflow between teams**
   1. **Single application for the entire SDLC** - no need to integrate 9+ tool categories

1. Why are we better than the competition?
   1. **Only GitLab is a complete DevOps platform, delivered as a single application that enables teams to collaborate, share and deliver software.**
   1. GitLab has 2/3 market share in the self-managed Git market
   1. GitLab is not only the industry-leading CI solution (per Forrester), but our CI is closely coupled to how the project management, source code management, testing,

1. What are the proof points that prove this?
   1. Customer stories/case studies
      1. [Ticketmaster - accelerated to weekly releases](https://about.gitlab.com/blog/2017/06/07/continuous-integration-ticketmaster/)
      1. [26x faster DevOps cycle at Axway](https://about.gitlab.com/customers/axway/)
      1. [Paessler AG switched from Jenkins to GitLab and ramped up to 4x more releases](https://about.gitlab.com/customers/paessler/)

   1. Analyst reports
      1. Forrester has evaluated GitLab as a Leader in Continuous Integration in The Forrester Wave™: Continuous Integration Tools, Q3 2017 report.
      1. Forrester has evaluated GitLab as a strong performer for VSM capabilities on top of its end to end DevOps capabilities.
      1. Gartner Peer Reviews - Customer's Choice (Applications release orchestration)
      1. IDC recognized GitLab as a top 3 innovator in Agile Code Development Technologies for 2018.

   1. Industry Awards
      1. G2 Crowd LEADER: https://www.g2crowd.com/products/gitlab/reviews
      1. Axosoft: GitLab is giving GitHub a run for its money! GitLab climbed the ranks 4 spots and overtook GitHub for the first year.

   1. Other assets?
      1. https://about.gitlab.com/why
      1. Whitepaper: SCALED CONTINUOUS INTEGRATION & DELIVERY https://page.gitlab.com/rs/194-VVC-221/images/gitlab-scaled-ci-cd-whitepaper.pdf
      1. GitLab and Agile Project Management
      1. https://about.gitlab.com/topics/devops/reduce-devops-costs/
      1. What is DevOps
      1. Starting and Scaling DevOps https://about.gitlab.com/resources/scaling-enterprise-devops/
      1. Whitepaper: on the Plan stage (currently in design and will be published ASAP)
