---
title: Market Insights
---

## Market Insights

## Market Insights at GitLab

Market Insights is a function of the Market Strategy & Insights team in Product Marketing.

*What is the Market Insights Program?*

We are a business partner who:

- Provides deeper market knowledge and understanding, clarity through fresh perspectives, and recommendations for effective business decision-making (innovation initiatives, pricing, messaging, benchmarking, etc.)
- Interprets data in narrative form that adds value and/or incites specific action
- Uses a wide range of data streams and a multi-disciplinary approach to identify near and long-term (1-3 years) growth and innovation strategies as well as a clear path to implementation
- Constantly searches for the "Why/What next?" for the company

*Questions We Seek to Answer:*

- What business-level objectives do enterprise customers need to satisfy? How does this translate into desired product functionality?
- What is the next industry analyst category we need to create/influence? What is the next big thing after the DevOps Platform Era?
- What do enterprise customers really value? Are there areas beyond DevOps where we can play?
- What might enterprise customers want in the future? How are market needs/trends evolving?
- To what extent are customers getting this need fulfilled from GitLab? Do we currently deliver it? (Is it on the roadmap? Should we add it?)
- How can we expand enterprise customer usage of GitLab?
- What adjacent audiences/markets can we identify/address?
- Which levers can we pull to improve product performance and perception relative to competitors?

## Mission of the Program

*To identify, qualify, and activate new avenues of pursuit and profitability for GitLab (range: 1-3 years)*

Our big picture:

**ELEVATE:** We seek to grow our value proposition beyond benefits/features--or even value drivers + use cases--to enable our customers' business outcomes

**IDENTIFY & ARTICULATE:** We look to leverage research & insights to identify [blue ocean strategy](/handbook/company/strategy/) opportunities

**OPERATE:** We will function as the company's think tank, helping GitLab to become our customers' recognized and essential catalyst for success

## How Our Work Supports the Organization

Deliverables that feed into and/or support the needs of other GitLab functions:

- New market identification & use case expansion / Blue Ocean Strategy thinking
- Industry vertical identification, prioritization & planning for implementation
- Research (support primary/ lead secondary) on current and future Enterprise IT trends
- Thought leadership speaking & content (whitepapers, web pages, case studies, conference presentations, sales enablement sessions, and executive presentations)
- Determining new opportunities among existing clients, and participating in new business initiatives
- Collaboration with GTM leaders in strategic planning and investment efforts
- Industry analyst briefing participation & inputs
- Regular Market Insights Team briefings

*How can Market Insights benefit your team?*

Market Insights deliverables can be used to (and/or augment your efforts to):

- Find new revenue sources
- Ensure messaging is reaching the precise customers for which it was tailored
- Develop marketing campaigns and pricing strategies
- Measure current performance against market potential
- Monitor brand awareness and customer sentiment
- Learn how our target customers actually use GitLab  on a daily basis, as well as their thought process during the buying process
- Understand what draws businesses to purchase from our competitors
- Create customized interactions or predict future actions using previous buying patterns or behaviors

## Market Insights Responsibilities

- Conduct research on current and future Enterprise IT trends through written reports, surveys, interviews and interactions with market analysts, industry conferences, self-study, and interactions with our customers to develop key insights for GitLab
- Help GitLab develop a deep knowledge and understanding of enterprise buyers including their challenges and goals that help them drive success for their companies
- Assess the DevOps ecosystem to distill the trends that influence GitLab's addressable market
- Contribute to a consumable deliverable (in-person discussion, presentation, written report)
- Evaluate, analyze and present research results in a consumable and actionable format (whitepapers, web pages, case studies, conference presentations, sales enablement sessions, and executive presentations)
- Help build and grow GitLab as a thought leader in the DevOps space by translating market insights into actionable recommendations for Product investment and GTM
- Participate and help prepare for industry analyst briefings as required
- Collaborate with GTM leaders (e.g. Sales, Channel, Sales Ops & Strategy) in strategic planning and investment efforts

## The Market Insights Process & Potential Market Approaches

**METHODOLOGY**

1. **Research & Data Gathering:** Collect information and data points, conduct and lead research, and build internal and external relationships to determine priorities and support the program.
1. **Analysis:** Synthesize and correlate data to develop fresh perspectives and innovative concepts.
1. **Validation & Iteration:** Incorporate feedback into insight, recommendations, and deliverables. Adjust research direction as necessary.
1. **Develop & Present Deliverables:** Translate insights and recommendations into consumable publications.
1. **Create Insights & Recommendations:** Distill insight into actionable ideas.

**RESEARCH PROCESS:**

1. **Topic identification** (internally decided or by stakeholder request)
1. **Determine required business objective**
   - Research--primary or secondary (technology/market/trend/topic/industry/vertical/solution or use case, user or persona, etc.)
   - Data review & interpretation with recommendations
   - Customer/prospect call participation
   - Event speaking
   - Thought leadership content creation/review
   - Other
1. **Articulate the WHY this deliverable is needed (problem statement).** What is currently happening? What is the pain that is being experienced and who is experiencing it? Why now? What will happen if the status quo continues?
   - What is your business objective and underlying rationale for this research?
   - Define the questions that must be answered

   Alternatively, is there an emerging technology or solution that we need to explore? What could the intersection of the tech/solution and the GitLab proposition be? Is this tech/solution being used (or could it be used) by our current customers or by potential, non-traditional GitLab users?

1. **Create the hypothesis** - Develop an explanation, argument, or analytical supposition about the topic.
1. **Create the appropriate issue(s)/epic(s) and link to source materials and related issues.**
1. **Data gathering from appropriate sources**: Collect information and data points, conduct and lead research. Sources include but are not limited to:
   - Primary or secondary research (e.g. IDC or Forrester we commission)
   - Social media and SEM analytics (e.g. [HackerNews](https://news.ycombinator.com/), LinkedIn, internal reports from SEO/SEM team)
   - Mainstream media and industry articles / reporting (Wall Street Journal, Washington Post, New York Times, [BBC News](https://www.bbc.com/news), [DevOps.com](https://devops.com/category/blogs/), Government Executive Media Group publications, etc.)
   - Market growth statistics (from industry analysts, DevOps media sources)
   - Channel / partner input
   - Internal Sales trends & reports
   - Sales feedback and QBRs
   - Customer meetings, calls & Chorus, SFDC
   - Analyst publications, conversations & presentations (e.g. Gartner, Forrester, IDC, 451 Research, etc.)
   - Competitive intelligence reports
   - CAB (product & C-level) feedback
   - Peer review comments (e.g. [G2](https://www.g2.com/products/gitlab/reviews#survey-response-5271767))
   - Wider future market trends and tech & business-focused reports from industry leaders (e.g. Accenture, Deloitte, McKinsey, HBR, etc.)
   - Industry conferences
   - Internal collaborative issues / topic & research requests
(Please share any interesting data sources, articles, etc. we'd find helpful in the *#market-insights* Slack channel.)

1. **Analyze data:** Synthesize and correlate data to develop fresh perspectives and innovative concepts
   - Use tools from the Market Insights Tool Chest to process and analyze data, current conditions, forecasts, trends, etc. to develop strategic recommendations.
1. **Validate & Iterate:** Incorporate feedback into insight, recommendations, and deliverables.
Adjust research direction as necessary.
1. **Create Insights & Recommendations:** Distill insight into actionable ideas and suggested activities.
1. **Develop & Present Deliverables:** Translate insights and recommendations into consumable publications. Specific deliverables may include:

   - An [Innovation Play](https://gitlab.com/gitlab-com/marketing/strategic-marketing/product-marketing/-/issues/6026)
   - A business case/rationale for investment or course of action
   - A report or summary assessment
   - A discussion
   - A presentation, whitepaper, case study, sales enablement, or executive presentation
   - A speaking engagement
   - An analyst briefing

**PROCESS FOR MARKET OBSERVATION OF INDUSTRY TRENDS & EVENTS:**

1. Identify an event (virtual, webinar, in-person) for attendance or an industry deliverable to consume.
1. Register and attend or read/watch content piece.
1. Take notes with appropriate screenshots. Insert links to relevant related content/sites.
1. Add GitLab-relevant insights and recommendations.
1. Download slides and/or deliverable to the Market Insights REPORTS & PUBS folder and post the notes in the NOTES folder. Make sure to link the replay and any login credentials in the top section of the notes document.
1. Highlight any essential learnings on the Monthly Bulletin and inform stakeholders in the *# market-insights* slack channel of any action items.

**GENERAL PROCESS FOR INNOVATION ACTIVATION:**

*What market approaches might GitLab take based on the identified opportunities?*

After a topic has been researched (see "RESEARCH PROCESS") and a recommendation for the business has been identified, Market Insights will help the DRI and team with next steps for activating the recommendation. (See "POTENTIAL MARKET APPROACHES".)

Recommendations for potential market approaches based on the results of the data assessed fall on the following spectrum of activity, ranging from the easiest level of effort, *Solution or Use Case Development*, to *Innovation Play/Campaign* to *Roadmap/Feature Development* to *Category Creation* to finally the most difficult and investment-intensive, *Market/Industry Repositioning*.

Based on the most appropriate approach for the opportunity, Market Insights will provide activation assistance to ensure that recommendation activities are sufficiently ramped up and owned by the DRI/ stakeholder(s).

In certain cases, this may entail creating or supporting the development of a full business case for E-Group presentation and approvals. In other cases, some recommendations may initially be best activated in an experimental manner, allowing data to be collected that can serve as real-world proof points for further analysis and recommendation.

Based on business priorities and constraints including executive direction, level of effort, cost, time, and other factors, we may choose to:

- Create a new solution/use case
- Develop an inovation play or campaign
- Add a feature request to the roadmap
- Pursue creating a new category
- Reposition ourselves in the market

**BUYER PERSONA DEVELOPMENT PROCESS:**

1. Gather research requirements. Define anticipated usage of research deliverable (persona profile).
1. Define the buyer journey for the persona and understand all of the corresponding organizational touchpoints.
1. Define research factors/dimensions and obtain stakeholder buy-in.
1. Perform a secondary research market analysis using: publicly available materials (Google search), analyst briefings/reports/primary research results, etc. to construct an initial understanding and framework of the identified persona and to identify what is missing to complete a full persona profile.
1. Develop the survey research instrument. Review with stakeholders and the UX team to validate. If feasible, test externally in a small setting and iterate based on feedback. Use Qualtrics as the survey tool.
1. Field the survey with internal and externally obtained target audiences. Use third party vendors to provide a blind experience, if possible.
1. Perform analysis and synthesis of the survey responses.
1. Using respondents and/or third party vendors, recruit for and plan the interview portion of the study.
1. Conduct approximately (10-30) one-on-one interviews with a wide demographic of the targeted audience(s). Use Zoom and record the calls. Note: It is important to obtain written permission to record in advance from the participants. Email is sufficient; however, ensure a double opt-in and add a line in that confirmation that they "may withdraw their consent" by informing you via email "at any time."

   Resources:

   - [Buyer persona discussion/interview guide](https://docs.google.com/document/d/1-7LO3rrvJj6fGojU2Q_KIA1u62N9ejSo1__jCeNgCKw/edit#)
   - [Buyer Persona Interview Summary Template](https://docs.google.com/document/d/1en9tLz1yQ2UnXPSGxgU2C7EfzsM0N52lTZIj41jHILU/edit)
   - [Market Insights Buyer Persona Interview Recording Consent Form Request](https://gitlab.com/gitlab-com/legal-and-compliance/-/issues/971)

1. Perform analysis and synthesis of the interviews.
1. Optional: Conduct messaging research interviews to determine how specific personas relate to products/branding/messaging, validate research from the first round of interviews, and fill in any gaps.
1. Create the persona profile.

   - Add to the [Product Marketing Buyer Persona Matrix](https://docs.google.com/spreadsheets/d/1YcMU4JfqEAtF9YiraJJgV2Y2sAXLmGQi0qePsLjuZPU/edit#gid=721271483)
   - Use an online tool (E.g. [Hubspot](https://www.hubspot.com/make-my-persona) ) to create the profile visual
   - Record a video

1. Execute an enablement plan:

    - Share via the Handbook
    - Share on Slack channels
    - Hold an enablement session for Marketing/Sales

**BUYER PERSONA INTERVIEW OUTREACH:**

Resources:

- [Example discussion guide](https://docs.google.com/document/d/1-7LO3rrvJj6fGojU2Q_KIA1u62N9ejSo1__jCeNgCKw/edit)
- Template for outreach to people who completed a survey and volunteered for future research opportunities:

  > Hi {name},
  >
  > At this year's `<conference>`, you kindly participated in our GitLab booth survey and indicated that you are open to further discussion on DevOps topics. Would you be willing to speak with me within the next two weeks for approximately 30 minutes regarding your DevOps work and how you are doing your job-related tasks?
  >
  > If you are interested, I'd like to set up a recorded Zoom call with you at your earliest convenience. I've provided my Calendly link below to share my availability for this important conversation. As a thank you for your time, we are offering `<incentive>`.
  >
  > Please reach out with any additional questions.*

**FOCUS GROUP (IN-PERSON) PROCESS**

1. Gather research requirements and determine objectives/topic of focus group.
1. Determine audience.
1. Create recruitment and incentive plan. Develop screener questions.

   - Recruitment sources may include:
      - Past conference attendees
      - Previous survey respondents who said they would participate in future research
      - Social media outreach
      - Booth visitors or general tradeshow attendees

1. Select moderator and co-moderator/recorder.
1. Coordinate video recording and logistics.
1. Coordinate venue.
1. Create discussion guide.
1. Develop materials to review with participants.
1. Execute recruitment plan.
   Collect the following info from recruits as we get volunteers:
   - Name
   - Organization
   - Title/Role (classify into Persona Group to attempt persona diversity)
   - Phone number
   - Email

   - Send confirmation email/text with logistics info
   - Send reminder (1) hour before session

1. Conduct session. Ensure consent forms are signed, recorded, and stored.

   - If necessary, provide [Uber gift cards ($10)](https://gifts.uber.com/) to participants (send after the session)
   - Pick up drinks and light snacks to have in the room
   - Verify TV/monitor connections for room
   - Determine needed signage
   - Assign handlers/guides (if necessary)
   - Collect addresses and sizes for swag distribution

   Things to Bring:

   - Laptop with loaded presentation of materials with connection cords
   - Include swag photo slide
   - Business cards
   - Refreshments
   - Tabletop signs for names
   - Markers
   - Extra masks (optional)
   - Printed video recording consent forms

    Sample agenda:

    - Welcome & Topic Overview

    *Our Marketing team has asked us to help them understand more about what our customers and prospective customers similar to you like, what you don't like, and how our messaging might be improved. We are having discussions like this with several groups both in person and virtually.*

    - Introductions
    Name
    Role/Title & Company
    Where you live
    If you are a current customer / user
    - Icebreaker
    What is your favorite place in the world and why?
    - Ground Rules
    - Discussion Prompts
    - Wrap Up & Thank You

1. Create transcripts (use the Rev tool).
1. Moderator and co-moderator debrief.
1. Create initial findings report and share with research team/internal stakeholders for feedback.
1. Prepare final report and post to research issue. Notify stakeholders.

## How to Engage with Market Insights

- Please join the discussion in the [#market-insights](https://gitlab.slack.com/archives/CHXUPL2EP) channel.
- View topics we are researching on our [Market Insight Research Board](https://gitlab.com/gitlab-com/marketing/strategic-marketing/product-marketing/-/boards/3593018?label_name[]=Market%20Insights)
- To create a Market Insights topic request, ask for insight into data or a report, make a request for us to join a customer call, or suggest a topic for research, please create an issue using the [Market Insights Request Template](https://gitlab.com/gitlab-com/marketing/strategic-marketing/product-marketing/-/issues/new#) in the Product Marketing project.

## Market Insights OKRs

[FY22 Q4 OKR: Enhance the Market Insights/Strategy Program to bring more Awareness to GitLab Product Positioning](https://gitlab.com/gitlab-com/marketing/corporate_marketing/corporate-marketing/-/issues/5558)

1. [FY23 Q3 Market Insights OKR 1 - Research/Data Collection at GitLab Events](https://gitlab.com/gitlab-com/marketing/strategic-marketing/product-marketing/-/issues/6491)
1. [FY23 Q3 Market Insights OKR 2 Buyer Persona Development v2](https://gitlab.com/gitlab-com/marketing/strategic-marketing/product-marketing/-/issues/6492)
1. [FY23 Market Insights OKR 3 - Q3 Big Rock - Market Segmentation Research & ICP Development](https://gitlab.com/gitlab-com/marketing/strategic-marketing/product-marketing/-/issues/6493)
1. [FY23 Q3 OKR 4 - Q3 Program Improvement - Continuing Development of Methodology/Processes](https://gitlab.com/gitlab-com/marketing/strategic-marketing/product-marketing/-/issues/6494)

## How We Measure Our Results

- Number of Product Roadmap issues and/or comments and product direction impact (narrative-driven)
- [KCG Share of Voice measurement metric](https://docs.google.com/presentation/d/1OVEZOAG8O5veRws6QE8dyjbTmyQ9LE3x/edit#slide=id.p19) targets increase 20% (baseline measure)

## Resources

- See our library of [research notes](https://drive.google.com/drive/folders/1PIUKOJCYPWPvNa-2h_r91Dz-i-4KCNSu?usp=sharing) and [recommendations](https://drive.google.com/drive/folders/1TXJrXleg2sB8qhIa5sAyqlqVAK_hljeI?usp=sharing)

- View our library of source [presentations and reports](https://drive.google.com/drive/folders/12QE97kGOfsIFbKqMMrBbwdRfew2IfyZM?usp=sharing)

## Market Insights Team

- [Traci](/handbook/company/team/#tracirobinson), Manager, Market Insights
- [Laura](/handbook/company/team/#lclymer), Director, Market Strategy & Insights
