---
title: "Product Marketing Messaging"
---

## What are the key customer problems?

Teams across the software delivery lifecycle function struggle with:

- Usage of different tools preferred by each team or individual
- Multiple integrations across the tools to make the lifecycle work
- Multiple configuration challenges
- Different work processes across teams
- Lack of common metrics across teams to measure improvements
- Sequential flow of processes and handoffs that are slow, error prone, and brittle

And they have processes which block reducing time to value, for example:

- Security reviews that are blocking until approved
- Infrastructure that has to be provisioned
- Fixed release windows
- Production teams need to manually approve releases
- legal/compliance sign offs are required
- Long testing cycles
- Separate build, QA, security, governance, and operations teams working in silos
- Hard to diagnose and time consuming to fix production failures

## GitLab value proposition

How does GitLab help solve the customer problems?

### Short single sentence

GitLab is The DevOps platform.

### Single sentence

GitLab is The DevOps platform that empowers organizations to maximize the overall return on software development by delivering software faster, more efficiently, while strengthening security and compliance.

### Short message (~50 words)

GitLab is The DevOps platform that empowers organizations to maximize the overall return on software development by delivering software faster and efficiently, while strengthening security and compliance. With GitLab, every team in your organization can collaboratively plan, build, secure, and deploy software to drive business outcomes faster with complete transparency, consistency and traceability.

For more information on messaging The DevOps Platform, please see the [DevOps Platform Message House](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/devops-platform/message-house/).

### Company overview text

The [company overview](/handbook/company/#about-us) can be found here.

### Press release boilerplate

The [press release boilerplate](/press/press-kit/#boilerplate) can be found here.

### Standard Email introduction text

GitLab makes it easier for companies to achieve software excellence so that they can unlock great software for their customers by reducing the cycle time between having an idea and seeing it in production. GitLab does this with The DevOps platform, which combines the ability to develop, secure, and operate software in a single application that is easier to use and leads to faster cycle times. GitLab is fundamentally changing the way Development, Security, and Ops teams collaborate. GitLab helps teams accelerate software delivery from weeks to minutes, reduce development costs, and reduce the risk of application vulnerabilities while increasing developer productivity. An estimated 30 million users across the globe trust GitLab to deliver great software at new speeds.

## Key messaging guidelines

### GitLab is a product and a platform

GitLab is both a product and a platform. It is a product in that it is a single application that you can buy and use. It is a platform in that it enables multiple use cases, and is a framework on which to build an unlimited number of additional use cases (because most functions are available through an API), supported by an ecosystem enablement group. Users have a fully functional product out-of-the-box, but they are not limited in extending and integrating with other systems. Other examples of products that are also platforms are: the iPhone (which didn't even have an app store when it launched) and Facebook.

While some more traditional definitions of platforms are [more limited](https://www.dictionary.com/browse/software-platform), there are other perspectives that take a broader view of the definition of platform. Specifically, Adrian Bridgewater explains the Facebook example in [this article](https://www.forbes.com/sites/adrianbridgwater/2015/03/17/whats-the-difference-between-a-software-product-and-a-platform/#5042c24056a6) and also quotes blogger Jonathan Clarks who says, "Platforms are structures that allow multiple products to be built within the same technical framework" - which, one could argue, describes GitLab very well. [Another article](https://medium.com/platform-hunt/the-8-types-of-software-platforms-473c74f4536a) by Platform Hunt, a blog that studies platform business models, outlines 9 types of software platforms. GitLab most closely resembles an interaction platform, where identity is the foundational characteristic and the platform facilitates digital interactions. In GitLab's case, those digital interactions are collaborative coding, facilitated through both MRs and Issues.

Referring to GitLab as a platform, delivered as a single application, does nothing to diminish the key competitive differentiation of GitLab, as a single application approach has [many benefits](/handbook/product/single-application).  Referring to GitLab as a platform also increases the potential CSM (total available market) for GitLab, and decreases potential confusion, as some might think that 'single application' refers to SCM only.

### Minimize Git and Git-Only related concepts when talking about the company

We want to focus on the 'The DevOps platform, delivered as a single application' message. Since "Git" is in our company name, we do not need to re-enforce that we are a Git-based SCM in our messaging. We should always default to the 'The DevOps platform, delivered as a single application' messaging, and, at a minimum, message multiple stage solutions.

### Headline copy is different than messaging

Sometimes, we will use headlines with the purpose of grabbing someone's attention on a billboard, banner ad or blog post. Headlines can be more experimental, and sometimes use different words than official messaging.  This is acceptable, as long as they are truthful and authentic. For example, our advertising headlines might be different than our value driver language. This is an appropriate use of different messaging for the purpose of engagement and experimentation.

### Messaging to avoid

1. Don't use terms like "first" and "only". They are extremely difficult to prove with evidence so they lack credibility. Additionally, our partners often have policies that explicitly forbid this type of messaging so whenever we do joint marketing (press release, event sponsorship, etc.) they ask us to change this wording.
2. Don't use the term "integrated". Yes, GitLab is an integrated product, but Atlassian can claim the same thing even though their product suite is made up of many different apps in different code bases with even the prem and cloud versions for the same app being written in different programming languages. Instead use, "single application", "built from the ground up", or "built in" to describe GitLab's integrated nature.

### Pricing tier messaging

Go to the [Pricing tier page](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/tiers/) to see [Tier Messaging](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/tiers/#tier-messaging)

### GitLab positioning FAQs

Go to the [GitLab positioning FAQ page](/handbook/marketing/positioning-faq/).
