---
title: "Continuous Delivery Message House"
---

### Messaging and Positioning

| **Positioning Statement** | Continuous Delivery with GitLab automates application delivery for DevOps engineers, Operations and Release Management Personnel via an out of the box, integrated solution to create application delivery pipelines that are consistent, repeatable and compliant. |
|------------------------|-------------------------------------------------------------------------|
| **Short Description** | GitLab's Continuous Delivery helps customers automate application deployment with repeatable and compliant delivery processes from a single application. |
| **Long Description** | As developers build code faster and organizations move towards more frequent deployments, automating the application delivery processes is crucial. Automation gives organizations better control over the deployments (what is delivered, when it is delivered, what features, who can approve etc) and allows teams to revert back to a previous state if needed. Without adequate controls, applications can become out of sync. Without adequate automation, organizations are forced to manually cobble up different tools to create a coherent Continuous Delivery pipeline. |

| **Key-Values** | CONSISTENT | EFFICIENT | COMPLIANT |
|--------------|----------------------------------------------------------|--------------|--------------|
| **Promise** | - Build repeatable application delivery processes  | - Integrated delivery pipeline to minimize manual cobbling together of tools <br> - End-to-end visibility of delivery pipeline and status | - Frictionless compliance with adequate controls to manage the application delivery process |
| **Pain points** | - Deployment is too manual <br> - Hard to maintain consistency in environments and configurations <br> - Hard to detect performance issues due to deployment and rollback  | - Manual/hard-coded processes <br> - Too dependent on other teams <br> - Team spending too much time in creating and maintaining toolset <br> - No unified view of deployment status | - Cannot determine adequately what went into a release, who approved it, was the action authorized etc |
| **Why GitLab** | GitLab provides the ability to visualize what goes into production (via [Review Apps](https://docs.gitlab.com/ee/ci/review_apps/)), what to deploy to production (via [Feature Flags](https://docs.gitlab.com/ee/operations/feature_flags.html)), who to deploy it to (via [Progressive Delivery](https://docs.gitlab.com/ee/ci/environments/incremental_rollouts.html) and deployment strategies like [Canary](https://docs.gitlab.com/ee/user/project/canary_deployments.html)), monitor performance of deployment (via [browser performance testing](https://docs.gitlab.com/ee/ci/testing/browser_performance_testing.html), performance monitoring/tracing) and rollback based on performance - all in a single application  | GitLab [Auto DevOps](https://docs.gitlab.com/ee/topics/autodevops/index.html) simplifies and accelerates delivery with a complete delivery pipeline out of the box. Simply commit code and GitLab does the rest. GitLab also provides an integrated dashboard that spans across the CI/CD pipeline status and deployment status | GitLab simplifies [compliance](https://docs.gitlab.com/ee/administration/compliance.html#compliance-features) with helping customers **define granular policies** such as who can approve MR, push to production, segregation of duties, release governance etc, **define security policies** such as license compliance, password policies, credential inventories etc, **track adherence to compliance** such as  user actions such as commits, permission changes, approval changes, logins, password changes, release evidence etc - all within a single application which allows **traceability** from deployment all the way back to code changes and requirements |
| **Customer Proof points** | Now it's so easy to deploy something and roll it back if there's an issue. It's taken the stress and the fear out of deploying into production." – Dave Bullock, [Wag!](https://about.gitlab.com/blog/2019/01/16/wag-labs-blog-post/) | - The built-in features of Auto DevOps have made our experience more rewarding and effective - [Daniel B on G2 Peer Reviews](https://www.g2.com/products/gitlab/reviews/gitlab-review-572450)<br/> - It has really helped us to shorten lead time, which has positively affected every single metric we measure - [Chorus.ai](https://about.gitlab.com/customers/chorus/) <br/> - GitLab Auto DevOps also delivered the technology component required for true CI/CD, accelerating product delivery with an end-to-end pipeline out of the box. - [ExtraHop Networks](https://about.gitlab.com/customers/extra-hop-networks/) | - During a recent audit for SOC2 compliance, the auditors said that Chorus had the fastest auditing process they have seen and most of that is due to the capabilities of GitLab - [Chorus.ai](https://about.gitlab.com/customers/chorus/) <br/> - There is no longer a need for license keys or several different logins, because of the built-in security and compliance. Software is deployed anywhere, which relieves developers localization constraints. |
