---
title: "CI Message House"
---

### Context

As a refresher, Continuous Integration empowers developers to regularly integrate code changes in small batches so they can be automatically built and tested before being merged into production. It may sound obvious to take that approach but most modern application development involves a variety of programming languages and tools that run on different platforms that makes integrations more complex.

Thinking more broadly in terms of Continuous Integration and Continuous Delivery (referencing [CI/CD](https://about.gitlab.com/topics/ci-cd/) together as one has become more common today), CI ensures software is automatically validated pre-deployment and ready for the next step in the application delivery process. CD acts as an extension of CI to automate the actual release process and gets software in a state where "it can be deployed to production at any time with the touch of a button," to reference Jez Humble's take on CD.

Below, you'll find messaging and positioning focused on the [CI use case](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/ci/) and [GitLab's CI capabilities](https://about.gitlab.com/solutions/continuous-integration/). Please feel free to provide input and help improve the content for future iterations. [Everyone can contribute](/handbook/company/strategy/#how)!

### Messaging and Positioning

| **Positioning Statement** | For developers, development leads, and DevOps roles (managers/architects) investing in CI/CD: Using GitLab for CI eliminates your need to cobble together multiple DevOps tools and removes dependencies on manual or legacy development processes by providing powerful, scalable, end-to-end automation that development teams can easily adopt to get started with CI/CD quickly. <br> <br> GitLab CI/CD is built-in to GitLab's complete DevOps platform and delivered as a single application to ensure quality code gets to production faster with the help of automation in place of tedious, manual development work. GitLab helps bridge the gap between Dev and Ops, lessens disruption to normal workflows, and helps both groups work together more efficiently. |
|------------------------|-------------------------------------------------------------------------|
| **Short Description** | CI with GitLab enables your teams to build high quality applications at-scale and speed up development through build automation, test automation, and developer collaboration. |
| **Long Description** | Driving your company through a digital transformation comes with unique business demands. You need to replace manual work with automation as much as possible throughout the entire software delivery lifecycle (SDLC), making continuous integration a requirement for any business going digital. Your development teams can't afford to add more complexity to the DevOps toolchain they maintain, and you shouldn't have to invest in laborious, manual, development work to modify an existing CI implementation to fit modern needs. <br> <br> GitLab offers a purpose-built CI solution that maximizes development time: improve your productivity, increase efficiency, and streamline workflows through built-in automation, testing, and collaboration. |

| **Key-Values** | **Efficiency** <br> Empower Dev and Ops to work better together | **Collaboration** <br> Improve visibility and communication | **Results** <br> Increase release velocity and ship reliable code |
|--------------|----------------------------------------------------------|--------------|--------------|
| **Promise** | - Bridge the gap between Dev and Ops: no more "throwing things over the wall" halting progress means teams spend their time shipping features that customers love. | - Gain faster feedback and integrate smaller changes frequently to reduce the risk of build-breaking changes. | - Faster time to market and more reliable builds mean value gets into the hands of customers sooner with a high degree of confidence in quality. |
| **Pain points** | - Manual development work and legacy approval processes that are tedious, time consuming, and unenjoyable for both dev teams and ops teams involved. <br> - Integrating different tools among multiple teams in different parts of the organization efficiently. | - Dealing with delivery bottlenecks, code breaking changes, and things like branch conflicts that are avoidable via effective collaboration. <br> - Visibility into pipelines and ongoing work across the org. | - Committing large chunks of code changes that are harder to detect and fix errors. <br> - Manual testing or maintenance tasks that take away from planned development time/work.  |
| **Why GitLab** | - GitLab's built-in CI is powerful, yet flexible, enough help Dev and Ops be at their best and work as efficient as possible. Delivering CI as a single application helps to naturally break down development silos and scale safely. | - We embrace transparency and collaboration as core value propositions and weave these principles into everything we do. No one else can say this -- even our proprietary product is shared source. | - GitLab provides modern CI capabilities that "just work" as expected. We practice what we preach to better understand what obstacles customers face so we can provide the best solutions to overcome challenges with CI. We are dedicated to rapid innovation and release new features and capabilities monthly. |

| **Proof points** | - [Goldman Sachs:](https://about.gitlab.com/customers/goldman-sachs/) improves from 1 CI feature branch build every two weeks to over a thousand per day. <br> - [Jaguar Land Rover](https://about.gitlab.com/blog/2018/07/23/chris-hill-devops-enterprise-summit-talk/) embraces CI to speed up their software lifecycle. <br> - placeholder |
