---
title: "DevOps Solution Resource: DevOps Platform"
---

**Looking for a customer-facing overview of GitLab's DevOps Platform? See the [DevOps Platform Solution](https://about.gitlab.com/solutions/devops-platform/)**

**GitLab field teams refer to this [DevSecOps Platform highspot page](https://gitlab.highspot.com/items/61f3f3d9fdce42ebbdf04f17) for latest information**

The page below is intended to align GitLab's sales and marketing efforts with a single source of truth for our go-to-market efforts around the benefits of a single DevOps Platform.

### Who to contact

| Product Marketing | Developer Advocate |
| ---- | --- |
| Saumya Upadhyaya (@supadhyaya) | [William Galindez Arias](https://gitlab.com/warias) |

**NOTE: If you are looking for messaging guidelines regarding The DevOps Platform, please visit [The DevOps Platform Message House](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/devops-platform/message-house/).**

## How to use this value play

This value play will provide an overview of the DevOps Platform solution and the pain points it addresses, outline key quenstions you can ask to assess the customer's needs and identify relevant aspects of the solution, and offer paths to other discussions of GitLab's value.

## Background

The DevOps Platform is more than just a collection of features and capabilities necessary to deliver software. It is a consciously-designed holistic solution, built to provide everything an organization needs to manage the ongoing DevOps lifecycle.

<iframe width="100%" height="500" src="https://www.youtube.com/embed/-_CDU6NFw7U" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>

### Desired business outcomes

- Increase operational efficiencies by reducing the overhead, maintenance, and context switching of a DIY toolchain.
- Deploy higher-quality software more quickly and consistently with a single application built to encompass the entire lifecycle, from ideation to production and back.
- Reduce risk by discovering vulnerabilities early in the process and enforcing consistent compliance guardrails throughout the DevOps lifecycle.
- Provide predictable cost scaling as your organization's needs evolve.
- Provide a seamless and copmprehensive single source of truth for all collaboration.

### Note: DevOps Platform vs. Single Application

While a [key technical differentiator](#key-differentiators) of The DevOps Platform is its single-application design, the *value* of that distinction is that GitLab becomes a true platform on which customers can build *business* success.

A good example of a similar phenomenon is Salesforce. Salesforce didn't simply replace point solutions for sales and marketing automation. It created a *new category* of business possibilities by providing a cloud-based unified *platform* for extracting, transforming, and utilizing customer insights. Likewise, GitLab has created a new category of solution that not only allows businesses to remove the unprofitable work of maintaining a toolchain, but also enables them to operate more effectively and collaboratively, across an expanded range of personas and use cases, by providing insights and efficiencies that no custom-built solution can match.

## Personas

### User Persona

There are two primary user personas:

1. [Devon - the DevOps Engineer](/handbook/product/personas/)
Devon assists multiple different teams with varied needs. A single DevOps platform provides a consistent and efficient development experience, eliminating the burden of supporting unique, team-specific implementations.

1. [Delaney - the Development Team Lead](/handbook/product/personas/#delaney-development-team-lead)
Delaney is responsible for communication and collaboration throughout the entire product lifecycle, and requires end-to-end visibility into work items and status to accurately estimate capacity, plan features, and coordinate with all parties. A single DevOps platform provides those services natively, allowing Delaney to access necessary information as needed, without dependencies.

### Buyer Personas

End-to-end DevOps requirements typically involve executive involvement - VP of DevOps, VP of Engineering, VP of Innovation and above.

The two primary buyer personas are:

1. [Erin - the Application Development Executive](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/roles-personas/buyer-persona/)
The consistency of a DevOps platform and the productivity gains of transparency and contextual aggregation of relevant information align to her primary goal of *predictable business results*.
1. [Kennedy - the Infrastructure Engineering Director](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/roles-personas/buyer-persona/)
For Kennedy, the most important benefit of a DevOps Platform delivered as a single application is a decreased cost-to-performance ration while enhancing security and compliance.

Both buyer personas are also secondary user personas. While their day-to-day tasks may not revolve around the DevOps lifecycle, the collaboration and broad visibility the DevOps Platform provides will offer benefit to all adjacent roles. For example, a Product Management executive may not have historically engaged with developers, but the DevOps Platform's ability to provide a value stream view of the product roadmap's execution may encourage the executive to engage more, help discover and remove blockers, and otherwise become more collaboratve.

## Discovery questions

The suggested discovery questions below are meant to help you uncover opportunities when speaking with prospects or customers who are not currently using GitLab or are only using GitLab as a point solution, and not experiencing the full value of an end-to-end platform.

Don't try to use them all—just those most relevant to your customer that will help you identify the value they need to see. Please contribute additional questions!

### Current state: Where's the pain?

1. **How far along are you in your DevOps journey?** This will scope their maturity and help you understand what success looks like. If the organization is new to DevOps, The DevOps Platform can be a guide toward DevOps best practices that helps them avoid common pitfalls as they mature. If the company is well along their journey already, they have likely encountered very specific challenges that the benefits of a single, end-to-end platform can help them overcome.
2. **What / how many DevOps tools are you using today?** Similarly, this will help scope the situation. A large number of tools will almost always equal integration complexity and sub-optimal communication among tools and teams. A very small number of tools could indicate a lack of automation or an acceptance that there are just some things they cannot do (see below).
3. **How do you involve business stakeholders in your DevOps process?** This will reveal the coordination and alignment of technology / development with business. In many cases, it will be nonexistent or strained, and the single source of truth of The DevOps Platform can help.
4. **How important are audits and compliance?** Audits are a well-understood risk with a well-documented cost, and they are one of the easiest problems for The DevOps Platform to address. The presence of a strong audit/compliance culture can often indicate a desire for business stakeholders to gain visibility into DevOps / software production practices—something a DevOps Platform can enable.
5. **Can you predict your tool costs 2-3 years out?** Since GitLab provides an end-to-end solution, it offers extremely predictable cost scaling, regardless of additional features activated, and its variety of deployment options provides additional future-proofing, even if infrastructure needs change.

### Future state: Where would you like to be?

1. **In an ideal world, what would collaboration look like in your organization?** In addition to spelling out success criteria, this can help identify companies who may not be thinking big enough because they aren't aware that a better option exists.
2. **Are there things you'd like to do with DevOps but complexity is holding you back?** This is a more explicit version of the question above, generally suitable for companies that are further along their DevOps journeys.
3. **What if your security teams, business stakeholders, and others had access to all the information they needed on-demand?** This paints a very clear picture of both the benefits of collaboration and the extent to which a DevOps Platform can broaden engagement beyond developers and operations. It can reveal a desire to get more people included in the conversation.
4. **What if you could track all your discussions, the code changes that resulted from them, the performance and security impact of those changes, and all the collaboration around them--in one place, automatically?** This is similar to the question above, but more appropriate for a compliance-minded or frequently audited organization.
5. **What would you do if you could reclaim the time you spend integrating and maintaining your DevOps toolchain?** This provides the customer an opportunity to discuss what true success would look like if given the opportunity to rise above task work. This is the kind of transformational success a DevOps Platform can enable by freeing resources to work on more business-productive value.

## Potential Objections

**I don't need "all that" -- I have very specific / limited needs**

This objection is most common with organizations just starting their DevOps journey. They have a specialized need (frequently, Continuous Integration, as that is the most common starting point after Source Code Management), and the market is full of specialized tools speaking to their current challenge.

The desire to avoid "boiling the ocean" is natural. The solution is to educate the organization about what DevOps *can* be, when embraced fully. Take a step back and ask what the organization would like to chage about software development and delivery on a *business* level. Do they want to be more responsive to market shifts? Do they want to increase product quality? Do they want to remain compliant while increasing velocity? With those business goals in mind, work them through the value of an end-to-end, fully automated solution, then examine the individual steps (for example, adding security scans to CI jobs, or aggregating and normalizing log data from multiple tools for audit reporting) it would take to get there.

Once the organization understands the end goal it wants to achieve and the compelxity necessary to fully realize that goal, the benefits of a platform become obvious. GitLab provides an end-to-end solution in a single application, allowing customers to activate new functionality as they are ready to broaden their DevOps footprint--without having to cobble together tool after tool.

**I don't want to rip-and-replace my existing tools**

As an all-in-one solution, it's easy to see how someone might assume GitLab requires customers to go "all in." While any customers do just that, most others adopt GitLab gradually. Many spin up new projects and teams on GitLab, while leaving others as is until they reach the end of their lifecycle. Others may migrate a portion of their existing projects to GitLab (for example, SCM and CI), while leaving other aspects of their projects to existing tools (for example, they might leave issues in Jira or continue to use a different security scanner).

GitLab fully supports coexistence with other tools. Since the DevOps Platform provides an end-to-end solution out of the box and our unified data store provides increasing value and visibility with broader usage, most customers eventually see the benefit of moving to a full-GitLab implementation eventually, but there is no need to adopt the entire platform if not desired.

**You can't be best at everything / I don't want to compromise**

By GitLab's own admission, [some aspects of the DevOps Platform are more mature than others](https://about.gitlab.com/direction/#maturity). Customers naturally want the best of everything, so the possibility of "missing out" is very much on their minds when considering solutions. In these cases, work with the customer to lay out their business needs and the tradeoffs they're making to integrate a given point solutions.

For example, if the customer is focused on a specific project planning solution, find out whether there are any specific must-have features that GitLab simply lacks. If that is truly the case, integrating that specific tool with the remainder of GitLab may be the best course of action as our functionality matures. On the other hand, if a solution is considered more mature for reasons that are irrelevant to the user or there is a different approach within GitLab that can meet the same business needs, the network effect of a DevOps Platform and the simplicity of maintaining it are more than enough reason to switch. In either case, the GitLab DevOps Platform can streamline and simplify the remainder of the customer's lifecycle.

**We've built a system that's optimized for our business**

More often than not, this objection reflects a desire to "not lose all the work we've put in" more than it does any unique business needs. With a DevOps Platform, businesses can focus their resources on differentiation that matters to the bottom line--the products and services organizations deliver to their customers. Work with customers to identify the costs (including staffing and opportunity costs) of building and maintaining their own toolchain (assets like the [Forrester Total Economic Impact report](https://about.gitlab.com/resources/study-forrester-tei-gitlab-ultimate/) can help start the conversation), then help them understand the customer value they could be generating if those resources were focused toward business goals instead of infrastructure.

**I don't want to retrain**

All change requires some amount of learning, but it's important to remember that training is never a "one and done," but an ongoing effort. All tools evolve, and a multi-tool toolchain with custom integrations will require ongoing training for each link in that chain. In contrast, the GitLab DevOps Platform has a single user interface, with a single, unified data store, and a single permissions model. Ramp time for GitLab is dramatically shorter than it would be for a bespoke toolchain, and ongoing training is also far simpler and faster. A common user experience also facilitates cross-functional collaboration and even career mobility within an organization.

### Relevant Market Segments

The DevOps Platform is relevant to all market segments and industries, though different aspects of the DevOps Platform will resonate with each group. The <a href="/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/devops-platform/message-house/">Message House</a> provides detailed information on segment messaging and positioning.

## Common pain points

### Operational efficiency

One common set of pain points solved by the DevOps Platform involves the inefficiency of [DIY DevOps implementations](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/devops-platform/message-house/#phase-3-do-it-yourself-diy-custom-integration). Custom toolchains are inefficient, diminishing the potential of workers who interact with it. This typically manifests in two ways.

- Productivity lost to toolchain creation and maintenance: By definition, DIY DevOps requires organizations to create and maintain a toolchain that often depends on a mix of APIs, third-party plugins, and custom code. None of the work necessary to build and maintain that toolchain produces measurable end-user value. Many organizations have tasked entire teams with toolchain maintenance, sapping resources from revenue-generating activities and, in many case, decreasing employee satisfaction by assigning less-visible, less-rewarding tasks to development and operations staff.
- Productivity lost to context switching: Even in a fully-integrated toolchain, moving from one set of tools to another creates a measurable dip in productivity, compounded by each additional tool in a toolchain. Industry experts such as Forrester have [noted the benefits of platforms in reducing this cost](https://www.forrester.com/report/accelerate-sustainable-innovation-with-platforms/RES171399) (please contact Analyst Relations for more information on this or other reports).
- Productivity lost to hard limitations: In many cases, DevOps toolchains are created by chaining together disparate tools that were never designed to work in concert, or in the ways modern organizations demand. In some cases, APIs mauy simply not offer access to necessary data, or organizations may need to embed sub-optimal workarounds into their toolchain to assemble necessary information.

### Business agility and innovation

The greater cost of operational inefficiencies is business agility.

- Visibility and metrics: If an organization cannot understand an optimize the flow of work through the Software Delivery Lifecycle, it lacks sufficient data to inform business decisions involving the creation and delivery of software products. The SDLC becomes a black box and a fulfillment blocker, rather than an agent of transformation and an input to planning for business success.
- Poor responsiveness: When a business must turn on a time to capitalize on an opportunity or respond top a competitive threat, a cumbersome toolchain or lack of automation can bog down implementation of that pivot to the point where it arrives too late.

## Key differentiators

| Differentiator | Value | Proof Point  |
|-----------------|-------------|---------------|
| **A Complete DevOps Platform delivered as a single Application** | A single application eliminates complex integrations, data chokepoints, and toolchain maintenance, resulting in greater productivity. | [DevOps Platform with GitLab](https://www.youtube.com/watch?v=2aJnWkzAwks) |
| **End-to-End Visibility** | GitLab's common data model enables end-to-end visibility and traceability throughout the DevOps lifecycle, correlating and aggregating data automatically. | [Deliver More Value and Fewer Headaches with an End-to-End DevOps Platform](https://youtu.be/wChaqniv3HI) |
| **Your software, deployed your way** | GitLab is infrastructure agnostic (supporting GCP, AWS, Azure, OpenShift, VMWare, On Prem, Bare Metal, and more), offering a consistent workflow experience - irrespective of the environment. | [Install GitLab: Supported Platforms](https://about.gitlab.com/install/) |

## Required capabilities

The DevOps Platform is more than a collection of features and capabilties—it provides synergistic business benefits by comboning those functions seamlessly and transparently. Still, the toolchain it replaces is comprised of necessary features that will be required by expected by customers.

| Market Requirement | Description | Typical capability-enabling features | Value/ROI |
|---------|-------------|-----------|------|
| 1. Agile Planning | The solution supports the planning, initiating, monitoring, controlling, closing, and measuring the value created by Agile teams and projects. | Requirements, Epics, Features, Stories, Iterations, Backlogs, Roadmaps, Boards | Allows businesses to budget for, prioritize, deliver, and assess the success of innovation initiatives. |
| 2. Source Code Management (Version Control & Collaboration) | Control and manage different versions of the application assets from code to configuration and from design to deployment. | Single sign-on, code ownership, change reviews and approvals, IP allowlist/denylist, activity stream, signed commits, branching and protected branches, diffing, merging, object storage, committer access rules, WebIDE, Geo and Geo HA, disaster recovery, project and file templates, design management, workflow automation, wiki, snippets, and [see full list](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/version-control-collaboration/#market-requirements) | Share and reuse code, prevent rework, and make reviews more efficient. Streamline reviews and collaboration around code changes. Ease compliance with approvals of code changes. |
| 3. Continuous Integration | Automate and streamline build and test to improve quality and velocity. | Build automation, test automation, pipeline configuration management, visibility & collaboration, multi-platform and language support, pipeline security, and more ([see full list](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/ci/#market-requirements)) | CI makes software development easier, faster and less risky for development teams. |
| 4. Security | Shift security left and make it relevant throughout the delivery lifecycle. | AST, DAST, IAST, license compliance, fuzz testing, load testing, real-time reporting | Test early to eliminate vulnerabilities at the source and reduce time and cost of remediation.  |
| 5. Continuous Delivery | Streamline and automate delivering and deploying code to different environments. | Progressive Delivery, Roll out scenarios, Feature Flags, Review Apps, Post Deployment Monitoring | Consistent and repeatable release processes, faster time to market and lower risk releases |
| 6. Governance, Risk Management, and Compliance | Define, enforce and report on compliance policies and frameworks | Requirements Management, Policy Management, Audit Management | Reduce risk exposure, educate developers about compliance in real-time, provide evidence of compliance to third parties. |
| 7. Incident Management | Organize multiple inputs into actionable workflows to allow the appropriate people to remedy anomalous conditions.  | Manage on-call schedules, receive notifications for triggered alerts. Triage alerts and incidents. Inform stakeholders of status. | Increase customer satisfaction and application uptime by ensuring the simplest path to resolution. |
| 8. Extensibility | Extend the system to work with business applications, external data sources, and legacy point solutions.  | Webhooks, APIs | Customize DevOps platform to any workflow or business need, adopt end-to-end DevOps incrementally |

## Key value per tier

### Premium

Generally, the more of the GitLab application in use, the greater the value of the Platform story, because there are more people in more roles contributing and accessing more data in one place. In addition to the benefits listed on the [Why Premium page](https://about.gitlab.com/pricing/premium/), there are a number of standout benefits in Premium vs. Free.

- **Substantially greater visibility** Advanced Search, Roadmaps, Contribution Analytics, burnup and burndown charts, and other visualizations make it far easier to achieve end-to-end visibility for a variety of needs.
- **Broader persona support** Features such as Epics, scoped labels, issue weights, and multiple issue assignees make Premium much more attractive as an enterprise-ready planning system, which, in turn, activates new personas such as Product Owners and Program Managers. Likewise, Auditor users and Audit Events extend the system to auditors.

### Ultimate

Ultimate supports the broadest possible range of personas, extending to Portfolio Managers with multi-level epics, and first-class support for Security and Compliance personas with role-specific dashboards and a host of other features. Ultimate offers free Guest User accounts, which can invite other stakeholders to participate in discussions at no cost.

## Proof points

### Quotes and Reviews

- "GitLab is really a full automated service covering all the stages of the project life cycle" [Ahmed K., G2](https://www.g2.com/products/gitlab/reviews/gitlab-review-4479054)
- "Best Code Collaboration Platform For Software Engineering Teams" [Sujay K., G2](https://www.g2.com/products/gitlab/reviews/gitlab-review-4608699)
- "GitLab : A professional collaboration tool" [Alay S., G2](https://www.g2.com/products/gitlab/reviews/gitlab-review-4449460)

### Analyst Research

In their [Market Guide for DevOps Value Stream Delivery Platforms](https://page.gitlab.com/resources-report-gartner-market-guide-vsdp.html), Gartner's Strategic Planning Assumption was:

**"By 2024, 60% of organizations will have switched from multiple point solutions to value stream delivery platforms to streamline application delivery, up from 20% in 2021."**

<sub>[Market Guide for Value Stream Delivery Platforms](https://page.gitlab.com/resources-report-gartner-market-guide-vsdp.html), Manjunath Bhat, Thomas Murphy, Daniel Betts, Chris Saunderson, Hassan Ennaciri, Joachim Herschmann, 18 October 2021</sub>

<sub>Gartner does not endorse any vendor, product or service depicted in its research publications, and does not advise technology users to select only those vendors with the highest ratings or other designation. Gartner research publications consist of the opinions of Gartner's research organization and should not be construed as statements of fact. Gartner disclaims all warranties, expressed or implied, with respect to this research, including any warranties of merchantability or fitness for a particular purpose.</sub>

GitLab believes this indicates that the market for a DevOps platform delivered as a single application will grow much faster than the DevOps market as a whole.

### Case Studies

- [BI Worldwide](https://about.gitlab.com/customers/bi_worldwide/) removed technology barriers to focus on building microservices.

> One tool for SCM+CI/CD was a big initial win. Now wrapping security scans into that tool as well has already increased our visibility into security vulnerabilities. The integrated Docker registry has also been very helpful for us. Issue/Product management features let everyone operate in the same space regardless of role.
>
> Adam Dehnel, Product Architect, BI Worldwide

- [Glympse](https://about.gitlab.com/customers/glympse/) consolidated ~20 tools consolidated into GitLab and remediated security issues faster than any other company in their Security Auditor's experience

>Development can move much faster when engineers can stay on one page and click buttons to release auditable changes to production and have easy rollbacks; everything is much more streamlined. Within one sprint, just 2 weeks, Glympse was able to implement security jobs across all of their repositories using GitLab's CI templates and their pre-existing Docker-based deployment scripts.
>
>Zaq Wiedmann, Lead Software Engineer, Glympse

- [Goldman Sachs](https://about.gitlab.com/customers/goldman-sachs/) improves from bi-monthly builds to over a thousand per day

> GitLab has allowed us to dramatically increase the velocity of development in our Engineering Division. We believe GitLab's dedication to helping enterprises rapidly and effectively bring software to market will help other companies achieve the same sort of efficiencies we have seen inside Goldman Sachs. We now see some teams running and merging 1000+ CI feature branch builds a day!
>
> Andrew Knight, Managing Director, Goldman Sachs

## Competitive comparisons

Amongst the many competitors in the DevOps space, few provide the scope to call themselves a platform, and none have been architected fromt he ground up as a single application.

When viewed through the lens of "the most comprehensive suite of end-to-end functionality provided in a single solution," the nearest competitor is Microsoft's [Azure DevOps]. Microsoft continues to build toward the same vision with [GitHub](https://about.gitlab.com/competition/github/), as well.

### Industry Analyst Relations (IAR) plan

- The IAR Handbook page has been updated to reflect our plans for [incorporating Use Cases into our analyst conversations](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/analyst-relations/#how-we-incorporate-use-cases-into-our-industry-analyst-interactions).
- For  details specific to each use case, and in respect of our contractual confidentiality agreements with Industry Analyst firms, our engagement plans are available to GitLab team members in the following protected document: [IAR Use Case Profile and Engagement Plan](https://docs.google.com/spreadsheets/d/14UthNcgQNlnNfTUGJadHQRNZ-IrAe6T7_o9zXnbu_bk/edit#gid=1124037301).

For a list of analysts with a current understanding of GitLab's capabilities for this use case, please reach out to Analyst Relations via Slack (#analyst-relations) or by submitting an [issue](https://gitlab.com/gitlab-com/marketing/product-marketing/issues/new) and selecting the "AR-Analyst-Validation" template.

## Professional Service Offers

GitLab offers a [variety of pre-packaged and custom services](https://about.gitlab.com/services/) for our customers and partners. The following are service offers specific to this solution. For additional services, see the [full service catalog](https://about.gitlab.com/services/catalog/).

- [DevOps Fundamentals Training](https://university.gitlab.com/courses/gitlab-devops-fundamentals) (all stages of the DevOps lifecycle)
- [GitLab CI/CD Training](https://about.gitlab.com/services/education/gitlab-ci/)
- [Integration Services](https://about.gitlab.com/services/implementation/integration/ )

## Resources

### Presentations

- [GitLab Enterprise DevOps Platform Customer Deck](https://docs.google.com/presentation/d/1vtFnh8DU6ZZzASTHg83UrhM6LJWqo5lq9mJDAY2ILpw/edit)

### DevOps Platform videos

- [Deliver more value with fewer headaches using an end-to-end DevOps platform](https://youtu.be/wChaqniv3HI)
- [Benefits of a single application](https://www.youtube.com/watch?v=MNxkyLrA5Aw)
- [GitLab in 3 minutes](https://www.youtube.com/watch?v=Jve98tlZ394)
- [Auto DevOps Click Through Demo Video](https://youtu.be/V_6bR0Kjju8?t=315)

### Clickthrough & Live Demos

- [All Marketing Click Through Demos](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/demo/#click-throughs)
- [All Marketing Live Demos](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/demo/#live-instructions)

### Message House

*The [message house](message-house/) provides a structure to describe and discuss value and differentiators for the value play.*

## Technical Resources for Solution Architects

Sometimes customers and prospects have unique requirements, often around using an preferred scanning tool to integrating with some other part of their tool chain. If you or your customer has a third party they'd like to see integrated into GitLab, send them to the [partner integration page](https://about.gitlab.com/partners/technology-partners/integrate/) for instructions. While GitLab can be a single platform to meet all of their needs, often they need an on-ramp to help them transition or proof of the integration before purchasing GitLab. The resources below may help.
**NOTE:** Please do not use these to put GitLab in the position where users expect us to support a 3rd-party product integration that we do not [officially recognize](https://about.gitlab.com/partners/technology-partners/).
