---
title: "DevOps Platform Message House"
---

## Overview

In the spirit of [Command of the Message](/handbook/sales/command-of-the-message/), this page will help GitLab team members understand and define the GitLab DevOps Platform solutions to customers in an authentic, consistent manner than differentiates us from our competitors. It includes:

- [Historical context of the market evolution](index.html#the-four-phases-of-devops)
- [General messaging guidelines](index.html#messaging-guidelines)
- [Third-party validation and perspective](index.html#supporting-data)
- [Segment-specific messaging suggestions](index.html#segment-messaging-and-positioning)

**NOTE: If you are searching for approved copy to describe The DevOps Platform, please skip ahead to [Messaging Guidelines](index.html#messaging-guidelines).**

## The Four Phases of DevOps

As [DevOps](https://about.gitlab.com/topics/devops/) has evolved, so has its complexity. This complexity is driven by two factors:

1. Organizations are moving from monolithic architectures to microservices architectures. By using microservices, teams can work independently and move faster.
1. As DevOps matures, organizations need more and more DevOps tools per project.

The result of more projects and more tools per project was an exponential increase in the number of project-tool integrations. This necessitated a change in the way organizations adopted DevOps tools. This evolution took place in four phases.

### Phase 1: Bring Your Own (BYO): Disparate tools

In the *Bring Your Own DevOps* phase, each team selected its own tools. This approach caused problems when teams attempted to work together because they were not familiar with the tools of other teams.

### Phase 2: Best In Class (BIC): Standardized toolchain

To address this, organizations moved to the second phase, *Best in Class DevOps*. In this phase, organizations standardized on the same set of tools, with one preferred tool for each stage of the DevOps lifecycle. It helped teams collaborate with one another, but the problem then became moving software changes through the tools for each stage.

### Phase 3: Do It Yourself (DIY): Custom integration

To remedy this problem, organizations adopted "Do It Yourself DevOps," building on top of and between their tools. They performed a lot of custom work to integrate their DevOps point solutions together; however, since these tools were developed independently without integration in mind, they never fit quite right. For many organizations, maintaining DIY DevOps was a significant effort and resulted in higher costs, with engineers maintaining tooling integration rather than working on their core product.

### Phase 4: DevOps Platform: Single application

A platform approach was needed to improve the team experience and to improve business efficiency. GitLab, *The DevOps Platform*, replaces DIY DevOps, allowing visibility throughout and control over all stages of the DevOps lifecycle.

By empowering all teams - Software, Operations, IT, Security, and Business - to collaboratively plan, build, secure, and deploy software across an end-to-end unified system, GitLab represents a fundamental step change in realizing the full potential of DevOps. The DevOps Platform is single application powered by a cohesive user interface agnostic of self-managed or SaaS deployment, built on a single codebase with a unified data store allowed organizations to resolve the inefficiencies and vulnerabilities of an unreliable DIY toolchain.

As we look ahead to software-led organizations becoming even more distributed and agile, every company will need The DevOps Platform to modernize software development and delivery. By making it easier and trusted to adopt the next generation of cloud-native technologies - from microservices to serverless and eventually edge architecture - all companies will be empowered to ship software faster, at maximum efficiency, with security embedded across their end-to-end software supply chain.

## Messaging Guidelines

| **Category Name** | The DevOps Platform |
|------------------------|-------------------------------------------------------------------------|
| **Category Definition** | A platform delivered as a single application with one user interface, a unified data store, and security embedded within the DevOps lifecycle. |
| **Category Rationale** | As every company realized they needed to become a software company to remain competitive, the DevOps industry expanded, the number and complexity of tool-project integrations within an organization expanded. This was the result of two developments in DevOps:<br><br>1. Companies moved from [monolithic architectures to microservices architectures](https://about.gitlab.com/topics/microservices/). By doing so, applications could scale independently, allowing teams to move faster.<br>2. The faster delivery of software also required companies to use more DevOps tools per project.<br><br>The linear growth of both or more projects and more tools per project led to an exponential increase in the number of project-tool integrations.<br><br>This resulted in longer cycle times and reduced productivity while increasing software vulnerability. To solve this, we need a platform to consolidate the tools that span the DevOps lifecycle. |
| **Single Sentence (Biz/Tech Leaders)** | GitLab is The DevOps Platform that empowers organizations to maximize the overall return on software development by delivering software faster, more efficiently, while strengthening security and compliance. |
| **Single Paragraph (Biz/Tech Leaders)** |GitLab is The DevOps Platform that empowers organizations to maximize the overall return on software development by delivering software faster and efficiently, while strengthening security and compliance. With GitLab, every team in your organization can collaboratively plan, build, secure, and deploy software to drive business outcomes faster with complete transparency, consistency and traceability. |
| **Single Sentence (Engineers)** | GitLab is The DevOps Platform, which combines the ability to develop, secure, and operate software in a single application that is easier to use and leads to a faster cycle time. |
| **Single Paragraph (Engineers)** | GitLab is The DevOps Platform, which combines the ability to develop, secure, and operate software in a single application that is easier to use and leads to faster cycle time. With GitLab, every team in your organization can collaborate in a single tool to manage the end-to-end development lifecycle, delivering more value faster, increasing visibility, and removing context switching.  |

| **[Key Values](/handbook/sales/command-of-the-message/#customer-value-drivers)** | Value 1: [Increase Operational Efficiencies](/handbook/sales/command-of-the-message/#customer-value-drivers)  | Value 2: [Deliver Better Products Faster](/handbook/sales/command-of-the-message/#customer-value-drivers)  | Value 3: [Reduce Security & Compliance Risk](/handbook/sales/command-of-the-message/#customer-value-drivers) |
|--------------|----------|----------|----------|
| **Promise** | **Efficiency**:<br>Maximize R&D and IT productivity. | **Velocity**:<br>Accelerate speed to market. | **Security**:<br>Compliance without compromise. |
| **Customer pain** |  Organizations waste time and resources maintaining toolchain integrations, create silos of tool-specific competencies, create "Data gaps" in integrations resulting in incomplete context and manual workarounds. | DIY toolchains limit visibility into critical DevOps data that should inform decisions. They are also unreliable and inconsistent, prohibiting organizations from executing on decisions at scale without dramatically increasing risk. | Security scanning happens too late--if at all--requiring extensive rework as developers trace vulnerabilities back to their source and repair both the vulnerable code and other code changes built upon it. |
| **GitLab Promise** | As a single application, built on a unified data source, GitLab provides a complete DevOps solution without the need to spend any resources on building and maintaining a DIY toolchain. If integrations are necessary for any reason, businesses can integrate once and have access to the entire platform. | GitLab's single application, built on a unified data source, provides a complete end-to-end view of the entire software supply chain, enabling full transparency. The lack of toolchain integrations creates a more consistent, predictable, lower-maintenance development flow. | With built-in security scanners, organizations can scan every line of code as it is committed, allowing developers to identify and remediate vulnerabilities before they are even pushed. |
| **ROI Theme** | As a single application, built on a unified data source, GitLab provides a complete DevOps solution without the need to spend any resources on building and maintaining a DIY toolchain. If integrations are necessary for any reason, businesses can integrate once and have access to the entire platform. | GitLab's single application, built on a unified data source, provides a complete end-to-end view of the entire software supply chain, enabling full transparency. The lack of toolchain integrations creates a more consistent, predictable, lower-maintenance development flow. | With built-in security scanners, organizations can scan every line of code as it is committed, allowing developers to identify and remediate vulnerabilities before they are even pushed. |
| **Product Proof** | - One system to install and maintain. - End-to-end lifecycle support from one provider. - One point of integration for external systems. - One user interface for the entire lifecycle. | - Value Stream Analytics allows you to monitor and manage the flow of work, identifying inefficiencies and blockers to value delivery. - Automatic correlation of artifacts and actions across the lifecycle--from ideation to code creation to testing, security scans, and performance impact--complete traceability. - Role-based dashboards (e.g., Security Dashboard, Epic Roadmaps) with contextual drill-downs into any level of detail | - Run static and dynamic security scans on every commit--without having to merge code. - Provide clear accountability for the introduction, remediation, and dismissal of security vulnerabilities and policy violations. - Maintain complete context by collaborating in a single system across development, operations, security, and audit/compliance. |
| **Customer Examples** | [Glympse](https://about.gitlab.com/customers/glympse/) (Replaced 20 distinct tools with GitLab), [Jasper Solutions](https://about.gitlab.com/customers/jasper-solutions/) (33-37% YoY Cost Savings, 30% reduction in cycle time, 25% increase in deployment frequency, 90-95% of projects on budget on time) | [Goldman Sachs](https://about.gitlab.com/customers/goldman-sachs/) (From biweekly builds to > 1000/day) [BI Worldwide](https://about.gitlab.com/customers/bi_worldwide/) (10X daily deployments for modernized applications, Eliminated challenges of multiple tools, logins, and user experiences) | [HackerOne](https://about.gitlab.com/customers/hackerone/)(Scanning earlier, more frequently, more economically) |

## Supporting Data

In their [Market Guide for DevOps Value Stream Delivery Platforms](https://page.gitlab.com/resources-report-gartner-market-guide-vsdp.html), Gartner's Strategic Planning Assumption was:

**"By 2023, 40% of organizations will have switched from multiple point solutions to DevOps value stream delivery platforms to streamline application delivery, versus less than 10% in 2020."**

<sub>[Market Guide for DevOps Value Stream Delivery Platforms](https://page.gitlab.com/resources-report-gartner-market-guide-vsdp.html), Manjunath Bhat, Hassan Ennaciri, Chris Saunderson, Daniel Betts, Thomas Murphy, Joachim Herschmann, 28 September 2020</sub>

<sub>Gartner does not endorse any vendor, product or service depicted in its research publications, and does not advise technology users to select only those vendors with the highest ratings or other designation. Gartner research publications consist of the opinions of Gartner's research organization and should not be construed as statements of fact. Gartner disclaims all warranties, expressed or implied, with respect to this research, including any warranties of merchantability or fitness for a particular purpose.</sub>

GitLab believes this indicates that the market for a DevOps platform delivered as a single application will grow much faster than the DevOps market as a whole.

<iframe width="100%" height="500" src="https://www.youtube.com/embed/-_CDU6NFw7U" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>

## Segment messaging and positioning

Below are summaries of the value different segments will find in the DeOps Platform use case and suggestions for how to position GitLab to best expain those values.

### SMB

All SMBs are dealing with some form of resource constraints as they grow. A DevOps platform will provide a growth path with the smallest amount of friction as they grow into the company they aspire to become.

Some SMBs will have a very clear idea of what they want from a DevOps solution, while others are just starting on their journey. For businesses in the former category, a DevOps platform provides a guide toward a productive solution that anticipates their needs as they grow, supported by evidence from successful companies of all sizes using the same solution, including some of the world's largest companies. A DevOps platform can guarantee minimal headaches from problems they have yet to encounter.

SMBs who are just starting with DevOps have likely already begun the process of integrating multiple tools, and are likely already resource constrained. These organizations are very aware of the time they waste on maintaining and integrating point solutions, and they would probably love to focus on more productive work.  They will eventually need to know that a DevOps platform can both meet their criteria and stand up to point solutions--particularly in Source Code Management and Continuous Integration. As with the other category of SMBs, customer evidence from relevant larger companies will be important third-party proof points.

### Mid-Market

Mid-Market companies are large enough and mature enough to have experienced the same challenges as larger enterprises, and much of the messaging mentioned in the Enterprise entry will generally resonate. Efficiency is essential, freeing up resources to develop more value, more quickly. Collaboration across the organization is also critical.

The key difference between the Mid-Market and Enterprise segments is the growth imperative. Mid-Market businesses are highly oriented toward growth and innovation, as they cannot yet compete on pure scale with larger competitors, but are large enough to be outmaneuvered by nimble startups. As such, they are very interested in moving quickly, but also wary of lock-in or poor scalability that could ultimately cap their upward or outward growth. To these businesses, proof points from larger businesses--particularly those of competitors or those from similar industries--are extremely helpful. The ability to adopt a platform on the fly--one component at a time, as opportunities arise--will be well-received.

### Enterprise

Enterprises will already be familiar with the pains of the multi-product integration "toolchain tax." Those who have been pursuing a more aggressive DevOps strategy will likely be spending a large amount of their resources building and maintaining more than one toolchain, while others may have scaled back their ambitions because of complexity and cost.

In either case, the efficiency of a single, end-to-end platform will resonate across all roles. Allocating fewer resources to maintenance and integration means less waste and more focus on productive, interesting outcomes. Additionally, a DevOps platform allows enterprises to improve the *quality* of the work they do by increasing visibility and collaboration and encouraging a deeper engagement in all parties with the SDLC. Planners and business stakeholders can trace their requirements and suggestions all the way to their business impact after deployment, while developers and operations and security professionals can understand and contribute to the context around business discussions. Security, compliance, and audits have complete traceability back to the source of irregularities.

Single-platform visibility and collaboration dovetails nicely with transformation initiatives, as well. As one platform for end-to-end DevSecOps, GitLab can become the engine of transformation from project- to product-based thinking, waterfall- to Agile-based methodologies, or other cultural and process transformations.

## Elevator pitches per segment and persona

Below are one-sentence summaries of value you can deliver to user and buyer personas to position relevant aspects of the DevOps Platform use case's value, based on the market segment of the persona's company.

### SMB

|   User: [Delaney - the Development Team Lead](/handbook/product/personas/#delaney-development-team-lead) |   User: [Devon - the DevOps Engineer](/handbook/product/personas/) |   Buyer: CTO<code>&ast;</code> |  Buyer: CIO<code>&ast;</code>  |
|--- |--- |--- |--- |
|   Receive immediate feedback on the quality, performance, and security of code as soon as you commit. Collaborate seamlessly among teams. |   Grow without having to build and support custom integrations. |   Collaborate in a single system, minimize context-switching, and increase developer productivity and focus. |   Grow without building and supporting custom integrations. Scale and manage a single system. |

*<code>&ast;</code> CTO (Dev, external focus) and CIO (Ops, internal focus) personas in development and may vary per segment.*

</div>

### Mid-Market

|   User: [Delaney - the Development Team Lead](/handbook/product/personas/#delaney-development-team-lead) |   User: [Devon - the DevOps Engineer](/handbook/product/personas/) |   Buyers: range from [Erin - the Application Development Executive](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/roles-personas/buyer-persona/#erin---the-application-development-executive-vp-etc) to the CTO<code>&ast;</code> |  Buyers: range from [Kennedy - the Infrastructure Engineering Director](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/roles-personas/buyer-persona/#kennedy---the-infrastructure-engineering-director) to the CIO<code>&ast;</code>  |
|--- |--- |--- |--- |
|   Receive immediate feedback on the quality, performance, and security of code as soon as you commit. Collaborate seamlessly among teams. |   Increase reliability and eliminate ad hoc, team-based integrations. |  Collaborate in a single system, minimize context-switching and waiting, identify and remove productivity blockers, and deliver more value faster with more productive, focused developers.  |   Increase reliability and performance while you grow by eliminating custom integrations. Scale and manage a single system. |

*<code>&ast;</code> CTO (Dev, external focus) and CIO (Ops, internal focus) personas in development and may vary per segment.*

### Enterprise

<div class="panel-body">

|   User: [Delaney - the Development Team Lead](/handbook/product/personas/#delaney-development-team-lead) |   User: [Devon - the DevOps Engineer](/handbook/product/personas/) |   Buyer: [Erin - the Application Development Executive](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/roles-personas/buyer-persona/#erin---the-application-development-executive-vp-etc) |  Buyer: [Kennedy - the Infrastructure Engineering Director](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/roles-personas/buyer-persona/#kennedy---the-infrastructure-engineering-director)  |
|--- |--- |--- |--- |
|   Receive immediate feedback on the quality, performance, and security of code as soon as you commit. Collaborate seamlessly among teams. |   Increase reliability and eliminate ad hoc, team-based integrations. |   Collaborate in a single system, minimize context-switching and waiting, identify and remove productivity blockers, and deliver more value faster with more productive, focused developers. |   Increase reliability and performance while you grow by eliminating custom integrations. Scale and manage a single system. |
