---
title: "Use case: GitLab + Google Cloud"
---

#### Who to contact

| Partner Marketing | Product Marketing |
| ---- | --- |
| [Sara E. Davila](https://gitlab.com/saraedavila) | [William Chia](https://gitlab.com/williamchia) |

## The Market Viewpoint

The landscape of software development is changing. Today's users expect to interact with software applications that are always-on and accessible from every device. To keep up, businesses of all sizes that have traditionally built and managed centralized, monolithic applications are shifting to distributed cloud services. And these services are being built and run by distributed teams located all around the world. Modernizing the business through IT is a cultural and technological shift.

With all of this complexity, software teams need DevOps tooling that works together with their cloud infrastructure to enable them to become faster and more efficient, while staying secure and reliable.

Modern Trends Impacting Software Development

- **GitOps** for modern infrastructure automation,
- Business emphasis on **improving developer experience** to attract and retain the best talent and improve productivity.
- Hybrid and **multicloud**
- **Cloud native** application architectures and legacy **application modernization**
- **Digital Transformation**
- Platform Modernization
- Accerlate App Dev & Delivery
- Developing App on Edge

## Personas

### User Persona

Sam, the SRE: Sam is responsible for the uptime and reliability of the application software running on the cloud infrastructure. He interfaces with Google Cloud services directly to meet his SLA (Service Level Agreements) and SLOs (Service Level Objectives). He can work on a dedictated team of SREs or be embedded into a product/service team with developers.

[Devon, the DevOps Engineer](/handbook/product/personas/): Devon is often the Ops interface for the development team. He provides support for infrastructure, environments and integrations. Devon is fairly conversant with code and would prefer administering infrastructure via code rather than a multitude of different tools and context switches.

[Priyanka, the Platform Operator](/handbook/product/personas/#priyanka-platform-engineer):  Infrastructure management is one of the main responsibilities of the platform team. Priyanka is responsible for providing, maintaining, and operating a shared platform - either traditional or modern cloud platform - which the development teams utilize to ship and operate software more quickly.

[Sydney, the System Administrator](/handbook/product/personas/#sidney-systems-administrator): Sydney defines, maintains and scales the infrastructure and configuration for the application teams. She often receives repetitive requests on the same task. Sydney's primary motivation is to automate repetitive tasks to minimize errors and save time as well as define the infrastructure and configuration in a way that changes are tracked and to stop infrastructure changes becoming the [wild west](https://en.wikipedia.org/wiki/Cowboy_coding).

### Buyer Personas

[Infrastructure Engineering Director](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/roles-personas/buyer-persona/), Kennedy

The Infrastructure Engineering Director is responsible for building and scaling highly available environments. They frequently have the agenda of cloud initiatives and cost optimization in the organization.

[Release and Change Management Director](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/roles-personas/buyer-persona/), Casey

The Release and Change Management Director is responsible for managing complex releases from concept to delivery. The CIO may be the final decision maker or buyer, but the Release and Change Management Director has significant influence in the buying process.

## The GitLab Solution

## Messaging and Positioning

### Positioning Statement

As DevOps maturity expands, software teams are looking for solutions that unify software lifecycle from planing and development to delivery and operation. Today's market is filled with siloed tools that either aren't designed to work with cloud infrastructure or are too tightly coupled to cloud providers other than Google Cloud. Businesses choose Google Cloud for their expansive fiber network, cost efficiency, and advanced capabilities such as ML and Kubernetes. GitLab and Google Cloud have partnered to bring unified solutions with tight technical integrations gives teams confidence in a seamless experience.

GitLab and Google Cloud work better together in several ways. You can install your Self-managed instance of GitLab and GitLab Runners on Google Cloud infrastructure. You can also use GitLab CI/CD to deploy your software to Google Cloud infrastructure using either a Self-managed GitLab instance, or GitLab.com, GitLab's SaaS service (which also runs on Google Cloud.)  From Anthos and Cloud Run to Compute Engine and Kuberentes Engine, GitLab works great with an array of Google Cloud services. See the full set of GitLab joint solution capabilities with Google Cloud at [https://about.gitlab.com/gcp](https://about.gitlab.com/partners/technology-partners/google-cloud-platform/)

### Short Description

GitLab and Google Cloud provide unified solutions to develop, deliver, and operate modern software applications with speed, efficiency, and reliability.

### Long Description

GitLab is a complete DevOps platform, delivered as a single application. Google Cloud provides cloud computing services such as Anthos, Cloud Run, and Google Kubernetes Engine. Together, GitLab and Google Cloud provide unified solutions to develop, deliver, and operate modern software applications with speed, efficiency, and reliability.

From modernizing legacy applications to cloud native architectures using containers, service mesh and microservices, to operating complex distributed applications using GitOps you can trust GitLab and Google Cloud to meet your business challenges head on.

See the full set of GitLab joint solution capabilities with Google Cloud at [https://about.gitlab.com/gcp](https://about.gitlab.com/partners/technology-partners/google-cloud-platform/)

| **Key-Values** | **Speed** | **Efficiency** | **Trust** |
|--------------|----------------------------------------------------------|--------------|--------------|
| **Promise** | Speed Promise | Efficiency Promise | Trust Promise |
| **Pain points** | one | two | three |
| **Why GitLab** |  one | two| three |

## Proof Points

[General proof points](/handbook/sales/command-of-the-message/proof-points/) and [Customer Recognition](https://about.gitlab.com/customers/marketplace/)

### Quotes and reviews

### Case Studies

## Resources
