---
title: "Version Control & Collaboration Message House"
---

| **Positioning Statement** | Application development and DevOps is fast and iterative, making it essential that teams can rapidly collaborate and iterate on new features and deliver business value. They must avoid working in silos which creates complex integration conflicts and constantly broken builds. GitLab is a comprehensive Version Control and Collaboration (VC&C) solution to deliver better software faster. A Git-based web repository that aggregates all development milestones and metadata, GitLab enables clear code reviews, asset version control, feedback loops, and powerful branching patterns to streamline software delivery. GitLab helps you deliver faster, more efficiently, and increase compliance. |
|------------------------|-------------------------------------------------------------------------|
| **Short Description** | GitLab makes sense of version control and collaboration by a seamless interface to collaborate and coordinate work, review changes, and manage delivery so team members focus on solving problems and shipping value |
| **Long Description** | Version control coordinates all changes in a software project, effectively tracking changes to source files, designs, and all digital assets required for the project as well as related metadata. Projects without version control and collaboration can easily devolve into an uncontrollable mess of different versions of tonnes of project files, hindering the ability of any software development team to deliver value. GitLab makes SCM easy assembling all critical project files and assets in one seamless interface and delivering it through a single application for the entire software development lifecycle.   |

| **Key-Values** | *VISIBILITY*  | *COLLABORATION* | *VELOCITY* |
|--------------|------------------------------------------------------------------|----------|----------|
| **Promise** | Visibility across projects, groups, epics and issues. Gain insight from aggregate dev metrics and assess gaps and bottlenecks. Analyse in detail each work flow and monitor task and feature progress | Effective, contextual and actionable communication to improve code quality. Set permissions, code owners and process approvers. Keep compliance frictionless and enable team members to push progress one commit at a time | Lightning-speed branching, automation rules for Merge Requests and CI/CD |
| **Pain points** | Development teams require a specific project file structure often dictated by the technology, architecture, domain, and goals of the project. Team leads and dev managers struggle to organize projects and teams to meet the company and leadership's expectations the most efficient way. It is not easy to connect the dots | It is difficult to collaborate and share feedback in the appropriate context and make it actionable immediately. At the same time, projects and groups require different levels of access and privileges which in turn result in a complex maze of permissions | Projects can become heavy and bloated over time with tens of thousands of files, versions, and associated metadata history, effectively making future changes and branching complex, error-prone and expensive. Lightweight projects, on the other hand, can be over-engineered easily |
| **Why GitLab** | GitLab Insights and Compliance Dashboard can aggregate and compose dashboards for Team Leads and Product Managers to capture bottlenecks, apply solutions and foster continuous improvement |  GitLab's Merge Requests and Code Quality provide the perfect canvas to manage all aspects of changing code and project assets, enabling reviews, feedback, and immediate action to improve code  | GitLab Merge Request design, automated merge approvals, issue closing, and more automate tedious tasks and allow developers to focus on shipping features |

| Proof points | |
|--------------|----------|
| | [Paessler's 90% of QA is self served](https://about.gitlab.com/customers/paessler/) thanks to immediate, contextual feedback |
| | [ESA (European Space Agency)](https://about.gitlab.com/customers/european-space-agency/) had more than 140 groups adopt GitLab |
| | [Goldman Sachs](https://about.gitlab.com/customers/goldman-sachs/) Improved from **1 build every two weeks to over a 1000/day** |
| | [Worldline](https://about.gitlab.com/customers/worldline/) spins source code repos in a matter of seconds |
| | [NorthWestern Mutual](https://youtu.be/kPNMyxKRRoM) completed a full migration to their enterprise environment in 8 months |
| | [Progressive Delivery at GitLab](https://redmonk.com/jgovernor/2019/07/10/progressive-delivery-at-gitlab/) fast iteration at GitLab dogfooding GitLab with Review Apps and short-lived branches |

*Gartner Peer Insights reviews constitute the subjective opinions of individual end users based on their own experiences and do not represent the views of Gartner or its affiliates. Obvious typos have been amended.*

>"The software is intuitive and quite easy to use. Since many software development projects require more than one person, this makes it easy to create teams and collaborate."
>
> - **Quality Engineer**, [Gartner Peer Review](https://www.gartner.com/reviews/market/application-release-orchestration-solutions/vendor/gitlab/product/gitlab/review/view/1037713)
>
>"Improves productivity of engineers by providing easy and fast ways to keep feature branches and merge them quickly and efficiently."
>
> - **Engineering Manager**, [Gartner Peer Review](https://www.gartner.com/reviews/market/application-release-orchestration-solutions/vendor/gitlab/product/gitlab/review/view/1060524)
>
>"Keeps your software projects under control. Rogue developers are kept at bay via enforced review processes and pipelines."
>
> - **Engineer**, [Gartner Peer Review](https://www.gartner.com/reviews/market/application-release-orchestration-solutions/vendor/gitlab/product/gitlab/review/view/1063180)
>
>"For managing git repositories it is the best product available right now in the market."
>
> - **Sr. Software Engineer**, [Gartner Peer Review](https://www.gartner.com/reviews/market/application-release-orchestration-solutions/vendor/gitlab/product/gitlab/review/view/1074452)
>
>"This has really aided in our ability to automate software delivery and return wasted overhead back to the pool of resources! This is a very simple to use and fast delivery tool to assist your code pipeline."
>
> - **Project Manager**, [Gartner Peer Review](https://www.gartner.com/reviews/market/application-release-orchestration-solutions/vendor/gitlab/product/gitlab/review/view/1078302)
>
>"We use this platform in our company to version our source [code] ensure they are up to date and as a backup option. It enables us build scalable and high quality products. Ease of use and compatible with most development environments."
>
> - **Sr. Software Developer**, [Gartner Peer Review](https://www.gartner.com/reviews/market/application-release-orchestration-solutions/vendor/gitlab/product/gitlab/review/view/1135664)
>
>"I appreciate its ability to run limitless. It has various features like issue tracker, protected branches and merge requests, which gives very nice experience."
>
> - **Sr. Software Engineer**, [Gartner Peer Review](https://www.gartner.com/reviews/market/application-release-orchestration-solutions/vendor/gitlab/product/gitlab/review/view/1142879)
>
>"GitLab is a very useful SCM. In our [organization] we have used it as a source code repository. We have extensively used branching and tags creation feature. As we work in a sprints, we have several sprint and feature branches."
>
> - **Lead Developer**, [Gartner Peer Review](https://www.gartner.com/reviews/market/application-release-orchestration-solutions/vendor/gitlab/product/gitlab/review/view/1144638)
>
>"GitLab is a superb source code management [provider]."
>
> - **Systems Engineer**, [Gartner Peer Review](https://www.gartner.com/reviews/market/application-release-orchestration-solutions/vendor/gitlab/product/gitlab/review/view/1194415)
>
>"Before GitLab, we used to make local copies of code or backup the code and then pass on the code through the server. But if our organization knew about GitLab from start, we would have immediately integrated with our development practises for ease of deployment."
>
> - **Software Developer**, [Gartner Peer Review](https://www.gartner.com/reviews/market/enterprise-agile-planning-tools/vendor/gitlab/product/gitlab/review/view/1016152)
