---
title: "Integrated Campaigns"
description: "GitLab Marketing Handbook: Integrated Campaigns"
twitter_image: '/images/tweets/handbook-marketing.png'
---

## Integrated Campaigns Overview {#integrated-campaigns}

The goal of a GitLab integrated campaign is to strategically land a cohesive message to a target audience across a variety of channels and offers, dependent on the goals of the campaign. Content types include a combination of blog posts, webinars, whitepapers, reports, videos, case studies, and more. Activation of the campaigns takes place in a number of marketing channels include digital ads, social, paid social, SEO, PR, email, and more.

**[Global Campaign Managers](/handbook/marketing/demand-generation/campaigns/)** are responsible for the strategizing of integrated campaigns and organizing timelines and DRIs for deliverables to execute on the campaigns.

**Questions? Please feel free to ask in the [#marketing-campaigns slack channel](https://gitlab.slack.com/archives/CCWUCP4MS) or ask in the [#marketing slack channel](https://gitlab.slack.com/messages/C0AKZRSQ5) and tag @marketing-campaigns.**

Below is a visual of the FY24 integrated campaigns and how they connect to activation in regions and across segments. [See the full visual here](https://docs.google.com/presentation/d/1O0O-d_i_24wHNjaPpnXdTTXVH0kuGHcD_YOqCt4bHQg/edit#slide=id.g2170ce436af_0_482) - GitLab Team Members Only

To understand the thought process behind our FY24 integrated campaigns structure, please review [these slides](https://docs.google.com/presentation/d/1_noCyTKTPLMdkNVmrbAbBm-F35yOlOQubkSDlj6A--o/edit#slide=id.g123a13deda8_0_405) & [recording](https://drive.google.com/file/d/1W-6-RohqhYt5p7ZH-yOmW4AHt7F5KDon/view?usp=sharing) - GitLab Team Members Only

## What is involved in an Integrated Campaign?

An integrated campaign is aligned to key go-to-market motions, decided in collaboration between marketing and sales, and built out by a [campaign core team](/handbook/marketing/campaigns/#campaign-core-teams). A [global campaign manager](/handbook/marketing/demand-generation/campaigns/) will lead the effort, working closely with the campaign core team, to develop a [campaign bundle](/handbook/marketing/campaigns/#campaign-bundles) that is then activated by the regional campaign managers [across various channels and tactics](/handbook/marketing/campaigns/#campaign-activation) in conjunction with ABM, Paid Digital, Lifecycle, Field Marketing, SDRs/BDRs, and Channel Partners.

### What is in a campaign bundle? {#campaign-bundles}

Think of a **campaign bundle** as the foundational pieces of an integrated campaign. They are used by all teams in marketing and sales to maintain a cohesive message and branding across all tactics and activities aligned to the topical campaign.

_The list below includes recommended items included in a **Campaign Bundle**, which is developed by the Campaign Core Team consisting of Campaigns, Product Marketing, Developer Advocacy, Content, Analyst relations, and Design.

To see a visual of campaign bundles, which are then leveraged in activation plans, please see [this figjam](https://www.figma.com/file/jakug8myj5tOcaYrNxRAq2/Campaigns-team-Roles-%26-Responsibilities-Visuals_2023-08-23_11-14-14?type=whiteboard&t=HDkNJDbCt6265Ezf-1).

**What is included in a Campaign Bundle?**

- Target personas
- Persona-based positioning and messaging
- Keyword research
- Content journey (including awareness, consideration, and decision stages)
- Supporting assets including Analyst relations content & Customer references (if available)
- Emails for content in buyer journey
- Creative for ads, emails, landing pages
- Alliance partner joint GTM campaigns and activities (if applicable)
- Channel partner "Instant Campaigns"
- Outreach sequences/templates
- Enablement sessions

## How are campaign bundles activated? {#campaign-activation}

Campaign bundles are leveraged by all teams in marketing and sales to drive a cohesive full-funnel approach with aligned personas, positioning, messaging, and branding across all touchpoints and conversations.

**Activation activities include:**

- Webcasts
- Tech Demos
- Workshops
- Regional events
- Corporate events
- Community events
- Owned events (Commit)

**Activation channels include:**

- Email nurture
- Paid digital (paid social, GDN, etc.)
- Social
- Blogs
- PR
- Community

### Campaign Core Teams {#campaign-core-teams}

A `Campaign Core Team` is led by a [Global Marketing Campaign Manager](/handbook/marketing/demand-generation/campaigns/) and is comprised of functional DRIs across marketing and revenue programs.

**Campaign Core Team Members:**

- Campaigns (DRI)
- Product Marketing (Primary)
- Developer Advocacy (Primary)
- Content Marketing (Primary)
- Brand (Primary)
- Alliance (Secondary)
- Partner (Secondary)
- Digital Marketing (Secondary)
- Organic Social (Secondary)
- Email Lifecycle (Secondary)
- Account Based Marketing (ABM) (Secondary)
- SDR Leadership (Secondary)
- SDR Enablement (Secondary)
- Corporate Marketing (Liaison for activation)
- Field Marketing (Liaison for activation)

**About Campaign Core Teams:**

- The Core Team's purpose is to collaborate on the research, positioning, messaging, general strategy, and overall timeline of the campaign, and related value plays.
- The Core Teams will determine a relevant and realistic timeline in line with overarching marketing themes, and including Campaigns and Value Plays.
- Each team member should formally commit to due dates for their work.
- Each team member is responsible for communicating as soon as possible when a due date is at risk.
- The Core Teams are comprised of functional DRIs from teams aligned to product specializations (SMEs within their teams)
- The Core Teams will kickoff together with the freedom to drive their campaigns as desired and with a strong team-oriented approach
- The Core Teams will ensure nothing happens in a vacuum, by proactively integrating corresponding activities across marketing, and including those beyond the core team for input
- The Core Teams are responsible for clearly communicating plans to all of Marketing ([also see Core Team communication](/handbook/marketing/campaigns/#core-team-communication))

#### Roles & Responsibilities {#roles-responsibilities}

<!-- DO NOT CHANGE ANCHOR -->

- **Product Marketing:** Responsible for the Solution GTM Strategy including narrative, messaging, and positioning. DRI for value plays. Marketing DRI for Sales and SDR enablement. DRI for buyer and influencer personas. Responsible for fostering participation of the entire team in the research, positioning, messaging, general strategy.
- **Marketing Campaigns:** DRI for marketing campaigns. Responsible for the production of lead generation campaigns and rallying relevant teams and team members to deliver integrated marketing plans.
- **Developer Advocacy:** Responsible for technical narrative and value proposition. DRI for practitioner personas. DRI for Customers Success enablement including SAs, CSMs, and Support. Responsible for technical content production such as demos, blogs, workshops, webinars, etc.
- **Content Marketing:** Responsible for content strategy and production related to the GTM motions and campaigns, and collaborating with other teams on prescriptive buyer journeys.
- **Digital Marketing:** Responsible for digital strategy and defining ideal marketing channels to reach goals.
- **Brand:** Responsible for cohesive branded journey across all tactics and between GTM Motions and campaigns.
- **Field Enablement:** Sales DRI for sales enablement and training, and collaborating with GTM core teams on launch timeline.
- **Sales Leadership:** Responsible for providing insight into the prioritization of value plays.

<details>

<summary>DACI Chart for Public Sector</summary>

|Item | Driver | Approver| Contributor|Informed| Note|
| ------ | ------ |-----|------|-------|-------|
|  Messaging or Message house  |   Product Marketing     |     | Federal CTO or Content| PubSec sales or marketing| |
|  Personas  |     Product Marketing   |     | Federal CTO| PubSec sales or marketing| |
|  Awareness/Consideration/Purchase Content  |     Product Marketing   |     | Federal CTO| PubSec sales or marketing| |
|  Content Strategy |   Product Marketing   |     | Content | PubSec sales or marketing |  |
|  Page/Keyword Rank/Research, SEO  |    Search  |     |     | PubSec marketing |  |
|  Buyer's Journey  |    Product Marketing |      | Federal CTO | PubSec sales or marketing |  |
|  Campaign epic/issue creation  |    Campaigns  |     |    | Multiple teams/individuals |  |
|  Internal content activation epic/issue creation  |    Campaigns   |  Various individuals/teams, Legal (if applicable)   | Product Marketing, Various | Multiple teams/individuals | Includes non-paid digital (organic/social), Paid digital |
|  External content activation epic/issue creation  |    Content   |  Various individuals/teams, Legal (if applicable)   | Various individuals/teams|    | Example: Analyst reports|
|  Campaign Development  |    Campaigns   |      | Product Marketing, Various individuals/teams |    | Examples: Strategy. Tactics such as email, webcasts, paid digital, organic social, content syndication |
|  Legal approval  |    Product Marketing   |     |   |   | Campaigns team creates issue and assigns to legal/product marketing|
|  Setting targets  |    Campaigns or Digital   |      |    | PubSec Sales/PubSec Marketing | Targets are set by campaigns for programs they drive end-to-end, such as webcasts. Digital team sets targets for programs driven primarily by their team, such as display.|

</details>

#### Campaign Core Team Communication {#core-team-communication}

- **Kickoff in Slack**: Campaign Manager will create a Slack channel for async communication
- **DRI definition in Slack**: Manager, Campaigns connects with leaders of functional teams to determine functional DRIs
- **Slack Kickoff Message**: Campaign Manager communicates via the new Slack channel that they will schedule synchronous kickoff with designated DRIs
- **Kickoff Call**: Campaign Manager hosts kickoff call with functional DRIs
  - Primary/Required Attendees: Campaigns, PMM, TMM, Content, Brand
  - Why? because they are key contributors to the initial deliverables that are dependencies for other teams
  - What will be covered?
      1. Share the need behind launching the campaign
      1. Spotlight team members involved
      1. Determine what success looks like
      1. Review workback timeline, identify any risks to timeline.
      1. Confirm launch date
- **Weekly Connect Call**: Campaign Manager runs weekly synchronous meeting with core team, always recorded for review
- **Weekly Status/Reminder Update in Slack:** Campaign Manager shares update including the following:
  - Takeaways
  - Progress
  - At Risk
- **Launch Announcement in Slack**:
- **Announcement Amplification in Slack**: Share announcement post in the following channel
  - marketing
  - TBD - issue to be opened to address
- **Post-Launch Connect Calls**: Campaign Manager drives call focused on outcomes of tactics aligned to the campaign
  - What webinars/tech demos/workshops were run? Or are planned?
  - What new content was developed/launched?
  - Potential optimizations based on performance
- **Campaign Analysis**: Campaign Manager provides analysis of campaign metrics 6 months in
  - Check quarter over quarter performance

*Because of the global nature of the GitLab team, schedules can be difficult to manage to ensure everyone can attend. For the Kickoff Call, the following team members are to be prioritized for attendance (because they are key contributors to the initial deliverables that are dependencies for other teams).*

## How do we measure performance?? {#campaign-performance}

We leverage multi-touch attribution reporting in Sisense and Tableau to help us understand which campaigns, activities, and channels drive the best results, with a goal of SAO and Pipeline. We review these metrics at a segment/region breakout level, as well as reviewing overall campaign metrics with the campaign core teams to identify optimization opportunities to maximize results.

Our dashboards are owned and managed by the Marketing Strategy and Performance team. [Learn more in the Bizible Handbook >>](/handbook/marketing/marketing-operations/bizible)

## Campaign terminology {#campaign-terminology}

- **Campaign - When you hear this term used alone, please clarify what type they are referring to (see below). Please speak in specific terms to communicate more clearly.**
- Integrated Campaign - Organized by marketing campaigns team, collaborating across marketing teams toward a launch date. It incorporates multiple offers and multiple channels.
- Digital Marketing Campaign - Online marketing efforts organized by the digital marketing programs team to drive engagement, conversions, traffic, or revenue
- Brand Awareness Campaign - Higher-level print and digital marketing efforts organized by the corporate marketing team. These are focused on brand recognition.
- Salesforce Campaign - An object within Salesforce that represents different types of offers. These are less-so theoretical and more to capture touchpoints of prospects and customers.

## FY24 Active and WIP Integrated Campaigns {#upcoming-integrated-campaigns}

<!-- DO NOT CHANGE THIS ANCHOR -->

- **[See FY23 Integrated Campaigns here>>](https://gitlab.com/groups/gitlab-com/marketing/-/epics/2851)**
- **[See FY22 Integrated Campaigns and GTM Motions here >>](/handbook/marketing/plan-fy22/)**
- **[See FY21 Integrated Camapigns here >>](https://gitlab.com/groups/gitlab-com/marketing/-/epics/749)**

The below global integrated campaigns are continally optimized by the Marketing Campaigns team, in collaboration wit Digtial Marketing, Developer Advocacy, Product Marketing, and beyond. These campaign bundles are leveraged by all teams in Marketing to apply cohesive and consistent messaging and approach across all marketing channels and tactics.

### 🚀 DevSecOps Platform Campaign (Previously DevOps Platform Campaign)

**Campaign Manager DRI: Eirini Pan**

**Refresh date:April 2023**

**Launch date: May 2021**

- [WIP:FY24 Epic in GitLab](https://gitlab.com/groups/gitlab-com/marketing/-/epics/3460)
- [WIP:FY24 Campaign Brief](https://gitlab.com/groups/gitlab-com/marketing/-/epics/3460#memo-campaign-brief)
- [FY24 Campaign Core Team Members](https://gitlab.com/groups/gitlab-com/marketing/-/epics/3460#busts_in_silhouette-campaign-core-team)
- [FY23 DevOps Platform Campaign Epic in GitLab](https://gitlab.com/groups/gitlab-com/marketing/-/epics/2858)
- [FY23 DevOps Platform Campaign Brief](https://gitlab.com/groups/gitlab-com/marketing/-/epics/2858#memo-campaign-brief)

### 🚀 Security & Compliance Campaign

**Campaign Manager DRI: Eirini Pan**

**Refresh date:April 2023**

**Launch date:FY23Q3**

- [WIP:FY24 Epic in GitLab](https://gitlab.com/groups/gitlab-com/marketing/-/epics/3612)
- [WIP:FY24 Campaign Brief](https://gitlab.com/groups/gitlab-com/marketing/-/epics/3612#memo-campaign-brief)
- [FY24 Campaign Core Team Members](https://gitlab.com/groups/gitlab-com/marketing/-/epics/3612#busts_in_silhouette-campaign-core-team)
- [FY23 Epic in GitLab](https://gitlab.com/groups/gitlab-com/marketing/-/epics/2868)
- [FY23 Campaign Brief](https://gitlab.com/groups/gitlab-com/marketing/-/epics/2868#memo-campaign-brief)

### 🚀 Automated Software Delivery Campaign {#cicd}

<!-- DO NOT CHANGE THIS ANCHOR -->

**Campaign Manager DRI: Shari Rances**

**Refresh date: April 2023**

**Launch date: August 2022**

- [WIP:FY24 Epic in GitLab](https://gitlab.com/groups/gitlab-com/marketing/-/epics/3611)
- [WIP:FY24 Campaign Brief](https://gitlab.com/groups/gitlab-com/marketing/-/epics/3611#memo-campaign-brief)
- [FY24 Campaign Core Team Members](https://gitlab.com/groups/gitlab-com/marketing/-/epics/3611#busts_in_silhouette-campaign-core-team)
- [FY23 Epic in GitLab](https://gitlab.com/groups/gitlab-com/marketing/-/epics/2790)
- [FY23 Campaign Brief](https://gitlab.com/groups/gitlab-com/marketing/-/epics/2790#memo-campaign-brief)

## Past Integrated Campaigns {#past-integrated-campaigns}

<!-- DO NOT CHANGE THIS ANCHOR -->

The below were campaigns run historically, and aligned to overall GTM. They have since been retired in order to run new global campaigns aigned to updated GTM strategies between Sales and Marketing.

### 🚀 CI/CD (Capability Campaign) {#cicd}

<!-- DO NOT CHANGE THIS ANCHOR -->

**Campaign Manager DRI : Agnes Oetama (interim until Jenny T backfill hired)**

**Launched: 2020-04-27 and continually optimized**

#### FigJam of FY23 campaign flow

- [FigJam of FY23 campaign flow>>](https://www.figma.com/file/Ei7B2jndU7eOwukjWuMbAk/CICD-GTM-Campaign-Flow-FY23_2023-08-22_10-27-25?type=whiteboard&t=HDkNJDbCt6265Ezf-1)
- [Campaign Brief](https://gitlab.com/groups/gitlab-com/marketing/-/epics/2850#memo-campaign-brief)
- [Campaign Core Team Members](https://gitlab.com/groups/gitlab-com/marketing/-/epics/2850#busts_in_silhouette-campaign-core-team)
- [Current/Planned Content and Events](https://gitlab.com/groups/gitlab-com/marketing/-/epics/2850#fy23-new-planned-content-events)
- [Epic in GitLab](https://gitlab.com/groups/gitlab-com/marketing/-/epics/2850)
- [Handbook: CI Solution Resource](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/ci/)
- [Handbook: CD Solution Resource](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/cd/)
- [Handbook: CI Message House](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/ci/message-house/)
- [Handbook: CD Message House](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/cd/message-house/)
- [Website: CI Solution Page](https://about.gitlab.com/features/continuous-integration/)
- [Website: CI Solution Page](https://about.gitlab.com/stages-devops-lifecycle/continuous-delivery/)
- [2022-04-07 CI/CD Campaign Review Deck](https://docs.google.com/presentation/d/1mqYScmF1bjON0PsjfurmsChcVdCkMsjkDvTK5YyOlIQ/edit#slide=id.g5e411f22b2_0_0) - GitLab Team Members Only
- [2021-09-09 CI/CD Campaign Review Deck](https://docs.google.com/presentation/d/1TG7SAHUub3BqclJg4nawDARecOOaQ4NpMaxDnXWWtF8/edit#slide=id.g5e411f22b2_0_0) - GitLab Team Members Only
- Slack: [#gtm-cicd](https://gitlab.slack.com/archives/CVDQL20BA)
- Campaign UTM = `singleappci`

### 🚀 DevOp Platform (Capability Campaign) {#devops-platform}

<!-- DO NOT CHANGE THIS ANCHOR -->

**Campaign Manager DRI: Indre Kryzeviciene**

**Launched: 2020-04-28 and continually optimized**

#### FigJam of FY23 campaign flow

- [FigJam of FY23 campaign flow>>](https://www.figma.com/file/OuFSfs8Eb1DRepmDxG6OKj/DevOps-GTM-Campaign-Flow-FY23_2023-08-22_10-36-34?type=whiteboard&t=n9XmTSuPFXL83Ruh-1)
- [Campaign Brief](https://gitlab.com/groups/gitlab-com/marketing/-/epics/2858#memo-campaign-brief)
- [Current/Planned Content and Events](https://gitlab.com/groups/gitlab-com/marketing/-/epics/2858#fy23-new-planned-content-events)
- [Campaign Core Team Members](https://gitlab.com/groups/gitlab-com/marketing/-/epics/2858#busts_in_silhouette-campaign-core-team)
- [Epic in GitLab](https://gitlab.com/groups/gitlab-com/marketing/-/epics/2858)
- [Handbook: DevOps Platform Solution Resource](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/devops-platform/)
- [Handbook: DevOps Platform Message House](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/devops-platform/message-house/)
- [Website: DevOps Platform Solution Page](https://about.gitlab.com/solutions/devops-platform/)
- [2022-04-05 DevOps Platform Campaign Review Deck](https://docs.google.com/presentation/d/1SaUSVSMr2vviMtZ6B30ld-or1bd4TuUjMn0EPFWT1QU/edit#slide=id.g5e411f22b2_0_0) - GitLab Team Members Only
- [2022-10-28 DevOps Platform Campaign Review Deck](https://docs.google.com/presentation/d/1yGif0bLL2xiC_fFUVzM4eSRcU9g-aOkqpPVAElby1KY/edit#slide=id.gaf9c1b1f24_0_0) - GitLab Team Members Only
- Slack: [#gtm-devops-platform](https://gitlab.slack.com/archives/C01NLEXE34L)
- Campaign UTM: `devopsgtm`

### 🚀 DevSecOps (Capability Campaign) {#devsecops-use-case}

<!-- DO NOT CHANGE THIS ANCHOR -->

**Campaign Manager DRI: Eirini Pan**

**Launched: 2020-04-29 and continually optimized**

#### FigJam of FY23 campaign flow

- [FigJam of FY23 campaign flow>>](https://www.figma.com/file/OuFSfs8Eb1DRepmDxG6OKj/DevOps-GTM-Campaign-Flow-FY23_2023-08-22_10-36-34?type=whiteboard&t=elKOAakWTl8snIYW-1)
- [Epic with tactical issues](https://gitlab.com/groups/gitlab-com/marketing/-/epics/743)
- [Solution Resource](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/devsecops/)
- [Campaign Review 2021-07-26](https://docs.google.com/presentation/d/1gPMLjIRPNOCt8DqHUWYdwxW2tNH528qg_YbmZaDYzl8/edit#slide=id.g5e411f22b2_0_0) - GitLab Team Members Only
- [SDR & Sales enablement epic](https://gitlab.com/groups/gitlab-com/marketing/-/epics/874)
- [Live landing page](https://about.gitlab.com/solutions/dev-sec-ops/)
- [Slack](https://gitlab.slack.com/archives/CV8GZ63GR)
- [SFDC campaign](https://gitlab.my.salesforce.com/7014M000001df4w?srPos=0&srKp=701)
- Campaign UTM: `devsecopsusecase`

### 🚀 GitOps (Capability Campaign) {#gitops-use-case}

<!-- DO NOT CHANGE THIS ANCHOR -->

**Campaign Manager DRI: Eirini Pan**

**Launched: 2020-06-22 and continually optimized**

#### FigJam of FY23 campaign flow

- [FigJam of FY23 campaign flow>>](https://www.figma.com/file/R5rSFgNdyW5mSN9mSHORJo/Campaigns-%3E-GitOps-GTM-Campaign-Flow-FY22---FY23_2023-08-22_10-43-13?type=whiteboard&t=elKOAakWTl8snIYW-1)
- [Epic with tactical issues](https://gitlab.com/groups/gitlab-com/marketing/-/epics/745)
- [Campaign Review 2021-9-26](https://docs.google.com/presentation/d/1eYF_H95XzrGmgrqbbRy6rYKsqZkpPvCt7sNxyuEsZuk/edit#slide=id.g5e411f22b2_0_0) - GitLab Team Members Only
- [SDR & Sales enablement epic](https://gitlab.com/groups/gitlab-com/marketing/-/epics/891)
- [Live landing page](https://about.gitlab.com/why/gitops-infrastructure-automation/)
- [Slack](https://gitlab.slack.com/archives/C0119FNPA84)
- [SFDC campaign](https://gitlab.my.salesforce.com/7014M000001dgJ9)
- Campaign UTM: `iacgitops`

### 🚀 GitHub - Light (Competitive Campaign) {#gitops-use-case}

<!-- DO NOT CHANGE THIS ANCHOR -->

**Campaign Manager DRI: Agnes Oetama**

**Launched: 2021-10-28 and continually optimized**

- [Competing with GitHub: ENT sales toolkit](https://docs.google.com/presentation/d/1Gg8c5OVoN5iweGMzyfWNjHg-iboTxgS8Wujf7Uduysw/edit#slide=id.gf73e101eb9_1_147)
- [Sales Levelup Webcast on GitHub](https://www.youtube.com/watch?v=jqUM-zJBdOY)
- [Customer Webinar: Conversica GitHub -> GitLab migration](https://page.gitlab.com/conversica-move-to-gitlab.html)
- [Pathfactory track](https://gitlab.lookbookhq.com/authoring/content-library/recommend/85076)
- [Design kit](https://www.canva.com/folder/FAFE58Mm_Qk)
- Campaign UTM: `20211202_GitHubCompetitive`

### 🚀 France CI Localized {#ci-france-localized}

<!-- DO NOT CHANGE THIS ANCHOR -->

**Campaign Manager DRI: Eirini Pan**

**Launched: 2020-05-15**

- [Epic with tactical issues](https://gitlab.com/groups/gitlab-com/marketing/-/epics/752)
- [SDR & Sales enablement epic](https://gitlab.com/groups/gitlab-com/marketing/-/epics/956)
- [Live landing page](https://about.gitlab.com/fr-fr/pourquoi/integration-continue-pour-construire-et-tester-plus-rapidement/)
- [Slack](https://gitlab.slack.com/archives/C012N4QKYQY)
- [SFDC campaign](https://gitlab.my.salesforce.com/7014M000001dfjQ)

### 🚀 Germany CI Localized {#ci-germany-localized}

<!-- DO NOT CHANGE THIS ANCHOR -->

**Campaign Manager DRI: Indre Kryzeviciene**

**Launched: 2020-04-29**

- [Epic with tactical issues](https://gitlab.com/groups/gitlab-com/marketing/-/epics/809)
- [SDR & Sales enablement epic](https://gitlab.com/groups/gitlab-com/marketing/-/epics/982)
- [Live landing page](https://about.gitlab.com/de-de/warum/nutze-continuous-integration-fuer-schnelleres-bauen-und-testen/)
- [Slack](https://gitlab.slack.com/archives/C012QLG1NJD)
- [SFDC campaign](https://gitlab.my.salesforce.com/7014M000001dfqW)

### 🌄 Version Control & Collaboration (VC&C) {#vcc-use-case}

<!-- DO NOT CHANGE THIS ANCHOR -->

**Campaign Manager DRI: Jenny Tiemann**

**Launched: 2020-06-09 and continually optimized**

- [Epic with tactical issues](https://gitlab.com/groups/gitlab-com/marketing/-/epics/742)
- [SDR & Sales enablement epic](https://gitlab.com/groups/gitlab-com/marketing/-/epics/927)
- [Live landing page](hhttps://about.gitlab.com/why/simplify-collaboration-with-version-control/)
- [Slack](https://gitlab.slack.com/archives/CVB3AKJNA)
- [SFDC campaign](https://gitlab.my.salesforce.com/7014M000001dfsw)

### 🌄 Competitive campaign 3.0 {#competitive-campaign-3}

<!-- DO NOT CHANGE THIS ANCHOR -->

**Campaign Manager DRI: Agnes Oetama**

**Launched (Original): 2020-11-16 and continually optimized**

- [Parent epic with tactical issues](https://gitlab.com/groups/gitlab-com/-/epics/1029)
- [Live landing page - Manager Persona](https://about.gitlab.com/blog/2019/11/26/migrating-from-jenkins/)
- [Live landing page - Practitioner Persona](https://page.gitlab.com/gitlabci-vs-jenkins-demo.html)
- [SFDC Campaign - Manager >>](https://gitlab.my.salesforce.com/7014M000001ll99?srPos=0&srKp=701)
- [SFDC Campaign - Practitioner >>](https://gitlab.my.salesforce.com/7014M000001dlvz?srPos=0&srKp=701)

### 🌄 Increase operational efficiencies {#increase-operational-efficiencies}

<!-- DO NOT CHANGE THIS ANCHOR -->

**Campaign Manager: Jenny Tiemann**

**Launched: 2019-08-23**

- *Note: this is being sunsetted in Q4 FY21 and existing records in nurture will continue until all emails have deployed.*
- [Epic with tactical issues](https://gitlab.com/groups/gitlab-com/marketing/-/epics/367)
- [Live landing page](https://about.gitlab.com/topics/devops/reduce-devops-costs/)
- [Slack](https://gitlab.slack.com/archives/CCWUCP4MS)
- [SFDC campaign](https://gitlab.my.salesforce.com/7014M000000CyiL)

### 🌄 Deliver better products faster {#deliver-better-products-faster}

<!-- DO NOT CHANGE THIS ANCHOR -->

**Campaign Manager: Zac Badgley**

**Launched: 2019-08-23**

- *Note: this is being sunsetted Q2 FY21 and existing records in the nurture will move to the CI use case campaign nurture.*
- [Epic with tactical issues](https://gitlab.com/groups/gitlab-com/marketing/-/epics/363)
- [Live landing page](https://about.gitlab.com/blog/2018/10/12/strategies-to-reduce-cycle-times/)
- [Campaign brief](https://docs.google.com/document/d/1dbEf1YVLPnSpFzSllRE6iNYB-ntjacENRMjUxCt8WFQ/edit)
- [SFDC campaign](https://gitlab.my.salesforce.com/7014M000000Cyhm?srPos=0&srKp=701)

### 🌄 Reduce security and compliance risk {#reduce-security-compliance-risk}

<!-- DO NOT CHANGE THIS ANCHOR -->

**Campaign Manager: Originally Jackie Gragnola, transitioned to Megan Mitchell**

**Launched: 2019-08-23**

- *Note: this is being sunsetted Q2 FY21 and existing records in the nurture will move to the DevSecOps use case campaign nurture.*
- [Epic with tactical issues](https://gitlab.com/groups/gitlab-com/marketing/-/epics/368)
- [Live landing page](https://about.gitlab.com/solutions/dev-sec-ops/)
- [Campaign brief](https://docs.google.com/document/d/1NzFcUg-8c1eoZ1maHHQu9-ABFfQC65ptihx0Mlyd-64/edit)
- [SFDC campaign](https://gitlab.my.salesforce.com/7014M000000CyeJ)

### 🚀 AWS Partner {#aws-partner}

<!-- DO NOT CHANGE THIS ANCHOR -->

**Campaign Manager: Nout Boctor-Smith**

**Launched: 2019-09-22**

- [Epic with tactical issues](https://gitlab.com/groups/gitlab-com/marketing/-/epics/624)
- [SDR & Sales enablement epic](https://gitlab.com/groups/gitlab-com/marketing/-/epics/638)
- [Live landing page](https://about.gitlab.com/webcast/aws-gitlab-serverless/)
- [Slack](https://gitlab.slack.com/archives/CRTE89C66)
- [SFDC campaign](https://gitlab.my.salesforce.com/7014M000001loj0)

### 🌄 Operation OctoCat {#operation-octocat}

<!-- DO NOT CHANGE THIS ANCHOR -->

**Campaign Manager: Jackie Gragnola**

**Launched: 2019-10-31**

- *Note: this is being sunsetted Q2 FY21 and existing records in the nurture will move to the CI use case campaign nurture.*
- [Epic with tactical issues](https://gitlab.com/groups/gitlab-com/marketing/-/epics/439)
- [SDR & Sales enablement epic](https://gitlab.com/groups/gitlab-com/marketing/-/epics/445)
- [FigJam of campaign user journey](https://www.figma.com/file/BYZIoMhJzI4FvM4nXit9Ca/OctoCat-Campaign-Flows-Actual-Sizes_2023-09-11_19-03-47?type=whiteboard&t=elKOAakWTl8snIYW-1)
- [Live landing page](https://about.gitlab.com/competition/github/)
- [Campaign brief](https://docs.google.com/document/d/1Mcy_0cwMsTPIxWUXPgoqw9ejsRJxaZBHi4NikYTabDY/edit#heading=h.kf9lglu57c0t)
- [SFDC campaign](https://gitlab.my.salesforce.com/7014M000001lmdK)

### 🌄 CI Build & Test Auto {#ci-build-test-auto}

<!-- DO NOT CHANGE THIS ANCHOR -->

**Campaign Manager: Agnes Oetama**

**Launched: 2019-08-23**

- *Note: this is being sunsetted Q2 FY21 and existing records in the nurture will move to the CI use case campaign nurture.*
- [Epic with tactical issues](https://gitlab.com/groups/gitlab-com/marketing/-/epics/379)
- [SDR & Sales enablement epic](https://gitlab.com/groups/gitlab-com/marketing/-/epics/432)
- [Live landing page](https://about.gitlab.com/resources/ebook-single-app-cicd/)
- [SFDC campaign](https://gitlab.my.salesforce.com/7014M000001lkp9)

### 🚀 Competitive campaign {#competitive-commit}

<!-- DO NOT CHANGE THIS ANCHOR -->

**Campaign Manager: Agnes Oetama**

**Launched (Original): 2019-04-02**

- [Parent epic with tactical issues](https://gitlab.com/groups/gitlab-com/marketing/-/epics/10)
- [SDR & Sales enablement epic](https://gitlab.com/groups/gitlab-com/marketing/-/epics/85)
- [Live landing page](https://about.gitlab.com/resources/ebook-single-app-cicd/)
- [SFDC Campaign >>](https://gitlab.my.salesforce.com/70161000000VxvJ)

### 🌄 Just Commit {#just-commit}

<!-- DO NOT CHANGE THIS ANCHOR -->

**Campaign Manager: Jackie Gragnola**

**Launched: 2019-02-18**

- [Parent epic with child epics and issues >>](https://gitlab.com/groups/gitlab-com/marketing/-/epics/7)
- [SDR & Sales enablement epic](https://gitlab.com/groups/gitlab-com/marketing/-/epics/50)
- [Former landing page (repurposed since close of the campaign)](https://about.gitlab.com/blog/2019/03/27/application-modernization-best-practices/)
- [SFDC Campaign](https://gitlab.my.salesforce.com/70161000000VwZq)
- [Meeting recordings >>](https://drive.google.com/drive/u/1/folders/147CtTEPz-fxa0m1bYxZUbOPBik-dkiYV)
- [Meeting slide deck >>](https://docs.google.com/presentation/d/1i2OzO13v77ACYo1g-_l3zV4NQ_46GX1z7CNWFsbEPrA/edit#slide=id.g153a2ed090_0_63)

## Campaign Planning {#campaign-planning}

<!-- DO NOT CHANGE THIS ANCHOR -->

**There will be an epic for every campaign - created by the Campaign Manager managing the campaign.**

- The campaign will have a clear launch date
- All action items will have DRIs and a timeline, working back from the launch date
- The campaign will be determined at least 45 days prior to launch to allow for a proactive, not reactive, timeline

Ideally, campaigns will be agreed at least a quarter in advance to allow for ample planning and execution, prep time with agencies, creative concepting, and communication internally. This is a collaborative effort to deliver a cohesive program.

### Overall Campaign Steps {#campaign-steps}

<!-- DO NOT CHANGE THIS ANCHOR -->

- **Campaign need/timing determined by Marketing Leadership and Revenue Programs**
- **Assign:** Campaign Manager is assigned
- **Assign:** Marketing team leads assign DRIs from their teams
- **Organize:** Campaign Manager creates Slack channel for ongoing async communication
- **Meeting:** Campaign Manager organizes campaign kickoff call
- **Plan:** Campaign Manager creates project plan (workback) with timelines and DRIs
- **Plan:** Campaign Manager creates the epic and related issues, including the due dates and DRIs from project plan
- **Meeting:** Campaign Manager organizes the core team connect call to cover milestones met and determine any blockers/at-risk action items
- **Meeting (optional):** Campaign manager seeks budget from VP of Product Marketing if we need to engage external agencies to help build out additional content/design assets for the campaign
- **Async:** *DRIs are responsible for delivering by their due dates, with timeline adherence being critical due to dependencies for later tasks to be completed by other teams*
- **Reporting:** Campaign Manager organizes reporting issue with clear DRI to include overall metrics and more detailed drill-in by channel (one month post-launch)
- **Optimization:** Campaign Manager creates issues for optimizing the landing page, channels, etc. and assigning to relevant DRIs

[See more in Core Team Communication section >>](/handbook/marketing/campaigns/#core-team-communication)

## Campaign Manager Epic Creation {#epic-creation}

<!-- DO NOT CHANGE THIS ANCHOR -->

***The Campaign Manager of the integrated campaign will create the epic with the following structure - details and links to be added up on creation of documents and timeline defined.***

### Epic Code {#epic-code}

<!-- DO NOT CHANGE THIS ANCHOR -->

```markdown
<!-- Name this epic: Name of Campaign [Integrated Campaign] (i.e. Automated Software Delivery [Integrated Campaign]) -->

### :calendar: [Campaign Execution Timeline >>]() - `to be added once created by Campaign Manager`
### :mega: [Slack Channel >>]() `to be added once created by Campaign Manager`

## :busts_in_silhouette: Campaign Core Team
| Primary Stakeholder | Name | Contact |
| ------ | ------ | ------ |
| Campaigns (DRI) | ? | @? |
| Product Marketing | ? | @? |
| Developer Advocacy | ? | @? |
| Content Marketing | ? | @? |
| Revenue Programs | ? | @? |
| Brand | ? | @? |
| Partner Marketing (Partner) | ? | @? |
| Partner Marketing (Alliance) | ? | @? |

| Secondary Stakeholder | Name | Contact |
| ------ | ------ | ------ |
| Digital Marketing | ? | @? |
| SDR Leadership | ? | @?  |
| SDR Enablement | ? | @? |
| Corporate Marketing (Liaison) | ? | @? |
| Field Marketing (Liaison) | ? | @? |

## :memo: Campaign Brief
### Campaign Focus Reasoning
`to be added`

### Business Objectives
`to be added`

### KPIs & Goals
`to be added`

### Target audience and persona
* **Level:** `to be added`
* **Function:** `to be added`

Optional: [Link to detailed persona & positioning doc>>]() - `to be added once created by PMM`| Example: https://tinyurl.com/444k8524

### Marketing message
* Overall: `to be added`
* Key Messages:
- `to be added`
- `to be added`

### New Planned Content & Events
* `To be added`
* `To be added`

### Existing Content & Videos/Recordings
* Needs to be added

### Marketing Channel Mix
`to be added upon discussion with activation teams (digital marketing, lifecycle marketing, ABM, SDR, etc.)`

Note that regional and global activation can ebb and flow in these always-on campaigns. The campaigns team and digital marketing continually review campaign performance to invest $$ (aligned to regional pipeline goals) based on campaigns and channels that are performing.

Organic:
* [ ] Email
* [ ] Organic Social (LinkedIn, Facebook, Twitter)
* [ ] Site Merchandising
* [ ] Podcast (audio)
* [ ] YouTube (video)
* [ ] Outreach Emails

Paid Media:
* [ ] Paid Social (LinkedIn, Facebook, Twitter) _any other channels to consider? where is our audience hanging out?_
* [ ] Paid Search (Google Ads)
* [ ] Demandbase (Key Accounts)

/label ~"dg-campaigns" ~"mktg-demandgen" ~"Content Marketing" ~"Digital Marketing Programs" ~"Product Marketing" ~mktg-website ~design ~"Social Media" ~"Portfolio Marketing" ~"mktg-status::wip"
```

## Sales Lead Funnel Cross-Over with All-Remote {#funnel-crossover-all-remote}

<!-- DO NOT CHANGE THIS ANCHOR -->

### Sales lead funnel cross-over with all-remote {#funnel-crossover-all-remote-diagram}

<!-- DO NOT CHANGE THIS ANCHOR -->

Discussion of how and when to "bridge the gap" between the funnels - potentially sharing GitLab audience-targeted offers within All-Remote communications - is included [in this issue](https://gitlab.com/gitlab-com/marketing/digital-marketing-programs/-/issues/2590).
