---
title: 'GitLab Speakers Resources'
---

The Corporate Communications and Developer Advocacy teams want to enable everyone to contribute and spread the message about GitLab, DevSecOps, AI, and cloud-native to the entire world. We are happy to help speakers in any way we can, including public speaking coaching and building out slides. Below you can find some resources for becoming a speaker, finding an event, submitting a talk, and putting together the presentation and speech.

## Becoming a Speaker

> 🤝 **These steps are required.** The Corporate Communications and Developer Advocacy teams are happy to help.

So you're interested in becoming a public speaker? That's great!

1. Complete the [GitLab external speaker training](/handbook/marketing/corporate-communications/resources-trainings/#external-speaking-trainings).
1. Join the [GitLab Speakers Bureau](https://about.gitlab.com/speakers/), see the [Developer Advocacy page on the Speakers Bureau](/handbook/marketing/developer-relations/developer-advocacy/speakers-bureau/).
1. If you're looking to learn how to be a more effective and confident public speaker, you can check out:
    - [LinkedIn Learning courses](https://www.linkedin.com/learning/public-speaking-foundations-2018/)
    - Books like _The Art of Public Speaking_ by Dale Carnegie
    - Blog post: [What makes a great tech talk](https://about.gitlab.com/blog/2022/10/04/what-makes-a-great-tech-talk/)
    - Or join your local [Toastmasters](https://www.toastmasters.org/Resources/Public-Speaking-Tips).
1. Review the steps on this page for
    - Getting help with CfP and talk ideas
    - Finding events
    - Process and requirements for speaking at events
    - Best practices

### Get help developing CFP ideas

> 🤝 This step is optional. The Developer Advocacy team is happy to help.

Sometimes people have an awesome story to share but can't find the time to put words on paper. We can help with that -- team members can always schedule coffee chats with [Developer Advocates](/handbook/marketing/developer-relations/developer-advocacy/#i-classfa-fa-users-aria-hiddentruei-team-members-and-focus-areas) to brainstorm talk ideas, get speaker coaching, and help with the presentation.

You can also request help with reviewing CFP abstract drafts and talk slide from the [Developer Advocacy team](/handbook/marketing/developer-relations/developer-advocacy/cfps/). Review examples:

- [Efficient Pipelines with CI/CD Templates abstract review](https://gitlab.com/gitlab-com/Product/-/issues/3866#note_852899090)
- [Secure CI/CD using JWT tokens abstract review](https://gitlab.com/gitlab-com/Product/-/issues/4474)

## Speaker Resources

Identify events to speak at, prepare for the Call-for-Papers, review and ensure the event requirements, and follow the process to speak at events.

### Finding an Event

> 🤝 These steps are optional. The Developer Advocacy team is happy to help.

1. Speaking opportunities are often posted in the [#cfp Slack channel](https://gitlab.slack.com/archives/C106ACT6C) (internal)
1. You can also tracked CFP with the [`CFP` label](https://gitlab.com/gitlab-com/marketing/corporate_marketing/corporate-marketing/-/issues?scope=all&utf8=%E2%9C%93&state=opened&label_name[]=CFP) (internal)
1. Events tracking at GitLab:
    - [GitLab events](https://about.gitlab.com/events/)
    - [Marketing team calendar](/handbook/marketing/#marketing-calendar)
    - [Developer Advocacy team calendar](/handbook/marketing/developer-relations/developer-advocacy/)
    - [Developer Relations events](https://gitlab.com/groups/gitlab-com/marketing/developer-relations/-/epics?state=opened&page=1&sort=start_date_desc&label_name[]=DevRel-Events)
1. More sources for events and CFPs:
    - [Developers Conferences Agenda](https://github.com/scraly/developers-conferences-agenda) by Aurélie Vache
    - [confs.tech](https://confs.tech/), Open-source and crowd-sourced list of conferences around software development
    - [PaperCall event directory](https://www.papercall.io/events)
    - [JoinedIn Call for Papers](https://joind.in/event/callforpapers)
    - [CallingAllPapers](https://callingallpapers.com/), crawling joind.in, confs.tech, papercall, and Sessionize.

When unsure about an event, you can ask in Slack, or actively [create a CFP issue](https://gitlab.com/gitlab-com/marketing/corporate_marketing/corporate-marketing/-/issues/new?issuable_template=CFP-Meta) to discuss the event potential and requirements.

### CFP Submission

> 🤝 **These steps are required.**

All talk submissions to the Call-for-Papers (CFP) process at events must be tracked in an issue, using the [`CFP-Meta` template](https://gitlab.com/gitlab-com/marketing/corporate_marketing/corporate-marketing/-/issues/new?issuable_template=CFP-Meta).

- If you have submitted a talk, or it was accepted already, please also create an issue.
- Inviting customers to speak, or co-submit a talk should also be coordinated in the CFP issue.

The CFP template provides guidance on the required event details (URL, location, dates, CFP notification dates, etc.). Please add as many details as possible. All DRIs are tagged automatically, and will be in touch for the next steps.

If you need help with abstract reviews, or slide deck reviews, please add a note into the issue too. You can also use the issue to get manager approval, discuss travel plans, and other required details.

For ideas to help you or your customers get their submissions accepted:

- Review [How to Get Your Presentation Accepted (video)](https://www.youtube.com/watch?v=wGDCavOCnA4).
- Schedule a chat with a [Developer Advocate](/handbook/marketing/developer-relations/developer-advocacy/).
- Search and review current and past events and [their CFP issues](https://gitlab.com/gitlab-com/marketing/corporate_marketing/corporate-marketing/-/issues/?sort=created_date&state=all&label_name%5B%5D=CFP&first_page_size=100).

#### Event Requirements

> 🤝 **These steps are required.**

Before accepting an invitation to speak at an event, please ensure that the conference aligns with GitLab's values around its mission that "everyone can contribute". The event should have both good intentions and accurately reflect those intentions.

1. Any event where a GitLab team member is speaking "on behalf of GitLab," requires to have at least two speakers on the event agenda from [an underrepresented group](/handbook/company/culture/inclusion/#examples-of-select-underrepresented-groups) and any panel a GitLab team member participates on should have at least one speaker from an underrepresented group.
1. Please ensure the event has an enforced, public Code of Conduct to ensure it is a safe environment for all contributing. If needed, event organizers are welcome to use GitLab's [Community Code of Conduct](https://about.gitlab.com/community/contribute/code-of-conduct/).

Follow these steps throughout the CFP process and speaker announcements:

1. Assign the CFP issue to yourself, set the due date to the CFP notification date, and review the speakers list once announced.
1. When speaking at an event (either by CFP or invite) please notify the conference organizers that your acceptance is contingent on this event requirement. You can share this requirement with the event organizers in the CFP submission forms or via email by linking to this handbook section.
1. If you are accepted as a speaker, and the requirements are not met, work with your manager and the [corporate communications](/handbook/marketing/corporate-communications/) and [developer advocacy](/handbook/marketing/developer-relations/developer-advocacy/) teams in the [#external-comms Slack channel](https://gitlab.slack.com/archives/CB274TZRR) to take appropriate actions. There may be some instances of smaller event gatherings where the organizer's had every intention of cultivating an agenda of diversity and unfortunately the available pool of speakers was limited due to various restrictions (geography, audience, available pool, travel guidance). If this occurs, please discuss the circumstances with the corporate marketing team and your manager before speaking.

#### Process

> 🤝 **These steps are required.**

If there is an event you would like to attend, are attending, speaking, or have proposed a talk and you would like support from GitLab to attend this event, the process goes as follows:

1. Create a [CFP issue](/handbook/marketing/corporate-communications/speaking-resources/#cfp-submission), if not existing already.
1. Contact your manager for approval to attend/ speak, and document it in the CFP issue.
1. After getting approval from your manager to attend, follow the steps in the Corporate Communications handbook section on [Speaking Opportunities](/handbook/marketing/corporate-communications/#speaking-opportunities-conferences-meetups-webinars-and-other-events).
1. If the conference does not cover your travel and expenses, GitLab will cover your expenses (transportation, meals, and lodging for days said event takes place). If those expenses exceed $500, please get approval from your manager. When booking your trip, use our [travel portal](/handbook/finance/travel/), book early, and spend as if it is your own money.
1. If you are not already on the [speakers page](https://about.gitlab.com/speakers/), please [add yourself](/handbook/marketing/developer-relations/developer-advocacy/speakers-bureau/#join-the-speakers-bureau).
1. We suggest bringing swag and/or stickers with you. Check the [Requesting Swag handbook](/handbook/marketing/brand-and-product-marketing/brand/merchandise-handling/#how-to-order-swag) how to request/order swag and stickers.

### Presentation Assets

For presentation assets like templates and slides, use the [GitLab branded Google slides](/handbook/tools-and-tips/#google-slides) and learn more about assets in the [Brand Design handbook](/handbook/marketing/brand-and-product-marketing/design/#working-with-the-brand).

Please review and follow the [brand guidelines](https://design.gitlab.com/brand/overview).

Consider using a [GitLab branded Zoom background](/press/press-kit/#green-screens) during your virtual presentation to show your GitLab pride!

### After your Talk

If your talk is recorded, we encourage speakers to publish their talks to YouTube.

Please [upload your talk recording to GitLab Unfiltered](/handbook/marketing/marketing-operations/youtube/#uploading-conversations-to-youtube) and add the video [GitLab Tech Talks playlist](https://www.youtube.com/playlist?list=PL05JrBw4t0KpNi9Wgvsu-_wdiFOYrL4LO) on GitLab Unfiltered. If the recording is published elsewhere on YouTube, add it to the playlist directly.

### Best Practices

Below are some tips on being a better presenter. For an in-depth book that covers the entire speaking process, from submitting an abstract through preparing a structured talk to practicing and delivering read [Demystifying Public Speaking](https://abookapart.com/products/demystifying-public-speaking).

1. Use a problem/solution format to **tell a story**. Many talks, especially tech talks, talk about what they built first and then what the result was. Flip this around and [start with the why](https://www.ted.com/talks/simon_sinek_how_great_leaders_inspire_action). Why did you need to take the action that you did? Talking about what problems you were encountering creates a narrative tension, and people will listen intently to the talk because they want to hear the solution.
1. **Drive towards an action**. Ask yourself, "What will people do once they hear this talk?" The answer can't be, "be more aware of this topic." By deciding what action you expect the audience to take, you can build your talk to drive towards this action. Talks that motivate the audience to action are more engaging and memorable than talks that simply describe. Some good example answers are
   1. Contribute to an open source project.
   1. Implement the technology or process you've come up with
   1. Follow the best practices you've outlined
1. **Practice how you play**. Practicing your talk is key to being a great presenter. As much as possible, practice exactly how you plan to give the talk. Stand up and pretend you are on stage rather than sitting down. If you'll demo, build the demo first and practice the demo. Even practicing while wearing the outfit you plan to wear can help.
1. **Give concrete examples**. Real life details bring a talk to life. Examples help people to understand and internalize the concepts you present. For each of your points, try to have a "for instance." As an example, "We recommend using this script to delete old logs and free up diskspace. For instance, one time our emails lit up as users were complaining about slow performance. Some were reporting tasks hanging for over an hour when they should have completed in less than a minute. It turned out we were out of diskspace because we had verbose logging enabled. Once we ran the script we saw performance return to normal levels."
1. **Be mindful of your body language** when presenting as it will impact the way the audience perceives your presentation. Move around the stage purposefully (don't pace or fidget). Make natural gestures with your hands, and maintain good posture to convey confidence and openness, which will help you to better connect with your audience.

## Finding a Speaker

To find a speaker for your event, you can see the following resources:

- Speakers Bureau: a catalogue of talks, speaker briefs and speakers can be found on our [Speakers Bureau page](https://about.gitlab.com/speakers/). Feel free to add yourself to this page and submit a MR if you want to be in our speaker portal and are interested in being considered for any upcoming speaking opportunities.
