---
title: Content in Campaigns
description: Everything you need to know about how we leverage content in marketing campaigns, including ungated content journeys and former gated landing page processes.
twitter_image: /images/tweets/handbook-marketing.png
twitter_site: '@gitlab'
twitter_creator: '@gitlab'
---

## Overview {#overview}

<!-- DO NOT CHANGE THIS ANCHOR -->

This page documents ways in which content is leveraged in campaigns, including in-house created content, analyst relations content, and downloadable competitive content.

In an effort to best engage our technical audience, we are pursuing an **ungated content journey** that leverages Pathfactory tracks, rather than gated landing pages. This allows viewers to preview content before signing up to view in its entirety. We have flexibility about when and how the forms display, and will test to deliver the best experience with proven results. This process will also be more efficient to launch new content so time can be focused on how to leverage the content in campaigns.

The epic code in each section below outlines the necessary issues to open in order to "check off" the list of action items to launch a new piece of content. *While this page exists within the Campaigns Team handbook page, it is meant to be contributed to by all teams in marketing. If you see an updated needed, please submit an MR and assign to `@aoetama`.*

- Jump to ungated content journey (Pathfactory) setup process
- Jump to gated content (Landing Page) setup process - *being phased out*

### Types of content in campaigns {#content-types}

<!-- DO NOT CHANGE THIS ANCHOR -->

- **Content for use in marketing campaigns:** we leverage the content in our marketing channels (website, email nurture, paid digital, organic social, etc.)
  - [Internal GitLab-created content](/handbook/marketing/demand-generation/campaigns/content-in-campaigns#internal-content): We created and developed the content in house
  - [External content (i.e. Analyst Relations)](/handbook/marketing/demand-generation/campaigns/content-in-campaigns#external-content): We have bought the rights to use the content from an external vendor (analysts or publishers, for example) or received the content from a partner
  - [On-Demand Webcasts](/handbook/marketing/virtual-events/webcasts/)
- **[Content syndication](/handbook/marketing/marketing-operations/campaigns-and-programs/#content-syndication)** (under Digital Marketing): We have promoted our content through a third-party vendor, but do not drive people back to our website. In these cases, we often have given them the resource to make available for download to their audience, and receive the leads to be uploaded.

## How to pick content for campaigns {#picking-content-for-campaigns}

<!-- DO NOT CHANGE THIS ANCHOR -->

**Search the entire Pathfactory Content Library**

https://gitlab.lookbookhq.com/authoring/content-library/content

Filter by one or multiple of the following:

- Topic
- Content Type
- Funnel Stage
- GTM Motion (Business Unit in Pathfactory)
- Language

**View reports to see what works**

- **Key metric to analyze: Engagement Time**
  - *"Why not total views?"* Engagement time is a better indicator of content effectiveness than views, which can be a self-fulfilling prophesy; the more views, the more it is used, the more it continues to climb in comparison to other content.

## Internally-Created Content (i.e. eBooks, Guides) {#internal-content}

<!-- DO NOT CHANGE THIS ANCHOR -->

The below process should be used for all new content (ebooks, guides, whitepapers, etc.). Creating the epic and related issues is the responsibility of the **Campaign Manager** to make sure that when the content is ready, the teams involved in putting into Pathfactory (MOps) and the teams involved in activating (Campaigns, Digital, ABM) are able to take action immediately.

### Epic code and issues - Internal GitLab Content {#epic-issues-internal-content}

<!-- DO NOT CHANGE THIS ANCHOR -->

#### Watch this video overview of the process

[Watch this video overview of the process >>](https://youtu.be/RbQ8Hr6DuQo)

If you have any questions on this process, please contact `@aoetama` in the [#marketing-campaigns](https://gitlab.slack.com/archives/CCWUCP4MS) Slack channel. This process has been iterated since 2018 for efficiency and to fit all teams' project management practices, and is meant to continually updated as needed!

1. **Internally-Created Content Epics:** `Campaign Manager` aligned to the integrated campaign creates epic (using code below) and associates to campaign epic
1. **Related Issues:** `Campaign Manager` aligned to the integrated campaign creates the issues as designated in the epic code, and associates to the content epic

:calendar: As a guide in developing timeline, please view the **[workback timeline calculator](https://docs.google.com/spreadsheets/d/1RvYLEUJvh9QZJZX1uXiKJPcOOSGd7dEeNneqyA2bt3A/edit#gid=969067029)*

```markdown
<!-- NAME EPIC: [type] <Name of Asset> (ex. [eBook] A beginner's guide to GitOps) -->

## Launch date: `to be added`

## Landing Page: (add when live)

## UTMs for [insert epic title here]

**Example utm structure:**

- `utm_campaign=autosd`
- `utm_content=awssecurityvideo`
- `utm_asset_type=video`
- `utm_budget=cmp`

- :nerd: Read about our UTM strategy in [this handbook page](/handbook/marketing/utm-strategy/).
- :link: Build a link with UTMs through this [UTM builder googlesheet](https://docs.google.com/spreadsheets/d/12jm8q13e3-JNDbJ5-DBJbSAGprLamrilWIBka875gDI/edit#gid=2043976569).

## Pathfactory link: (add when live)

#### :key: Key Details

- **Content Owner:**
- **Campaign Manager:**
- **Official Content Name:**
- **Official Content Type:**
- **Primary Campaign:**
- **Primary Sales Segment:**

  - [x] Enterprise
  - [x] Mid-Market
  - [x] SMB
  - [ ] PubSec
    - [ ] Civilian (CIV)
    - [ ] Department of Defense (DOD)
    - [ ] Federal Systems Integrators (FSI)
    - [ ] National Security Group (NSG)
    - [ ] PUBSEC General Nurture
    - [ ] State, Local and Education (SLED)
- **Primary Buying Stage:**
  - [ ] Awareness
  - [ ] Consideration
  - [ ] Decision/Purchase
- **Primary Persona:**
  - [ ] User (ICs/Managers)
  - [ ] Buyer (Director+)
  - [ ] Default
- ** Region:**
  - [ ] GLOBAL
  - [ ] AMER
  - [ ] APAC
  - [ ] EMEA
  - [ ] LATAM
- **Language:**
- **Key metrics for success:** `Add goals here (e.g. number of downloads, INQs, MQLs, SAOs)`
- **Marketo Program Name:** `YYYY_Type_NameAsset` <!-- as content owner, you make this up. Follow structure, no spaces, keep it short - i.e. `2020_eBook_BegGuideGitOps`. This will be used for MKTO/SFDC program. -->
- [ ] [main salesforce program]() - `to be created`
- [ ] [main marketo campaign]() - `to be created`
- [ ] [asset copy draft]() - `doc to be added by Content Marketing`
- [ ] [pathfactory track link]() - `link to PF track (the track in PF, not the live link) when created`

### :rocket: Promotion tactics and channels

- [ ] Gated Landing page
- [ ] Email Nurture
- [ ] Organic Social
- [ ] Paid Digital
- [ ] Content Syndication
- [ ] Blog
- [ ] Press release
- [ ] Other - `Add`

### :books: Issues - Content Owner to Create

<details>
<summary>Expand below for quick links to optional activation issues to be created and linked to the epic.</summary>

[Use the workback timeline calculator to assign correct due dates based off of launch date](https://docs.google.com/spreadsheets/d/1RvYLEUJvh9QZJZX1uXiKJPcOOSGd7dEeNneqyA2bt3A/edit#gid=969067029)

**Required Issues:**

- [ ] :calendar: Not an issue, but an action item for content owner: Add to [SSoT Marketing Calendar](https://docs.google.com/spreadsheets/d/1Tk5fVSwpsEZVFbKOtuaPAItTpAE2PjPeyZ4jKoDe42w/edit#gid=571560493)
- [ ] Asset Copy Issue (open based on which team is content owner)
  - [Content Asset Copy Issue](https://gitlab.com/gitlab-com/marketing/inbound-marketing/global-content/content-marketing/-/issues/new?issuable_template=content-resource-request) - Content
  - [PMM Asset Copy Issue](https://gitlab.com/gitlab-com/marketing/strategic-marketing/product-marketing/-/issues/new) - PMM (no issue template)
- [ ] [Nurture Email Issue](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=add-to-intelligent-email-nurture) - Content, Lifecycle & Campaigns
- [ ] [Asset Design Issue](https://gitlab.com/gitlab-com/marketing/inbound-marketing/global-content/content-marketing/-/issues/new?issuable_template=design-request-content-resource) - Digital Design
- [ ] 🧨 Not an issue, but an action item for content owner: upload to Pathfactory
- [ ] :dart: Not an issue, but an action item for content owner: add to HighSpot
- [ ] [Pathfactory Track Issue](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=request-pathfactory-track) - Campaigns
- [ ] [Resource Page Addition Issue](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=request-resource-page-addition) - Campaigns

**Supplemental issues:**

- [ ] [Landing Page Issue](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=request-content-landing-page) - Content & Campaigns _(only if promoting via Facebook and Google AdWords)_
- [ ] [Digital Marketing Promotion Issue](https://gitlab.com/gitlab-com/marketing/demand-generation/digital-marketing/-/issues/new?issuable_template=paid-digital-request) - Digital Marketing
- [ ] [Organic Social Issue](https://gitlab.com/gitlab-com/marketing/corporate_marketing/corporate-marketing/-/issues/new?issuable_template=social-gtm-organic) - Social
- [ ] [Blog](/handbook/marketing/blog/) - Editorial
- [ ] [PR Announcement Issue](https://gitlab.com/gitlab-com/marketing/corporate_marketing/corporate-marketing/issues/new?issuable_template=announcement) - PR

</details>

/label ~"Content Marketing" ~"Gated Content" ~"mktg-demandgen" ~"dg-campaigns" ~"mktg-status::wip"
```

## Externally-Created Content (i.e. Analyst Relations) {#external-content}

<!-- DO NOT CHANGE THIS ANCHOR -->

External content can be sourced from Analyst Relations, partners, and other vendors with whom we work. Some examples would be vendor comparisons (i.e. Gartner/Forrester) or industry/market analyses (i.e. DevOps Institute).

When a GitLab team member (i.e. AR) is evaluating a potential content for sponsorship, they are responsible for working with the [GTM Motion teams](/handbook/marketing/plan-fy22/#core-teams) to discuss how to leverage the content and if it makes sense for us to sponsor. They can do so by opening a [decision matrix issue](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=decision-tree-matrix) (see step by step process below). The campaign manager will evaluate the decision matrix inputs and give the final go/no go on sponsorship decision. If the decision is to sponsor the external content, the campaign manager will create the content activation epic and associated issues to request work of all relevant teams (outlined below to try to make it efficient, comprehensive, and repeatable!).

All external content should be planned in advance of purchase with `at least a 30 business day time to launch date`. This allows time to plan activation into existing and future integrated campaigns and GTM Motions.

### The decision matrix

The purpose of the decision matrix is to gather cross-functional feedback whether a new analyst report will be a lucrative investment to solidify GitLab's positioning in the market. It will also outline the campaigns and persona it is aligned to as well as the channels where it will be activated.

#### Step by step decision matrix process

1. **Analyst relations** will open a [decision matrix issue](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=decision-tree-matrix) and assign to relevant Campaign Manager.
1. **Campaign Manager** to tag relevant product marketing, sdr enablement, and field enablement counterparts on the decision matrix issue and comment to submit their inputs by agreed upon SLA date. | `SLA: 1 Business Day`
1. **Product Marketing,SDR Enablement, Field Enablement** to fill out their portions for relevant channels, campaign, persona. Tag relevant technical counterparts for input. | `SLA: 3 Business Days`
1. **Campaign Manager** fills out the suggested channel for promotion and makes the go/no go decision on sponsorship, tagging analyst relations |  `SLA: 3 Business Day`

**Decision Matrix end to end decision timeline (SLA): 7 Business days**

### Epic code and issues - External Content {#epic-issues-external-content}

<!-- DO NOT CHANGE THIS ANCHOR -->

#### Watch this video overview of the process

[Watch this video overview of the process >>](https://youtu.be/RbQ8Hr6DuQo)

If you have any questions on this process, please contact `@aoetama` in the [#marketing-campaigns](https://gitlab.slack.com/archives/CCWUCP4MS) Slack channel. This process has been iterated since 2018 for efficiency and to fit all teams' project management practices, and is meant to continually updated as needed!

1. **External Content Epics:** `Campaign Manager` creates epic (using code below) and associates to primary GTM Motion epic
1. **Related Issues:** `Campaign Manager` creates the issues as designated in the epic code, and associates to the external content epic

As a guide in developing timeline, please view the workback timeline calculator [here](https://docs.google.com/spreadsheets/d/1RvYLEUJvh9QZJZX1uXiKJPcOOSGd7dEeNneqyA2bt3A/edit#gid=969067029)

```markdown
<!-- NAME EPIC: [type] <Name of Asset> (ex. [Report] Gartner MQ for ARO) -->

- [ ] Make sure epic is CONFIDENTIAL, if applicable (i.e. Analyst Reports)

## Launch date: `to be added`

## [Pathfactory link]() - `to be added when live`

### :key: Key Details

- **Analyst Relations DRI:**
- **Product Marketing DRI:**
- **Campaigns DRI:**
- **Official Content Name:**
- **Official Content Type:**
- **Primary Campaign:**
  - [ ] DevSecOps platform
  - [ ] Automated Software Delivery
  - [ ] Security & Compliance
- **Primary Sales Segment:**
  - [ ] Enterprise
  - [ ] Mid-Market
  - [ ] SMB
- **Primary Buying Stage:**
  - [ ] Awareness
  - [ ] Consideration
  - [ ] Decision/Purchase
- **Primary Persona:**
- **Language:**
- **Budget:** <!-- Match to Allocadia -->
- **Marketo program name:** `YYYY_Type_VendorNameAsset` <!-- as content owner, you make this up. Follow structure, no spaces, keep it short - i.e. `2020_report_GartnerMQARO`. This will be used for MKTO/SFDC program. -->
- [ ] [main salesforce program]() - `to be added`
- [ ] [main marketo campaign]() - `to be added`
- [ ] [pathfactory track link]() - `link to PF track (the track in PF, not the live link) when created`
- [ ] [Pathfactory & Resource Page Copy]() - `doc to be added by Content Owner` ([use template here](https://docs.google.com/spreadsheets/d/1dKVIZGbbOLoR5BdCqXqCQ40qJlQNif9waTiHc8yWggQ/edit#gid=1837173931)
- [ ] UTMS: `utm_campaign=[add here]&utm_content=[add here]`

#### :dart: Timeline / Promotional asset list (add links when completed) and DRIs
Adjust list as applicable for each report activation:

- [ ] 2023-xx-xx add report to **Pathfactory** `@DRI`
- [ ] 2023-xx-xx **landing page** live `@DRI`
- [ ] 2023-xx-xx add to [Analyst research page](https://about.gitlab.com/analysts/) `@DRI`
- [ ] 2023-xx-xx report live on [**resources page**](https://about.gitlab.com/resources/) `@DRI`
- [ ] 2023-xx-xx publish **blog** `@DRI`
- [ ] 2023-xx-xx publish **commentary page** `@DRI`
- [ ] 2023-xx-xx add on **website pages** (solution pages, homepage) `@DRI`
- [ ] 2023-xx-xx **press release** live `@DRI`
- [ ] Field Enablement `@DRI`
  - [ ] 2023-xx-xx send **field FYI**
  - [ ] 2023-xx-xx conduct **field enablement session**
- [ ] Organic social `@DRI`
  - [ ] 2023-xx-xx **Facebook** post(s)
  - [ ] 2023-xx-xx **LinkedIn** post(s)
  - [ ] 2023-xx-xx **Twitter** post(s)
- [ ] **Executive social sharing** posts `@DRI`
- [ ] 2023-xx-xx add to **Highspot** `@DRI`
- [ ] 2023-xx-xx add to **Intelligent email nurture** `@DRI`
- [ ] 2023-xx-xx add to **paid digital** `@DRI`


### :books: Issues to Create & Tasks to complete

Adjust list as applicable for each report activation. [Use the workback timeline calculator to assign correct due dates based off of launch date](https://docs.google.com/spreadsheets/d/1RvYLEUJvh9QZJZX1uXiKJPcOOSGd7dEeNneqyA2bt3A/edit#gid=969067029)

**Analyst relations** `@DRI`

- [ ] Provide reprint link and expiration date
- [ ] Secure analyst citation review / approval
- [ ] [Open Analyst Report Commentary Page Issue](https://gitlab.com/gitlab-com/marketing/strategic-marketing/product-marketing/-/issues/new?issuable_template=AR-Commentary-Page)
- [ ] Add to the open Product Marketing / Field Communications Planning epic (see [handbook entry](/handbook/sales/field-communications/#recurring-announcements) for more detail & link to latest epic)

**Product Marketing** `@DRI`

- [ ] Add to HighSpot
- [ ] [Open PR Announcement Issue](https://gitlab.com/gitlab-com/marketing/corporate_marketing/corporate-marketing/issues/new?issuable_template=announcement)
- [ ] [Open Blog Issue](https://gitlab.com/gitlab-com/marketing/inbound-marketing/global-content/content-marketing/issues/new#?issuable_template=blog-post-pitch)
- [ ] Open MR to add to add to web pages (e.g. solutions pages, homepage etc.)
- [ ] Open issue for executive social sharing

**Campaign Manager** `@DRI`

- [ ] Add to [SSoT Marketing Calendar]https://docs.google.com/spreadsheets/d/1Tk5fVSwpsEZVFbKOtuaPAItTpAE2PjPeyZ4jKoDe42w/edit#gid=571560493)
- [ ] [Open Pathfactory upload Issue](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=request-pathfactory-upload)
- [ ] [Open Nurture Email Issue](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=add-to-intelligent-email-nurture)
- [ ] [Open Resource Page Addition Issue](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=request-resource-page-addition)
- [ ] [Open Expiration Issue](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=campaigns-expire-analyst)
- [ ] [Open Landing Page Issue](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=request-content-landing-page) - Assign to Content & Campaigns _(only if promoting via Facebook and Google AdWords)_
- [ ] [Open Digital Marketing Promotion Issue](https://gitlab.com/gitlab-com/marketing/demand-generation/digital-marketing/-/issues/new?issuable_template=paid-digital-request)
- [ ] [Open Organic Social Issue](https://gitlab.com/gitlab-com/marketing/corporate_marketing/corporate-marketing/-/issues/new?issuable_template=social-general-request)

</details>

/label ~"Analyst Relations" ~"Gated Content" ~"mktg-demandgen" ~"dg-campaigns" ~"mktg-status::wip"
```

## Adding new content to the Resources page {#add-to-resources-page}

<!-- DO NOT CHANGE THIS ANCHOR -->

**[Video walkthrough](https://www.youtube.com/watch?v=G8NZV75H7lw) of adding a resource to <https://about.gitlab.com/resources/> by using the CMS (Contentful).

<iframe width="560" height="315" src="https://www.youtube.com/watch?v=G8NZV75H7lw" frameborder="0" allow="autoplay; encrypted-media" allowfullscreen></iframe>

**Step by step instructions below**

1. Go to the [Resources page](https://app.contentful.com/spaces/xz1dnu24egyd/entries/5sF9ZMv4xAffzAKEnQGozh?focusedField=title) entry in Contentful
1. Click on the "Browse all resources" section of page content
1. Scroll waaaaay to the bottom and select + Add Content -> Card
1. From here, it might be helpful to open an existing card and make sure the same fields are filled out, but the gist is:

   - the Title goes in both `Internal Name` and `Title`
   - the Language goes in `Subtitle`
   - the Teaser goes in `Description`
   - the Topics go in `List` (hit enter after each topic)
   - the Solutions go in `Pills` (hit enter after each topic)
   - the Type of resource goes in `Icon Name`
   - the URL goes in `Card Link`

Publish that card, drag it to the top of the list if you want it to appear first, and publish that section too!

If you want to edit other parts of the page the process is similar, just follow the existing pattern of the other cards! The only section to watch out for is the Featured resource - the one you want to feature has to be first in that list, and has to have an image.

*Note: For ungated journeys, the URL drives to the PF asset/track, instead of a landing page.*

**TYPES to choose from (select one)**

- eBook
- Report
- Webcast
- One-pager
- Whitepaper
- Demo
- Comparison
- Assessment

**LANGUAGES to choose from (select one)**

- English
- Korean
- Japanese
- Spanish

**TOPICS to choose from (add all that apply):**

*Note from @aoetama: let's see if we can align this with topics in Pathfactory for efficiency (if we don't go the route of Pathfactory explore page).*

- Agile
- CD
- CI
- Cloud infrastructure
- Continuous Delivery
- Continuous Development
- Continuous Integration
- Cloud Native
- DevOps
- DevSecOps
- Git
- GitOps
- GitLab
- Infrastructure as code
- Kubernetes
- Public Sector
- Security
- Single Applicaton
- Software Development
- Toolchain
- Version Analytics
- Version Control & Collaboration

**SOLUTIONS to choose from (select best aligned)**

- Accelerated Delivery
- Deliver better products faster
- Executive visibility
- GitLab & AWS
- GitLab & Pulumi
- GitLab & Terraform
- GitOps
- Google Anthos and GitLab
- GitLab & AWS
- Improve operational efficiencies
- Project compliance
- Quality
- Security
- Security and quality

## How to extend analyst assets {#extend-analyst-assets}

<!-- DO NOT CHANGE THIS ANCHOR -->

At times, we will extend the rights to an asset if it is heavily used by sales or performing in campaigns. In that case the decision is indicated in the [Expiration Issue](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=campaigns-expire-analyst).

Follow the steps outlined [in the Pathfactory Content Library Handbook](/handbook/marketing/marketing-operations/pathfactory/content-library/#replacing-or-updating-the-verson-of-an-asset-after-initial-upload).

## How to retire analyst assets when they expire {#retire-analyst-assets}

<!-- DO NOT CHANGE THIS ANCHOR -->

An [Expiration Issue](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=campaigns-expire-analyst) will be opened by the Campaign Manager DRI for each analyst asset, and related to the overarching Epic (with due date for when the asset is set to expire). When the decision is made to expire the asset, the teams involved will check off their respective action items in the issue.

### Retire Marketo landing page {#retire-marketo-page}

<!-- DO NOT CHANGE THIS ANCHOR -->

**First you will remove the form from the page and add a "no longer available" message**

- In the Marketo program, click "edit" on the Registration Page
- On right rail under "Variables" (below "Elements"), find `2column Visibility` and switch to "Hidden"
- On right rail under "Variables" (below "Elements"), find `2column Sidebar` and switch to "No Sidebar"
- On right rail under "Variables" (below "Elements"), find `flex1 Visibility` and switch to "Visible"
- In flex1 section, double-click then click to edit in HTML > add the code below into the section and save
- Approve Landing Page and test live. You should no longer be able to see the form or paragraph text, and only see the notice about resource no longer being available.

```html
<h1>This resource is no longer available.</h1>
<p>Thank you for your interest in this resource, but it is no longer available for download. <a href="https://about.gitlab.com/analysts/" target="_blank" id="">Click here to visit our industry analysts page to view other reports and best practices!</a></p>
```

### Remove from Intelligent Nurture {#remove-intelligent-nurture}

<!-- DO NOT CHANGE THIS ANCHOR -->

Please follow the process outlined in the [Emails/Nurture Handbook](/handbook/marketing/lifecycle-marketing/emails-nurture).

### Remove from Pathfactory {#remove-pathfactory}

<!-- DO NOT CHANGE THIS ANCHOR -->

Please follow the process outlined in the [Pathfactory Handbook](/handbook/marketing/marketing-operations/pathfactory/content-library/#removing-an-asset-from-the-library).

### Marketo automation and setup for gated landing page {#steps-gated-landing-pages}

<!-- DO NOT CHANGE THIS ANCHOR -->

**!!! REMINDER: We are using ungated content journeys via Pathfactory. This process should only be used for specific scenarios, and used sparingly.**

[Watch the video tutorial >](https://www.youtube.com/watch?v=RrmDCZPh1nw)

:exclamation: Dependencies: delivery of final asset, completion of final landing page copy, and final asset added to pathfactory and placed in a track must be complete before setting up the Marketo program.

**The TL;DR of what you'll do:**

- Create Marketo program, tokens, and SFDC campaign sync
- Edit registration page and thank you page URLs
- Edit and Activate smart campaign(s)
- Update SFDC campaign
- Test live registration page and flows
- Add new content to the Resources page (separate issue)

#### Create Marketo program, tokens, and SFDC campaign sync {#steps-gated-mkto-sfdc}

<!-- DO NOT CHANGE THIS ANCHOR -->

- Clone the [Marketo Gated Content Template](https://app-ab13.marketo.com/#PG5111A1) and name new program using naming convention (YYYY_Type_AssetName, i.e. 2020_report_GarnterVOC_ARO)
- Create SFDC program (Program Summary > `Salesforce campaign sync` > click "not set" and choose "Create New" from dropdown) - leave the name as auto-populates, and add the epic url to the description and "Save"
- Update Marketo tokens (Program Summary > "My Tokens" tab)
  - `{{my.bullet1}}` - bullet copy with approved [character limits](https://docs.google.com/spreadsheets/d/1dKVIZGbbOLoR5BdCqXqCQ40qJlQNif9waTiHc8yWggQ/edit#gid=905304679)
  - `{{my.bullet2}}` - bullet copy with approved [character limits](https://docs.google.com/spreadsheets/d/1dKVIZGbbOLoR5BdCqXqCQ40qJlQNif9waTiHc8yWggQ/edit#gid=905304679)
  - `{{my.bullet3}}` - bullet copy with approved [character limits](https://docs.google.com/spreadsheets/d/1dKVIZGbbOLoR5BdCqXqCQ40qJlQNif9waTiHc8yWggQ/edit#gid=905304679)
  - `{{my.bullet4}}` - bullet copy with approved [character limits](https://docs.google.com/spreadsheets/d/1dKVIZGbbOLoR5BdCqXqCQ40qJlQNif9waTiHc8yWggQ/edit#gid=905304679)
  - `{{my.contentDescription}}`    - 2-3 sentences with approved [character limits](https://docs.google.com/spreadsheets/d/1dKVIZGbbOLoR5BdCqXqCQ40qJlQNif9waTiHc8yWggQ/edit#gid=905304679), this will show up in page previews on social and be used in Pathfactory description.
  - `{{my.contentDownloadURL}}` - skip updating in initial registration page setup (update during on-demand switch), Pathfactory link WITHOUT the `https://` NOR the email tracking part (`lb_email=`)
    - Example of correct link to include: `learn.gitlab.com/gartner-voc-aro/gartner-voc-aro` - the code in the Marketo template assets will create the URL `https://learn.gitlab.com/gartner-voc-aro/gartner-voc-aro?lb_email={{lead.email address}}&{{my.utm}}`
    - Note that both parts of this url include custom URL slugs which should be incorporated into all pathfactory links for simplicity of tracking paramaeters
  - `{{my.contentEpicURL}}` - no longer used in automation, but helpful for reference
  - `{{my.contentSubtitle}}` - content subtitle to display to viewer (throughout landing page, emails, etc.)
  - `{{my.contentTitle}}`    - content title to display to viewer (throughout landing page, emails, interesting moments, etc.), with approved [character limits](https://docs.google.com/spreadsheets/d/1dKVIZGbbOLoR5BdCqXqCQ40qJlQNif9waTiHc8yWggQ/edit#gid=905304679)
  - `{{my.contentType}}`    - content type to display to viewer (throughout landing page, emails, interesting moments, etc.)
  - `{{my.contentTypeSFDC}}` - pick from following list (critical to avoid Marketo > SFDC sync errors): whitepaper, report, video, eBook, general
  - `{{my.emailConfirmationButtonCopy}}`    - leave as `Download`  (but can be updated if needed)
  - `{{my.formButtonCopy}}`    - leave as `Download  now` (but can be updated if needed)
  - `{{my.formHeader}}`    - leave as `Free Instant Download:` (but can be updated if needed)
  - `{{my.formSubhead}}`    - form subhead (not currently used for gated content landing page to try to keep form shorter)
  - `{{my.heroImage}}` - image to display above landing page form ([options in Marketo here](https://app-ab13.marketo.com/#FI0A1ZN9784))
  - `{{my.introParagraph}}`    - intro paragraph to be used in landing page and nurture email, with approved [character limits](https://docs.google.com/spreadsheets/d/1dKVIZGbbOLoR5BdCqXqCQ40qJlQNif9waTiHc8yWggQ/edit#gid=905304679)
  - `{{my.or}}` - leave as `?` (but can be updated to `&` if during Pathfactory upload, the custom URL slugs were not applied to both the asset and the track). If this is not correctly applied and there are multiple `?` question marks in the URL, it will break. [WATCH THE VIDEO EXPLAINER](https://www.youtube.com/watch?v=VHgR33cNeJg)
  - `{{my.socialImage}}`    - image that would be presented in social, slack, etc. preview when the URL is shared, this image is provided by design/social, leave the default unless presented with webcast specific image.
  - `{{my.utm}}` - this should match the aligned campaign utm
  - `{{my.valueStatement}}` token with the short value statement on what the viewer gains from the webcast, this ties into the follow up emails and must meet the max/min requirements of the [character limit checker](https://docs.google.com/spreadsheets/d/1dKVIZGbbOLoR5BdCqXqCQ40qJlQNif9waTiHc8yWggQ/edit#gid=905304679)

#### Edit registration page and thank you page URLs {#steps-gated-registration-page}

<!-- DO NOT CHANGE THIS ANCHOR -->

- Right click the landing page object > "URL Tools" > "Edit URL Settings"
- Input new Registration Page URL (format: `resources-type-name-of-asset`, i.e. `resources-ebook-ci-best-practices`)
- Input new Thank You Page URL (format: `resources-type-name-of-asset-thank-you`, i.e. `resources-ebook-ci-best-practices-thank-you`)
- For both, leave `"Throw away" existing url` selected and click save

#### Edit "resulting page" from the form submit {#steps-gated-resulting-page}

<!-- DO NOT CHANGE THIS ANCHOR -->

- the cloned program will automatically reference the Marketo program template Thank You Page
- Right click the registration landign page > "Edit Draft"
- On the right rail of the edit mode, under `Elements` right click on the `Form Custom` element and click "Edit"
- Next to `Follow-up page`, clear out the automatic reference to the template, and start to type in your program name - the approved thank you page should show up. Choose your thank you page
- Click "Swap" button at the bottom
- At top left of page, click `Landing Page Actions` > "Approve and Close"

#### Activate smart campaign(s) {#steps-gated-activate-smart-campaigns}

<!-- DO NOT CHANGE THIS ANCHOR -->

- Click to `01 Downloaded Content` smart campaign
- Click on `Smart List`
- Confirm that the first trigger for `Fills out Form` is set to `Form Name` is any, `Web Page` is (the name of your landing page). This should already be set properly.
- the second trigger for `Fills out Form` should be set to `Form Name` is "Form 2074: PF General". In `Referrer` contains, enter the Pathfactory asset name slug. For example `guide-to-devops`.
- the third trigger for `Fills out Form` should be set to `Form Name` is "Pathfactory Webhook". In `Referrer` contains, enter the Pathfactory asset name slug. For example `guide-to-devops`.
- Filter 1 - `Filled Out Form` should already be set properly. This will be `Form Name` is any. `Web Page` is (the name of your landing page).
- Filter 2 - `Filled Out Form` should be set to `Form Name` is "Form 2074: PF General". In `Referrer` contains, enter the Pathfactory asset name slug. For example `guide-to-devops`.
- Filter 3 - `Filled out Form` should be set to `Form Name` is "Pathfactory Webhook". In `Referrer` contains, enter the Pathfactory asset name slug. For example `guide-to-devops`. `Date of Activity` should already be set to in the past 1 hour.
- Filter 4 - `Pathfactory Engagement Time` greater than 60 is set as the default. 60 is the Pathfactory view threshold for eBooks and Whitepapers. If your content falls into this category, no updates are necessary. Any other content types should be updated with the threshold outlined under [Pathfactory Scoring](/handbook/marketing/marketing-operations/pathfactory/#pathfactory-scoring). For example, if you are creating an analyst report, you will enter 120 instead of 60.
- Advanced filters will be set to `1 or 2 or (3 and 4)`
- Flow: it's all set! For your first few, feel free to review the flows (but they are all using tokens, so it should be ready to go automatically)
- Schedule tab: click "Activate" (note: the settings should be that "each person can run through the flow once every 7 days" - this is to avoid bots resubmitting repeatedly)

#### Update SFDC campaign {#steps-gated-update-sfdc}

<!-- DO NOT CHANGE THIS ANCHOR -->

- Navigate to [https://gitlab.my.salesforce.com/701?fcf=00B61000004NY3B&page=1&rolodexIndex=-1] campaigns in Salesforce
- `Campaign Owner` should be the campaign creator
- `Active` field should be checked
- `Description` must include the epic url, best practice to include the registration page URL
- `Start Date` should be date of launch
- `End Date` should be one year later
- `Budgeted Cost` is required, if cost is $0 list `1` in the `Budgeted Cost` field - NOTE there needs to be at least a 1 value here for ROI calculations, otherwise, when you divide the pipeline by `0` you will always get `0` as the pipe2spend calculation.
- `Bizible Touchpoints Enabled` leave this blank (because this would be an online touchpoint)

#### Test live registration page and flows {#steps-gated-testing}

<!-- DO NOT CHANGE THIS ANCHOR -->

- Click to the landing page object and click "View Approved Page"
- Final QA of all copy
- Submit the form
- Final QA that the form submit brings you to the thank you page
- Final QA that the link on the thank you page sends to Pathfactory **with*- the tracking for the email address (`&lb_email=[email submitted in form]`)
- Check that you received the follow up email
- Final QA of confirmation email copy
- Final QA that the confirmation email link sends to Pathfactory with the tracking for the email address  (`&lb_email=[email submitted in form]`)

## Potential backup process {#retire-marketo-page}

<!-- DO NOT CHANGE THIS ANCHOR -->

To be completed by the content owner if Pathfactory access is granted. If no access, please open an issue in Campaigns team based on epic category above.

**Add to /downloads/ repository** (only available and recommended for assets under 2 MB size)

*The purpose of this step is to make it possible to flip the autoresponder if Pathfactory were to have an outtage, at which point, we would still have the PDF version available in Marketo for a quick turnaround.*

1. Save the pdf to your computer with naming convention `[asset-type]-short-name-asset`, ex: `ebook-agile-delivery-models`
1. Navigate to the (de-indexed) [`resource/download`](https://gitlab.com/gitlab-com/www-gitlab-com/tree/master/sites/uncategorized/source/resources) directory
1. Where it says `www-gitlab-com / sites / marketing / source / resources / +`, click the plus drop down and select "Upload File"
1. Upload the file you've saved to your computer with the naming convention above
1. For commit message, add `Upload [Asset Type]: [Asset Name]`, check box for "create new merge request", name your merge request, and click "Upload file"
1. Add description to MR, complete the author checklist, assign to `@aoetama` and click "Submit Merge Request"
1. In your Marketo program, for the `pdfVersion` My Token, add the naming convention above which will be available when the MR is merged. (the token should look like `https://about.gitlab.com/resources/downloads/add-file-name-here.pdf`)
