---
title: "Education Program"
description: "Learn about the GitLab for Education Program and other education-related programs from GitLab's Developer Relations team"
---

## About

GitLab's Education program is part of the [Community Programs](/job-families/marketing/community-programs/) team.

On this page, you'll find information about the GitLab for Education Program Team, our vision, our methods, our initiatives, and our program requirements.

The primary mission of the GitLab for Education Program is to facilitate and drive the adoption of GitLab at educational institutions around the globe and build an engaged community of GitLab evangelists and contributors in the next generation of the workforce.

Additionally, the Education Program seeks to evangelize the benefits of an all-remote operating model and GitLab's associated [company values](/handbook/values/) with students.

## How to reach us

* DRI: [@Akarsten1](https://gitlab.com/Akarsten1)
* Email: `education@gitlab.com`

Additionally, see the following Slack channels.

| Channel | Purpose |
|---------|---------|
|[#community-programs](https://gitlab.slack.com/messages/community-programs)| Communication regarding the GitLab for Education,GitLab for Open Source, and GitLab for Startups Programs.|
|[#gitlab-for-campuses](https://gitlab.slack.com/messages/gitlab-for-campuses)| This channel is for discussing [the GitLab for Campuses](/handbook/product/packaging-and-pricing/gitlab-for-campuses/) (paid) offering |

## Vision and goals

The vision of the GitLab for Education Program is to enable educational institutions to be successful in teaching, learning, conducting research with GitLab.
We seek to build an engaged community of GitLab users around the world who actively contribute to GitLab and each other's success, and ultimately become evangelists of GitLab in the workplace and beyond.

Our goals are:

* Align the program structure and license offerings with the needs and operating models of educational institutions while providing the best GitLab has to offer to students, faculty, and staff.
* Grow the base of educational institutions, students, faculty, and staff using GitLab.
* Build a robust and engaged educational community full of members who collaborate, contribute, and enable each other to be successful with GitLab.
* Build meaningful relationships with the Education Program member institutions.
* Provide a wealth of resources for adopting GitLab in an educational setting including course materials, case studies, code examples, syllabi, and presentations.
* Evangelize the benefits of DevOps as a discipline and GitLab as the leading single application for the DevOps lifecycle.
* Bring DevOps into the classroom in related disciplines such as computer science and infrastructure technology.
* Be a thought leader in the discipline of DevOps by engaging with related academic disciplines, academic organizations, and associations.
* Evangelize the benefits of an all-remote operating model and GitLab's associated company values to the next generation of the workforce.

## What we're working on

GitLab for Education Program issues typically exist in the [Education Program subgroup](https://gitlab.com/gitlab-com/marketing/developer-relations/education-program) of the [Developer Relations Group](https://gitlab.com/gitlab-com/marketing/developer-relations).
But they may also reside in [Field Marketing](https://gitlab.com/gitlab-com/marketing/field-marketing), [Corporate Marketing](https://gitlab.com/gitlab-com/marketing/corporate_marketing/corporate-marketing), or other [marketing subgroups](https://gitlab.com/gitlab-com/marketing).

### Work labels

We use the following labels to track our work across these spaces.

| Label  | Use  |
|--------|------|
|`Education Program`| General label for all issues related to program management|
|`edu-feedback`| Marks issues that contain feedback from program and community members|
|`OKR` | Related to OKRs for the quarter   |
|`Education:: EAB`| Related to the Education Advisory Board |
|`edu-conference`| Related to conferences the education team is involved with|
|`edu-evangelism`| Related to the education Evangelist|
|`edu-stakeholder-mtng`| Used for meetings with members of the outside education community|

### OKRS and KPIs

We track progress on OKRs using the `Education Program` and `OKR` labels.

The GitLab for Education Program has quarterly OKR in order to measure impact and drive program improvement.

See the [FY25-Q4 Developer Relation & Strategy OKRs](https://gitlab.com/gitlab-com/gitlab-OKRs/-/work_items/10245) for more details.

## How to help

Alumni are an important part of every school's community.
You can assist the GitLab for Education team by connecting GitLab to your alma mater.
To get started:

* Email former professor you really liked and share information about our GitLab for Education Program. Email template coming soon.
* Contact your alumni association about "Alumni updates" and share what you do at GitLab.
* Contact student organizations you were part of, especially if as realted to software or digital technology in some way.
* Offer to visit your alma mater virtually to give an "Introduction to DevOps guest lecture"

## GitLab for Education Program

In order to qualify for the [GitLab for Education Program](https://about.gitlab.com/solutions/education/join/), applicants must meet the [GitLab for Education Program Requirements](https://about.gitlab.com/solutions/education/join/#requirements).
Once accepted in the program, institutions must agree to and are subject to the [GitLab for Education Program Agreement](/handbook/legal/education-agreement/).

### GitLab for Education Program requirements

In order to qualify for the GitLab for Education Program, applicants must:

* **Be a qualified educational institution**: A qualified educational institution is one that has been accredited by an authorized agency within its applicable local, state, provincial, federal, or national government and has the primary purpose of teaching its enrolled students. Qualified educational institutions can be public or private and must be non-profit/non-commercial. For reasons relating to trade controls, we are unable to accept applicants from Cuba, Iran, Syria, North Korea, Russia, Belarus, or Ukraine.
* **Meet the use case requirements**: The GitLab educational license can be used solely for the purposes of **instructional use** or **non-commercial academic research**. Instructional use includes activities related to learning, training, research and development. Non-commercial academic means conducting not-for-profit research projects conducted by the program member, and not at the request of a third party, which are not intended to, or in fact, produce results, works, services, or data for commercial use by anyone to generate revenue, or for the benefit of a third party. The GitLab educational license cannot be used for commercial, professional, or any other for-profit purposes. **Specifically, it is not authorized for use to run, administer, or operate an institution.**
* **Be a full-time faculty or staff member at the qualified educational institution**: We can only issue licenses to full-time faculty or staff who are directly employed full-time at the educational institution. Students who may also be employed in a staff role cannot apply.

**Please note:** the decision to issue a GitLab license via the GitLab for Education Program is always at the discretion of GitLab.
If you have questions on the application and decision making process, please contact education@gitlab.com.

### Examples of educational institutions that qualify

* K-12 institutions include Elementary, Middle, and High Schools, which may include both publicly and privately funded institutions (**Note:** GitLab.com (SaaS software) is not available to K-12 institutions. However, K-12 institutions may apply for GitLab self-managed instances.)
* Junior Colleges, Community Colleges, and Technical Schools
* Universities
* Research Institutes or Centers directly *owned and operated by* a University

### Examples of entities that do not qualify

* Training centers
* Churches and libraries
* Medical research centers or institutions associated with a hospital or health care system
* Independent research laboratories
* Re-training programs
* Military schools, institutes, or training centers within a branch of the military
* Research institutes or National Laboratories that are owned by a Federal Government
* eLearning platforms not directly affiliated with or operated by an accredited academic University
* Coding academies, bootcamps, or independent learning platforms

### Examples of acceptable use cases

* Classroom use: All activities related to the instruction of students in the classroom
* Non-commercial academic research: Activity related to not-for-profit research projects at an educational institution that are not conducted for the benefit of a third party.
* Organizational use: Activity related to a club or organization at an educational institution as related to the development of students; this could include open source student clubs, robotic clubs, engineering clubs or the like. Note that the non-acceptable use cases still apply to clubs and organizations.

### Examples of non-acceptable use cases

* Information technology/professional use: Use for maintaining or running the infrastructure, technology or otherwise, of the institution
* Administrative use: Use for any administrative functions of the institution including program management, planning, marketing, and service delivery
* Commercial research: Research conducted by any commercial programs or entities operated by or affiliated with the educational institution for a commercial purpose.
* Third party directed research: For example, the US Government may open a request for proposals for a specific project with a well-defined results. Research laboratories, owned and operated by a University such as an Advanced Research Laboratory (ARL), may apply and be awarded the project in the form of a contract. This type of work, with the goal of benefitting a third party through producing a given outcome, rather contributing to the general body of scientific research itself, does not qualify. An Advanced Research Laboratory or entity of the like, can still hold and apply for a GitLab for Education license but any work completed for the benefit of a third party, or under contract for example, cannot occur on the free license.
* Services: Any activities conducted by a consulting center, super computer laboratory, or entity that provides services for the benefit of a third party are not acceptable under the free license.

### Issuing licenses to students

At this time, GitLab does not issue licenses directly to students as part of the GitLab for Education Program.
Students are welcome to encourage their educational institution to apply to the program directly.
Students can access a free subscription for GitLab.com or a free download of our core self-managed offering.
Students can also apply for a 30-day trial if they would like to test more advanced features of GitLab.
Children under the age of 13 are not permitted to use GitLab.com (SaaS Software).

### Requests for support

When we are reviewing opportunities or requests for support, we must be able to answer yes to each of these questions to move forward with the work:

1. Will this work support, grow, and/or engage the GitLab for Education community?
1. Can it grow the skills and abilities of the education evangelist to ultimately make them a better resource to our community?
1. Is there a measurable impact on the GitLab for Education community? This can include influence on a GitLab KPI, progress on an OKR, or completion of responsibilities that are defined in the GitLab handbook.
1. Has an issue been created with the appropriate labels to define the work and assign a DRI?

If the answer to any of the above questions is "no", our team will collaborate with each other and the requestor to do one of the following actions:

1. Make adjustments so we can take on the work.
1. Find another team that is better suited to deliver the work.
1. Come to an agreement that the work should not be done.
