---
title: "Pricing and Packaging - GitLab for Campuses"
canonical_path: "/handbook/product/packaging-and-pricing/gitlab-for-campuses/"
---

---

## GitLab for Campuses

## Overview

GitLab provides qualified educational institutions with three different options for using GitLab on their campus:

1. **GitLab for Education**: The GitLab for Education Program provides free, unlimited, licenses of GitLab's top-tiers, either self-managed or SaaS, to [qualified educational institutions](/handbook/marketing/developer-relations/community-programs/education-program/#gitlab-for-education-program-requirements) for the **purposes of teaching, learning or non-commercial research only**. Use in Professional Information Technology or for *any* administrative purposes is **strictly prohibited** under the GitLab for Education license. Please see the [GitLab for Education handbook](/handbook/marketing/developer-relations/community-programs/education-program/) and [marketing pages](https://about.gitlab.com/solutions/education/) for more details. Universities must [apply here](https://about.gitlab.com/solutions/education/join/) to be accepted into the program.
2. [**Academic Discount**](/handbook/product/packaging-and-pricing/gitlab-for-campuses/#academic-discount): GitLab licenses are available at a 20% Academic Discount off list price for any qualifying educational institution. There are no use-case restrictions on these licenses.
3. [**GitLab for Campuses**](/handbook/product/packaging-and-pricing/gitlab-for-campuses/#gitlab-for-campuses-enterprise-offering): Qualifying educational institutions may purchase an enterprise campus-wide license. The campus-wide license offers unlimited seats (up to the last published enrollment of the institution) of GitLab's top-tiers, either self-managed or SaaS. This offering permits all use cases to occur within one license for the campus. *NOTE:* The ability to participate in any of the Education options (stated herein) is subject to GitLab's sole discretion. Please follow the applicable steps regarding qualification. **Purchases or requests shall not be considered accepted (or legally binding) unless and until executed between the parties in writing.**

## Academic Discount

Qualifying educational institutions may receive an Academic Discount of 20% off the current GitLab list price for each tier, either self-managed or SaaS. The discount will be applied at the discretion of the account owner and their regional sales leadership where applicable.

- The academic discount is available as of 2021-02-01. The academic discount will not be retroactively applied to close-won deals or true-ups.
- The academic discount can be applied at the time of the renewal if it is after 2021-02-01.
- The academic discount is not currently available to be purchased directly in the GitLab Customers Portal.

## GitLab for Campuses: Enterprise Offering

Qualifying educational institutions may purchase a campus-wide enterprise license.

### Details

- Only the top-tier of self-managed and SaaS GitLab are available in the campus-wide offering. Lower tiers are not available. The primary goal of this offering is to provide all of campus with the best GitLab has to offer and incentivize students, faculty, and staff to adopt GitLab's highest tier features.
- A single campus-wide enterprise license can have an unlimited number of seats **up to** the most recently published total student enrollment of the institution.
- The institution will provide documentation to the GitLab account owner for the most recent published student enrollment numbers (graduate and undergraduate) for within one year of the date of deal closing.
- The subscription at the agreed upon enrollment tier is valid for one year from the close date. No adjustments to the tier will be made during the subscription year.
- Multiple year subscriptions are not available at this time. Institutions must purchase and renew on annual basis. Annual renewal ensures the abilty to verify the enrollment tier at time of enrollment.

- The unit (or SKU) is available to an **individual educational institution** (see definitions below).
- The appropriate SKU will be determined based on the total number of enrolled students at the institution for the last published year of data available by the account owner.
- The institution may not request more seats than the last published enrollment number.
- The seats are available to all sub-units within the educational institution including campuses, colleges, schools, and divisions.
- The seats for each SKU are only available within the individual education institution and are not available outside of the institution. See definitions below for more details.
- Each individual educational institution within a  state, regional, or national system much purchase an individual license (SKU). The license (SKU) cannot be shared across individual institutions within a system.
- The GitLab for Campuses enterprise offering is not currently available through the Customers Portal. Universities must work with their regional sales account owner to obtain a license.

### Support

- A named single point of contact is provided for each college, school, or division within the institution. This reach expands to those units that serve as a primary tier administrative level for the institution. For example, the College of Engineering may have a named contact but the 8 individual departments within the College do not have a named support contact. Named support limits for Ultimate tier apply.
- The named contacts must be provided to GitLab and included in the support database. The account owner has the primary discretion to include or not include provided named support contacts based on the definitions below.
- Individual students, faculty, and staff outside of the named single point of contact for each primary division cannot directly contact GitLab support.
- Please refer customers to the GitLab Support process for [Managing Support contacts and handling details](https://about.gitlab.com/support/managing-support-contacts/) in order to seed a list of named support contacts.

### Tiers

The GitLab for Campuses enterprise offering is available at the following tiers:

| Institution Size | Deployment | SKU Name |
|------------------|------------|----------|
|Up to 4,999  |SaaS |[EDU Enterprise-Small] SaaS - Ultimate (formerly Gold) - 1 Year|
|5,000 up to 9,999 |SaaS |[EDU Enterprise-Medium] SaaS - Ultimate (formerly Gold) - 1 Year |
|10,000 up to 24,999 |SaaS |[EDU Enterprise-Large] SaaS - Ultimate (formerly Gold) - 1 Year|
|25,000 and over^+ |SaaS |[EDU Enterprise-XLarge] SaaS - Ultimate (formerly Gold) - 1 Year|
|Up to 4,999 |Self-Managed |[EDU Enterprise-Small] Self-Managed - Ultimate - 1 Year |
|5,000 up to 9,999 |Self-Managed |[EDU Enterprise-Medium] Self-Managed - Ultimate - 1 Year |
|10,000 up to 24,999|Self-Managed |[EDU Enterprise-Large] Self-Managed - Ultimate - 1 Year|
|25,000 and over^+|Self-Managed |[EDU Enterprise-XLarge] Self-Managed - Ultimate - 1 Year|

*Institution size is determined by the last published student enrollment (undergraduate and graduate) within one year of the contract closing.

- System limitations require a max number of seats. The XLarge SKUs are set to a max of 50,000k seats. If the number of seats needed is higher than 50,000 the Account Owner should notify Deal Desk in SFDC before sending the quote.

## Steps for Building a GitLab for Campuses Quote

The steps for building a GitLab for Campuses quote vary slightly from standard quotes.

1. Before building the quote, determine the proper tier based on the most recently published enrollment data provided by the insitution.
2. After creating the opportunity and a new quote following the steps in the [Sales Order Processing handbook page](/handbook/sales/field-operations/order-processing/)

   - On the `Select Billing Account page`choose the appropriate Quote Template - `01.21 New Order Form - EDU / 01.21 Amendment Order Form - EDU / 01.21 Renewal Order Form - EDU`.
   - Proceed as usual until the  `Add base products`, and Click `Select Plan` on the relevant product. Scroll to the appropriate product SKU names from the table above. For example, `[EDU Enterprise-Small] SaaS - Ultimate (formerly Gold) - 1 Year`.
   - Proceed as usual.

### GitLab for Campuses Order Form

The GitLab for Campuses Order form must be used for all GitLab for Campuses quotes because it contains specific language regarding the size of the institution.

#### Resellers

GitLab for Campuses can be sold through GitLab resellers. The specific language regarding the size of the institution from the GitLab for Campuses Order Form must be added to the Reseller Order Form.

### GitLab for Campuses Agreeement

The standard [GitLab Subscription Agreement](/handbook/legal/subscription-agreement/) is applicable to the GitLab for Campuses offering.

#### Definitions of Qualifying Education Institutions and Associated Entities

**Qualified educational institution**: an institution that has been accredited by an authorized agency within its applicable local, state, provincial, federal, or national government and has the primary purpose of affording instruction and conferring degrees. Qualified educational institutions can be public or private and must be non-profit/non-commercial.

The individual educational institution maybe organized under one corporate organization and government. Individual educational institutions generally have a uniquely identifiable email domain, governance, branding, degrees, administration, and colleges.

Individual institutions may be part of a larger state, regional, or national university system.

**University or Institution Campus**: individual educational institutions may have campuses located in a geographically separate locations from their main campus. The campus is generally a sub-unit of the main educational institution such that it reports to the same administration, uses the same email domain, has some level of shared degrees and services, and often the mascot and branding are shared.

**University College or University School**: a constituent unit or division of an educational institution. Generally, colleges are a collection of various related departments organized within its own governance within the wider educational institution structure. Colleges or schools may be named according to the types of degrees offered within the unit, for example, professional degrees or academic degrees. Colleges and schools are typically directly administered by a Dean that reports to the institution's governance.

**Research centers, institutes, and center-like units**: educational institutions commonly have a sub-unit organized around a specific research topic. These units may be the administrative home to faculty, students, and staff. Governance of the unit falls within the institution as a whole. Email domains, shared services, are all aligned with the primary institution.

**Stand-alone College**: this type of college is typically a stand-alone, entity smaller than a typical university, that emphasizes undergraduate education. Some colleges offer a broad range of academic areas while others specialize in professional or vocational training.  In this U.S., there are nearly 1,000 community colleges that offer 2-year associate degrees or 4-year degrees. Stand-alone colleges are considered in an individual educational institution for the purposes of this model.

**University System or Institutional System**: a system is a set of affiliated universities, colleges, educational institutions, or research institutions that are geographically distributed and governed by a system-wide governing body such as a board of regents or a board of trustees.

**Online Campus/University**: An online campus or online university, often branded as a Global Campus, may be affiliated with a University but is often a separate entity. The entity may be legally organized as a as a non-profit University or as a public-benefit corporation. Wholly online campuses or universities associated with a institution are considered an individual educational institution for the purposes of this model. The eligibility of wholly online campuses and universities will be determined on a case-by-case basis at the discretion of the regional sales team. The legal organization, for-profit status, enrollment, and other factors will be examined in determining the eligibility of the entity.

**For-Profit Universities/Colleges**: Universities and colleges owned and operation by for-profit businesses are not eligible for the enterprise education offering.

**For-Profit Units**: Individual non-profit institutions may have directly affiliated entities that are managed and operated by a for-profit entity or mechanism with a separate tax status than the parent University. This may include online program managers (for-profit online programs), endowment money managers, startup incubators, etc. For-profit units are excluded from the enterprise education offering unless specifically agreed upon by GitLab and indicated on the order form.

**Educationally Related Entities**: any entity that does not meet the qualifying criteria, such as code academies, massive open online course providers, bootcamps, and professional training centers, do not qualify for the GitLab for Campuses enterprise offering.

#### Medical Colleges

In order to be eligible for the education enterprise pricing model medical colleges must meet the following criteria:

- Be owned and operated directly by an accredited, degree-granting, non-profit, public or private, educational institution with the primary purpose of educating its enrolled students or
- Be owned and operated directly by an [academic health science center](https://en.wikipedia.org/wiki/Academic_health_science_centre).

#### Ineligible Entities

The following are **not** eligible for the GitLab for Campuses enterprise offering:

- Medical colleges directly owned or operated by a public hospital or a private hospital
- Medical colleges directly owned or operated with a integrated delivery network or system
- Medical colleges affiliated but with a University but not owned and operated by that University
- Medical colleges or teaching facilities owned and operated by a federal institute such as the National Institutes of Health or the CDC
- Training centers
- Independent research laboratories
- Re-Training programs
- Military schools, institutes, or training centers within a branch of the military
- Research institutes or National Laboratories that are owned by a Federal Government
- eLearning platforms or providers not directly owned and operated by an accredited academic University
- Bootcamps or independent learning platforms
