---
title: "Developer Advocacy: Mentoring and Coaching"
---

## Introduction

This handbook page documents best practices how Developer Advocates can help wider community members with mentoring and coaching.

## Mentoring

### Finding a mentor

GitLab Developer Advocates actively engage with mentoring wider community members. The team's time is limited with [our many activities](/handbook/marketing/developer-relations/developer-advocacy/), please understand when we decline a request. [Polywork](https://www.polywork.com/discover) and other platforms can help finding mentors.

### Resources

- Review the process and tips in [Mentoring at GitLab](/handbook/people-group/learning-and-development/mentor/)
- [How to be a mentor: 4 ways to change someone's life](https://www.betterup.com/blog/how-to-be-a-mentor)

### Topics

If the career path is to becoming a Developer Advocate, the [Developer Advocacy handbook](/handbook/marketing/developer-relations/) provides many resources.

Engineering and coding sessions depend on the knowledge and [focus area of the mentor](/handbook/marketing/developer-relations/developer-advocacy/).

Other examples are:

- Open Source contributions, code reviews, building communities, etc.
- Personal brand, thought leadership, speaking, content creation, developer advocacy

### Tips as a mentee

1. Share career ambitions and thoughts where you want to be.
1. Think of your personal challenges, and ask for familiarities and advice
1. Create a tag cloud of topics you'd like to ask your mentor in the future (Observability, Cloud-Native, etc.)
1. Take notes (pen and paper, whiteboard with post-its, GitLab issues, Notion, etc.)
1. Ask questions, share notes and code

#### Resources and plans

1. Define time commitment, and how much you can invest into the mentorship.
1. Document your learnings, and become a future mentor yourself.

#### Learning a new technology

1. Define goals ambitiously but do not overload yourself
1. Recap what you have learned, write a monthly blog post and use other methods to document your success and learnings
1. Adjust the goals if they feel reached too early.

### Tips as a mentor

1. Define your knowledge and set expectations.
1. Define goals and success.
1. Listen with empathy, cheer and encourage.
1. Discuss career and learning goals and progress.
1. Take action
    1. Burnout: Feeling tired, not sharing good vibes, only work topics, etc.
    1. Blockers: Ask for the problem and google together in a screen share.
1. Provide access to resources and people.
1. Turn learning sessions into fun pair programming and optionally record for later.

Document feedback and learnings in the handbook.

### Collaboration

#### Schedule regular chats

Make it a coffee chat with an agenda, following [GitLab communication best practices](/handbook/communication/#external-communication).

1. Offer a monthly chat, for example on the first Tuesday of the month, time XY.
1. Create a 1:1 Google doc with an agenda
    1. Document all URLs shared in the chat, share async "as you see them"
    1. Write down thoughts and ideas

```text
1. Good vibes
1. Asks
1. Discussion
1. FYI
```

#### Learn together in public GitLab groups and projects

- Create a public group and projects for code snippets, learning projects, etc. in the [EveryoneCanContribute DevRel group](https://gitlab.com/everyonecancontribute/devrel) on GitLab.com
  - Organize learning activities in a group epic for one year ([example for FY24 (Feb 2023 - Jan 2024)](https://gitlab.com/groups/everyonecancontribute/devrel/learn-julia/-/epics/1)).
- Re-use best practices from [Developer Advocate workflows](/handbook/marketing/developer-relations/developer-advocacy/workflow/)
- Use GitLab for learning technologies, practice CI/CD and DevSecOps, and create talk demos

Example in FY23: [Julia Furst Morgado](https://gitlab.com/everyonecancontribute/devrel/learn-julia) changes careers to learn DevRel, related technologies (cloud native, Kubernetes, etc.) and CFP talk submissions.

Example in FY24: [Aakansha Priya](https://gitlab.com/everyonecancontribute/devrel/learn-aakansha) learns DevRel, works on Linux, container, Kubernetes, cloud-native topics, and learns the DevSecOps journey. Created epics and issues to organize tasks and goals:

- [Events and CFPs epic](https://gitlab.com/groups/everyonecancontribute/devrel/learn-aakansha/-/epics/1)
- [DevSecOps journey epic](https://gitlab.com/groups/everyonecancontribute/devrel/learn-aakansha/-/epics/2)
- [Cloud-native journey epic](https://gitlab.com/groups/everyonecancontribute/devrel/learn-aakansha/-/epics/3)

Organisation:

- Maintain a [templates project for the DevRel group](https://gitlab.com/everyonecancontribute/devrel/gitlab-templates), which [provides issue/MR templates in a single source of truth](https://docs.gitlab.com/ee/user/project/description_templates.html#set-group-level-description-templates).
  - Edit new projects in `Settings > Default description template for issues` with the following text: `<!-- Please choose a description template from the dropdown above to continue. Accept to override this text. -->`

#### Talks and Call for Papers

Start drafting talk ideas in a dedicated Google doc for each topic, and discuss the story and technologies in 1:1s. Add thoughts async, and share suggestions directly.

Organisation and workflow tips:

1. Create a calendar with events in the coming year, and keep track of Call for Paper due dates. Use `cfps.dev` (link no longer available) by Brendan.
1. Copy the [Developer Advocate CFP workflow](/handbook/marketing/developer-relations/developer-advocacy/workflow/#cfp-workflow) with issues and scoped labels into a new group/project for CFPs. Example for [KubeCon EU 2023](https://gitlab.com/everyonecancontribute/devrel/learn-julia/cfps/-/issues/2).
1. Add issue references to Developer Advocate CFP issue tracking to coordinate efforts.
1. Review the talk title and abstract in the Gdoc async or sync. As a mentor, change to `suggesting` mode in the Gdoc and provide suggestions with all thoughts. Encourage the mentee to review the suggestions, and accept if reasonable. This workflow will enable mentees to take feedback from everyone in the future.
1. Encourage social shares when the CFP has been submitted. Start without the talk title, later encourage to add the topic that has been submitted. Example from Julia Furst Morgado in [this tweet](https://twitter.com/juliafmorgado/status/1593696600366391299) for KubeCon EU 2023.

_Tip_: Talks are stories that evolve each time they are told. Think of a rock band giving a concert, each song is a little different when played live. The same applies to a talk story - iterate on talk questions and feedback, and also add new learnings and technologies over time. Events that accept a talk do not have the same audience and new folks can learn from talks.

Events and CFP forms collect different information, and also have different character limits for abstracts, etc. Iterate on collecting all details in a Google doc for the abstract as a single source of truth.

- Context (inspiration sources, other talks, community feedback)
- Submissions (list of events with URLs into CFP issues, acceptance state with emoji)
- Title
- Abstract
  - 1000 chars (fits KubeCon)
  - Less than 900 chars
  - Less than 700 chars
- Ecosystem benefits (KubeCon)
- Knowledge required
- Learning goal
- Open Source Projects
- Track
- Bio/CV (add URL to speaker's SSoT website/Gdoc)

Use these templates:

- [CFP template Google doc](https://docs.google.com/document/d/1vF9i4ZaR1_u52r_vUcVls0uhQIi7gzG9WkQ6l369FU4/edit#).
- [Biography template Google doc](https://docs.google.com/document/d/1e_Sk0OGpKjWbs8C3xrIk33cShvTgoqRO3r1aQApiB5M/edit)

## Coaching

Mentoring usually happens in 1:1 conversations, building trust and relationships, with optional public sharing. Coaching can happen in private and public, and can involve different types of short or long term help.

Engage with public replies in Twitter threads, LinkedIn posts, etc. and offer coffee chats or private conversations to wider community members who seek for advice. Listening to the story and plans helps with making suggestions efficiently, and builds trust and relationships too.

### Coaching Areas

Developer Advocates are encouraged to help with

- [Review talk abstracts and slide decks](/handbook/marketing/developer-relations/events/#speaker-enablement)
- [Social media best practices](/handbook/marketing/developer-relations/developer-advocacy/social-media/)
- Help with advice on detecting and preventing burnout
  - [Twitter Thread](https://twitter.com/dnsmichi/status/1534256896135335936) as a response to the question `How do I know when I'm showing signs of burnout?`

## Feedback

### Getting Started with Cloud-Native Help

Getting started in the cloud-native community with a huge landscape of tools to understand can be overwhelming. Learning technologies and frameworks, from Kubernetes to beyond, requires guidance and a plan for individual growth.

Michael had a [coffee chat with Edidiong Asikpo](https://twitter.com/Didicodes/status/1436280427505930240) who started her cloud-native journey as Developer Advocate at AmbassadorLabs in 2021. They discussed a learning plan as a DevRel in cloud-native, and shared ideas on demo deployments, learning with Observability, and also looked into the [Developer Advocacy social media handbook](/handbook/marketing/developer-relations/developer-advocacy/social-media/).

In 2022, Edidiong shared her promotion to Senior Developer Advocate, [responding to Michael's wishes](https://twitter.com/Didicodes/status/1547337357434753027):

> The conversation we had when I started my journey in the Cloud Native space gave me the context I needed to learn and improve my skills. Thank you.
