---
title: "Evangelist Program"
---

## Overview

At GitLab our mission is to change all creative work from read-only to read-write so that **everyone can contribute**. In order to fulfill this mission, we need to create both the tools and platform to enable this change and a community of contributors who share our mission. We are just getting started in building the GitLab community and we encourage everyone to contribute to its growth.

There are many ways to participate in the GitLab community today: [contributing to an open source project](/handbook/marketing/developer-relations/contributor-success/), [contributing to our documentation](https://docs.gitlab.com/ee/development/documentation/), [hosting your open source project on GitLab](https://about.gitlab.com/solutions/open-source/), or teaching your colleagues and collaborators about the value of [Concurrent DevOps](https://about.gitlab.com/topics/devops/ ).

We are building an evangelist program to support people who share our mission and want to give tech talks, run local meetups, or create videos or blogs. For now, please email `evangelists@gitlab.com` if you have feedback on our vision, ideas for how we can build our community, or suggestions for a name for our evangelist program.

## How to see what we're working on

We use the `Evangelist Program`, `Heroes`, and `Meetups` labels to track issues. The [Evangelist Program issue board](https://gitlab.com/groups/gitlab-com/marketing/community-relations/-/boards/951386?&label_name[]=Evangelist%20Program) provides an overview of these issues and their status.

Evangelist Program issues typically exist in the `Evangelist Program` subgroup but they can also exist in Field Marketing, Corporate Marketing, or other marketing subgroups. Our upcoming Meetups are tagged with the `Meetups` label and listed on the [Meetups board](https://gitlab.com/groups/gitlab-com/marketing/-/boards/962542?&label_name%5B%5D=Meetups).

We utilize a process of having a epic for current OKRs and using labels and boards to track ongoing work related to our KPIs (for example: Meetups). As our OKRs and KPIs change, this page will be updated so you can see what we are working on and track our progress.

### Evangelist Program OKRs and KPIs

We are actively looking at ways to improve the data collection for our Evangelist Programs. If you have ideas for how we can improve, please reach out to [evangelists@gitlab.com](mailto:evangelists@gitlab.com).

#### KPIs

Key Performance Indicators for the Evangelist Program can be found in the [Marketing section](/handbook/company/kpis/#marketing-kpis) of GitLab's KPI index.

#### How to report on program metrics and activity

When reporting on program activity, you may wish to include charts or graphs for different program KPIs. For example, you will likely want to update the program metrics when preparing for a Group Conversation. When you need to report on program metrics and activity, please follow these steps:

**Meetup metrics**

1. Visit GitLab's [Meetup Pro page](https://www.meetup.com/pro/gitlab/)
1. The number of countries, meetups, and members can be found next to the GitLab logo near the top of the page.
1. Additional Meetup insights can be found in the [Pro admin dashboard](https://www.meetup.com/pro/gitlab/admin/analytics) on Meetup (note: requires admin access)

**GitLab Heroes members**

1. Visit the [GitLab Heroes members page](https://about.gitlab.com/community/heroes/members/).
1. The number of current Heroes on the page will be listed within the hero section of the page. This is our single source of truth for the number of GitLab Heroes in the program.
1. We welcome all level of contributors to [apply](mailto:incoming+gitlab-com-marketing-community-relations-evangelist-program-git-18503012-issue-@incoming.gitlab.com) to the GitLab Heroes program. If you would like to refer someone to the program, use the GitLab Heroes referral [form](https://forms.gle/X632fCybQ5tsRQWt9).

**GitLab Heroes contributions**

1. Heroes Contributions are documented in the [heroes_contributions.yml](https://gitlab.com/gitlab-com/www-gitlab-com/-/blob/master/data/heroes_contributions.yml) file. This is the single source of truth for Heroes contributions.
1. You can see recent commits to this file in the [file history](https://gitlab.com/gitlab-com/www-gitlab-com/-/commits/master/data/heroes_contributions.yml). These will provide you insight into the recent activities of the GitLab Heroes members which you can include in your reporting on the program.

### Upcoming events

The [GitLab Developer Advocate calendar](/handbook/marketing/developer-relations/developer-advocacy/#-team-calendar) includes a list of our upcoming meetups, hackathons, office hours, and other community events. After opening the calendar, you can click on the `+` in the bottom right corner of the browser window to add `GitLab Developer Advocacy` to your list of calendars in Google Calendar.

## Meetups

GitLab supports team members and members of the wider GitLab community who want to organize or speak at meetups. Our goal in supporting these events to better engage with and increase connections among the GitLab community, increase awareness of GitLab, and better educate the technology community.

### Organize a meetup

- We love and support meetups. If you participate in local tech groups and are interested in having a GitLab speaker or GitLab as a sponsor, members of the wider GitLab community should email `evangelists@gitlab.com`. Team members should submit an [issue](https://gitlab.com/gitlab-com/marketing/community-relations/evangelist-program/general/issues/new?issuable_template=community-event). Please note, providing sufficient lead time (at least a month) allows us to better support your event so feel free to reach out as soon as possible.
- When a meetup issue is submitted by a community member, an issue should be created using the [community event template](https://gitlab.com/gitlab-com/marketing/community-relations/evangelist-program/general/issues/new?issuable_template=community-event), labeled with the [`Meetups`](https://gitlab.com/groups/gitlab-com/marketing/-/issues?label_name%5B%5D=Meetups) label, and be given a due date on the date of the event. Meetup issues created by a GitLab team member should receive the same treatment.
- If you are interested in creating your own GitLab meetup or if you already have an existing meetup on meetup.com that you would like to link to GitLab's meetup.com Pro account, please email `evangelists@gitlab.com`. You can find the list of GitLab meetups on the [meetup.com page](https://www.meetup.com/pro/gitlab).
  - Connecting your group to GitLab's Meetup Pro instance will also allow you to utilize easy-to-use, custom templates for your Meetup events. When scheduling a new event on Meetup, you can choose a template by clicking on `Start from a template` in the right sidebar and choosing a template that best fits your event.
- When you are getting started, we recommend scheduling at least 2 meetups. Publish your first meeting with a date and topic, and then a second meeting with a date and topic. The second meeting can have a flexible topic based on how the first meeting goes. The point of setting two meet-ups is to help build momentum in the new group.
- Often, we try to have GitLab employees attend the first couple of meetups. Once the group has hosted a couple of successful events, it becomes easier for the group to sustain itself. It is much harder to start new meetups versus maintaining existing ones. So we make an effort to support and keep new meetups going.
- Additional information on organizing your own meetup events can be found on our [Meetup checklist](https://about.gitlab.com/community/meetups/checklist/).

#### Meetup format ideas

Think outside the box. All meetups and community events are different. Find what works for your members and fits the event goals.

- Panel: Ask 3-4 people to share or breakdown their favorite feature
- Roundtable discussion: Attendees will discuss the new features in a structured manner. Assign someone who will document the pros, cons, and neural thoughts of the new release. Share the discussion with the GitLab DE team.
- Workshop: Conduct detailed instructions to highlight use cases
- Lighting Talks: multiple speakers who present for 5 - 10 minutes associated with Release 15
- Social hour: An organized networking event where folk of similar interest comes together to build relationships and rapport

#### Create a new Meetup group

- First,  contact the Evangelism Program Manager, they will ensure you are granted access by sending you a ticket. The ticket link grants the organizer access to meetup. You then will follow the prompts to set up your new group. Happy organizing.
- Internal steps: Dashboard → Groups → Click the button to "+ Add group" → Click button to "Create tickets" → open txt file →Copy and paste link → Send to the requestor (via Slack or Email)

#### Meetup Promotion

GitLab provides support to meetup organizers to drive attendance at meetup events. In order to help support our organizers, GitLab will consider the following:

- Add meetup event to the [GitLab Events](https://about.gitlab.com/events/) page on our website by `Edit this page` action at the bottom.
- Add meetup event to the [Community Events calendar](https://calendar.google.com/calendar/embed?src=gitlab.com_90t5ue1q8kbjoq5b0r91nu7rvc%40group.calendar.google.com&ctz=America%2FNew_York).

Organizers are encouraged to take the following steps to drive attendance to their events:

- Use your personal social media to promote the event within your network and invite your members to do the same.
- Post about the event, including a link to the registration page, in the [News section](https://forum.gitlab.com/c/announcements/5) on forum.gitlab.com.
- Send at least two reminders in the weeks and days leading up to your meetup reminding people to RSVP.
- Reach out to other related meetups (ex: DevOps, Cloud, Kubernetes) in your area and invite them to your event to help grow your community.

Note: GitLab asks that community organizers do not create social media accounts that make use the GitLab logo or trademark in their username and profile as this may create confusion as to whether or not you are affiliated with GitLab in any way. Instead, we encourage our community organizers to leverage the communications tools on Meetup and their own social media profiles for community building and outreach. If social media outreach is needed to promote events or attract new members to a group, GitLab's social media team will amplify the personal accounts of organizers, when appropriate.

#### Meetup Expenses

**IMPORTANT: We have resumed providing some support for in-person events. Support for any in-person events is dependent on the meetup group and event. If you are planning a meetup event and wish to get reimbursed for event-related expenses, please confirm your event's eligibility in writing in a GitLab issue before spending money towards your meetup.

#### Virtual Meetup support

For some virtual meetups, a Zoom link may be required to execute the event. To create a Zoom link for a meetup, follow these steps:

1. Log into Zoom.us with your GitLab Zoom account.
1. Click "My Account" in the menu bar located in the upper right corner of the page.
1. Click "Meetings" in the left side menu.
1. Click the "Schedule a meeting" button on the right side of the page.
1. Enter meeting info. Make sure to set "Meeting ID" to "Generate automatically", check the "Passcode" box, check "Mute participants on entry", and check "Automatically record meetings" and set to record "In the cloud".
1. Click "Save" button.
1. On the meeting page, the "Invite link" is the link that should be shared with the meetup group and used on the event page.

If you must edit a meeting, following steps 1-3 from above will show a list of your upcoming meetings. Then click the "Edit" button next to the meeting that you want to change.

### Speak at a meetup

Meetups help us raise awareness of GitLab and build communities in new places. We love to track them to know where the community is growing. If you are speaking at a meetup as a representative of GitLab or you are giving a talk about GitLab, please let us know! Here's how and why we do this:

- GitLab team member speakers should use the [Meetup Speaker template](https://gitlab.com/gitlab-com/marketing/community-relations/evangelist-program/general/issues/new?issuable_template=meetup-speaker) to create a new issue with the details for your meetup talk. Community members can contact `evangelists@gitlab.com` if they wish to share an upcoming speaking opportunity with the GitLab team.
- Opening an issue helps us support you. A few ways we can help:
  - Marketing: We'll share the event on our blog, via social, and with GitLab community members in the area to raise awareness of the event.
  - Sponsorship: GitLab will cover the cost of food and beverages for meetup organizers.
  - Swag: Our swag is pretty popular so we'll send you plenty of stickers and _maybe_ some other fun stuff to give away.
  - Speaker prep: If you need help with your deck or would like someone to offer feedback on a dry run of your talk, the [Evangelist Program Manager](mailto:evangelists@gitlab.com) is happy to help.

### GitLab Virtual Meetup group

- GitLab's Evangelist Program Manager organizes the [GitLab Virtual Meetup](https://www.meetup.com/gitlab-virtual-meetups/) group. This group brings together our global community for virtual meetup events.
- GitLab virtual meetups typically feature one speaker followed by randomized breakout groups using the Zoom breakout room feature. The normal duration of these events is one hour in total.
- For GitLab Virtual Meetups, the Evangelist Program Manager will upload the recordings to GitLab Unfiltered.
- If you would like to present at a GitLab virtual meetup, please email `evangelists@gitlab.com`.
- Additional information on organizing your own virtual meetup events can be found on our [Meetup checklist](https://about.gitlab.com/community/meetups/checklist/#planning-a-virtual-meetup).

### Inactive Meetups

To ensure proper metrics we must vet for:

1. Check meetup activity for communities every quarter (3-4 months)
2. If a chapter has zero meetups within the quarterly span:
    1. contact the listed organizer to check in on status of group.
    2. Email members, ask about interest in organizing chapter
    3. Update the program sheets with new contact information

## GitLab Heroes

[GitLab Heroes](https://about.gitlab.com/community/heroes/) engages, supports, connects, and recognizes members of the wider GitLab community who make outstanding contributions to GitLab and our community around the globe. Examples of activities that may make a member of the wider GitLab community eligible for the Heroes program include:

- Organizing meetups
- Recording demos for YouTube
- Giving talks at conferences and events
- Writing technical blog posts
- Contributing to our open source project

Heroes are eligible for rewards to help enable and encourage contributions. These rewards include:

- Invitations to special events including GitLab Commit
- Support for travel to speak about GitLab at events
- GitLab Ultimate licenses
- Special Heroes swag so people know how awesome you are
- Access to GitLab's product, engineering, and developer advocate teams to help with reviews of talks and blog posts

We have three levels of Heroes: Contributor, Hero, Superhero. A community member's contributions will determine at which level they enter the program and the benefits for Heroes increase as they progress through the levels. More detail can be found in the [Hero's Journey](https://about.gitlab.com/community/heroes/#heroes-journey) section of the Hero's page.

Community members who are interested in applying for the Heroes program should apply through the [application form](https://about.gitlab.com/community/heroes/#apply) on the Heroes page.

The Heroes program is managed by the Evangelist Program Manager with support from the GitLab's Developer Advocate team. The Evangelist Program Manager leads the review of applications along with the Developer Advocate team. The Evangelist Program Manager also serves as the main point of contact with the Heroes community, manages Heroes related marketing pages and events, and is responsible for the administration of the program including metrics and KPI tracking.

Select Heroes may be asked to join the GitLab Developer Adocate Community. At that point, those community members will be supported by and engage with the Developer Advocate team.

Please email us at `evangelists@gitlab.com` if you have questions about the GitLab Heroes program.

### GitLab Heroes Application Process

We use GitLab to manage our Heroes application process. To apply for GitLab Heroes, community members must follow these steps:

1. Click the "Become a Hero" button or the "Apply to become a GitLab Hero" button on the [GitLab Heroes page](https://about.gitlab.com/community/heroes/#apply)
1. Clicking the button will open an email message, in which, the applicant will be prompted to send an email which creates an issue in the [`GitLab Heroes Application`](https://gitlab.com/gitlab-com/marketing/community-relations/evangelist-program/gitlab-heroes-applications) project using GitLab's [Service Desk](https://docs.gitlab.com/ee/user/project/service_desk/) feature. _Note: only GitLab team members can view this project as the issues may contain applicants' email addresses._
1. Using Service Desk, an auto-reply will send an application template to the applicant.
1. Once the applicant replies with their completed the application, the Evangelist Program Manager should apply the `heroes-application` template to their Service Desk issue.
1. Hero applications will expire 5 weeks after they are received if there is no communication from the applicant. If you are interested in the program and your original application has expired, you are encouraged to reapply.

After completing the above steps, the application is ready for review. The review committee consists of the Evangelist Program Manager as the lead with the Contributor Success team members supporting. The composition of the review committtee is subject to change. Any changes will be reflected here.

Generally, applicants will receive a response from GitLab within two weeks of submitting an application. Following the review process, the Evangelist Program Manager will inform folks who are selected to be GitLab Heroes of your status including the level (`Contributor`, `Hero`, `Superhero`) at which time you will enter the program. If you have any questions about the status of your application, please reach out to [evangelists@gitlab.com](mailto:evangelists@gitlab.com) for support.

We conduct semi-annual reviews of the current GitLab Heroes members to ensure they are remaining active in the community in order to maintain their GitLab Heroes status. When a current GitLab Hero is inactive, the Evangelist Program Manager will contact them to identify the reasons and work with them to resolve any blockers or issues. When a GitLab Hero no longer plans to remain active in the GitLab community, the Evangelist Program Manager will remove them from the active membership of the program.

### Adding yourself to the Heroes page

Upon acceptance, Heroes are asked to submit a Merge Request to add themselves to the [GitLab Heroes members page](https://about.gitlab.com/community/heroes/members).

To add yourself to the Heroes page, you will need:

- Your personal Twitter / GitLab handles
- A picture of yourself for the Heroes Members page

> **Picture Requirements**
>
>
> - Crop image to a perfect square.
> - Keep maximum dimension under 400 by 400 pixels.
> - Use the JPEG (`.jpg`) or PNG (`.png`) format.
> - Test image in color and black-and-white.
> - Name file `yournameinlowercase` and add the appropriate file extension.

Once you have the above items, follow these steps to add yourself to the Heroes page:

1. Go to the [Heroes file in the GitLab.com / www-gitlab-com](https://gitlab.com/gitlab-com/www-gitlab-com/blob/master/data/heroes.yml) project.
1. On the file page, click on the button labeled `Web IDE` near the middle of the page.
1. When prompted, click `Fork` to create a Fork of the repo which will allow you to make changes and submit a Merge Request.
1. You should see the `heroes.yml` file open in your browser once the fork has been created. Add the following fields to the end of the file and enter your information into each of the blank fields:

``` yaml
- type: person
  name:
  locality:
  country:
  role: GitLab Hero
  twitter:
  bio:
  gitlab:
  picture:
  # List of your domains of expertise, remove the ones that do not apply
  # or add others if missing
  domains:
    - frontend
    - backend
    - database
    - documentation
    - blog posts
    - videos
    - talks
  # List of your interests related to GitLab, for example Project Management,
  # CI/CD, etc.
  interests:
    - Interest A
    - Interest B
  story: # The story of your GitLab journey
```

1. After updating `heroes.yml`, use the file browser on the left side of the screen to navigate to `source/images/heroes`.
1. Click the `⋁` icon next to the `heroes` directory, select upload file, and upload the photo of yourself. Be sure to follow the picture requirements listed above and confirm that the file name matches your `picture` entry in `heroes.yml`.
1. Once you have finished this, click the `Commit` button in the bottom left. It should say something like `2 unstaged and 0 staged changes`. This will bring up a sidebar with an `Unstaged` and `Staged` area.
1. Check the files to ensure your updates are what you expect. If they are, click the check mark next to the filename to "stage" these changes.
1. Once you have verified all of the edits, enter a short commit message including what you've changed. Choose `Create a new branch`. Name the branch in the format of `YOURINITIALS-heroes-page` or similar. Tick the `Start a new merge request` checkbox. Then click `Commit` once more.
1. Click on the Activity link in the header to go to your Activity page. Once there, click on the blue `Create merge request` button at the top of the page.
1. Fill out the merge request details. Please ensure you tick the box to `Allow commits from members who can merge to target branch` as detailed on the [Allow collaboration on merge requests across forks](https://docs.gitlab.com/ee/user/project/merge_requests/allow_collaboration.html#enabling-commit-edits-from-upstream-members) page in our docs.
1. Mention `@gitlab-da` in a comment in the merge request so our team can review and merge.

### Adding members to the GitLab Heroes project

Upon accepting new members to the GitLab Heroes program, newly accepted members should be invited to the [GitLab Heroes project](https://gitlab.com/gitlab-com/marketing/community-relations/gitlab-heroes).

To add a new member to the project:

1. Navigate to [GitLab Heroes project](https://gitlab.com/gitlab-com/marketing/community-relations/gitlab-heroes)
1. Go to `Project information > Members` in the left sidebar.
1. On the `Invite Member`, input all new members using their GitLab username or email address associated with their application.
1. Set `Choose a role permission` to `Developer`.
1. Set `Access expiration date` one year from the date of acceptance.

### Communication with Heroes

Communication with Heroes applicants and members of the GitLab Heroes program is conducted through email updates, generally from the Evangelist program, and via the [GitLab Heroes project](https://gitlab.com/gitlab-com/marketing/community-relations/gitlab-heroes). Please communicate using MRs and Issues in the GitLab Heroes project whenever possible to provide transparency to the wider GitLab community and allow for easier collaboration.

The [GitLab Heroes Feedback form](https://forms.gle/kGp9num9nHGWk4TF6) collects the feedback of the heroes who are looking for a more private way to contact the Evangelist Program Manager.

When communicating with GitLab Heroes:

- you may wish to use the **GitLab Heroes Email Templates doc** in Google Drive for acceptances, declines, follow-ups for clarification on contributions, and regular program updates. Access to these templates is limited to GitLab employees due to the sensitivity of some of the content in the templates (such as codes for Heroes swag).
- when emailing multiple Heroes, please use BCC to add them to the email. If the intent of the email is to encourage communication between Heroes (which would be impaired by using BCC), use an issue and send it to the necessary Heroes using BCC.

#### Virtual Heroes Hangouts

The purpose of monthly hangouts is to bring together the Heroes to network, share hacks and build camaraderie amongst the GitLab Heroes. As the evangelism program manager, one of my goals is to get to know more of the GitLab Heroes and engage with you all on a regular basis.

Each hangout is either hosted by a GitLab evangelist team member or a hero. The goal of rotating hosts is to be inclusive to all regions.

- Each hangout is recorded
- There is a Heroes Hangout doc to capture notes from the chat

#### Requests for Heroes

Please follow the process detailed in the GitLab Heroes project to [request support from Heroes](https://gitlab.com/gitlab-com/marketing/community-relations/gitlab-heroes#requesting-support-from-heroes).

### GitLab Heroes Licenses

If you are a GitLab Hero seeking access to Ultimate and Duo, please create an issue in the GitLab Heroes project using the [heroes-license-request template](https://gitlab.com/gitlab-com/marketing/community-relations/gitlab-heroes/-/issues/new?issuable_template=heroes-license-request).

Please note:

- These licenses are only available to GitLab Heroes at the Hero or Superhero level.
- Licenses are for personal use and therefore limited to one user.
- Licenses are only availble for a personal subgroup within the Community group on GitLab.com.
- Membership to the group will be issued for 6 months and can be extended as long as the GitLab Hero maintains their Hero or Superhero status in the program.

GitLab team members should follow the steps in the License Request issue to fulfill the license request.

### GitLab Hero Alumni Group

We are planning to launch the GitLab Heroes Alumni group in early February 2022. The alumni group provides a way for us to continue to recognize the important contributions of Heroes who are no longer able to contribute regularly. As folks experience changes to their personal and professional lives and as we have all had to adjust to new norms, we understand and empathize. We are implementing this solution to keep alumni involved and connected to our community while allowing us to focus our program resources on our most active community members.

Those who join the GHA group are welcome to reinstate their active status upon resuming community activity at the GitLab Heroes level.

The requirements listed on the [hero's journey table](https://about.gitlab.com/community/heroes/#heros-journey) will continue to be the standard for qualifying to be a Hero.

**The ask**

If you would like to remain in the active GitLab Heroes group, please update your community contributions to maintain your GitLab Heroes status by following these steps:[Adding a contribution to the GitLab Heroes Contributions](https://gitlab.com/gitlab-com/marketing/community-relations/gitlab-heroes#adding-a-contribution-to-the-gitlab-heroes-contributions-page).

If you have not shared any recent contributions or otherwise been involved in the GitLab community between February 1, 2021 and January 31, 2022, the Evangelist Program Manager will reach out with an invite to join the GitLab Heroes Alumni group.

**Looking ahead**

The evangelism team is looking towards the future of the GitLab Heroes program and wants to ensure we are supporting each of you.

The future of the program includes:

- Heroes summits hosted during GitLab Commit conferences
- Wider community meetups and other auxiliary events
- Speaker support
- and more.

These are just a few benefits of being an active hero. We look forward to learning more about each of your contributions to GitLab. #EveryoneCanContribute

### GitLab Heroes Swag

GitLab Heroes swag is available only for GitLab Heroes.

GitLab Heroes swag fulfillment is managed by Boundless.

Note: Process will be updated soon, new merch is coming soon.

To replish Heroes swag, please follow the necessary steps in the [Merchandise workflow](/handbook/marketing/brand-and-product-marketing/brand/merchandise-handling/#ordering-new-swag) pages of the Handbook.

### GitLab Heroes Project

The [GitLab Heroes project](https://gitlab.com/gitlab-com/marketing/community-relations/gitlab-heroes) is used for discussion via Issues, as a repo for materials that GitLab Heroes create, and a home for other resources for members of the program. Everyone in the program will have Developer access. GitLab Heroes and our community are encouraged to contribute to the project.

## Community events

If you are organizing or speaking at a community-driven GitLab-centric event, we will do our best to support you including connecting you with speakers and, when possible, sending stickers or other small swag items. At this time, we are unable to provide financial support to community events. If you have questions, you can always reach us by sending an e-mail to `evangelists@gitlab.com`.

### Student-run hackathons

Student hackathons are the events most frequently submitting requests for support from GitLab. Hackathon organizers who wish to leverage GitLab's DevOps platform for their events are encouraged to use free trials for their events. This can be done by directing hackathon participants to apply for a [free trial of GitLab](https://about.gitlab.com/free-trial/) for use during the hackathon which will allow them to use all of GitLab's features. In some cases, if your event meets [the criteria](/handbook/marketing/developer-relations/workflows-tools/team-budgets/#community-event-sponsorship) above at a score of 9 or higher, we may also send stickers for participants or swags as prizes. Given the volume of requests we receive, providing financial support for these events is not feasible.

## Beyond Code Series

### What is Beyond Code on Twitter Spaces?

The Beyond Code series elevates non-technical conversations and connects GitLab to the wider community. The topics are relatable, ranging from burnout, developer relations, remote work, branding, and much more. The chats are casual and intended for all audiences. We would like folks to feel included and heard in the discussions.

We chose to host the conversations on [Twitter Spaces](https://help.twitter.com/en/using-twitter/spaces). It is an audio-only component of the social platform, Twitter. Hosting on Twitter Spaces allows us to expand our reach of listeners. Everyone is able to listen in from their phone or a web browser. Attendees can also ask questions by 'raising a hand' or by using the hashtag #BeyondCode. Speakers are required to join the Twitter Space from the Twitter application on their phones (iOS or Android) in order to be able to speak. A recording is available on Twitter after the space ends.

- Each space is required to have a corresponding call to action (CTA). Examples of CTAs include a link to the handbook to drive traffic, a link to a GitLab issue for discussion, a blog post, learning course, or event.

#### What if I have an idea for a Beyond Code Episode?

Use the [Beyond Code Episode Proposal](https://gitlab.com/gitlab-com/marketing/community-relations/evangelist-program/general/-/issues/new?issuable_template=beyond-code) issue template to share your idea. We look forward to hearing from you!

#### Structure of a Beyond Code Conversation

- 1 Moderator (GitLab Team Member)
- 2-3 Speakers
- 45 minute live-recorded conversation
- 1 administrator from the Social Media Marketing team

#### Social Team Support

The social team plays a very key role in the success of each episode of a Beyond Code episode. Alisha Ward, Sr. Social Media Marketing Manager, is the driving force behind all of the behind-the-scenes social media strategies of the series.

- Creating the Twitter Space, including bit.ly link
- Pre and post-event engagement
- Recordings
- Providing metrics/ analytics
- and any other amplification of the episode

#### Choosing speakers

Each conversation should showcase a diverse array of thoughts on the topic. The max number of speakers should be 3-4 max. Given the allotted time of 45 minutes, this number of speakers allows for a natural flow of conversation. One or two speakers should be external to GitLab and, in line with GitLab's [speaking policies](/handbook/marketing/corporate-communications/speaking-resources/#event-requirements), at least two speakers should be from an underrepresented group.

When looking for internal guests, mention the topic in the #whats-happening-at-gitlab slack channel. If you have a particular person or persons in mind for the topic mention them directly in the issue template.

Contact external guests by sending an email. The email allows for tracking the conversation taking place. Being that everyone doesn't have a GitLab account.

Use the guest invitation copy provided [here](https://docs.google.com/document/d/1YdyPNOFoOomhlAfyo5CQBoBuCUI00o2GW17zZUC7CA4/edit). The email template has the Know-Before-You-Chat checklist which sets expectations for pre, post, and day-of logistics for each conversation.

#### Digital Assets

We have digital assets on Canva that were created by the GitLab Design team.

There will be digital asset cards created for every episode. All cards have pertinent information to promote the episode. Only selected team members have access to edit these assets.

- Introducing the event (date, time, speakers, and topic)
- All speakers will receive a speaker card to share on social media platforms
- Post-event retweet cards

#### Past and Upcoming Beyond Code Conversations

<table>
  <tr>
   <td><strong>Episode </strong>
   </td>
   <td><strong>Date </strong>
   </td>
   <td><strong>Time</strong>
   </td>
   <td><strong>Live Listeners </strong>
   </td>
   <td><strong>Playbacks</strong>
   </td>
  </tr>
  <tr>
   <td>
<ol>

<li>GitLab talks DevRel: Don't Judge a Career by its Title?
</li>
</ol>
   </td>
   <td>May 6
   </td>
   <td>2 PST
   </td>
   <td>277
   </td>
   <td>(no recording)
   </td>
  </tr>
  <tr>
   <td>
<ol>

<li><a href="https://twitter.com/i/spaces/1yNxaYplmVvxj?s=20">Reigniting the flame: Burnout is Real!</a>
</li>
</ol>
   </td>
   <td>June 8
   </td>
   <td>1 PST
   </td>
   <td>448
   </td>
   <td>1596
   </td>
  </tr>
  <tr>
   <td>
<ol>

<li>Rebrand Rewind with GitLab
</li>
</ol>
   </td>
   <td>July 7
   </td>
   <td>2 PST
   </td>
   <td>
   </td>
   <td>
   </td>
  </tr>
</table>

#### Resources

- [Beyond Code Proposed Conversation Issue Template](https://gitlab.com/gitlab-com/marketing/community-relations/evangelist-program/general/-/blob/master/.gitlab/issue_templates/beyond-code.md)
- [Guest Invitation Email Template](https://docs.google.com/document/d/1DXPP1GQ8IhYV4tWSWXJ6wdh0CMBfvzOfImSzSLp6Ymo/edit)
- [KBYC (Know Before You Chat) Checklist](https://docs.google.com/document/d/1DXPP1GQ8IhYV4tWSWXJ6wdh0CMBfvzOfImSzSLp6Ymo/edit)

## Find a tech speaker

We'd love to support you if you are organizing an event, be it GitLab-centric or around a topic where GitLab content is relevant (e.g. DevOps meetup, hackathon, etc.). There are a few ways you can get in touch with speakers from the GitLab team and the wider community to participate and do a talk at your event:

- Review our list of [GitLab Heroes members](https://about.gitlab.com/community/heroes/members/) to see if there is a GitLab Hero near you. If you'd like to request support from a GitLab Hero, please follow the process detailed in the GitLab Heroes project to [request support from Heroes](https://gitlab.com/gitlab-com/marketing/community-relations/gitlab-heroes#requesting-support-from-heroes).
- Visit our list of active speakers on our [Speakers Bureau](https://about.gitlab.com/speakers/) page. Once you find a speaker in your region, contact them directly.
- If you are unable to find a speaker in your region, you can complete our [speaker request form](https://docs.google.com/forms/d/e/1FAIpQLSc6jQWbh-63myQu7EBuZZ0KY2J_EKSAZPH6OP2TURNBmfMjtg/viewform).

For GitLab team members, you can check the #cfp channel on Slack where many of our active tech speakers will see your speaker request. Most speakers will also be able to do talks remotely if the event is virtual or if travel is a challenge.

If you have questions, you can always reach us by sending an e-mail to `evangelists@gitlab.com`.

## Community nominations

GitLab team members and members of the wider GitLab community are encouraged to nominate community members to participate in our programs. This is a valuable way to contribute to the growth and success of the GitLab community.

To nominate a community member who may be interested in becoming a code contributor or meetup organizer, who actively shares their knowledge of GitLab in talks or blog posts, or who meets [the criteria for the GitLab Heroes program](https://about.gitlab.com/community/heroes/#heros-journey), please contact the Developer Relations team by emailing evangelists@gitlab.com.

## Community content

GitLab actively supports content contributors. If you would like to submit your content for review, please create an [issue](https://gitlab.com/gitlab-com/marketing/community-relations/evangelist-program/general/issues/new?issuable_template=community-content) on our evangelist program project.

We make an effort to amplify and support content contributions that generate value for our community. Criteria we consider include: how well a post addresses an issue in the Community Writers issue tracker, how well a post aligns with our strategy and values, and how well a post is written.

### Media Releases

GitLab must collect a signed `Media Consent and Release Form` before their content is published by GitLab. GitLab team members can request a copy of the form to send to members of the wider GitLab community via the [#legal](https://gitlab.slack.com/archives/C78E74A6L) channel in Slack.

## Evangelist Program Office Hours

Join GitLab Developer Advocates and community program managers as they host Community Program office hours. Office hours will begin May 10, 2022, via Zoom every other Tuesday at 10:30 - 11:10 AM ET - excluding holidays. They want to answer all things pertaining to contributions, release features, hackathons, meetups, events, and more. The team wants to connect with you all. Find the meeting information on the [Community Events](<a target="_blank" href="https://calendar.google.com/event?action=TEMPLATE&amp;tmeid=NTEzZGhmMWpiOWg0cjBmcXJydTZuc202MzAgZ2l0bGFiLmNvbV9ldGE3bzR0bjRidG44aDBmOGVpZDVxOThyb0Bn&amp;tmsrc=gitlab.com_eta7o4tn4btn8h0f8eid5q98ro%40group.calendar.google.com"><img border="0" src="https://www.google.com/calendar/images/ext/gc_button1_en.gif" alt=""></a>) calendar and our [meetup group](https://www.meetup.com/gitlab-virtual-meetups/).

## Helpful Resources

- [Community Events Calendar](https://calendar.google.com/calendar/embed?src=gitlab.com_90t5ue1q8kbjoq5b0r91nu7rvc%40group.calendar.google.com&ctz=America%2FNew_York)
- [Meetups Checklist](https://about.gitlab.com/community/meetups/checklist/)
- [Swag](/handbook/marketing/brand-and-product-marketing/brand/merchandise-handling/#ordering-new-swag)
- [Speakers Bureau](/handbook/marketing/developer-relations/developer-advocacy/speakers-bureau/)

### Resources for speakers

For resources for GitLab team members who are planning on attending events or speaking at conferences, see [Speaker Resources](/handbook/marketing/corporate-communications/speaking-resources/).
