---
title: "Leading Organizations"
description: "Leading Organizations are groups and people who consistently make meaningful contributions to GitLab."
---

## Overview

GitLab's [mission](/handbook/company/mission/#mission) is to make it so everyone can contribute.

The GitLab Leading Organization program supports this mission by recognizing and incentivizing organizations and individuals who are among our most active contributors. This initiative rewards and encourages co-creation. Through this program, we seek to strengthen the open source ecosystem. Leading Organizations drive their company's innovation and employee retention through contributions while influencing GitLab's product trajectory.

Our goal is for 10% of GitLab customers to be Leading Organizations by FY25Q4. This supports our [strategy](/handbook/company/strategy/#2-build-on-our-open-core-strength) to grow to 1000 contributors per month.

## Qualification

Definition: A company or individual that reaches 15 merged merge requests or more over a trailing three full calendar month basis. See more about qualification Leading Organizations in the [code review section](/handbook/engineering/workflow/code-review/#leading-organizations).

Continued program membership for existing Leading Organizations will be reviewed [quarterly](/handbook/communication/#communicating-dates-and-time).

## Why

Open source is eating the world. The organizations that will stand out as leaders in the next decade are those who understand, embrace, and contribute to open source - building cultures where everyone can contribute.

### Increase Hiring and Retention

Lack of developer talent is one of the biggest threats to businesses. Contributing to open source enables your company to be competitive in a tight market.

1. Highly skilled developers often participate heavily in open source projects and seek out companies with an active open source presence.
1. Public recognition builds employer brand and incentivizes individual employees.
1. Employee satisfaction increases through skill building, training, and knowledge sharing.

### Reduce Cost & Improve Innovation

80% of companies expect to increase their use of enterprise open source software for emerging technologies.[^1]

1. Paying employees to contribute to open source can double the company's productivity, when compared to non-contributing competitors.[^2]
1. Open source saves time and money while increasing efficiency.[^3]
1. Consistent contributing enables organizations to replace point solutions faster while reducing technical debt.

## Program Benefits

Leading Organizations receive:

- Faster time to review [service level objective](/handbook/engineering/workflow/code-review/#review-response-slo) from GitLab team members
- A quarterly dialogue with the Contributor Success team to discuss features important to you and define next steps
- Public recognition with special Leading Organization badge visible on LinkedIn and other social channels
- Opportunities to increase employer brand visibility through blog posts on GitLab.com, contributor stories, and social media
- A shared Slack channel between your organization and GitLab to provide guidance and answer questions using direct communication lines with GitLab team members including, but not limited to, Contributor Success Engineers, Merge Request Coaches, Product Engineers, Product Managers & Developer Relations Team
- General guidance on the legal considerations of contributing to open source and open core software projects

## Enrollment

To apply to join the Leading Organization program:

1. Schedule a workshop, click [here](https://calendly.com/nick_vh).
1. Once accepted into the program, you'll receive a welcome e-mail
1. Schedule an onboarding workshop

## Workshops

GitLab hosts workshops with organizations interested in increasing their contributions and becoming eligible for the program. The Leading Organization team will reach out directly to organizations that either meet or are close to meeting the [qualification requirement](#qualification). For organizations interested in starting to contribute, please fill out [this form](https://forms.gle/HRWyXBKkgbnwhUdU6).

**Types of Workshops**

1. **Program Workshop** - Program Overview and Benefits
   1. Audience: Business Stakeholders, GitLab: Leading Organization Team and CSM/Account Executive
   <object data="/handbook/marketing/developer-relations/leading-organizations/leading-org-workshop-handbook-page.pdf" type="application/pdf" width="100%" height="500px">
   <p>Unable to display PDF file. <a href="/handbook/marketing/developer-relations/leading-organizations/leading-org-workshop-handbook-page.pdf">Download it</a> instead.</p>
   </object>

2. Onboarding Workshop & Technical Deep Dive
   1. Audience: Technical Leadership, Engineers interested in contributing, GitLab: Contributor Success
   1. Content: This is typically performed in two stages:
      1. Meet with Contributor Success cohort and receive a high level technical overview of contribution. As a part of this session, an exploration of the contributing organization's GitLab usage is performed. This is typically a hands on session, the purpose of which is to uncover potential _itches_ that could be used as a starting point for future contribution. From this session, a number of issues are potentially surfaced for exploration in a follow-up.
      1. In this session, the process of contribution is covered in a practical fashion. Concrete steps are covered including development environments, repository forking and getting started. This is a hands on session, where the Contributor Success engineer will then proceed to explore one of the previously surfaced issues in a live code exploration. From this session, there could be an MR raised, or potentially a path unlocked to the creation of one.

## Tips from GitLab on how to accelerate your organization's contribution rate

- Ensure your contributions are being counted by entering your organization's name into your GitLab profile details
- Enable employees to make their [first contributions](https://about.gitlab.com/community/hackathon/)
- Join [Monthly Hackathons](https://about.gitlab.com/community/hackathon/)
- Allocate dedicated time for employees to contribute back to open source
- Address legal questions about contributing with [this FAQ](https://about.gitlab.com/community/contribute/dco-cla/#frequently-asked-questions)

## Communication with GitLab

Email: [leadingorganizations AT gitlab DOT com](mailto:leadingorganizations@gitlab.com)

Contribution Help:

- [Developer Relations team](/handbook/marketing/developer-relations/)
- [Contributor Success team](/handbook/marketing/developer-relations/contributor-success/)
- [Core team](https://about.gitlab.com/community/core-team/)
- [MR Coaches](/job-families/expert/merge-request-coach/)

## Who

The Leading Organizations program is a top cross-functional initiative and [working group](/handbook/company/working-groups/leading-organizations/).

[^1]: RedHat, The State of Enterprise Open Source (February 22, 2022). Available at: [https://www.redhat.com/en/resources/state-of-enterprise-open-source-report-2022](https://www.redhat.com/en/resources/state-of-enterprise-open-source-report-2022)
[^2]: Nagle, Frank, Learning by Contributing: Gaining Competitive Advantage Through Contribution to Crowdsourced Public Goods (December 21, 2017). Available at SSRN: [https://papers.ssrn.com/sol3/papers.cfm?abstract_id=3091831](https://papers.ssrn.com/sol3/papers.cfm?abstract_id=3091831)
[^3]: Tidelift, 2020 Managed Open Source Survey (October 2020). Available at Tidelift: https://tidelift.com/subscription/2020-managed-open-source-survey
