---
title: "Technical Marketing"
description: "Learn more about the purpose, process and output of GitLab's Technical Marketing."
---

## Team overview

### Our purpose (Why)

The Technical Marketing team's purpose is twofold. Externally, we aim to help prospects make informed decisions when seeking solutions and comparing vendors. We showcase the technical capabilities of our product as valuable solutions to our target audiences, guiding them towards making the right choice. Internally, we also play a crucial role in helping individuals within our organization understand our product better and enable them to better position our product in the market from the technical perspective.

### Our process (How)

We do this by teaching and enabling our audiences about modern software delivery methods and how it can be valuable to them, introducing them to new concepts which can help them achieve their goals, and by showcasing the capabilities of the product for the use cases which our audiences care about.

### Our output (What)

We produce and deliver demos, videos, workshops, webinars, tutorials, blog posts, white papers, articles, conference presentations and lightning talks, demos to analysts, speak at events and more.

## Working with the Technical Marketing Managers

### What are we currently working on?

View the [Developer Relations roadmap](https://go.gitlab.com/community-roadmap) and Technical Content plan (team members should search for Google Sheet titled "Technical Content" in Google Drive) to see what the TMM team is working on.

### Where to find our work

You can find the content we create in the following places:

1. [Highspot](https://gitlab.highspot.com/) - Highspot is a sales enablement tool we use to gather, categorize, and share content within GitLab and externally to our customers. Any content that can support our customers or sales teams should be added to Highspot. More info on how we use Highspot can be found in the Highspot section of this page.
1. [Content Library](/handbook/marketing/developer-relations/technical-marketing/content-library) - this houses some of the assets our team has created in the past. This can be helpful for historical context but our most recent resources will be available in Highspot.
1. [GitLab Snapshots YouTube playlist](https://www.youtube.com/playlist?list=PLFGfElNsQthYDx0A_FaNNfUm9NHsK6zED) - this playlist houses technical videos created by Technical Marketing Managers.

### Request support from Technical Makreting

To make a request of the Technical Marketing team please follow the [content request process](/handbook/marketing/developer-relations/content-request/) for the Developer Relations team.

## Prioritizing work

Our work is mainly driven and prioritized by the following Marketing defined [Core DevOps Solutions](/handbook/marketing/use-cases/) and can be tracked on the [Solutions Go-to-market](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/). Specifically, our deliverables contributing to this effort are sorted by priority below (subject to change).

* Analyst Demos/Analyst Evaluations
* Core Solutions Demos
* Tech Webinars
* Field Marketing Workshops
* Technical Blogs
* Sales Support
* Technical Enablement (Internal)
* Workshops
* CS Skills Exchange
* Release Showcase
* Competitive Analysis
* Conference Demos/Workshop
* Whitepapers and e-books
* Evangelization

## Content

### Types of content we create

#### Demos

One form of output is demo videos to help show the value GitLab can bring to customers.

* Learn about our [demo creation and publishing practices](howto/create-and-publish-demos.html)

##### Updating demos

1. **Can we update a current video with new features?** \
Yes we can, however. . .

1. **What is the process for updating videos when new features come out?** \
. . . because of the end to end data trail that flows throughout the product, it can be difficult sometimes to just add new parts into existing demos, depending on what's being shown, and so sometimes requires extensive, if not complete, redo. Because of this and the high frequency of changes we don't make updates for EVERY new feature/change. We look for when there are significant enough features/changes that affect the value we are demonstrating. We watch ourselves, but also look to PMM and PM and sales to indicate that updates should be done. \
\
Anyone can [open an SM request](https://gitlab.com/gitlab-com/marketing/strategic-marketing/product-marketing/-/issues/new?issuable_template=A-SM-Support-Request) for us to update a demo. If there are significant enough changes then we will put the update into the backlog and work with stakeholders to set the right priority to get it completed.

1. **Can we update/create a new video to address a different persona/theme?** \
Switching a demo to a different persona usually should mean a new demo/video, as changing the target persona should result in changes in the pain points and story, and hence likely the video/screenshots that are shown. It is certainly possible that the existing footage can fit a new persona's story, or that we can change the story to include multiple personas. But more likely than not, if this is easy to do to an existing demo then it is probably because it wasn't properly focused on a persona in the first place.

### Presentations

Presentations are prepared and delivered at conferences, meetups, or any relevant event, often in the form of slides.

### Lightning talks

Fast-paced presentations that last for a few minutes to spark new conversations and collaborations. These are commonly requested for the GitLab booth at conferences sponsored by the [Corporate Events](/handbook/marketing/integrated-marketing/corporate-events/) team. Where slides are used, they are often not more than 5 slides.

### Blog posts

Blog posts are informative or descriptive articles that present an idea or viewpoint. Blog posts are mainly for awareness, without necessarily going into the details of how the idea presented can be achieved. Blog posts are published on the GitLab blog, third-party blogs or personal websites.

### Webinars/Webcasts

Presentations delivered to an audience online, who can be customers or prospects. Webinars are typically lead by the [Campaigns](/handbook/marketing/demand-generation/campaigns/) team. Webinars are often demonstrative in nature.

### Click-through demos

Click-through demos are content that visually walks users through the features of a product. They are used to educate prospects and customers at events or self-paced.

### Tutorials (self-paced or instructor-led)/ How-to's

A tutorial is a step-by-step demonstration of the process to complete a workflow or task. It not only informs the reader but teaches by example and supplies the information needed to complete a certain task. A tutorial can be delivered interactively online or physically, in a long-form blog post, or a video.

## Chat, say hi, quick question

Slack channel: [#dev-advocacy-team](https://gitlab.slack.com/archives/CMELFQS4B)

### Content requests

To request content from our team, please follow the [content request](/handbook/marketing/developer-relations/content-request/) process which starts by opening an issue using the Developer Relations [content request template](https://gitlab.com/gitlab-com/marketing/developer-relations/developer-advocacy/developer-advocacy-meta/-/issues/new?issuable_template=content-request).

### Content distribution

Content we create is distributed internally and externally to our stakeholders, customers, and community. We follow the [content distribution](/handbook/marketing/developer-relations/developer-advocacy/#content-distribution) process from the Developer Advocacy handbook page.

## Which Technical Marketing Manager?

Each TMM is listed with their areas of primary responsibility, but all TMM's should be able to help in other areas of the product as well:

* [Itzik Gan-Baruch](/handbook/company/team/#itzikgb) - CI, CD, Software Delivery Automation, Value Stream Analytics, WebIDE, Workspaces.
* [Fernando Diaz](/handbook/company/team/#fjdiaz) - DevSecOps, Security, Continuous Software Security Assurance, Continous Software Compliance.
* [Cesar Saavedra](/handbook/company/team/#csaavedra1) - CD/GitOps/IaC, Software Delivery Automation, DORA, GitLab agent for Kubernetes, GitLab Flow, Feature Flags, advanced deployment techniques, Progressive Delivery, Developer Experimentation.

## Technical Marketing Howto's

* Creating a Demo Environment.
* Examples of StoryBoarding (make a new template).
* Links Technical Marketing GitLab page with actual demos.

## Making better videos

With the internet's attention span, the more successful videos are short form. GitLab Marketing's has adjusted it's video strategy to focus on short form, educational videos. With that move we've begun to learn about how to make better videos. The ["Making better videos" page](making_better_videos.html) covers our research and pointers we are going to do our best to follow.

## OKRs

* [OKR list](https://gitlab.com/gitlab-com/gitlab-OKRs/-/issues?first_page_size=20&label_name%5B%5D=dev-evangelism&sort=updated_desc&state=opened&type%5B%5D=objective)
