---
title: "Publish a video on YouTube"
---

### 1. Upload a video

1. There are two YouTube channels we use at GitLab:

   - [Branded](https://www.youtube.com/channel/UCnMGQ8QHMAnVIsI3xJrihhg): used for official content intended for people in the wider community. This content must be approved by the Brand team.
   - [Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A): used for content intended for team and community members. This content does not require approval from the Brand team but still should follow all brand guidelines and use up-to-date brand assets.

   Contact the Brand team in the `#brand_video` Slack channel for any questions.

   WARNING:
   You should never publish [**SAFE**](/handbook/legal/safe-framework/) data to any of these channels, and if you think it may be something confidential consult legal.

1. Login to the GitLab YouTube account where you would like to post a video.
   You should already have permission to do that from your GitLab login.
   If you don't and believe that you should then open an access request.

1. Click on the profile picture and select **YouTube Studio**

   ![youtube studio option](/handbook/marketing/developer-relations/technical-marketing/images/publish_video_on_youtube/youtube_studio.png)

1. Then click on the **CREATE** button next to your profile picture and select **Upload videos**

   ![upload video option](/handbook/marketing/developer-relations/technical-marketing/images/publish_video_on_youtube/upload_video_option.png)

1. A popup window will appear and ask you to upload a video

   ![upload video popup](/handbook/marketing/developer-relations/technical-marketing/images/publish_video_on_youtube/upload_video_popup.png)

1. Once the video is uploaded, you will see a video configuration screen

   ![video configuration screen](/handbook/marketing/developer-relations/technical-marketing/images/publish_video_on_youtube/video_configuration_screen.png)

### 2. Configuration of the video

1. In the **Details** tab, you can configure various video settings. Among them:

#### Title

   1. The title is one of the first things potential viewers see, so it plays a crucial role in whether they decide to click on your video.
      - The title should clearly describe the content of the video.
      - Keep it brief and to the point.
   1. Title is important for search and, therefore, while developing a title you should consider targeting users that will search for your video and use relevant keywords.

#### Description

   1. The description should clearly lay out the topic and quickly explain what the viewers can expect to learn.
   1. The first couple of lines are crucial as they appear in the search results and above the "show more" fold on the video page.
      - Incorporate relevant keywords naturally into your description.
      - They should be related to the video content and what your target audience might search for.
   1. If you mention any resources, tools, or references in the video, include links or further information about them.
   1. Provide links to platforms where the audience can connect with you.
   1. Include a call to action (CTA).
   1. Include relevant hashtags at the end of the description for better visibility

#### Hashtags

   Check this document to find out [how to use hashtags on YouTube](https://support.google.com/youtube/answer/6390658?hl=en#:~:text=You%20can%20add%20hashtags%20to,to%20associate%20with%20your%20video)

##### Chapters

   1. If your video is lengthy or covers multiple topics, include timestamps.
   1. By providing well-structured and accurate timestamps, you enhance the user experience, making it easier for viewers to navigate to the content they find most relevant, thereby increasing viewer engagement and satisfaction.
   1. The timestamp includes the time **"HH:MM:SS"** followed by a brief description of what the segment is about.
   1. To include timestamps and split a video into chapters, you need to provide a list of timestamps in the **Description** field

      ![timestamps in the description](/handbook/marketing/developer-relations/technical-marketing/images/publish_video_on_youtube/timestamps_in_description.png)

      and it will generate such a view under the published video and allow the viewer to quickly find a video part they interested in

      ![chapters on published video](/handbook/marketing/developer-relations/technical-marketing/images/publish_video_on_youtube/published_video_chapters.png)

   1. List the timestamps in the order they appear in the video.
   1. Make sure they correspond correctly to their segment in the video.
   1. If there are particularly important or popular moments in the video, make sure these are marked with timestamps.

#### Thumbnail

   1. A thumbnail is important for suggested videos.
   1. Use high-resolution, eye-catching images ensuring the thumbnail is clear and simple, and accurately represents the video content.

#### Tags

   1. Use relevant, specific keywords in tags that accurately describe your video to make it more discoverable.
   1. While YouTube allows a lot of tags, using too many can dilute their effectiveness. Follow this link for details [about YouTube tags](https://support.google.com/youtube/answer/146402?hl=en).

   Scroll to the bottom of the popup window and select **SHOW MORE** to see a full list of settings in the **Details** tab:

   ![show more link in the details tab](/handbook/marketing/developer-relations/technical-marketing/images/publish_video_on_youtube/show_more_in_details_tab.png)

   Once you finished with setting up in this tab, select **Next** button to go to the **Video Elements** tab:

   ![next button in the details tab](/handbook/marketing/developer-relations/technical-marketing/images/publish_video_on_youtube/next_in_details_tab.png)

1. In the **Video Elements** tab, you can:
   - Add subtitles
   - Add an end screen to promote related content at the end of your video
   - Add cards to promote related content during your video

   ![video elements screen](/handbook/marketing/developer-relations/technical-marketing/images/publish_video_on_youtube/video_elements_screen.png)

#### Cards

   To promote other videos, channels, playlists, and links during the video we can use **Cards** and configure the time they appear in the video

   ![cards screen](/handbook/marketing/developer-relations/technical-marketing/images/publish_video_on_youtube/cards_screen.png)

#### An end screen

   View this guide on [how to add an End Screen](/handbook/marketing/developer-relations/technical-marketing/howto/add-ctas-to-learn-videos/)

   Select **Next** button to go to the **Checks** tab:

   ![next button in the video elements tab](/handbook/marketing/developer-relations/technical-marketing/images/publish_video_on_youtube/next_in_video_elements_tab.png)

1. In the **Checks** tab, YouTube posts a verification status of the video

   ![checks screen](/handbook/marketing/developer-relations/technical-marketing/images/publish_video_on_youtube/checks_screen.png)

   Select **Next** button to go to the **Visibility** tab:

   ![next button in the checks tab](/handbook/marketing/developer-relations/technical-marketing/images/publish_video_on_youtube/next_in_checks_tab.png)

1. In the **Visibility** tab, you specify the visibility and can schedule a date when the video will be public

   ![visibility screen](/handbook/marketing/developer-relations/technical-marketing/images/publish_video_on_youtube/visibility_screen.png)

### 3. Publish a video

1. Click on the **Save** button once you configured everything

   ![save button](/handbook/marketing/developer-relations/technical-marketing/images/publish_video_on_youtube/save_button.png)

1. Go to view your video in the channel and make sure everything shows up as expected.
