---
title: "Community Discord workflow"
---

## Overview

The [GitLab Community Discord](https://discord.gg/gitlab) server is a place to connect with the wider GitLab community, join live streams and pair-coding sessions, share projects, and discuss contributions with other community members. Whether you're new to GitLab and looking for help getting started or an experienced user looking to share your knowledge with others, the server is a place to chat with the community in real-time.

In our community server, you can:

- Connect with other GitLab users and developers
- Contribute to GitLab issues and pair-program with other developers
- Share tips, tricks, and best practices for using GitLab
- Stay up-to-date on the latest GitLab news and releases
- Participate in community-led discussions and events

To ensure we keep a positive, welcoming, and inclusive environment for everyone to contribute, all members of our Discord server must adhere to our [Community Code of Conduct](https://about.gitlab.com/community/contribute/code-of-conduct/) at all times.

The Developer Relations team manages the Discord server with support from Contributor Success. If you have questions or want to request a GitLab team member role, ping `@devrel-team` in the `#developer-relations` Slack channel.

## Discord Community Overview

Our server has several channels dedicated to different topics of discussion. Here's a quick overview of the channels and what they're for:

| Channel | Purpose |
| ------ | ------ |
| `#announcements` | Staff will use this channel to share news and announcements. |
| `#rules` | Server rules for all users on the server. |
| `#general` | Main channel for general discussions. |
| `#community-help` | Forum format channel for support questions - community helping the community. |
| `#contribute` | Contribution discussions focused on the making & enhancing of GitLab. |

There are also more specific channels for the hackathon, events, and community-based support.

## Unsolicited messages and friend requests

To keep our community and team members safe, server rule #5 covers keeping questions in public channels
and not allowing unsolicited friend requests or direct messages without consent.
If you receive a private message you can refer the user to this rule or use the following response:

```markdown
Please refer to the GitLab Community #rules (https://discord.com/channels/778180511088640070/778194316191465474)
and remember to use public channels instead of direct messages, thanks!

> 5. All questions should be asked in public so that anyone can answer and everyone can learn from the discussion.
> This is a community server with volunteers helping one another.
> Please do not ping specific people to answer your question or send unsolicited friend requests or direct messages without consent.
> See GitLab's communication values to Use Public Channels (/handbook/communication/#use-public-channels)
> and Be Respectful of Others Time (/handbook/communication/#be-respectful-of-others-time).
```

### Tools

We use Discord bots and integrations to manage our community.

| Tool | Purpose |
| ------ | ------ |
| [WickBot](https://wickbot.com/) | A discord bot that helps with moderation and security. |
| [NeedleBot](https://needle.gg/) | A discord bot that creates Discord threads automatically. |
| Community Pairs | Custom bot that announces the GitLab Live Stream. |

In order to maintain our custom invite link `https://discord.gg/gitlab`, we maintain a Server Boost Level 3 through 14 server boosts, paid annually.

## Moderation

We strive to maintain a positive environment on the Discord server. These moderation guidelines are designed to ensure an inclusive and respectful environment for all community members. At this time, GitLab team members and [GitLab core team](https://about.gitlab.com/community/core-team/) members serve as moderators.

### Moderation Guidelines

Every moderation situation is unique and will be dealt with on a case-by-case basis. This tier system seeks to provide a general framework for handling situations and for supporting our moderators. In many cases, there will be multiple tiers required to complete the necessary actions. For example, a message that results in a temporary timeout (Tier 2) should also be reported to Discord (Tier 0).

#### Tier 0 - Report to Discord

If a message violates Discord's Terms of Service or Community Guidelines (e.g., illegal content, explicit harassment, doxxing, etc.), moderators should report the violation directly to Discord via the reporting feature. See [how to report content to Discord](https://discord.com/moderation/360058643194-104-how-to-report-content-to-discord).

##### Tier 1 - Warning and Message Deletion

For minor violations of server rules, moderators should remove the message and leave an official explanation in the channel where the warning occurred, explaining which rule was broken. A clear warning can also be sent to the user privately with the same explanation as the cause of their message deletion. If there's a fear the situation will escalate, the moderator can handle things privately, but where possible, it's important to be transparent about enforcing the rules.

For example:

```markdown
Your message was removed for violating the following rule in our [GitLab Code of Conduct](https://about.gitlab.com/community/contribute/code-of-conduct) or GitLab Discord Server:

> (The rule violated)
```

Moderators should also leave a note on the member's profile regarding the warning for documentation purposes. If this is not the community member's first offense, more serious action is recommended (e.g. Tier 2).

To review and add notes to member profile, moderators can use the following shortcuts to interact with Wick Bot:

```markdown
- Add note: /notes add (it prompts you for a user and a note)
- List all notes: /notes view
- List all notes for a user: /notes view user<enter> (it'll prompt you for the user)
- View a specific note: /notes view note_id<enter> (it'll prompt you for the note id, which can be found by listing all notes for a user)
```

#### Tier 2 - Temporary Timeout

If the message is a serious violation (e.g. repeated spam, trolling, political attacks) or a community member continues to break the rules after receiving an official warning, moderators should temporarily prevent them from interacting with the server via a timeout. The duration of the timeout can be adjusted based on the severity of the violation. Moderators are also encouraged to seek support from the rest of the moderator team if they need a second opinion. See [how to set a timeout for a user](https://support.discord.com/hc/en-us/articles/4413305239191-Time-Out-FAQ).

#### Tier 3 - Ban

If the message is a severe violation (e.g hate speech, harrassment, threats, inappropriate content) or if a member has repeatedly violated the rules and well-being of the community despite an official warning and/or temporary timeout, moderators should consider a ban and [raise a Code of Conduct issue](/handbook/marketing/developer-relations/workflows-tools/code-of-conduct-enforcement/) to discuss the violation. It is not necessary to raise an issue for one-off violations, such as a spam. Use issues as a basis of documentation and discussion for more serious violations that may require follow-up or proof of decision making in case of escalation or a ban appeal from the user.

##### Ban Appeals process

As a GitLab Community Discord member, if you feel you've received an unfair timeout or ban, you can submit an appeal. The appeals process is as follows:

1. Email `community@gitlab.com` to initiate the appeal. Include your Discord username and a description of why you believe the ban was unjustified.
1. The moderation team will review your appeal and any associated documentation (e.g. admin notes on a member profile notes or a code of conduct issue). Once reviewed, the moderation team will decide to either uphold the ban, reduce the duration, or the lift the ban.
1. If the ban is reduced or lifted and a member returns to the server, any further violations of the community rules will be taken very seriously.

We appreciate your patience as we take time to look over appeal requests.

### Reporting Unacceptable Behavior

To report unacceptable behavior or abuse, use the Discord reporting feature. See [how to report content to Discord](https://discord.com/moderation/360058643194-104-how-to-report-content-to-discord).
