---
title: 'Digital Experience: Foundations Agenda'
description: "The goal of this page is to identify blockers and highlight the value of unlocking our team."
---

## Digital Experience: Foundations Agenda

> To date, at GitLab, we've called it our "_marketing website_." As a $1B company about to go public we need to elevate our main marketing tool and operationalize our efforts by developing a "_digital marketing platform_." Currently, we do not have foundational elements in place to make this change. As such, we must mature our toolset and upgrade our technology.

### The goal of this page is to identify blockers and highlight the value of unlocking our team

| MAIN ISSUES | BLOCKERS |
| ----------- | -------- |
| **We can't scale effectively**<br>[⏱️ Efficiency](/handbook/values/#efficiency) | - Our digital marketing platform is not optimized for results<br>- We're missing key tools to enable scaling<br>- The tools/technology we're missing are "boring solutions" that can be implemented in a series of MVCs that will allow us to iterate to a better future state<br>- We don't have a system that we can operationalize<br>- Our digital marketing platform is not optimized for the right group<br>- Our experience is inconsistent (specifically, user flows and funnel progression) which makes it difficult to learn from/ improve upon |
| **It's challenging to learn**<br>[🤝 Collaboration](/handbook/values/#collaboration)<br>[👣 Iteration](/handbook/values/#iteration)<br>[👁️ Transparency](/handbook/values/#transparency) | - Lack of consistency minimizes the value of our data<br>- The lack of focus on the [loyalty flywheel](https://unity.trustradius.com/wp-content/uploads/hubspot-flywheel-inbound-method-lifecycles-1024x1024.png) minimizes the effects of the changes we make<br>- Challenging to work as a community without a SSOT or understanding of our Customer |
| **High likelihood of human error**<br>[⏱️ Efficiency](/handbook/values/#efficiency) | - No automated build process<br>- No weekly or bi-weekly review of automated or user generated data<br>- Will enable us to shorten our iterations and cycle time |
| **Hard to consistently stick to our plan**<br>[📈 Results](/handbook/values/#results) | - Without an operationalized approach it's harder keep a bias towards action against competing forces |

---

### 🎯 We need to have plan that we're confident in, stick to, and consistently deliver results

---

| WHAT NEEDS TO HAPPEN | VALUE |
| -------------------- | ----- |
| **Implement a CMS** | - Optimize and focus on efficiency for the right group (Content Marketing)<br>- Increase ability to self-service and self-learn<br>- Respects others' time. Frees up Digital Experience effort that is high frequency/ low value |
| **Switch Static Site Generator (SSG)** | - Align with GitLab's technology strengths (Ruby & VueJS)<br>- Optimize and focus on efficiency for the right group (Digital Experience development team)<br>- Allows Marketing to use better tools to unlock our potential to scale and deliver |
| **Implement a [Design System](https://gitlab.com/gitlab-com/marketing/inbound-marketing/slippers-ui)** | - Lower the cost of iteration and release<br>- Creates a common design language everyone can contribute too, and also supports our commitment to efficient "boring" solutions vs slow and expensive custom solutions.<br>- Allows us to onboard, ramp up, and scale quicker - both team members and vendors |
| **Incorporate a build process (Gulp or Webpack)** | - Decrease human error<br>- Boring solution that has been industry standard years<br>- Faster page load times<br>- Automate image compression<br>- Minimize CSS + JS<br>- Identify duplicate code<br>- Automatically add above the fold styles to increase perceived load times |
| **Remove images from GIT and push directly to CDN** | - Reduces repo size<br>- Makes the repo faster to work with<br>- Faster to push changes |
| **Customer Data Platform** | - Gather an accurate understanding of our user segments<br>- Enables a single source of truth accessible by all GitLab team members<br>- Increases transparency by making information public within GitLab<br>- Enable us to make informed lead decisions (we appear to be good with lag/data informed decisions)<br>- Activate our thinking and opportunities for experimentation<br>- Lay groundwork for an Experimentation Platform/Program and Personalization |
| **Experimentation Platform/Program** | Using LaunchDarkly and an agile/ spring based approach aim to significantly increase the amount of tests released and running on our marketing platform |
| **Personalization** | - Increase MQLs<br>- Increase conversion rate<br>- Increase engagement<br>- Guide users towards IATV and LTV |
| **Improve Marketing site's Information Architecture** | - Increase focus on progressing through sales funnel<br>- Increase conversion<br>- Improve impact of experiments and changes<br>- More valuable data |
| **Add Session Replay / Logging Tool** | - Understand how users engage with our marketing site<br>- Identify any API or code issues |
| **Identify Automation Opportunities** | Free up our people to focus on what matters most |

## Open Opportunities

This [Get It Done Matrix](https://docs.google.com/spreadsheets/d/1G809pSClwbGCMaEJdzz_MHykVBOlPV3XYFi-IhU02Oo/edit#gid=0) highlights open epics and issues that we could use to begin elevating our digital marketing platform.

The numbers indicate large gains if we focus on [**Implementing a Design System**](https://gitlab.com/gitlab-com/marketing/inbound-marketing/slippers-ui), **Implementing a CMS**, and **Incorporating a Build Process**. The open bodies of work that present the most opportunity to deliver are [Marketing Site Refresh Strategy](https://gitlab.com/groups/gitlab-com/marketing/growth-marketing/-/epics/32#note_384150218) and [Phase 5: Systems for Continuous Improvement](https://gitlab.com/groups/gitlab-com/marketing/growth-marketing/-/epics/55#note_381002507). Both of these epics are a decent way in the future and the hope of the Digital Experience team is to re-prioritize to unlock our potential.
