---
title: "Field Marketing"
description: "The role of Field Marketing at GitLab is to work closely with sales to support marketing messages & pipeline building at a regional level through in-person and virtual interactions."
---

## Field Marketing Mission

The mission of Field Marketing at GitLab is to strategically support the Large, Mid-Market & Public Sector go-to-market teams at **a regional level** through in-person and virtual interactions (quality vs. quantity) as well as serving as the voice of the regional go-to-market teams to the wider marketing team, and being the voice of marketing into the go-to-market teams we support, in order to create, accelerate, and expand the sales pipeline with our direct sellers and partner ecosystem. In alignment with the marketing mission of being New First Order focused, Field Marketing also supports the expand motion with customers.

## Field Marketing Vision

We want to be the most innovative and pipeline centric team within the marketing organization that uses data to make informed decisions while also continuing to invest in ourselves to promote career growth and opportunities.

## Field Marketing Goals

- Sales Acceleration
  - Engaging with existing customers
  - New growth opportunities
- Demand
  - Unique inquiries
  - Influence of [sales accepted opportunities](/handbook/marketing/sales-development/#common-sales-development-org-terms-and-definitions)
  - Influence of sales pipeline
  - Both direct and channel driven
- Market Intelligence
  - Test out new messaging or positioning

## Countries of Focus

In alignment with the FY25 Marketing strategy, Field Marketing focuses on specific countries. Details can be found here in our [internal handbook](https://internal.gitlab.com/handbook/marketing/fy25-strategy/#target-markets-and-segments).

## Cities of Focus

## Tier 1 Cities

A Field Marketer should have no more than 5 cities - cities with the largest LAM - that you want to build a ground swell in and be physically present at least 2/quarter.

## Tier 2 Cities

A Field Marketer should have no more than 3 Tier 2 cities - cities you want to be physically present in at least 1/quarter.

FMMs should work with Large & MM sales teams to determine these cities.

## Types of Programs Field Marketing Runs

## GitLab Owned Field Events

### GitLab Connect

[GitLab Connect](https://www.youtube.com/watch?v=aKwpNKoI4uU) is a full or half day event with both customers and prospects in attendance sharing stories & lessons learned about GitLab. SAE's will be responsible for asking customers to speak and Marketing, through a combination of SDR outreach, database and ad geotargeting will drive attendance to the event. If you would like to propose a GitLab Connect in your city, please follow [these instructions](/handbook/marketing/events/#suggesting-an-event) for requesting an event. Interested in seeing a GitLab Connect in action? [Check it out.](https://www.youtube.com/watch?v=aKwpNKoI4uU)

### Field Marketing Owned Virtual Events

For information regarding process, epic codes, templates and more, please visit our [**Field Marketing Owned Virtual Events**](/handbook/marketing/field-marketing/field-marketing-owned-virtual-events/) page.

### Executive Roundtables

Executive Roundtables can be run virtually or in-person, and be organized through a 3rd party vendor or GitLab. These events differ from webcasts/events mainly due to the size of the audience and the interactivity level. A roundtable is run as an open discussion between the host (usually 3rd party vendor), GitLab presenter and the audience. The host would open with an introduction of themselves and the topic for the session, then introduce the GitLab presenter and have them give an overview of GitLab followed by the host asking questions directly to specific people in the audience for them to openly answer and discuss. The advantage of a roundtable is that you can document the meeting more closely and understand more about an organization's pains and problems.

Below are best practices when running a roundtable:

- Content creation - FMM to work with Sales Managers to decide on most relevant or hot topics in the region
- Speaker request - Put through a Product and Solution Marketing Support Request and fill out the template
- [Example of scripts](https://docs.google.com/document/d/1iy7AreiMM7seZM_EidixqdUw-OG__-cnl6pihqH72eY/edit#heading=h.btpndxf36cvl) for host and GitLab presenter
- [Example of meeting notes](https://docs.google.com/document/d/1T2m3Izn66u9xuWGDHmR5_YJcWdUhKupfVlWVPjWGLL0/edit) to document conversations during the session
- Ensure questions are prepared between host and GitLab presenter beforehand to lead the conversations within the session
- Assign notes of each delegate to list leads for upload onto SFDC
- Pre-analysis of delegates - check to see if their organization is currently a user of GitLab, whether they're CE or EE customers. This could be a great way to start or dig into deeper conversations with the delegate.
- Ensure you have familiarised yourself with the [White Glove Event Follow Up process](/handbook/marketing/sales-development/#white-glove-event-follow-up-flows) for this type of event.

## 3rd Party Events

We will sponsor regional 3rd party events in an effort to build the GitLab brand and also to gather leads. Different types of 3rd party events include, but are not limited to:

- Agile Events
- City run technology meetings
- Customer/prospect run DevOps events on invite
- Executive relationship building events via companies like Apex Assembly & Argyle Executive Forum

### Meeting Setting

Meeting Setting occurs when the Corporate Events team sponsors a large conference and requests the Field Meeting team manage setting up on-site meetings during the event. As for all Corp Events, the Marketing Operations team will set up the overall Conference Marketo program and SFDC campaign as well as the  Meeting Setting Marketo program and SFDC campaign for Field Marketing. Meeting Setting is not its own campaign type and is categorized as a [Conference](/handbook/marketing/marketing-operations/campaigns-and-programs/#conference), so the Conference progression statuses should be utilized. The overall Conference is owned by the Corporate Events team, but Marketing Ops will set up the Meeting Setting SFDC campaign as FM-owned.

## Other Tactics

Being the marketing experts for the region, GitLab Field Marketers are also responsible for using other tactics to help generate leads to build pipeline. We have options such as survey tools, both of current employees and past employees based on the 3rd party vendor we use, webcasts, direct mailings, and also various digital tactics.

## Regional Marketing Content

Current regional marketing content and presentations can be accessed [here](drive.google.com/drive/u/0/folders/0AHFbLUWw3IEJUk9PVA).
Content is classified into 2 groups: Economic Buyer and Technical Buyer. Choose the content category that aligns best to your audience needs - Economic Buyer for those focusing on business aspects, and Technical Buyer for those interested in technical details or specifications.
Field Marketing Managers are responsible for adding new content for Own Events and Executive Engagement Tactics to this folder on an ongoing basis. NOTE: Naming convention of the folder should reflect the SFDC Campaign name for easier tracking.

## Digital Tactics

- To run plays where we are targeting a specific geography or where we would like to propose content syndication, we work through our Digital Marketing Programs team. Please create an issue utilizing DMPs [Paid Digital Request Issue Template](https://gitlab.com/gitlab-com/marketing/demand-generation/digital-marketing/-/issues/new?issuable_template=paid-digital-request) if you'd like them to do work for you.
- To run plays where we are targeting a specific list of accounts, we utilize [6sense](/handbook/marketing/marketing-operations/6sense/).

### Tracking success of digital tactics

Please ensure you are using our UTM tracker (look up `Google Analytics Campaign Tagging Tool - UTM generator for tracking` in the Gdrive to find doc). In order to identify which campaigns are from the Field Marketing team, you must add the letters `fmm` at the end of your campaign name in column E. All lowercase with no spaces or special characters. This allows us to pull ROI reporting, so please don't leave these letters out or else you will lose reporting from a dashboard standpoint.

## Confidentiality in GitLab Issues and Epics

When working in GitLab issues and epics, please remember that due to GitLab's value of [Transparency](/handbook/values/#transparency), many of our issues and epics are, by default, public. Best practice is to avoid including any PII or login details in issues and epics directly. If posting details of this nature is a necessity, please remember to always make your [issue](https://docs.gitlab.com/ee/user/project/issues/confidential_issues.html#make-an-issue-confidential) or [epic](https://docs.gitlab.com/ee/user/group/epics/manage_epics.html#make-an-epic-confidential) `Confidential` when doing so. Please also be diligent in your issues and epics regarding comments made by other team members as well. If you notice another team member has posted details that should not remain public, immediately make the [issue](https://docs.gitlab.com/ee/user/project/issues/confidential_issues.html#make-an-issue-confidential) or [epic](https://docs.gitlab.com/ee/user/group/epics/manage_epics.html#make-an-epic-confidential) `Confidential`. Other options to allow our issues to remain public, are including PII in a spreadsheet or document posted in the issue or epic that are only accessible by certain people. If logins need to be shared, please utilize the Marketing Vault in [1Password](password-guidelines#1password).

For more information regarding confidentiality levels and compliancy, please visit [this handbook page](/handbook/communication/confidentiality-levels/).

## Global Field Marketing Vendor Feedback

[This feedback epic](https://gitlab.com/groups/gitlab-com/marketing/-/epics/4736)/spreadsheet is only open to GitLab team members. FMMs and managers to keep details in this spreadsheet regarding both positive and negative experiences with various event vendors for team reference.

## Field Marketing Campaign Issue Templates, Epic Codes and Progression Status

Field Marketing utilizes the below issue templates and epic codes for virtual events and other campaign tactics.

## Conference (In-Person)

- [Progression Status](/handbook/marketing/marketing-operations/campaigns-and-programs/#conference)
- [Issue Template](https://gitlab.com/gitlab-com/marketing/field-marketing/-/issues/new?issuable_template=In-Person_Conference_Template)
- [Epic Code](/handbook/marketing/field-marketing/field-marketing-epics/#conference-in-person)

## Conference (Virtual)

- [Tactic Details](/handbook/marketing/virtual-events/external-virtual-events/#virtual-conferences)
- [Progression Status](/handbook/marketing/marketing-operations/campaigns-and-programs/#conference)
- [Issue Template](https://gitlab.com/gitlab-com/marketing/field-marketing/-/issues/new?issuable_template=Virtual_Conference)
- [Epic Code](/handbook/marketing/field-marketing/field-marketing-epics/#conference-virtual)

## Conference (Hybrid)

- [Progression Status](/handbook/marketing/marketing-operations/campaigns-and-programs/#conference)
- [Issue Template](https://gitlab.com/gitlab-com/marketing/field-marketing/-/issues/new?issuable_template=Hybrid_Conference)
- [Epic Code](/handbook/marketing/field-marketing/field-marketing-epics/#conference-hybrid)

## Conference (FM Meeting Setting for a Corporate Events Conference)

- [Tactic Details](/handbook/marketing/field-marketing/#meeting-setting)
- [Progression Status](/handbook/marketing/marketing-operations/campaigns-and-programs/#conference)
- [Issue Template](https://gitlab.com/gitlab-com/marketing/field-marketing/-/issues/new?issuable_template=Meeting_Setting_Template)
- [Epic Code](/handbook/marketing/field-marketing/field-marketing-epics/#meeting-setting)

## Content Syndication

- [Tactic Details](/handbook/marketing/demand-generation/campaigns/content-in-campaigns/)
- [Progression Status](/handbook/marketing/marketing-operations/campaigns-and-programs/#content-syndication)
- [Issue Template](https://gitlab.com/gitlab-com/marketing/field-marketing/-/issues/new?issuable_template=Content_Syndication_Template)
- [Epic Code](/handbook/marketing/field-marketing/field-marketing-epics/#content-syndication)

## Direct Mail

- [Tactic Details](/handbook/marketing/demand-generation/campaigns/direct-mail/)
- [Progression Status](/handbook/marketing/marketing-operations/campaigns-and-programs/#direct-mail)
- [Issue Template](https://gitlab.com/gitlab-com/marketing/field-marketing/-/issues/new?issuable_template=Direct_Mail_Template)
- [Epic Code](/handbook/marketing/field-marketing/field-marketing-epics/#direct-mail)

## Executive Roundtable (In-Person, Virtual or Hybrid)

- [Tactic Details](/handbook/marketing/virtual-events/external-virtual-events/#executive-roundtables)
- [Progression Status](/handbook/marketing/marketing-operations/campaigns-and-programs/#executive-roundtables)
- [Issue Template](https://gitlab.com/gitlab-com/marketing/field-marketing/-/issues/new?issuable_template=Executive_Roundtable)
- [Epic Code](/handbook/marketing/field-marketing/field-marketing-epics/#executive-roundtable)

## Owned Event (In-Person, Virtual or Hybrid)

- [Progression Status](/handbook/marketing/marketing-operations/campaigns-and-programs/#owned-event)
- [Issue Template](https://gitlab.com/gitlab-com/marketing/field-marketing/-/issues/new?issuable_template=Owned_Event_Template)
- [Epic Code](/handbook/marketing/field-marketing/field-marketing-epics/#owned-events)

## Sponsored Webcast

- [Tactic Details](/handbook/marketing/virtual-events/external-virtual-events/#sponsored-webinars)
- [Progression Status](/handbook/marketing/marketing-operations/campaigns-and-programs/#sponsored-webcast)
- [Issue Template](https://gitlab.com/gitlab-com/marketing/field-marketing/-/issues/new?issuable_template=Sponsored_Webcast)
- [Epic Code](/handbook/marketing/field-marketing/field-marketing-epics/#sponsored-webcast)

## Survey

- [Progression Status](/handbook/marketing/marketing-operations/campaigns-and-programs/#survey)
- [Issue Template](https://gitlab.com/gitlab-com/marketing/field-marketing/-/issues/new?issuable_template=Survey_Template)
- [Epic Code](/handbook/marketing/field-marketing/field-marketing-epics/#survey)

## Vendor Arranged Meetings (In-Person, Virtual or Hybrid)

- [Tactic Details](/handbook/marketing/virtual-events/external-virtual-events/#vendor-arranged-meetings)
- [Progression Status](/handbook/marketing/marketing-operations/campaigns-and-programs/#vendor-arranged-meetings)
- [Issue Template](https://gitlab.com/gitlab-com/marketing/field-marketing/-/issues/new?issuable_template=Vendor_Arranged_Meetings)
- [Epic Code](/handbook/marketing/field-marketing/field-marketing-epics/#vendor-arranged-meetings)

## Webcast

- [Tactic Details](/handbook/marketing/field-marketing/field-marketing-owned-virtual-events/)
- [Progression Status](/handbook/marketing/marketing-operations/campaigns-and-programs/#webcast)
- [Issue Template](https://gitlab.com/gitlab-com/marketing/field-marketing/-/issues/new?issuable_template=Webcast_Template)
- [Epic Code](/handbook/marketing/field-marketing/field-marketing-epics/#webcasts)

## Workshop (In-Person, Virtual or Hybrid)

- [Tactic Details](/handbook/marketing/field-marketing/field-marketing-owned-virtual-events/)
- [Progression Status](/handbook/marketing/marketing-operations/campaigns-and-programs/#workshop)
- [Issue Template](https://gitlab.com/gitlab-com/marketing/field-marketing/-/issues/new?issuable_template=Workshop_Template)
- [Epic Code](/handbook/marketing/field-marketing/field-marketing-epics/#workshops)

## Event Lead Collection Should-Knows

Not every field event or lead are the same. There will be times when meeting/scanning leads and notetaking for the interaction will require a tweaked processing procedure. A few examples are below:

`High Priority` leads: There are situations where GitLab leadership wants extra attention placed toward a prospective lead/account, assuming the right criteria is met for that lead/account. These leads are referred to as `High Priority` and utilize the `high priority` process. This label not only means its namesake, but it also means the lead will circumvent our normal lead routing and MQL processes to be sent immediately to SDR/BDR for strategic outreach. There are a few reasons why a lead would be marked as `High Priority`, but for this particular handbook page there are two primary definitions to focus on:

- **High Priority Campaign**: This lead was acquired during a `high priority` event. While strategizing for the quarter and year, Sales and Marketing leadership discuss what upcoming field events will be important based on GitLab's current and future goals. If a field event is determined to fit the criteria, all leads collected from this event will be marked as `high priority` and quickly routed for follow up. Leadership will communicate what campaigns qualify
- **White Glove**: A white glove lead needs strategic outreach and will involve the [SDR, Account Executive and maybe more](/handbook/marketing/sales-development/#white-glove-event-follow-up-flows). Generally, these leads were highly engaged in conversation about GitLab, have detailed event notes about the engagement and or were engaged with specific GitLab team members during the event. White glove leads can exist within a high priority campaign, so use best judgement on which label is most appropriate between the two
  
 Recording `high priority` status for either of these types is simple and included in the spreadsheet used for [self-service list uploads](/handbook/marketing/marketing-operations/automated-list-import/#data-cleaning-instructions) under the `High Priority Reasons?` column - as a dropdown option. The reason feeds into Marketo's `High Priority Reason temp` field, which [then processes](https://engage-ab.marketo.com/?munchkinId=194-VVC-221#/classic/SC56504A1ZN19) the lead for early lead routing.

## Post event lead flow for each campaign

After Field Marketing has executed a campaign, the Field Marketing Manager is responsible for ensuring that the campaign has been fully operational to include the following:

- he campaign DRI reviews and cleans up the list following the guidelines for[list imports](/handbook/marketing/marketing-operations/list-import/)
- SDRs should not be asked to follow up leads before they are added to Salesforce
- If a follow-up email was to go out to all attendees and no-shows, the FMM is responsible for ensuring that emails were sent.
- Did the campaign respondents receive the correct amount of MQL points they should have received the activity they participated in?
  - Person scores are available for viewing in our `Custom Links` section of each SFDC campaign. This allows you to view the MQL score of the campaign members, whether they be a lead or contact, all within one view.
- Did a lead/contact hit our MQL threshold and have the SDRs followed up with this record and moved them beyond the [MQL stage](/handbook/marketing/marketing-operations/)?
- Update all the relevant tabs in the field marketing campaign event planning sheet.

## ROI tracking for Field Marketing

For complete instructions on FMM ROI, [please see here](/handbook/marketing/strategy-performance/marketing-metrics/#field-marketing-metrics).

## Adding SFDC Campaigns to Leads for Attribution

For instructions on how to add a SFDC campaign to a lead for attribution, please watch this two minute [instructional video](https://youtu.be/IYzkR3h4Ajo) (you must be signed into GitLab Unfiltered to view).

## Field Marketers within SFDC

To help with reporting within SFDC, each Field Marketing Manager is assigned the accounts based on SAE/AE assignment. Field Marketing has decided to align with the SAE/AE vs. 100% geo focused in an effort to foster collaboration.

Routing for geo reps is done through zip codes worldwide. Named accounts and the US Public Sector are manually handled differently. Sales Ops will run monthly audits to update PubSec and Named accounts. Field Marketing Management works with Sales Ops to keep this information up to date.

Should you come across an account you believe should be owned (or perhaps NOT owned by you) please follow these steps:

1. Within the account in SFDC, please chatter @sales-support and provide reason why this account should be updated
1. If more than 10 accounts need updated or if a FMM changes regions, then please open a [sales ops issue](https://gitlab.com/gitlab-com/sales-team/field-operations/sales-operations/-/issues/new?issuable_template=General%20Request) requesting the update be made.

Complete details on how GitLab Sales handles rules of Account Engagement can be [found here](/handbook/sales/field-operations/gtm-resources/rules-of-engagement/).

### PathFactory

Via our Marketing Operations team, Field Marketers can request Author Role access to PathFactory to upload and curate assets into tracks that are then disseminated for use in Marketo, about.gitlab.com, and other campaign-related channels. Field Marketing currently has Reporter level access. To view the difference in user roles, head over to the [PathFactory page](/handbook/marketing/marketing-operations/pathfactory/#access).

### The Benefits of having Author Role Access

1. Efficiency gains: It takes more time to create a request issue for the Campaigns Team and wait for the request to be processed than it takes to upload an asset or create the track yourself.
1. Ownership: Having author role access to PathFactory will allow Field Marketing to have control on asset uploads and content tracks to ultimately personalise the PathFactory experience according to region, country and target accounts.
1. Optimisation: Viewing each asset/track's performance can help Field Marketing refine and optimize the content with monthly or quarterly refreshes.

### Getting Started

Visit the [user role](/handbook/marketing/marketing-operations/pathfactory/#user-roles) section of the PathFactory page to learn more about the author role.

### Required Training

Please review the [Pathfactory Training](/handbook/marketing/marketing-operations/pathfactory/#training) videos (specifically the author role training) before submitting an AR to request author role access.

This section will continue to be fleshed out as we rollout to the global Field Marketing team.

## Process for Issues Moving from Plan to WIP

The following is the process for when a Field Marketing issue moves from `mktg-status::plan` to `mktg-status::wip`.

## SLAs

Please plan your timelines accordingly based on the below SLAs. Keep in mind these SLAs must also include additional time for any Friends & Family Days or holidays.

*FMMs - For the asset copy process, please allow for a total of 8 business days (which encompasses the SLAs below).*

- **Contract Requests:** 3 business days
- **Plan to WIP Requests** - 5 business days
- **Copy to FMCs for Review** - 24 hours
- **Marketing Operations Requests** - [5 business days](/handbook/marketing/marketing-operations/campaign-operations/#slas) (not including the day the triage request is sent)

## Items required by FMM to request moving an issue from Plan to WIP

- If a contract is required, the FMM is to obtain the agreement from the vendor, review and make any changes needed with the vendor, then submit a [Contract Request](/handbook/marketing/field-marketing/#field-marketing-contract-requests) to their FMC for processing through Zip. Please note the contract request issue template has very detailed instructions for our finance and procurement process. The FMM should contact their FMC if they have any special requests or specific questions.
- The Event Details and FMC Checklist sections in the main issue must be completed in full and finalized (specifically the date of the event, as shifting dates after moving from Plan to WIP requires many adjustments by the FMC).
- The Allocadia sub-category and line item detail panels must be updated and finalized and the FMM will include their correct forecast cost that matches the amount stated in their contract request, as well as check that the forecasted cost is in the correct month (according to the [prepaid policy](/handbook/finance/accounting/#prepaid-expense-policy)).

Once the FMM has submitted the Contract Request to their FMC and the remaining above items have also been completed, the FMM can proceed with requesting the FMC move from [Plan to WIP](/handbook/marketing/field-marketing/#moving-from-plan-to-wip).

**PLEASE NOTE**: While we are able to move an issue to WIP after the above items have been completed, note that travel should not be booked and additional event costs should not be charged until the contract has been fully approved via the procurement process.

## Moving from Plan to WIP

- FMM pings the FMC in the main Field Marketing issue and requests the FMC move the issue to WIP (FMM keeps issue label `mktg-status::plan`)
- FMC reviews the Allocadia sub-category and line item panel details, as well as checks that the forecasted cost is in the correct month (according to the [prepaid policy](/handbook/finance/accounting/#prepaid-expense-policy)) for the tactic and makes any changes necessary
- FMC creates the epic and sub-issues utilizing [this list of epics](/handbook/marketing/field-marketing/#field-marketing-campaign-issue-templates-epic-codes-and-progression-status)
- FMC creates the [Marketo program and SFDC campaign](/handbook/marketing/marketing-operations/campaigns-and-programs/#campaign-type--progression-status) utilizing the [Program Tracking](https://gitlab.com/gitlab-com/marketing/field-marketing/-/blob/master/.gitlab/issue_templates/program-tracking.md) sub-issue previously created
  - FMC pings the FMM in the Program Tracking issue that the Marketo program and SFDC campaign have been created and closes issue
- FMC adds the event to the appropriate events calendar. All events should be added to the appropriate calendar from the list below.
  - [In-Person Events and Sponsorship](https://calendar.google.com/calendar/u/0?cid=Z2l0bGFiLmNvbV9laWN2b3VkcHBjdTQ3bG5xdTFwOTlvNjU2Z0Bncm91cC5jYWxlbmRhci5nb29nbGUuY29t)
  - [External Virtual Events](https://calendar.google.com/calendar/u/0?cid=Z2l0bGFiLmNvbV8xOGVqOHN0NmlxajZpYXB1NTNrajUzNHBsa0Bncm91cC5jYWxlbmRhci5nb29nbGUuY29t)
  - [GitLab Hosted Zoom Webcasts](https://calendar.google.com/calendar/u/0?cid=Z2l0bGFiLmNvbV8xcXZlNmc4MWRwOTFyOWhldnRrZmQ5cjA5OEBncm91cC5jYWxlbmRhci5nb29nbGUuY29t)
- FMC adds the event to the [GitLab Events Page](https://about.gitlab.com/events/) utilizing [these instructions](/handbook/marketing/events/#how-to-add-events-to-aboutgitlabcomeventshttpsaboutgitlabcomevents), if applicable (specified by the FMM in the FMC Checklist section of the issue)
- When all the above tasks have been completed, the FMC will ping the FMM in the main issue to confirm completion of the above tasks and will move the issue label `mktg-status::plan` to `mktg-status::wip`.
- FMC and FMM to follow the [Copy Deadline Process](/handbook/marketing/field-marketing/#field-marketing-event-copy-deadline-process) for any assets the FMM has requested in the main issue's FMC Checklist.
- FMC and FMM to follow the [Lead List Deadline Process](/handbook/marketing/field-marketing/#lead-list-deadline-process) for lead list upload process and SLAs.
- If applicable, FMC is to shut down the Marketo LP due to capacity, or after event is complete using [these instructions](/handbook/marketing/field-marketing/#process-to-close-marketo-landing-pages-and-landing-page-forms).

### Plan to WIP video walk through

[Plan to WIP Video](https://youtu.be/7l59sm_5aD4) - You must be logged into GitLab Unfiltered to view.

## Field Marketing Event Copy Deadline Process

Please review [SLAs](/handbook/marketing/field-marketing/#slas) above.

- FMM to assign FMC in main event issue.
- FMC to attach their regional event tracking label to the event issue.
- FMM and FMC to follow the [Process for Issues Moving from Plan to WIP](/handbook/marketing/field-marketing/#process-for-issues-moving-from-plan-to-wip).
- FMC to create a [Write Copy Issue](https://gitlab.com/gitlab-com/marketing/field-marketing/-/blob/master/.gitlab/issue_templates/write-copy.md) and fill in the requested copy due dates for each asset the FMM has requested in the FMC checklist, and then attach the issue to the epic.
- FMM to update the Copy Document file the FMC created for them (linked in the epic) with copy for each asset. Previous Copy Documents for reference are available in the [Event Support Folder](https://drive.google.com/drive/folders/1S-4PVueBj7FPAE9fB-IKz_Bbuz17rPtH).
- Once the FMM completes copy, they will ping the FMC in the [Write Copy Issue](https://gitlab.com/gitlab-com/marketing/field-marketing/-/blob/master/.gitlab/issue_templates/write-copy.md) to notify them which asset copy has been completed.
- If copy has not been completed for an asset yet, (1) business day before copy is due, the FMC will ping the FMM in [Write Copy Issue](https://gitlab.com/gitlab-com/marketing/field-marketing/-/blob/master/.gitlab/issue_templates/write-copy.md) with a copy due reminder.
- FMC will make sure copy has been provided or continue to remind the FMM, if needed.

## Lead List Deadline Process

- FMC to create the [List Clean and Upload](https://gitlab.com/gitlab-com/marketing/marketing-operations/issues/new?issuable_template=event-clean-upload-list) issue during the [plan to WIP process](/handbook/marketing/field-marketing/#process-for-issues-moving-from-plan-to-wip)
- FMC to assign a due date of 2 business days post-event
- One (1) business day after the issue is due, FMC to ping the FMM in the list clean and upload issue to remind them leads are due
- FMC will make sure leads have been provided or continue to remind the FMM, if needed

## Rescheduling or Canceling Events

## Rescheduling or Canceling a Webcast or Virtual Workshop

Please note that the process for rescheduling or canceling a webcast or virtual workshop involves additional steps. For details regarding these instructions, please see below.

Please see process [here](/handbook/marketing/field-marketing/field-marketing-owned-virtual-events/#rescheduling-a-workshop-or-webcast) for rescheduling and [here](/handbook/marketing/field-marketing/field-marketing-owned-virtual-events/#canceling-a-workshop-or-webcast) for canceling.

For all other event types (including in-person workshops), please see instructions below.

## Rescheduling Events

### FMM Tasks

- FMM to ping the FMC and staff/DRIs in the main Field Marketing issue to communicate the updated date(s).
- FMM to obtain an addendum/updated contract from the venue with the new date(s) (if applicable). The FMM will then re-open the original contract request and ping the FMC with new date(s) and addendum/updated contract.
- FMM to update the date with any additional vendors (such as Boundless, PizzaTime, etc.).
- If utilizing their personal Zoom for the event, FMM to make the date change in the Zoom account where the event was set up. Make sure to check the `Notify registrants about changes to this meeting` checkbox so registrants gets the date change email notification with their unique join link from Zoom.
- If there are registrations for the event, please either notify the registrants of the date change directly, or ask your FMC to create a date change email issue and provide copy in the copy doc. Note that this email must follow the [MOps SLA](/handbook/marketing/marketing-operations/campaign-operations/#slas).

### FMC Tasks

- FMC to update the new date(s) in the Allocadia sub-category and adjust the forecasted amount (if over the prepaid $5k threshold and if the new date falls in a new month).
- The FMC will update the event listing in the [Marketing Calendar](/handbook/marketing/#marketing-calendar) with the updated date(s).
- The FMC will update the date(s) in the appropriate Google calendar for the event invite.
- The FMC will update the epic details and sub-issue due dates (and issue titles), as well as make the necessary changes to any upcoming asset send dates. If there are any emails scheduled to send, the FMC will ping MOps specially in those issues to have them unschedule the sends first.
- The FMC will re-open the Marketo LP issue and request the date be changed in the LP. This will most likely change the LP URL as well, in which case, the FMC will update the LP link in the epic and notify the FMM of the changed link (to communicate to the sales team).
- The FMC will follow [these instructions](/handbook/marketing/events/#how-to-add-events-to-aboutgitlabcomeventshttpsaboutgitlabcomevents) to update the date of the event on the [Events Page](https://about.gitlab.com/events/) (if applicable).
- Allocadia: FMC to change the ISO date in the SFDC campaign name to the new start date.
- SFDC: FMC to change the ISO date in the SFDC campaign name to the new date and update the start and end date fields.
- Marketo: FMC to change the ISO date in the Marketo program to the new date and update the `event date` and `UTM tokens`. Also update [asset expiration](/handbook/marketing/marketing-operations/campaigns-and-programs/#step-5-setting-landing-page--smart-campaign-expiration-asset-expiration).
- If the FMM has submitted an addendum/updated contract, FMC to submit a [PO change request via Zip](/handbook/business-technology/enterprise-applications/guides/zip-guide/#how-to-do-a-request-change).

## Canceling Events

### FMM Tasks

- FMM to ping the FMC and staff/DRIs in the main Field Marketing issue to communicate the cancellation and close out the issue.
- FMM to update the cancellation status with any additional vendors (such as Boundless, PizzaTime, etc.).
- If utilizing their personal Zoom for the event, FMM to delete the event from the Zoom account where the event was set up. Make sure to check the `Send meeting cancellation email to registrants` checkbox so registrants gets the cancellation email notification from Zoom. You will also be able to edit the cancellation message in the body of the email.
- If there are registrations for the event, please either notify the registrants of the cancellation directly, or ask your FMC to create a cancellation email issue and provide copy in the copy doc. Note that this email must follow the [MOps SLA](/handbook/marketing/marketing-operations/campaign-operations/#slas).

### FMC Tasks

- FMC to update Allocadia showing the event as canceled by going to the event sub-category panel and selecting `Yes` to the `Campaign Canceled?` dropdown. FMC to also add in `CANCELED` to the event sub-category title and to the `Official Event/Campaign Name` field so the title in the main issue stays updated.
- FMC to remove any planned/forecasted costs in Allocadia accordingly.
- The FMC will update the [Marketing Calendar](/handbook/marketing/#marketing-calendar) by selecting the event line item and adding a strikethrough to indicate the event has been canceled.
- The FMC will delete the Google calendar invite in the appropriate calendar.
- The FMC will follow [these instructions](/handbook/marketing/events/#how-to-add-events-to-aboutgitlabcomeventshttpsaboutgitlabcomevents) to delete the event from the [Events Page](https://about.gitlab.com/events/) (if applicable)
- The FMC will comment regarding the cancellation in all open sub-issues and close out the issues. If there are any emails scheduled to send, the FMC will ping MOps specifically in those issues to have them unschedule the sends first.
- If applicable, FMC to ping procurement and finance in the Coupa req to notify them that the event has been canceled.
- If the FMM is not sending their own cancellation email to registrants and would like to send a Marketo cancellation email, create an [issue](https://gitlab.com/gitlab-com/marketing/field-marketing/-/blob/master/.gitlab/issue_templates/request_email_invite.md) for the request and triage to Marketing Ops. Please Note: This email must be scheduled and sent BEFORE the rest of the steps below can be completed.
- Once all sub-issues are closed, the FMC will also note the cancellation in the epic and close the epic.
- SFDC: Add `[CANCELED]` to the campaign name and select `Aborted` in the `Campaign Status` dropdown.
- Marketo: Add `[CANCELED]` to the program name. Go to the `Salesforce campaign sync` field and click on the linked campaign, select `None` from the dropdown and click `Save.` This removes the SFDC and Marketo sync for the program. Deactivate any [activated smart campaigns](/handbook/marketing/marketing-operations/campaigns-and-programs/#step-4-activate-marketo-smart-campaigns).
- FMC to ping MOps with the Marketo program link in the `#mktgops` Slack channel and request the program be deleted (FM does not have access in Marketo to delete programs). Please Note: Once the Marketo program is deleted, the Marketo LP will also be deleted and not accessible by anyone with the registration link.

## Process to Close Marketo Landing Pages and Landing Page Forms

## Marketo Asset Expiration

Please follow the instructions found on the [campaigns and programs](/handbook/marketing/marketing-operations/campaigns-and-programs/#asset-expiration-use-cases) handbook page to set expirations on program assets during program set up.

## Options for Closing LPs and LP Forms

There are two options for closing Marketo landing pages:

1. Closing the LP registration form (which removes the registration form from the LP so registrations can no longer be accepted) and updating the LP to explain why the registration form is no longer available (either the event has reached capacity or the event has occurred).
2. Closing the entire LP. If someone clicks on the LP link, it will take them to our about.gitlab.com page instead of a registration LP. This option is now done automatically during the [Marketo Asset Expiration process](/handbook/marketing/marketing-operations/campaigns-and-programs/#asset-expiration-use-cases). Asset expiration occurs 4 weeks after the event date, so it is important to close the registration form and update the LP verbiage once an event reaches capacity or has occurred so the LP does not remain open and active during this time.

The FMC will track all open Marketo LPs and will be responsible for requesting the LP form be closed by Marketing Ops once the event occurs or if an event reaches capacity.

To close the LP registration form, the FMC will re-open the Marketo LP issue and request Marketing Ops follow one of the below processes (depending on campaign type, as Marketo program templates vary across different tactics). In the LP issue, the FMC will request Marketing Ops remove the registration form and will provide Marketing Ops specific verbiage for the top of the LP page. Please see standard verbiage options below. If the event is a workshop that was listed on the demo/workshop page, the FMC will also request Marketing Ops remove the listing. The FMC will update the due date of the issue.

## If an event has reached capacity

- The FMC will follow the above instructions to close the LP registration form and update the verbiage to specify the event has reached capacity.
- If there are remaining invite issues open once registration is closed, the FMC will note this in the issue(s) and close them. If an invite is already scheduled to be sent, the FMC will ask Marketing Ops to unschedule the send before closing the issue. The FMC will update the due date of the issue.
- If a LinkedIn campaign was run, the FMC will request the ABM team close the LinkedIn registration form in their ABM issue.
- There is no need to remove the event listing from the [Events Page](/handbook/marketing/events/#how-to-add-events-to-aboutgitlabcomevents) if an event has reached capacity. Having a sold out event listed could create more excitement over the event and encourage future attendees to register for events sooner.

## Standard verbiage for closing a Marketo LP after the event has occurred

*The below verbiage can be utilized/sent to Marketing Ops when closing a Marketo LP form after an event has occurred.*

Thank you for your interest in this [insert event type]. This event has concluded and registration is now closed, but GitLab has a number of hands-on events and educational programs scheduled at any given time. Please visit our [events page](https://about.gitlab.com/events/) for more information on upcoming events and dates.

## Standard verbiage for closing a Marketo LP if an event is at capacity

*The below verbiage can be utilized/sent to Marketing Ops when closing a Marketo LP form if an event is at capacity.*

Thank you for your interest in this [insert event type]. The event has reached capacity and registration is now closed, but GitLab has a number of hands-on events and educational programs scheduled at any given time. Please visit our [events page](https://about.gitlab.com/events/) for more information on upcoming events and dates.

## Closing a Marketo LP Form

These instructions explain how to close a Marketo LP form and how to update the LPs verbiage at the top of the page. The page and the information on it will still be visible to visitors, but there will no longer be a form to fill out for registration.

### Closing a Webcast Marketo LP Form

See instructions [here](/handbook/marketing/field-marketing/field-marketing-owned-virtual-events/#closing-a-webcast-landing-page).

### Closing a Workshop Marketo LP Form

See instructions [here](/handbook/marketing/field-marketing/field-marketing-owned-virtual-events/#instructions-for-closing-registration-for-a-workshop).

## Adding and Removing Workshop Postings on the Regional Workshop Demo Pages

We market our workshops on both the [GitLab events page](https://about.gitlab.com/events/) and via the below EMEA regional workshop/demo page (the AMER and APAC demo pages have been deprecated). The GitLab events page listings require an MR to add new events (see instructions [here](/handbook/marketing/events/#how-to-add-events-to-aboutgitlabcomevents)) and events will automatically drop off the page once the event date passes. But the regional workshop/demo pages require manual adjustment. When an EMEA workshop LP is created by Marketing Ops, they will add to the EMEA workshop/demo page once the LP is approved. When the workshop is completed and the FMC requests that Marketing Ops closes the LP, Marketing Ops will also remove the listing from the regional workshop/demo page.

- [EMEA Workshop/Demo Page](https://page.gitlab.com/technical-demo-series-emea.html)

### Regional Workshop Demo Pages - Instructions for Marketing Ops

Marketing Ops will add EMEA workshops only to the [EMEA Tech Demos and Workshop page](https://engage-ab.marketo.com/?munchkinId=194-VVC-221#/landingpage/16146).

For more information regarding the regional workshop/demo pages, please visit [this handbook page](/handbook/marketing/virtual-events/webcasts/#technical-demo-landing-pages).

## Closing a Marketo LP

These instructions are standard across all campaign types and will close down the entire LP and re-routes visitors to our about.gitlab.com page. If you have set up [asset expiration](/handbook/marketing/marketing-operations/campaigns-and-programs/#asset-expiration-use-cases) previously, this step will occur automatically.

- Sign into Marketo
- Click into the Marketo program for the landing page you wish to close
- Click into `Assets`
- Click `Registration Landing Page`
- At the top of the page click `Landing Page Actions`
- In the drop down list click `Unapprove`
- Click the orange `Unapprove` button in the pop up box
- Go to your landing page URL and make sure the landing page is no longer active (the site that should pop up is `about.gitlab.com`)
- Go to the `01a or 01b Registration Flow and deactivate the smart campaign`

## Adding a Registrant after Marketo LP Reg Form is Closed

If you have closed a Marketo LP registration form because your event has reached capacity but need to add in an important registrant after the fact, please follow the below instructions.

**IMPORTANT NOTE:** Field Marketing does not have access for the below actions. Please ping Marketing Operations in the `#mktgops` Slack channel to add registrants when needed.

Important context: The landing page and form themselves have no bearing on whether or not someone is synced. The sync relies solely on `Program Members` and their statuses. Thus, a person can fill out a form, but if their program member status is never updated to `Registered`, they will never sync over into the webcast in Zoom. Likewise, we can update someone's status to `Registered` without any form every being filled out, and they will still sucessfully sync to Zoom.

1. Navigate to the `Database` tab in Marketo
1. In the quick find box, type in the person's email and click the magnifying glass to search (If they do not exist, click `NEW` in the upper ribbon and add a `new person`. It will take up to 10 minutes for them to then show in the lead database)
1. It will take you to a screen with everyone matching your query. Once you find the correct person, click them to highlight.
1. Once highlighted, you can right click or select `Person Actions` from the upper ribbon
1. Hover over `Programs` and click on `Change Program Status...`
1. Search for the program you want to add them to (it should be the main program, not an invite send, etc) and select the status of `Registered`
     - Check how many people this will affect. It should just be 1 (or the number you highlighted)
1. Click `RUN NOW` to execute the action
1. A status box will appear on the top right and tell you when the action finishes processing
     - Once added as `Registered` scoring will trigger for the registrant
     - Once the registrant is synced to zoom (within 30 min or so), the registrant will receive a confirmation email automatically from Zoom.

You can use these steps to add anyone to a Marketo program.

## Registration Problems on a GitLab Landing Page

If a registrant is having issues registering for an event on a GitLab landing page, please have them first try the below fixes. If these still do not work, open a [bug issue](https://gitlab.com/gitlab-com/marketing/marketing-operations/-/blob/master/.gitlab/issue_templates/bug_request.md?_gl=1%2a1652726%2a_ga%2aMTg4MDU0MzY5Ni4xNjAxMTI2MTEw%2a_ga_ENFH3X7M5Y%2aMTY2NzU3MzczMi4xNTAuMS4xNjY3NTc3MDQyLjAuMC4w) with Marketing Ops to help determine if there is a problem with the landing page.

- Ask what browser they are utilizing and if there are any plugins potentially blocking the registration page.
- If they have not already, have them try registering utilizing Chrome.
- Have them try registering using Incognito Mode.

## Owned Tactics that Involve Collecting Addresses

There are times that Field Marketing will run campaigns that involve building a landing page in Marketo in order to collect addresses for shipping swag. Examples of these instances are a 5k run, GitLab-hosted tasting event, direct mail campaigns, etc. When collecting addresses, please follow the below instructions for ensuring PII compliancy.

## Landing Page Verbiage

When collecting addresses on our Marketo landing pages, make sure to always include the following verbiage on the page - `By giving us your address, you are giving us permission to mail items to your home or office. We will not use this data for any other purposes.`

## Pulling Addresses for Swag Sends

Please note that due to PII compliancy, addresses collected in Marketo landing pages are not synced to SFDC. As a result, Marketing Ops support is required to pull the address list from Marketo (Field Marketing does not have this level of access in Marketo).

## Removing PII from Marketo

Once the report is downloaded (or the event/tactic has ended and all swag has been sent), Marketing Ops will then also delete the PII information directly in Marketo. To request this support, please review [this page](/handbook/marketing/marketing-operations/marketo/#list-exports) and open an [export request issue](https://gitlab.com/gitlab-com/marketing/marketing-operations/-/issues/new?issuable_template=export_request) to specify when a list pull and PII deletion is needed. Also remember to delete PII from any order spreadsheets once swag has shipped.

## Field Marketing Swag

## Brand Details for Swag and Event Assets

For information regarding Brand support, please visit the [Brand Creative Handbook Page](/handbook/marketing/brand-and-product-marketing/design/). Templates for requesting design/brand support are located [here](/handbook/marketing/brand-and-product-marketing/design/#brand--marketing-design-issue-templates). You can also watch [this video](https://www.youtube.com/watch?v=bBzasucNkh0) (must be logged into GitLab Unfiltered) regarding Brand templates and repos for previous and current brand designs.

## AMER Field Marketing Swag

The AMER Field Marketing team utilizes GitLab's swag and fulfillment vendor [Brilliant](https://www.brilliantmade.com/) for all of our swag and event asset requirements. Brilliant is available to produce, ship, and store swag and event assets.

### Brilliant Store Portal

Field Marketers are responsible for accessing the [Brilliant store portal](https://app.brilliantmade.com/users/sign_in) utilizing their individual logins to order all swag and assets for their events.

#### Brilliant Store Portal Training

[**Watch Training Video Here**](https://youtu.be/YRqPeom_H-Q)  *(Note: You must be logged in to GitLab Unfiltered to view)*

### Brilliant Support

For Brilliant support, please see email addresses below. For any questions or concerns, please reach out to `@krogel`.

- `gitlab@brilliantmade.com` for net-new orders
- `support@brilliantmade.com` for order/shipping support in North America
- `international.support@brilliantmade.com` for order/shipping support in EMEA, UK and APJ

### Specialty Swag Orders, Invoicing, and Brand Approval

- If you would like to order specialty swag for a specific event, please reach out to `gitlab@brilliantmade.com` and provide the following details:
  - Item you are looking to source
  - Any links or pictures for reference
  - Budget
  - In-hand ETA
  - Where swag will be shipped (if swag is to be stored in the warehouse, please include `@krogel` on correspondence)
- PLEASE NOTE: Every new swag order requires a PO number before Brilliant will submit the order to production. Please make sure to build this approval time into your overall timeline!

#### Approval Process through the Brilliant Store Portal

- Brilliant will send the FMM an order estimate through the [Brilliant store portal](/handbook/marketing/field-marketing/#brilliant-portal) (FMM will receive an email notification). FMM to go to the order estimate and save the order to PDF and submit a [contract request](/handbook/marketing/field-marketing/#field-marketing-contract-requests) to the FMC.
- FMC to route the order through the procurement process.
- Once the PO number is obtained, the FMM will log back into the Brilliant store portal, go to the order estimate, and click `approve`. An additional screen will pop up where the FMM will include the PO number and then submit.
- Once the order is approved in the store portal, Brilliant will submit the order to the vendor.
- All new swag artwork (inlcuding logo placement) will be reviewed and approved by the Brand team.
  - If the swag item chosen only requires a GitLab logo to be added, Brilliant will provide a proof to the FMM through the store portal (FMM will receive an email notification) and then once approved in the portaly by the FMM, the proof will be sent to the Brand team for final approval (within the Brilliant store portal as well).
  - If the swag item chosen requires a full design, please follow the instructions to submit a design request [here](/handbook/marketing/brand-and-product-marketing/brand/merchandise-handling/#swag-program-owners).
- Once the order has been shipped, Brilliant will submit the invoice through Coupa directly.

### Store Portal Orders and Shipping Charges

- Please see the homepage of the [Brilliant store portal](https://app.brilliantmade.com/users/sign_in) for specific ordering instructions and helpful details.
- General swag items in the store have previously been ordered and paid for in bulk. You are not required to pay for these swag items from your individual budgets. The cost of the swag items are shown to help indicate the level of swag and how much should be utilized.
- You are required to provide an Allocadia ID and event name for all Brilliant store orders. All charges related to shipping will be associated to your specific campaign and these charges will process through our monthly invoice. When you place your orders through the store, you will be provided a shipping estimate during checkout. If you are returning items, you can estimate the same return shipping and add that total to your forecast.
  - PLEASE NOTE: Our monthly Brilliant invoice covers all charges for the previous month. Due to our prepaid policy, your shipping charges for the previous month will be reconciled in the following month, so please forecast accordingly. Example - You ship swag in August for an August event. Our August monthly invoice processes in September, so those August shipping charges should be forecasted in September.
- Item quantities are listed in the portal. Please select from the current items in stock for your event. If you need a larger quantity of an item over what is available, you intend to utilize the remaining stock for an item, or you are ordering over 500 pieces of an item, please reach out to `@krogel` for reordering.
- Please be aware that ordering newly designed swag or placing reorders for existing items requires adequate lead time. Time frames vary greatly based on the items selected, design approval, and availability. General Lead Times: 6-8 weeks to produce a new item and 2-3 weeks to reorder current designs

### New swag ideas for bulk orders

If you would like to source a new swag item for the team's inventory, please reach out to `@krogel` directly. All new swag items must be approved by the Brand team for brand consistency.

### Field Marketing Event Assets

Event assets utilized for shows (including backwalls, tablecloths, popup banners, event kits, etc.) are stocked at the Brilliant warehouse and can be ordered for events using the [Brilliant store portal](https://app.brilliantmade.com/users/sign_in). It is also recommended that each Field Marketer keep a separate GitLab tablecloth, popup banner and table runner with them at home for easy access and to be utilized for events.

### Returning Field Marketing Event Assets and Swag

It is the FMM's responsibility to not only ship assets to events, but to also ensure the onsite event DRI ships the items back within **3 days** of the end of the event. Every order placed through the Brilliant portal will include return labels (one return label per box) in a red envelope adhered to the inside flap of the box. The FMM is to make sure the onsite event DRI is aware of the location of the return shipping labels and of their responsibility to ship the items back.

**PLEASE NOTE:** Trash and items not stored in the Brilliant warehouse should not be put in the return shipping boxes. All event assets are to be folded neatly and packed up cleanly and securely in their original boxes. All tool kit items should be returned to the tool kits for future event use. Please do not send small numbers of swag back to the warehouse if the items were bundled, only send full bundles back to the warehouse for restock. Example: If pens come in bundles of ten, please do not send back 2 pens as these cannot be re-bundled. Feel free to keep small quantities of extra swag to give out to customers, if appropriate. Also, only open swag bundles as they are needed so items can be returned if not used. If you have any questions, please contact `@krogel`.

### Warehouse Address

AMER Warehouse
Attn: GitLab AMER FM Store - c/o Kerry Phan
Brilliant
1605 S Waukegan Rd
Waukegan, IL 60085
415-980-4600.

### Stickers

For sticker orders, please reach out to `@krogel` for details.

### Print Collateral

In order to stay environmentally-friendly, we generally do not provide large quantities of print collateral at events. However, if you do need printouts or gift bag stuffers for events, we utilize [Vistaprint](https://www.vistaprint.com/). Please log in using the Marketing 1pass. Another option in lieu of hundreds of printed handouts is to have a handful of printed and laminated pieces of collateral to utilize for visual reference while speaking with customers at an event. Additionally, you can create a [QR Code](/handbook/marketing/events/#field-marketing-qr-codes-for-events) to display at your event with that same piece of content for customers to download to their own devices.

## EMEA Field Marketing Swag

The EMEA Field Marketing team utilises [Reachdesk](/handbook/marketing/marketing-operations/#project-management) to source, fulfill, ship and store (European and UK warehouses) swag branded swag items.  We also utilise vendor [Ten&One](https://www.tenandone.com) who can source swag items and who also currently store all EMEA event material. The FMC is responsible for ensuring adequate stock levels and coordinating field event swag logistics. Additional event assets utilized for shows (including backwalls, tablecloths, popup banners, etc.) are stocked at the Ten&One warehouse and can be shipped

- **Budget Allocation:**
  - If there is an individual order dedicated to support one specific event (e.g Cloud Expo) an Allocadia line item should be created by the FMM in their regional activity plan under this specific event.
  - If swag is required from the bulk order (e.g AWS, GCP, smaller events) the FMM should assign budget and move it to All EMEA per Quarter.
  - If the event e.g Connect Day is handled by Ten & One as an all-in budget under the contract with Ten & One this should be included in that event sponsorship line item within the FMM's regional plan.
Please note shipping cost to be included in the SWAG cost that you budget per event.

- **Invoicing:** All invoices for Field Marketing are required to include the campaign's Allocadia ID to allow for proper finance coding.

- **Existing Items:** Item descriptions and quantities are listed on the Reachdesk portal, please reach out to `@helenadixon` for current inventory levels.
- **New Items and Designs:** Requests for new swag items not already available require management approval. Any new swag designs must be approved by the brand team for brand consistency. You can suggest new designs in the swag slack channel or more formally in an issue in the [Swag Project](https://gitlab.com/gitlab-com/swag_suggestions).
- **Large Orders:** For orders over 500 pieces, contact `@helenadixon` for assistance.
- **Shipping:** Please make sure to specify all shipping requirements and deadlines when ordering your items and include in the swag section of the relevant issue.
- **Lead Times:** Please be aware that ordering newly designed swag or placing reorders for existing items requires adequate lead time. Timeframes vary greatly based on the items selected and design approval. General Lead Times: 6 weeks to produce a new item and 2-3 weeks to reorder current designs.
- **Stickers:** For sticker orders, please utilize our [Sticker Mule](https://www.stickermule.com/) account or contact `@helenadixon` for assistance with ordering.
Delivery options and timelines are provided during the ordering process. Any new sticker designs must be approved by the brand team for brand consistency. You can suggest new designs in the swag slack channel or more formally in an issue in the [Swag Project](https://gitlab.com/gitlab-com/swag_suggestions).
- **Non-Marketing, How to request SWAG for EMEA events:** For orders from non-marketing, create an issue in the [Field marketing project](https://gitlab.com/gitlab-com/marketing/field-marketing/issues) using the `EMEA_SWAG_Request_template`. This will add all labels automatically.
- **Field Marketing, How to request SWAG for EMEA events:** For Field Marketing EMEA, add your SWAG request to the description in the `EMEA_Event_Field_Marketing` template.
- **Required information**:
  - Contact name(s)(onsite contact)
  - Complete shipping address (Be specific as possible)
  - Phone number
  - Email address
  - Date (timeline when shipping can arrive)
  - Swag items required and Quantities
- **Return Event Material from event locations to warehouse**: FMC will coordinate with Ten&One the return of all banners, table cloths, back walls, counter top, iPads (not SWAG) back to Ten&One Address: Agentur, Meyerbeerstraße 12, 81247 München, Germany, Phone: +49 89 2554190

## Swag for Non-Field Marketing Teams

If you are looking to order swag or event assets for a non-Field Marketing event or would like to order swag for a customer, please see [details here](/handbook/marketing/brand-and-product-marketing/brand/merchandise-handling/).

## AMER Field Marketing Badge and Event Check-In Process

For details regarding this process, please visit our Events Page [here](/handbook/marketing/events/#amer-field-marketing-badge-and-event-check-in-process).

## Field Marketing Fedex Account

The Field Marketing team utilizes the Field Marketing Fedex Account for shipping (details located in the Marketing 1pass). Please always include a reference when using the account (Allocadia ID, name of event, etc.) so charges can be tracked appropriately. For any questions regarding the Field Marketing Fedex account, please contact `@krogel`.

## Field Marketing Food and Beverage Vendors for Virtual Events

## AMER Field Marketing Virtual Food and Beverage Vendors

The AMER Field Marketing team utilizes [Grubhub](https://www.grubhub.com/) and [Pizzatime](https://pizzatime.xyz/) for all virtual events with a food and beverage component. Both vendors offer a wide range of food and beverage options to fit the needs of your virtual event best.

### Grubhub

#### When to use Grubhub

[Grubhub](https://www.grubhub.com/) will be utilized for smaller, owned, and partner events that will host executive-level registrants. Cost per person to be between $35-$50.

It is important to note that Grubhub will be utilized for *post-event meal credit distribution*. The FMM is responsible for taking account of registrants who attend in the first 30 minutes of the event. The FMM will utilize the list of attended registrants to upload to Grubhub prior to the conclusion of the event.

#### Order Link Sharing

It is important to note that there is a limit on link sharing when utilizing the Grubhub platform. When registrant information is uploaded to the platform for event preparation, said registrants will receive a **unique, non-sharable link** to place their order.

#### Details Regarding Grubhub Financials and Budgeting

- It is important to note that Grubhub invoices on a monthly cycle and this invoice will be paid via the FY24 Grubhub Blanket PO. `@nataliepicci` and `@krogel` are the DRIs for the Grubhub monthly invoice.
- Once the invoice is received, the FMC is to ensure the invoice includes the Grubhub Blanket PO number and the final order amount. The FMC is to send this invoice to AP for processing and the amount is to be added to the forecast line item in the AMER ALL plan in Allocadia.
  - *To confirm which month the spend will hit, please refer to our [Prepaid Policy](/handbook/finance/accounting/#prepaid-expense-policy).*
- The FMM is required to transfer the invoiced Grubhub spend from their regional plan to the AMER ALL plan in Allocadia as soon as the event has concluded.

#### Grubhub Portal

<details markdown=1>

<summary><b>Expand below to see details regarding Accessing the Grubhub Portal</b></summary>

**[How to sign into your account](https://corporate.grubhub.com/resource/signing-in/)**

- You should have received a [Welcome Email](https://corporate.grubhub.com/resource/automated-welcome-emails-for-new-corporate-diners/) through which you created your credentials. If you never received a Welcome Email, please contact your FMC. Go to grubhub.com, click "Sign in" and enter your Grubhub credentials.

**How to access the Admin Portal**

The Admin Portal is where you manage all aspects of your Corporate Account from adding employees and creating meal credits to viewing invoices and order history.

- To access your Admin Portal, click on the person icon in the upper right corner of the homepage, then Business Account.

*If you do not see the Business account page, you are not an assigned Admin user on the account. Contact your FMC and they will request the appropriate access.*

</details>

#### Grubhub Training

***Watch*** - [Admin: How to navigate the Admin Portal and create Meal Credits](https://youtu.be/F0Pt4h9Z4P0)

***Watch*** - [Overview of the Grubhub Ordering Process](https://youtu.be/HrsleE6YMfQ) - (Note: You must be logged in to GitLab Unfiltered to view)

#### Grubhub General and Corporate Support

<details markdown=1>

<summary><b>Expand below to see details regarding Grubhub General and Corporate Support</b></summary>

**Grubhub General Support**

- [Grubhub Help Center](https://www.grubhub.com/help/contact-us)
- Grubhub Support Email: help_me@grubhub.com
- Grubhub Customer Support Number: (877) 585-7878

**Grubhub Corporate Support**

- [Grubhub Corporate Learning Center](https://corporate.grubhub.com/learning-center)
- Grubhub Corporate Support Email: clients@grubhub.com
- Grubhub Corporate Support Number: (844)-478-2249
  - Press 1 for order status
  - Press 2 for all other order issues
  - Press 3 for questions about your account setup

</details>

#### Overview of the Grubhub Ordering Process

*More detailed instructions are listed below.*

1. FMM to log into their Grubhub Admin Portal.
2. FMM to create a group, naming the group the title of the event.
3. FMM to create a meal credit for the event, assigning the meal credit to the created group.
4. FMM to take account of the attended registrants in the first 30 minutes and bulk upload the *attended* registrant information and assign it to the created Group prior to the conclusion of the event.
5. FMC to bulk remove registrant information once the event has concluded and the invoice has been received (all invoices are sent to FMCs on a monthly cadence).

#### Creating Group Accounts

<details markdown=1>

<summary><b>Expand below to see details regarding Creating Group Accounts</b></summary>

[Group Management](https://corporate.grubhub.com/resource/creating-a-group/)

Before you [create a Meal Credit](https://corporate.grubhub.com/resource/meal-credits/), make sure that you have created a Group to associate with that credit.

**Note**: `Employees` in the Grubhub portal refer to our registrants for an event.

1. Log into corporate.grubhub.com. In the top right corner, click the person icon and select Business Account.
2. In the navigation bar, hover over Employees & Groups and click "Groups".
3. Here, you can manage all your Groups. Select Add new group.
4. Give your new Group a name (event name) and description, then click Add group.
5. Now, assign employees to that Group. Employees must first be added to your account before they can be assigned to a Group.
    - If you already have employees added to your account, click Add employees and select the employees you want to add to this Group.
    - If you don't already have employees added to your account, hover over Employees & Groups in the navigation bar and click Employees. You can manually add employees one by one with the "Add New Employee" button, or [bulk add employees](https://corporate.grubhub.com/resource/admin-portal/uploading-employees-in-bulk/).
        - It is important to note that when bulk-adding employees you must include the name of the group in the upload file where applicable. This ensures the employees are assigned to a group.
6. Now you can [create your meal credits](https://corporate.grubhub.com/resource/meal-credits/).
7. FMC to bulk remove registrant information once the event has concluded and the invoice has been received (all invoices are sent to FMCs on a monthly cadence).

</details>

#### Corporate Account and Manual Employee Edits FAQ

<details markdown=1>

<summary><b>Expand below to see details regarding Corporate Account and Manual Employee Edits</b></summary>

**[Corporate Account Edits](https://corporate.grubhub.com/resource/uploading-employees-manually/)**

**How do I add users to an account?**

You are able to upload new employees to your corporate account manually. We recommend that you upload employees manually if you have 10 or fewer; otherwise, we recommend uploading them in [bulk](https://corporate.grubhub.com/resource/admin-portal/uploading-employees-in-bulk/).

1. To upload a new employee manually, click the Employees & Groups tab and select Employees.
2. Then click Add New Employee and input the employee's information. Please note that first and last name, phone number, and email address are all required.
3. You will also need to indicate if the user is a standard user or an admin user.
4. Click Add New Employee.
5. You will now be able to add the employee to any existing Groups so they can be assigned to a line of credit.
6. Go back to the Employees page, locate this user, and click on the envelope icon near their name to send their [Welcome Email](https://corporate.grubhub.com/resource/automated-welcome-emails-for-new-corporate-diners/).

**Manual Employee Edits**

**How do I create another admin user?**

- If the employee already has an account, click on the pencil next to their name, then the "edit" button and under the Permissions section, select "Admin User". If the employee does not have an account, follow the instructions above.

**Removing Individual Employees**

1. Select the person icon at the top right of your screen and Business Account from the drop-down menu.
2. Under Employees & Groups, select Employees. Click the pencil next to the employee you would like to remove.

**How do I change a user's email address?**

- Delete the user and re-add them to the account with the new email address. Make sure to re-add them to their group(s).

**What if a user has already registered their email with a personal Grubhub account?**

- The credit will automatically show up on their account when it is active. They do not need to set up a new account.

</details>

#### Creating Meal Credits

<details markdown=1>

<summary><b>Expand below to see details regarding Creating Meal Credits</b></summary>

 [Creating Meal Credits](https://corporate.grubhub.com/resource/meal-credits/)

Before you create a Meal Credit, make sure that you have [created a Group to associate with that credit](https://corporate.grubhub.com/resource/creating-a-group/) (details above).

**Note**: `Employees` in the Grubhub portal refer to our registrants for an event.

1. Hover over "Meal credit settings" and click "Meal credits". Then, click "Add meal credit".
2. Name your meal credit; this is what your employees will see. We suggest including the name of the event or company associated with this meal credit so it's easy for your employees to identify.
3. Choose how long this budget is available.
    - One-day budgets are best for single-day events (e.g. happy hours, meetings, celebrations). They can also repeat on specific days of the week.
    - Weekly budgets are best for ongoing meal programs (e.g. providing employees lunch for the week). They can also repeat on a weekly basis.
4. Then, select the time window for when the order must be placed and delivered, or simply check the "All day" box. Orders can be placed in advance but must be delivered within the designated timeframe.
5. Next, choose what geographic areas your employees can order from. To ensure they can order from their home, select "Anywhere".
6. Under "Order Settings", you can choose how your employees order their meals. Checking all options provides the most flexibility.
7. Next, choose to require any sort of expense code/comments at checkout.
8. Lastly, we recommend notifying your employees when their meal credit becomes available. We'll send a customized, one-time email the morning their meal credit begins – so long as you create and assign meal credits the night before. Diners added to an existing budget will receive an email the morning after they're added.
9. Now, click "Add Meal Credit" and you can start adding groups to your new meal credit.
10. Scroll down to select the group(s) you want associated with this meal credit and enter the budget amount.
11. Click "Save" and you're done!

</details>

#### Meal Credits FAQ

<details markdown=1>

<summary><b>Expand below to see details regarding Meal Credits</b></summary>

**How do I create meal credits?**

- Please see the above section, Creating Meal Credits, for a step-by-step guide.

**Can I change a meal credit after it starts?**

- Yes. However, the date, frequency, and order window cannot be changed.

**My employee is not seeing their meal credit balance and/or is being asked to enter their personal credit card upon checkout.**

There could be a few reasons. Check to make sure all the below items are addressed. If you're still facing this issue, please reach out to Grubhub Corporate Support.

- The account your employee is ordering from is not tied to a corporate account. If the employee is tied to the corporate account, please check that a welcome email has been sent and that the employee registered their account.
- The user is signing in using the wrong email.
- The user is on the account but not tied to a group.
- The user is tied to a group that is not tied to an active meal credit.
- The order exceeds the amount budgeted to the user (a credit card may be required to cover overages).
- The user is attempting to order outside of your company's allotted ordering times.

</details>

### Pizzatime

#### When to use Pizzatime

[Pizzatime](https://pizzatime.xyz/) will be utilized for larger, virtual-owned events that will host mid to executive-level registrants. Cost per person to be between $20-$40.

It is important to note that Pizzatime will be utilized for *pre-event meal credit distribution*.

#### Order Link Sharing

It is important to note that there is no limit on link sharing when utilizing the Pizzatime platform. Meaning, once registrants receive the link to place their order, **they can share it with non-registrants** who can then redeem it for a meal.

##### Limiting Meal Redemptions

 If attempting to limit the number of meal redemptions for an event, the below steps are recommended:

- Enable a [`Waitlist`](/handbook/marketing/marketing-operations/campaigns-and-programs/#waitlist-processing---owned-event-workshop-webcasts) for the Marketo Landing Page and establish a redemption limit.
- Include the Pizzatime order link in your `Confirmation Email` copy.
- Individually [register](/handbook/marketing/marketing-operations/campaigns-and-programs/#moving-from-waitlist-to-registered---owned-event-workshop-webcasts) registrants until the established redemption limit is reached.
  - Note: When a registrant is moved from `Waitlisted` to `Registered`, they will receive the `Confirmation Email`.
- Once the established redemption limit is reached, re-open the Marketo LP issue and request Marketing Ops remove the Pizzatime order link from the `Confirmation Email` copy.

#### Details Regarding Pizzatime Financials and Budgeting

- It is important to note that in order to place an order with Pizzatime, you will be required to request a [Coupa Virtual Card](/handbook/business-technology/enterprise-applications/guides/coupa-virtual-cards/) for payment.
- Please submit a [Contract Request](/handbook/marketing/field-marketing/#field-marketing-contract-requests) for the Coupa Virtual Card to your FMC with all the required details pertaining to your event.
- **Note**: Ensure all cost estimates have been added to Allocadia. If the final Pizzatime order cost is 10% above the requested Coupa Virtual Card amount, please inform your FMC as they will need to submit a [PO Change Request](/handbook/business-technology/enterprise-applications/guides/coupa-guide/#how-to-do-a-purchase-order-change-request).
- **Note**: The order confirmation page on Pizzatime will serve as your SOW. The steps below detail how to get to the confirmation page.
- *To confirm which month the spend will hit, please refer to our [Prepaid Policy](/handbook/finance/accounting/#prepaid-expense-policy).*

#### Pizzatime Training

[Watch Training Video Here](https://youtu.be/Jc3QU2HeFZU) - *(Note: You must be logged in to GitLab Unfiltered to view)*

#### Pizzatime Support

<details markdown=1>

<summary><b>Expand below to see details regarding Pizzatime Support</b></summary>

- [Pizzatime Help Desk](https://pizzatime.helpscoutdocs.com/)
- Pizzatime Support Email: pizza@pizzatime.xyz

</details>

#### Details Regarding Pizzatime Ordering

- Steps to place your Pizzatime order can be found in the *Steps to Placing your Pizzatime Order* section below.
- Once you place your Pizzatime order, Pizzatime will provide a unique ordering link for your event. You will then share this link with your registrants in the registration confirmation email and/or the reminder email (please remember to add it to your copy doc), to allow them to place their orders.

#### Steps to Placing Your Pizztime Order

1. Proceed to [book your Pizzatime order](https://app.pizzatime.xyz/book/date).
1. Follow all of the prompts, selecting food & drink options relative to your event.
1. Once you reach the confirmation/payment page, take a screenshot of the entire page. Attach this screenshot to your contract request (this serves as your SOW).
1. Submit a [Contract Request](/handbook/marketing/field-marketing/#field-marketing-contract-requests) to your FMC. They will provide you with your Coupa virtual card information, once the order has been approved and the card has been issued.
1. Once you have the Coupa virtual card information from your FMC, proceed to book/pay for your Pizzatime order via the Pizzatime website.
1. Provide the payment receipt to your FMC for reference.

## AMER Field Marketing Event Venue Tracking

The below epic is for tracking venues we would like to utilize for future events, or as a way to evaluate event venues we have already worked with to note the pros and cons of various event space across different regions.

- [AMER Field Marketing Event Venues Epic](https://gitlab.com/groups/gitlab-com/marketing/-/epics/625)

## Corporate Memberships Owned by GitLab Field Marketing

- [AFCEA](https://www.afcea.org/site/) - Membership is handled by the Public Sector Field Marketing Manager. Account information is stored in the marketing 1Pass vault. Please ping Kira Aubrey for assistance.
- [ACT-IAC](https://www.actiac.org) - Membership is handled by the Public Sector Field Marketing Manager. Please ping Kira Aubrey for details if you'd like to join.
- [Charleston DCA](https://www.charlestondca.org/) - Membership is handled by the Public Sector Field Marketing Manager. Please ping Kira Aubrey for details if you'd like to join.
- [G2xExchange](https://g2xchange.com/) - Membership is handled by the Public Sector Field Marketing Manager. Please ping Kira Aubrey for details if you'd like to join.
- [NASCIO](https://www.nascio.org/) - Membership is handled by the Public Sector Field Marketing Manager. Please ping Kira Aubrey for details.
- [GBEF](https://gbef.tech/) - Membership is handled by the Public Sector Field Marketing Manager. Please ping Kira Aubrey for details.
- [INSA](https://www.insaonline.org/) - Membership is handled by the Public Sector Field Marketing Manager. Please ping Kira Aubrey for details.
- [USGIF](https://usgif.org/) - Membership is handled by the Public Sector Field Marketing Manager. Please ping Kira Aubrey for details.
- [NASTD](https://www.nastd.org/home) - Membership is handled by the Public Sector Field Marketing Manager. Please ping Kira Aubrey for details.

## What's currently scheduled in my region?

| Region | FM DRI | GitLab User ID | Slack Channel |
| ------ | ------ | -------------- | -------------- |
| [AMER - East - NE SE & NYC Metro](https://gitlab.com/groups/gitlab-com/marketing/-/boards/5290066?label_name[]=East%20-%20Canada&label_name[]=East%20-%20NE%20SE%20%26%20NYC%20Metro)| Beth Parker | `@BParker` | |
| [AMER - East Canada](https://gitlab.com/groups/gitlab-com/marketing/-/boards/5290066?label_name[]=East%20-%20Canada&label_name[]=East%20-%20NE%20SE%20%26%20NYC%20Metro)| Beth Parker | `@BParker` | |
| [AMER - East - South Central & Mid Atlantic](https://gitlab.com/groups/gitlab-com/marketing/-/boards/5290100?label_name[]=East%20-%20South%20Central%20%26%20Mid%20Atlantic&label_name[]=East-%20LATAM)| Jonathan Santiago  | `@JonathanSanti` | |
| [AMER - East - LATAM](https://gitlab.com/groups/gitlab-com/marketing/-/boards/5290100?label_name[]=East%20-%20South%20Central%20%26%20Mid%20Atlantic&label_name[]=East-%20LATAM) | Jonathan Santiago  | `@JonathanSanti` | |
| [AMER - West -Northwest & North Central](https://gitlab.com/groups/gitlab-com/marketing/-/boards/5290156?label_name[]=WEST%20-%20NW%20%26%20North%20Central) | Julie Wyatt | `@Julie Wyatt` | |
| [AMER - Southwest & Bay](https://gitlab.com/groups/gitlab-com/marketing/-/boards/5290054?label_name[]=WEST%20-%20SW%20%26%20Bay%20Area) |  Lisa Rom | `@lrom`  | |
| [AMER - Public Sector DoD/NSG/Alliances](https://gitlab.com/groups/gitlab-com/marketing/-/boards/933456?&label_name[]=Public%20Sector) | Kira Aubrey |  `@KiraAubrey` | |
| [AMER - Public Sector SLED/Civ](https://gitlab.com/groups/gitlab-com/marketing/-/boards/933456?&label_name[]=Public%20Sector) | Kira Aubrey |  @kiraaubrey` | |
| [APAC](https://gitlab.com/groups/gitlab-com/marketing/-/boards/933488?&label_name[]=APAC) | Kate Baker | `@kbaker4` | |
| Japan - link WIP | Shu Kawaguchi | `@skawaguchi1` | |
| [EMEA Southern Europe](https://gitlab.com/groups/gitlab-com/marketing/-/boards/1426531?&label_name[]=Southern%20Europe) | Juliette Francon | `@ju` | [#emea_southern_europe_fieldmarketing](https://gitlab.slack.com/archives/CQ6FG8ETY) |
| [EMEA Northern Europe](https://gitlab.com/groups/gitlab-com/marketing/-/boards/1438252?scope=all&utf8=%E2%9C%93&label_name[]=Northern%20Europe&label_name[]=EMEA) | Neha Pujari | `@npujari2` |[#emea_northern_europe_fieldmarketing](https://gitlab.slack.com/archives/CQGV58A90) |
| [EMEA UK](https://gitlab.com/groups/gitlab-com/marketing/-/boards/1438265?&label_name[]=UK%2FI) | Neha Pujari | `@npujari2` | [#field-marketing-uki](https://gitlab.slack.com/archives/C048KPPE1V1) |
| [EMEA Central Europe](https://gitlab.com/groups/gitlab-com/marketing/-/boards/1438243?label_name[]=Central%20Europe&label_name[]=EMEA) | Sarina Kraft | `@sarinakraft` | [#emea_central_europe_fieldmarketing](https://gitlab.slack.com/archives/CQJ90VD8B)|

**NOTE:** to see the full list of events, you need to be logged into your GitLab account. There are times we make issues private.

To find out what upcoming events GitLab will be involved in please visit our [Events Page](https://about.gitlab.com/events/).

For details on how we handle events please visit the [GitLab Event Information](/handbook/marketing/events/) page.

## AMER Field Marketing Event Tracker for Sales

It is the responsibility of each field marketing manager to ensure that [this tracker](https://docs.google.com/spreadsheets/d/1-McecmJ7MVgdmVrjzBdrxrx6CfJ6U0dqnMILBNl67j0/edit#gid=0) is up to date with all AMER Field Marketing initiatives. Sales should consider this spreadsheet live and current daily.

## Google Calendar links

If you prefer to see the events in an actual calendar view please refer to the following:

- [External virtual events](https://calendar.google.com/calendar/u/0?cid=Z2l0bGFiLmNvbV8xOGVqOHN0NmlxajZpYXB1NTNrajUzNHBsa0Bncm91cC5jYWxlbmRhci5nb29nbGUuY29t)
- [GitLab hosted Zoom webcasts](https://calendar.google.com/calendar/u/0?cid=Z2l0bGFiLmNvbV8xcXZlNmc4MWRwOTFyOWhldnRrZmQ5cjA5OEBncm91cC5jYWxlbmRhci5nb29nbGUuY29t)
- [In person Events and Sponsorship](https://calendar.google.com/calendar/u/0?cid=Z2l0bGFiLmNvbV9laWN2b3VkcHBjdTQ3bG5xdTFwOTlvNjU2Z0Bncm91cC5jYWxlbmRhci5nb29nbGUuY29t)

## Suggesting an Event or Tactic

If you are interested in requesting Field Marketing's support for a particular in-person or virtual event or tactic, please follow the process listed on our [Events Page](/handbook/marketing/events/#suggesting-an-event).

## Field Marketing planning

It is our goal to have [planning](https://drive.google.com/drive/folders/1xtePKOl4RSINaPPr3InQNisYTQyOJ5JE) for each qtr completed four (4) weeks before the next quarter starts. At this time, we have the following time line set for regional plans:

- Q1 plan is due Jan 13
- Q2 plan is due April 3
- Q3 plan is due July 3
- Q4 plan is due Oct 2

A standard deck will also be used to ensure consistency across the world in terms of how the plan is presented.

The SSOT of the plan remains in GitLab on our [various issue boards](/handbook/marketing/field-marketing/#whats-currently-scheduled-in-my-region).

- [FY25 Standard deck](https://docs.google.com/presentation/d/1RtQuOE-mYoVUBygIihJlUvtZqUOhwIco9_xGv3ou17k/edit#slide=id.g1287bf62b57_0_209).
  - Note: The deck is additive. You are only responsible for completing the slides that are due for the quarter we are in.
  - As the slides are due one (1) month before the end of the quarter.
  - The completed deck should be stored in your correct regions [shared folder](https://drive.google.com/drive/folders/1xtePKOl4RSINaPPr3InQNisYTQyOJ5JE). Anyone within GitLab has access to search and find this folder.

## Regional Marketing QBRs

Shortly following the day that the regional plans are due, each region will hold its own QBR. The regional Manager of Marketing will be responsible for setting up this meeting and inviting the necessary team members. The point of the QBR is for the Field & Channel Marketing Managers to share their qtrly long plans with their SDR Manager colleagues, Field Marketing colleagues, and Field Marketing Leadership. This time together is meant to be informative and also educational to all who are attending.

This deck should also be used to present the regional plans to the sales teams.

### FMM QBR attendees

| Regional attendees:                                   |
|-------------------------------------------------------|
| VP of Regional Marketing                          |
| Manager of FMM, REGION                                |
| Regional FMMs & FMC/S                                 |
| ABM delegate                                          |
| Manager of SDR, REGION                                |
| SDR Managers                                          |
| Mktg Ops (optional)                                   |
| Regional Campaign Manager (optional)  |
| Anyone else the Manager of FMM REGION deems necessary |

## Next Steps after Quarterly  plans are complete

In an effort to share the regional marketing team's plans with the rest of the marketing team, the below steps will be followed:

### Marketing SSoT calendar

Within two days of the quarterly plan being [locked by Finance](https://internal.gitlab.com/handbook/finance/financial-planning-and-analysis/marketing-finance/#important-dates) in Allocadia, the Regional Managers will download the teams' plans from Allocadia and will upload to the shared [marketing calendar](/handbook/marketing/#marketing-calendar).

In order to ensure the formulas carry over properly, the download from Allocadia will need to be cleaned, similiar to how we clean our leads for list upload.

The [Calendar cleaner spreadsheet](https://docs.google.com/spreadsheets/d/19XsjDlnAJ_lmWysIcD1XSL1JT3R0awDUd_7MRCGgMgs/edit#gid=777223734&range=A1) should be used to do this. Once the data is cleaned, it then can be copied into the [marketing calendar](/handbook/marketing/#marketing-calendar).

[Video walk through on how to clean.](https://youtu.be/xiABH1Gjkw4) *on GitLab Unfiltered.

After the initial pull, the regional marketers are responsible for adding any new tactics for the quarter if we are mid-quarter.

If an event is created after this quarterly transfer, the event DRI is responsible for adding the event to the SSoT calendar. Please see the [rescheduling or cancellation guidelines](/handbook/marketing/field-marketing/#rescheduling-or-cancelling-events) for additional details regarding changes or cancellations to existing events.

#### AMER SSoT

In the AMER region, managers are responsible for the [Marketing SSoT above](/handbook/marketing/field-marketing/#marketing-ssot-calendarhandbookmarketingmarketing-calendar), but also the AMER SSoT [here](https://docs.google.com/spreadsheets/d/1Tss2_8rz9vZdDE68T11dOMlCZPRowhANKLHgAazmSJA/edit#gid=222941017) (internal).

Within two days of the quarterly plan being [locked by Finance](https://internal.gitlab.com/handbook/finance/financial-planning-and-analysis/marketing-finance/#important-dates) in Allocadia, the AMER Regional Manager will download the team's plans from Allocadia and will upload to the [AMER SSoT](https://docs.google.com/spreadsheets/d/1Tss2_8rz9vZdDE68T11dOMlCZPRowhANKLHgAazmSJA/edit#gid=222941017) (internal).

After the initial pull, the regional marketers are responsible for adding all details not included in the pull, any new tactics for the quarter that weren't pulled from Allocadia, and also moving completed tactics to the `Completed Events - Results` tab and providing all retrospective information required.

### Asks into Digital Campaigns

Details on how Field Marketing shares quarterly plans with the Digital team can be [found here](/handbook/marketing/integrated-marketing/digital-strategy/digital-strategy-management/).

### Asks into Product Marketing

~~By the 15th of the 3rd month of the quarter, all asks for the Portfolio Marketing team for the upcoming quarter should be opened up for their review. Following their process outlined here. It's the responsibility of each FMM to ensure their asks are in by this time. The ~Field Marketing label must be added to the request in order for the PM team to review. We will use [this list](https://gitlab.com/gitlab-com/marketing/strategic-marketing/product-marketing/-/issues?label_name%5B%5D=Field+Marketing&label_name%5B%5D=sm_request&scope=all&sort=due_date&state=opened&utf8=%E2%9C%93) to review.~~

#### Asks into the Customer Reference team

After the quarterly FMM plans have been added to the [marketing calendar](/handbook/marketing/#marketing-calendar), the regional Manager of FMM will set up an alignment meeting with the Director of Market Strategy & Insights. The regional FMMs as well as the regional customer reference manager should also be invited to this meeting. During this meeting, the team will review asks into the [Customer reference team](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/customer-advocacy/) and agree on asks for the quarter.

You will note in Allocadia in the details panel if you need a customer speaker. [Video walk through](https://youtu.be/VYwBXmpJrDg) (you must be logged into GitLab Unfiltered to view.)

### Asks into BDR org

After the quarterly FMM plans have been added to the [marketing calendar](/handbook/marketing/#marketing-calendar), the regional Manager of FMM will set up an alignment meeting with the Regional Manager of BDR and Director, Sales Dev Operations. The regional FMMs as well as the regional managers should also be invited to this meeting. During this meeting, the team will review asks into the BDR org. Further details on this process can be [found here.](/handbook/marketing/sales-development/#approvals-required)

You will note in Allocadia in the details panel if you need BDR support. [Video walk through](https://youtu.be/VYwBXmpJrDg) (you must be logged into GitLab Unfiltered to view.)

### Asks into the SA org

After the quarterly FMM plans have been added to the [marketing calendar](/handbook/marketing/#marketing-calendar), the regional Manager of FMM will set up an alignment meeting with the Regional Manager of SAs. The regional FMMs as well as the regional managers should also be invited to this meeting. During this meeting, the team will review asks into the SA org.

You will note in Allocadia in the details panel if you need SA support. [Video walk through](https://youtu.be/VYwBXmpJrDg) (you must be logged into GitLab Unfiltered to view.)

## Field Marketing/Channel Marketing Engagement

We know and understand the importance of working with our channel partners in region to help build pipeline, and ultimately contribute to closed won business. Jointly with their regionally aligned Channel Marketing Manager & Field Sales teams, Field Marketers should be thinking about which partners will help their sales teams build pipeline in the region and include them in their campaigns.

### The Field Marketing team will work with channel partners that have successfully

1. Executed at least 3 MDF campaigns in the last 12 months - achieving ROI of 10 x Pipe 2 Spend and targeted # of DRs
1. Booked business threshold.
    - Please revivew the internal handbook for the [required threshold of business booked](https://internal.gitlab.com/handbook/marketing/integrated-marketing/#threshold-of-booked-business).

The Channel Marketing Manager is responsible for keeping track of which partners fall within this category and will support the FM campaign DRI as the link between channel partner and us to ensure a smooth campaign execution on both sides.

The complete list of Marketing Channel Partners are identified in SFDC [here](https://gitlab.my.salesforce.com/00OPL0000002muz).

## FMM/CAM alignment

| Region | FMM | PTM |
| ------ | ------ | -------------- |
| AMER East & Canada Enterprise| Beth Parker | Jay Bahar |
| AMER South Central & LATAM Enterprise| Jonathan Santiago | Rodrigo Rios - LATAM and Joe McAninch - Central |
| AMER North Central Enterprise| Julie Wyatt | Joe McAninch - Central |
| AMER Southwest & Northwest Enterprise | Lisa Rom | Kyle Olsen |
| AMER ALL Commercial | Beth Parker, Jonathan Santiago, Julie Wyatt and Lisa Rom | Lisa Cartegna - AMER Commercial NAMED|
| AMER ALL Commercial | Beth Parker, Jonathan Santiago, Julie Wyatt and Lisa Rom | Maria Henry- AMER Commercial |
| AMER Public Sector | Kira Aubrey | Chris Novello|
| APAC | Kate Baker | Dirk de Vos |
| APAC - Japan | Shu Kawaguchi |  |
| EMEA Southern Europe | Marcus Hall & Juliette Francon | Tristan Ouin |
| EMEA META | Marcus Hall & Juliette Francon | Adham Alattar |
| EMEA Northern Europe | Neha Pujari| Michal Kulakowski |
| EMEA UK/I | Neha Pujari | Aaron Burgess |
| EMEA DACH | Sarina Kraft | Ilaria Pazienza |
| EMEA CEE | Sarina Kraft | Michal Kulakowski  |

## Field Marketing initiated and funded campaigns

Once the partner has reached the threshold, the Channel Marketing Manager will collaborate with the Field Marketing Manager on planning and next steps.

Suggested process:

1. Identify region/area where there is a pipeline need
1. Develop partner campaign objectives and set goal. Set up recurring biweekly cadence with partner, CMM, GitLab sales and FMM to keep planning and campaign action items on track
1. Agree to campaign tactics and persona targets, develop budget request and expected outcomes in the form of Deal Registrations
1. Ensure that you know and understand who/what each team is bringing to the campaign.
   - If there is an invitation involved, ensure that both companies have [UTM tracking links](/handbook/marketing/utm-strategy/) to know who has driven who to the event so you all can stay aligned and ensure proper follow ups are taking place.

Note: The Channel Partner Enablement team is the DRI to make sure each Partner is fully enabled prior to FMM engagement. FMMs should not be involved in any channel enablement.

### Funding joint Marketing

Campaigns with partners can be:

- Fully funded by FMM budget
- Funded jointly by FMM budget and Partner budget

We cannot use GitLab MDF dollars to fund joint campaigns.

### Sample types of activities to engage with partners

- Workshops
- Webcast / Lunch and Learn programs
- Account Acceleration Programs such as executive roundtables
- Direct Mail Programs
- Surveys

### Lead Management in the Channel

Please refer to the [Channel Partner Joint GitLab events handbook page](/handbook/marketing/marketing-operations/campaigns-and-programs/#joint-gitlab-and-partner-campaigns) for details on how we set up our joint campaign and also lead sharing with the channel as a result of those campaings.

All campaigns we are working with channel partners must flow through the outlined process as a way to ensure we are tracking the success of the campaign properly.

### Tracking success of FMM campaigns with Channel

Please refer to the [Marketing Performance handbook](/handbook/marketing/strategy-performance/marketing-metrics/#back-up-sfdc-pipeline-reports) for additional information.

### Useful Fields in SFDC that relate to Vartopia

1. Please refer to [this handbook page](/handbook/marketing/marketing-operations/vartopia/#partner-prospect-admin) for further details.

## Field Marketing with Alliance Partners

## AWS

## Google

### Register your event with Google

- If you have a joint event you are running with Google and you would like for their sales and marketing teams to help recruit attendees, you must [register your event here](https://docs.google.com/forms/d/e/1FAIpQLSfWoX35znH5PpR2LTlL7DQzCf3CoW2KkOc9egEa_FoaH6XC4A/viewform).

## Field Marketing - Public Sector

### Requesting support for a Public Sector event

Requests will be reviewed by the Staff Public Sector Field Marketing Manager. Even if the event is free or low-cost, all requests must be approved by the manager prior to any commitment to ensure the event or tactic aligns to the marketing strategy within the SLA required below, and the team has the resources to support the event.

#### Requirements

- 60 days notice, prior to the start of the event
- Support needed from Field Marketing (landing page, swag, invites, etc.)
- Budget
- Have we run or sponsored this event in the past?
  - If yes - Please provide ROI details from previous SFDC campaign
  - If no - Please provide valid justification for adding this event to the Field Marketing plan

### Charitable Donations for Event Attendance

As incentive for attending an event, GitLab can promote and process a monetary donation per participant to a charitable organization. For example: GitLab promotes a $25 donation per attendee for attending an event, 100 attendees participate in the event and GitLab donates $2,500 to the selected charity. **Please Note**: Donations are not to be made in a participant's name or reference a participant's organization.

All GitLab donations to charitable organizations must follow the [Philanthropy Approval Process](/handbook/legal/esg/#philanthropic-requests).

### PubSec FMM Calendar share

In alignment with the PubSec team's [process to lock down shared data](https://gitlab.com/gitlab-com/customer-success/okrs/-/issues/150) that is accessible to teams outside of our US PubSec team - (will link to handbook page once its been created!) the Public Sector Field Marketing Managers, by default, will mark their calendar details as private. Google calendar [has a feature](https://support.google.com/calendar/answer/37082?hl=en#zippy=%2Cunderstand-permission-settings-for-shared-calendars%2Cstop-sharing-your-calendar-publicly-with-your-organization-or-with-specific-people) that allows you to share your calendar with individuals once its been marketed as private and at a minimum, the FMM team member should share their calendar with both their direct manager as well as their aligned Field Marketing Specialist, pending those people are US Citizens.

### GitLab Government User Group Program

#### Purpose

To build a community of GitLab users within Government and Education where peers can share best practices, connect with GitLab Team members and collaborate on how to best serve the public sector.

#### Mission Statement

To provide opportunities for discussion, education and community building for individuals who serve the Public Sector through Meetups (both virtual and in person), training and team building

#### User Group Values

 Transformation, Collaboration, Education, Iteration, Inclusion

#### Four Pillars of our User Group

1. Member Development: Helping our members grow both through both technical and professional education
1. Outreach: Engaging with the greater Public Sector community
1. Awareness & Education: Helping to drive conversations on how DevOps can benefit the communities we serve
1. Contributing: Continue to support the growth and transformation of DevOps within the technical community

#### Code of Conduct

To ensure a positive experience we will adhere to the GitLab code of conduct [found here](https://about.gitlab.com/community/contribute/code-of-conduct/)

#### Boilerplate Verbiage

Join us as we build a community of GitLab users within Government and Education where peers can share best practices, connect with public sector GitLab Team members and collaborate on how to best serve the public sector.

We are committed to providing opportunities for discussion, education and community building for individuals who serve the public sector. We look forward to connecting through both virtual and in person events, training and team building!

#### Branches

- Caffeine and Collaboration #caffeineandcollaboration
- User Group Workshops #usergroupworkshop
- Iterate! Start something new!

#### Recommended Formats for Event

- Roughly 1.5 hours in length
- Series of 2-3 speakers (one GitLab and 1-2 customers)
- AMA or Panel

#### Sample Agenda/Example Slide Deck

[Sample Agenda/Example Slide Deck](https://docs.google.com/presentation/d/1hwU1nt8wb8ADtj9JFq-zTg1bbZNf3L5H/edit?usp=sharing&ouid=114806938780598580840&rtpof=true&sd=true)

#### GitLab Forum

- Encourage members, registrants and attendees to get involved and open up discussions on the [GitLab Forum page](https://forum.gitlab.com/c/gitlab-government-user-group/44) for the GitLab Government User Group.

#### Imagery

- Branding should remain consistent across the entire User Group program leveraging marketing approved Tanuki graphics.
  - Press kit for Tanuki designs can be found [here](https://about.gitlab.com/press/press-kit/)

#### Hashtags and Social Media Promotion

- The following hashtags should be used when promoting on social platforms:
  - #gitlabgovernmentusergroup
  - #caffeineandcollaboration (when applicable)
  - #gitlab
  - #devops
  - #devsecops
  - #gitlabusergroupworkshop (when applicable)
- Event should be promoted via GitLab's corporate LinkedIn Events page. Reach out to @KiraAubrey in Field Marketing to have the event placed on the site.
- Event should be promoted via Bambu. Reach out to @KiraAubrey to get a post created, approved and ready for team sharing.
- Encourage relevant people from the sales, marketing and technical teams to promote via their social pages.

#### When Engaging a Partner

**Consider the following items**:

- Will the partner be hosting the meeting? (applicable to both in-person and virtual versions)
- Will the partner be collecting the registrations and how/when will those be shared with GitLab?
- Ensure that the partner is aware this is NOT a marketable event.
- Ensure branding is in alignment with GitLab Government User Group branding.

#### Backend Processes

**Getting Started with Meetup.com**

1. Create your meetup page on meetup.com
1. Reach out to the community team to let them know you've created a new meetup and request the GitLab Corporate Account code
1. The community team will provide you a unique ticket link. Click and follow prompts to have your meetup page join larger GitLab network on Meetup.com
1. Once page is established alert your team that it is live and encourage page engagement
1. Once an event has been established it should be announced on the [GitLab Government User Group meetup.com page](https://www.meetup.com/gitlab-government-user-group/). Please reach out to @pmejia and/or @KiraAubrey to have the event published.
   - **Please Note**: Meetup.com will be leveraged for announcements and save the date messaging. Actual registration will take place on external registration sites via GitLab or the involved partner.
   - **Best Practice**: Create a Save the Date event for your upcoming event on meetup.com!

#### Best Practices - Sample Timeline for a User Group Run Through Carahsoft

- GitLab Team Member nominates a Speaker and Proposed Topic/ Speaker submission form is received
- Intro call with GitLab and Speaker
  - **Agenda**
    - Confirm topic
    - Confirm availability for the event
      - Confirm ability to reference agency in promo materials
      - What approvals do they need
      - What details do they need from GitLab to secure approvals
  - **Discuss Desired Format**
    - Presentation
    - Interview
    - Panel Interview
  - **Review Logistics**
    - Carahsoft hosts via Fed Zoom
    - Meetup.com page will be leveraged (ask speaker to join our user group on meetup!)
  - **Outline Next Steps**
    - GitLab to provide speaker with any information needed for approvals
    - Speaker to secure approvals
    - GitLab to introduce Carahsoft to schedule the dry run
    - GitLab and speaker walk through the agenda prior to Dry Run
    - Speakers will need to provide a headshot and bio
    - Carahsoft will host Dry Run
  - **Event Completed**
    - Follow up between GitLab and Speaker on approvals until they are secured
    - Team effort between marketing channel and nominator
    - Follow up between GitLab and Carahsoft once approvals are in flight
  - **Invite email copy**
    - Confirmation email copy and resources
    - Assets
    - Coffee order form if applicable
  - **Request Graphics from Carahsoft**
    - Email banner
    - Social media
  - **Update Meetup.com with a Save the Date or Event Placeholder**
    - Once Approvals are secured Introduce Speakers to Carahsoft
    - Carahsoft to work on scheduling dry run
    - Carahsoft to share invite for speakers to leverage
    - Carahsoft/GitLab to prompt speakers for headshots and bio
  - **GitLab and Carahsoft to Collaborate on Event Assets**
    - Slide Deck
    - Script
    - Polling Questions
    - Best practice: separate doc for polling questions
  - **GitLab and Speaker Sync to Review Content for the Event**
    - Dry Run for GitLab, Carahsoft and Speaker
    - Review Zoom logistics
    - Early login for all participants
    - Polling question logistics
    - Review Script and flow for the day of the event
    - Ensure speakers are comfortable
    - Reminder to join user group on Meetup.com
    - Reminder to order coffee if applicable
  - **Carahsoft and GitLab to leverage cadence call prior to event for moderator prep**
    - Review script and define responsibilities around hosting, muting, poll questions etc.
    - Review slides
  - **Finalize copy for Thank you email and confirm CTA's and resources**
  - **Carahsoft to Load Poll questions into Zoom meeting**
  - **Day Before Event**
    - Carahsoft sends reminder email
    - GitLab sends reminder email via meetup.com prompting RSVP's to register if they haven't already
    - Carahsoft confirms all poll questions are loaded
  - **Day of Event**
    - GitLab checks meetup.com for any questions and updates invite with zoom link (in case folks want to attend but don't want to register via Carahsoft)
    - Carahsoft and moderators to join 30 minutes early
    - Speakers to join 15 minutes early
    - Carahsoft to kick off event a couple minutes past the start time
  - **Follow Up**
    - Carahsoft to send thank you email with resources and prompt to join the next event

**User Group Event Checklist**

```text
        - Invite Copy
        - Confirmation email copy
        - Resources for confirmation email
        - Coffee order link (if applicable)
        - Graphics
        - Email banner
        - Social
        - Slide template
        - Zoom background
        - Script
        - Poll questions
        - Thank you email
        - Resources
        - Invite for next event (or meetup.com save the date link)
```

## GitLab Company Information (Including Tax ID)

[Useful Company Information](https://gitlab.com/gitlab-com/Finance-Division/finance/-/wikis/company-information)

## AMER Field Marketing iPad Purchasing and Setup Instructions

### Purchasing Details

[iPad Pro 12.9 inch/256GB/wifi](https://www.apple.com/shop/buy-ipad/ipad-pro/12.9-inch-display-256gb-space-gray-wifi)
[iPad Pro 12.9 inch Smart Keyboard Folio](https://www.apple.com/ca/shop/product/MXNL2LL/A/smart-keyboard-folio-for-ipad-pro-129-inch-6th-generation-us-english)

- When purchasing, please utilize the GitLab Business Account for corporate discounts. The Apple store/online representative will look up the GitLab Business Account associated with GitLab's 268 Bush St., San Francisco, CA 94104 address.
- Do not purchase AppleCare
- iPads can only be purchased by the regional Field Marketing Manager

### iPad Tracking

#### AMER

In the AMER region, we utilize [this issue](https://gitlab.com/gitlab-com/marketing/field-marketing/issues/1031) to track the team's iPads.

#### EMEA

In the EMEA region, [Ten&One](/handbook/marketing/field-marketing/#emea-field-marketing-swag) is utilized for the team's iPad tracking.

#### APAC

TBD

### Setting Up Logins

**iPad Password**

- Utilize the password listed in the notes section of the AMER Field Marketing Apple ID located in the Marketing 1Pass

**Field Marketing Apple ID**

- Log in to the AMER Field Marketing Apple account utilizing the username and password listed under the AMER Field Marketing Apple ID located in the Marketing 1Pass. Please take note of the additional information listed in the notes section regarding cell phone verification.

**Google Drive and Slides**

- Follow the instructions [HERE](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/demo/conference-booth-setup/#ipads) to set up Google Drive and Slides

## Working with Field Marketing

### Requests to Field Marketing leadership team

If you are a Field Marketing Manager and you would like to make a request in order to achieve better business results aligned to our values, please submit an issue using the [Field Marketing Leadership request issue template](https://gitlab.com/gitlab-com/marketing/field-marketing/-/issues/new?issuable_template=leadership_request).

FM leadership team will review all requests on a bi-weekly basis, and will prioritize as necessary or will share with you relevant issues if the request is already being worked on.

**Why we use this template:**
Funneling similar requests from a global team and addressing shared pain points in a single issue with a [DRI](/handbook/people-group/directly-responsible-individuals/) will help to reduce noise and churn for other teams we collaborate with and ideally helps to improve a process that works for the WW Field organisation.

This issue should not be used as a shortcut to get questions answered but for request where FM leadership can help to improve a process which does contribute to our success as a team.

## How Field Marketing Tracks Campaign Expenses

For information on how Field Marketing tracks campaign expenses, please visit the Marketing handbook page section [here](/handbook/marketing/marketing-team-processes/#how-marketing-tracks-campaign-expenses).

## Field Marketing Labels in GitLab

The Field Marketing team works from issues and issue boards. If you need our assistance with any project, please open an issue and use the `Field Marketing` label anywhere within the GitLab repo.

### General Field Marketing Labels

- `Field Marketing`: Issue initially created, used in templates, the starting point for any issue that involves Field Marketing
- `FY25-Q1` `FY25-Q2` `FY25-Q3` `FY25-Q4`: What event or activity is set to take place or be due in this quarter in the specific year
- `mktg-status::plan`: work that is proposed, in an exploratory state
- `mktg-status::wip`: work in progress that has been accepted and assigned to a DRI
- `Events`: Issues related to events - this label is held at the gitlab.com level
- `Content Syndication`: Issue related to content syndication
- `DevOpsDays`: Issue related to DevOps Days
- `Direct Mail`: Issue related to Direct Mail
- `Executive Roundtable`: Issue related to Executive Roundtables
- `GitLab Connect`: Issue related to GitLab Connects
- `Hybrid Conference`: Issue related to Hybrid Conferences
- `In-Person Conference`: Issue related to In-Person Conferences
- `Meeting Setting`: Issue related to Meeting Setting
- `Owned Event`: Issue related to Owned Events
- `Webcast - Sponsored`: Issue related to Sponsored Webcasts
- `Survey`: Issue related to Surveys
- `Vendor Arranged Meetings`: Issue related to Vendor Arranged Meetings
- `Virtual Conference`: Issue related to Virtual Conferences
- `Webcast - GitLab Hosted`: Issue related to GitLab-Hosted Webcasts
- `FM Workshop`: Issue related to Field Marketing-run workshops

### Regional Field Marketing Labels

- `APAC`: Issues that are related to the APAC sales team
- `EMEA`: Issues that are related to the EMEA sales team
- `FM AMER ALL`: Issues that are related to the AMER ALL Allocadia plan
- `Central Europe`: Issues that are related to the EMEA Central Europe (DACH) sales team
- `Europe CEE`: Issues that are related to the EMEA Central Eastern Europe sales team
- `Southern Europe`: Issues that are related to the EMEA Southern Europe (France, Italy, Spain, Portugal, Greece, Cyprus) sales team
- `Northern Europe`: Issues that are related to the EMEA Northern Europe (Nordics & Benelux) sales team
- `UK/I`: Issues that are related to the EMEA UK & Ireland sales team
- `Russia`: Issues that are related to the EMEA Russia & Ukraine sales team
- `MEA`: Issues that are related to the EMEA MEA (Middle East & Africa) sales team
- `East - NE & NYC Metro`: Issues that are related to the US East - NE sales team and East - NYC sales team
- `East - SE & Mid Atlantic`: Issues that are related to the East - SE sales team and East - Mid-Atlantic sales team
- `EAST - South Central`: Issues that are related to the EAST - South Central sales team
- `WEST - SW & Bay Area`: Issues that are related to the West - SW sales team and West Bay Area sales team
- `WEST - NW & North Central`: Issues that are related to the West - NW sales team and Central - North Central sales team
- `LATAM`: Issues that are related to the LATAM sales team
- `Public Sector US`: Any issues related to US Public Sector
- `AMER PubSec - FED`: AMER FED tactics
- `AMER PubSec - SLED/CIV`: AMER SLED tactics
- `AMER - DOD`: AMER DOD tactics
- `AMER - CIV`: AMER Civilian tactics
- `AMER - SLED`: AMER SLED tactics
- `AMER - NSP`: AMER National Security tactics
- `FMS AMER`: FMS AMER general requests
- `FMS AMER - Swag`: FMS AMER swag requests
- `FMS AMER - Contracts`: FMS AMER contract requests
- `FMC EMEA`: Apply this label for the attention of the Field Marketing Coordinator-EMEA
- `FMC EMEA - Event Tracking`: Event/deadline tracking related to FMC EMEA
- `SDR-GO Live`: Label FMMs add to the SDR Request issue that notifies the SDR team that the issue has been completed and is ready to be worked by the SDRs. [SDR-GO Live Summary board.](https://gitlab.com/groups/gitlab-com/marketing/-/boards/2124068?&label_name[]=SDR-GO%20Live)

For more information on how Field Marketing utilizes GitLab for agile project management, please visit [Marketing Project Management Guidelines](/handbook/marketing/#-marketing-project-management-guidelines).

## The Field Marketing Budget

Field Marketing manages its budget in [Allocadia](/handbook/marketing/strategy-performance/allocadia/). Specific instructions on how we manage our expenses:

1. Each FMM will have a quarterly allocation of money to spend based on territory pipeline needs.
1. Every month on t -6 days (so 6 business days before the start of the next month) finance will do a pull of this data and push it into the company planning tool called Adaptive. Field Marketing Managers must always keep their budgets up to date, but it is essential the budget is accurate for the month prior to t -6 days, as FMM Leadership reviews the budget vs. actuals on a monthly basis.
   - Via Geekbot, each FMM will receive a reminder t-8 days before the start of the next month - or 2 days before the monthly forecast is due to Finance.
1. Direct Mail accrual process - Spend should be planned and expensed in the month in which they are sent out to recipients vs. the month in which the recipient could use the direct mail piece, as we have no control over when a gift card (as an example) is used.
1. Survey accrual process - If you are using a 3rd party to complete a survey, it's the responsibility of the FMM DRI to account for the percent of work that was completed in that month in the budget. As an example, if you signed a contract with a vendor to complete 100 surveys, and in month 1, 50 of the 100 contracted for surveys were completed, then you would account for 50% of the expense in month 1.
   - This update in monthly expense is due to be updated directly in the budget document, in the correct month, in advance of the t -6 days before the end of the month, which is when Finance does a pull of our budget doc to run a budget vs. actuals comparison
1. Content Syndication accrual process - If you are using a 3rd party to run a content syndication play, it's the responsibility of the FMM DRI to account for the percent of work that was completed in that month in the budget. As an example, if you signed a contract with a vendor to complete 100 leads, and in month 1, 50 of the 100 contracted for leads were delivered, then you would account for 50% of the expense in month 1.
   - This update in monthly expense is due to be updated directly in the budget document, in the correct month, in advance of the t -6 days before the end of the month, which is when Finance does a pull of our budget doc to run a budget vs. actuals comparison
1. The entire cost of the program is to be forecasted for - Sponsorship + lead scanners + monitor + any other auxiliary cost that the company will incur.
1. If the event is just 1 day, then the start and end date would be the same.
1. Any expense that is less than $5,000 USD will be expensed against your budget in the month it is paid. This is in alignment with our [GitLab Prepaid Expense Policy](/handbook/finance/accounting/#prepaid-expense-policy). It is essential that you have this expense in the correct month within Allocadia.
1. For expenses more than $5,000 USD (also in alignment with our Accounting rules), we recognize the expense in the month when the work happens, NOT when we the cash leaves our doors.
   - As such, when you are running paid digital ads to support campaign work, you must account for the spend in a separate line item (this is aligned with our practice of [creating separate line items for each individual invoice/spend](/handbook/marketing/strategy-performance/allocadia/#buttons). You will keep the same campaign name for the digital spend, but you will need to account for the different vendor and different time frame in the additional line item.
1. If you are running a campaign that has more than one tactic, and there are specific dates for the tactics, then each tactic will need its own line item in Allocadia.
    - As an example: If you are running a country specific campaign on CI/CD and there are 2 webinars and a workshop included in that campaign with a different specific date, then each webinar and the workshop will need its own tag, in addition to its own line item in the budget.
1. Each folder in Allocadia is protected based on the managers/DRI's for each region. Only those with permissions will be able to edit each folder. Please reach out in the #allocadia_mktg-budget-holders slack channel if you need permissions updated.
1. At times, expenses are shared across an entire region. These expenses are housed in the ALL region folders. Any activity plans should transfer money to the ALL folder when looking to share the cost of expense. The same expense should NOT live in multiple activity plans if its an expense that is shared amongst more than 1 activity plan.
   - As an example: If all regions within AMER want to collaborate on the same campaign and they each want to spend $5k on the campaign, the FMMs would use the [transfer budget feature within Allocadia](/handbook/marketing/strategy-performance/allocadia/#request-transfer) to transfer that money into the All AMER activity plan. Once in All AMER,  the correct sub-geos should be selected in the details panel so its clear how this campaign will support the different regions/sub-geos. Transferring to the All folders also prevents FMMs from having to divide out the MQLs amongst the various regions as well for ROI calculation purposes.
   - In order for the shared activity to be pulled into the regional pipeline reporting for QBRs, the FMM will need to remember to also select the ALL folder in addition to their activity plan name in order to pull their full plan noted in [reports 3 & 4 here.](/handbook/marketing/strategy-performance/allocadia/#reports-field-marketing-uses)
   - [Video walk through](https://youtu.be/w3Vs5lbBogU) - must be logged into YouTube Unfiltered
   - SFDC campaign owner will be the specific DRI for the overall campaign if running a shared campaign.
1. When splitting a tactic between territories, all money should be transferred to one activity plan and the PO should be raised from that one line item.
1. For budgeting purposes we need to stipulate the amount in USD (as we currently operate in USD) in the FMM budget. Allocadia does have a multi-currency function where you right click in the planned or forecasted sections and the conversion amount is completed for you pulling exchange rates that are loaded on the back end by our finance team.
1. VAT and GST does not need to be included into budget planning as these do not attribute to program expenses, however sales tax in the US does.
1. As it relates to procurement issues being approved, it is essential that the contract details are submitted with the procurement issue, that way the approver is clear about what they are signing off on.
    - We aim for an MQL to not cost us more than $500, should a contract be submitted that is over the $500 goal, there needs to be a documented reason + path to success shown in the procurement issue. It is the responsibility of the FMM Country Manager to ensure this documentation is listed in the procurement issue before the issue is sent on to further leadership to review/approve. For C-level and other campaign where we target decision makers, the customer journey needs to be documented and we acknowledge that the MQL might be higher.

## Customer Speaker Gifts

Please note that there is a limit of $75 USD annually per person on customer speaker gifts.

## Field Marketing and the Procurement Process

### Field Marketing Contract Requests

In Field Marketing, the FMCs manage all [Zip requisitions](/handbook/business-technology/enterprise-applications/guides/zip-guide) for their regions. For contracts or invoices ready to submit for approval, the FMM will open an issue utilizing the [`Contract_Request`](https://gitlab.com/gitlab-com/marketing/field-marketing/issues/new?issuable_template=Contract_Request) template and follow the instructions to provide important details required before assigning to the regional FMC.

#### SLAs

The SLA for your FMC to submit your request to Zip/Coupa is **3 business days** from when they are assigned the contract request issue. Please keep in mind it generally takes a week+ to obtain all approvals and/or signatures during the procurement process (longer for more complicated contracts that may require redlines from legal), so please plan accordingly.

#### Document Review

Please make sure you have reviewed your document carefully and have pre-filled the contract details required in the agreement *before* assigning the issue to your FMC. Below are some items to keep in mind when both the FMMs and FMCs are reviewing contracts...

- Correct [GitLab entity](https://gitlab.com/gitlab-com/Finance-Division/finance/-/wikis/company-information) that needs to be utilized, along with the correct address associated with that entity
- GitLab company name spelled correctly (capital L!)
- Lead specifics - What contact information will be provided and when?
- Correct event dates, cost, and sponsorship level
- Clear vendor goals and if the vendor fails to deliver against T&Cs/goals, a detailed make-good clause
- If a room block is involved, accurate attrition requirements have been included

#### Month Close

Please Note: AP typically closes out the month by the third business day **before** the last day of the month (Day -3). Once AP closes the month, any charges under $5k (under $50k for swag/shipping) occurring via a credit card or invoice approvals will be reconciled the following month. The month close date will be announced each month in the `#allocadia_mktg-budget-holders` Slack channel and will also be added to the [Marketing Finance Dates Calendar](https://calendar.google.com/calendar/embed?src=c_j581mpq4tcn6bjojs1bqnl4eg0%40group.calendar.google.com&ctz=America%2FDenver).

#### Prepaid Policy

Please make sure you have reviewed our company's [prepaid policy](/handbook/finance/accounting/#prepaid-expense-policy) and have forecasted your cost(s) correctly in Allocadia.

#### Signature Authority

GitLab team members DO NOT have [signature authority](/handbook/company/authorization-matrix/expenses-and-signatures/#signature-authority---sales-and-vendor-contracts). This means that FMMs are not allowed to sign any legal documents pertaining to quotes, orders, contracts, BEOs, etc. If you have a document that requires a signature, please submit it in a contract request to your FMC to process through procurement.

#### Coupa Card Versus Navan Card

This template is to be utilized for all contracts/orders/invoices that either require a signature/acceptance of terms and conditions and/or are over $5,000 in cost. If your order does not require a contract/signature and is under $5,000, you may utilize your [Navan credit card](/handbook/finance/accounts-payable/corp-credit-cards/) for payment.

#### Coupa Card Limits

Please be aware that your Coupa card limit is directly associated to the approved PO amount. We have a 10% overage on the card and if you try to charge more than 10% over the PO amount, the card will decline. If you require additional funds be added to the card limit, you will need to request your FMC submit a [PO Change Request](/handbook/business-technology/enterprise-applications/guides/zip-guide/#how-to-do-a-request-change) to increase the PO total and the card limit.

#### Coupa Card Max (Onboarding New Vendors)

Please also note, we can only use Coupa cards for POs up to $25,000. Anything over $25,000 requires ACH payment and onboarding the vendor through Zip/Coupa. If you know you have an upcoming contract/payment over $25,000, please contact your FMC in advance so they can check to see if the vendor is currently in Zip/Coupa and if not, they can request the vendor be onboarded in advance by submitting a [Zip request](/handbook/business-technology/enterprise-applications/guides/zip-guide/#how-to-request-a-new-vendor). No contract is required to submit this request and an estimated cost can be provided. Please note in the title of the submission that the request is for new vendor onboarding only. For any questions, please reach out to your FMC.

#### Various Charges on Coupa Card

If you are submitting various charges for approval on a Coupa virtual card, please make sure you either provide the PDF contract/order/quote or, if ordering through an online portal, please include a screenshot of the items you need to order. Each separate order requires a supporting PDF or screenshot that shows the vendor name, items being ordered, and total cost. These requests will be reviewed during the procurement process and if approved, the Coupa card issued will cover all costs submitted. Only one Allocadia line item is required per Coupa card approved. For example, if you submit a contract request for booth, AV, and IT charges for a show that equal $3,000, you only need one Allocadia line item ID for all three charges and your plan/forecast number would equal $3,000.

PLEASE NOTE: These charges follow the [prepaid policy](/handbook/finance/accounting/#prepaid-expense-policy) and you will always reference the total cost of the charges/PO amount for determining the prepaid threshold. For example, if you submit a $3,000 AV order and a $3,000 booth items order together on one PO, the total PO amount is $6,000. Even though each charge is under the $5k prepaid threshold, the total amount of the PO is $6,000, so you would forecast the charges under the month the event occurs.

#### Multi-Event Contracts

We often receive a discount for multiple events and the vendor includes all events under one contract. When this occurs, the FMM will need to create an Allocadia sub-issue and line item for each event and provide all of the Allocadia IDs in the contract request for the FMC. The FMC will submit the contract in ZIP and add separate lines for each event with that specific event's information and Allocadia ID.

PLEASE NOTE: These charges follow the [prepaid policy](/handbook/finance/accounting/#prepaid-expense-policy) and you will always reference the total cost of the charges/PO amount for determining the prepaid threshold. For example, if you submit a contract for 3 events and each event costs $3,000, the total PO amount is $9,000. Even though each event is under the $5k prepaid threshold, the total amount of the PO is $9,000, so you would forecast each event charge under the month the event occurs.

#### F&B/AV/Additional Event Charges

Since we often don't have the exact headcount for an event in advance, additional costs (such as AV, F&B, etc.) can be estimated for initial procurement approval. If your additional costs are included in the initial venue contract, please ask the venue to provide pricing for your estimated headcount in the contract (especially for F&B costs, so that you are not only submitting your F&B minimum). This will give us a baseline cost estimate for approval and your FMC will adjust the PO amount as needed, based on final cost (a PO change request will be issued for charges above 10% over the original PO amount). If your additional costs (catering, AV, etc.) are being provided by different vendors from the venue, please make sure you have separate Allocadia line items for those charges and also submit separate contract requests (if a contract is required by the vendors). If the vendor does not require a contract and charges are under $5,000, you can pay with your Navan card.

## Sourcing New Field Marketing Vendors

Field marketers are always looking for new ways to support the sales teams within their regions and to provide unique, alternative ways to draw potential prospects closer to our company and show value to our current customers in order to expand within those accounts. Field marketers have a vast tool kit of marketing initiatives for precisely that. However, sometimes a gap is identified and field marketers will look to external third party vendors to help fill that gap when it comes to achieving their goals to their marketing metrics.

When souring and selecting a new third-party vendor, there are a few things that should be considered:

1. What are you trying to achieve? What is the gap you have identified? Is it filling the top of the funnel? Building relationships within a specific target audience (i.e. C-Level)? Maybe your goal is delivering on more qualified leads? Be clear on your end goal(s) from the beginning.
1. Can this vendor achieve your goal? Have the vendor show you proven use cases and references on your specific goals.
1. Have you sourced more than 1 vendor? A good point of reference is to research at least 2 or 3.
1. Is this vendor willing to proceed with a pilot program with you? Even with the best intentions, not all 3rd party vendors will fulfill your needs as originally discussed. A pilot program will allow you to try out the vendor and/or their product without requiring a full investment up front.
1. Identify all of the pieces of the contract. Ensure that you and the 3rd party vendor are aligned on the following:
    - Cost
    - Timeline of project
    - Timeline of onboarding
    - What is required when it comes to integration - Full Access, No Access or Partial Access
    - What are your deliverables?
    - What are their deliverables?
    - Identify who needs to be trained. What does that training involve?
    - Who will be the DRI for the project (always have 1 person who will support you during your contract process)?
    - What is the cost of renewal, or, if you are running a pilot, what is the cost of a full term contract?
    - If you're running a pilot, what are the goals you have in place to determine if you should invest beyond the pilot phase?

Once you feel confident that you have chosen the right 3rd party vendor, now is the time to begin the following review process.

### Working with vendors that are brand new

New vendors are popping up frequently and in the spirit of iteration and testing, the Field Marketing team at time may want to engage with a vendor that is brand new to the space (remember, at one point in time way back in 2011, GitLab the company was brand new too!). You should work with your leader to assess these opportunities. To ensure we are protecting our own company, you should follow these steps when working with a brand new vendor:

1. If contacted via social media or other manner by an unknown individual and/or individual(s) related to an event, review all event/program materials, including a detailed review of the organizers website to confirm past events. In addition, review various social media materials.
1. If an event is unknown, new or first time, the Team Member can engage with Alliance and Channel Team Members to gather feedback on the events organizer and ensure value, use your netowrk internally and ask around if folks know this vendor.

- Where applicable, request details and documentation related to previous event(s) hosted by the organizer.
- In situations where an organizer is hosting an inaugural event, Team Members can ask for other partners / sponsors who are participating, and receive direct confirmation from the event space host (e.g, hotel).
- In situations with first events, the field marketing team can engage the GitLab Legal Team for additional review.
- [Video walk through](https://youtu.be/Ao-HUl15c1A) with our legal team outlining this process can be found on GitLab Unfiltered.

## Software Vendor/Product Approval Process

1. FMM and FMC to review the [Procurement Handbook Page](/handbook/finance/procurement/) so you are familiar with the procurement process and lead times. Please be aware of the SLAs listed in the [Procurement Process](/handbook/finance/procurement/#the-procurement-process) for processing all reviews, approvals and contract negotiations. Note the [bid process](/handbook/finance/procurement/#how-to-start-the-procurement-process) based on thresholds as well.
1. FMM to open a Field Marketing issue and detail out the justification for the potential new vendor/product. Include any presentations, slides and demos that have been provided to help explain the product. Tag your regional manager in the issue to review and discuss. Approval must be received to move forward. Make sure to attach all of the following issues to your main Field Marketing Issue for easy access.
1. FMM to open a [Contract Request](https://gitlab.com/gitlab-com/marketing/field-marketing/-/issues/new?issuable_template=Contract_Request) issue and assign to the regional FMC.
    - SLA for FMC to complete the Contract Request issue is 3 business days from the date all needed info is filled out by the FMM in the Contract Request issue. FMM to leave a note if turnaround is urgent (FMCs have been averaging 1-2 business days currently).
1. FMC to process an NDA with the vendor, specified in the procurement handbook [here](/handbook/finance/procurement/#documentation). Remember to attach your executed NDA when opening your Zip requisition in the steps below.
1. If you're requesting a new software tool, FMM to open a [Marketing Ops Tools Eval issue](https://gitlab.com/gitlab-com/marketing/marketing-operations/-/issues/new?issuable_template=tools_eval). Marketing Ops will help evaluate the product and will assist in the procurement process. They will also help you determine if an integration is required with any products in our current tech stack and if so, which team will be the DRI for the integration.
1. FMC to follow [these instructions](/handbook/business-technology/enterprise-applications/guides/zip-guide/) for opening a Zip requisition. Please note that you can submit the Zip requisition even before a contract has been provided. This template details the following approvals:
    - NDA requirement
    - Privacy review (if applicable)
    - Security review
    - Tech stack request (for new software purchases)
1. If you're requesting a new tool, and if the new product requires integration with any of our existing products (SFDC, Marketo, Outreach, etc.) FMC to open an integration request issue with the appropriate team (see step above where the Marketing Ops team will help determine). Integration will not begin until all approvals are final and the contract has been fully executed, but opening the integration issue early will give the appropriate team advance notice for planning.

## Field Marketing and Legal

### Legal Approvals

Field Marketing executes contracts with outside vendors to support the work we do. We do so by following the company [procure to pay process](/handbook/finance/procurement/). All legal approvals will flow this process.

It should be a rare occasion (and not a result of poor planning), that a contract would need to be urgently (less than 5 business days) turned around. Only after all FMM approvals have happened, should the FMC ping legal on slack asking them to please approve an urgent ask.

### Sweepstakes

Field Marketing follows the legal team's process [here](/handbook/legal/marketing-collaboration/#promotional-games) for contests and sweepstakes.

## Field Marketing Communications

### Regional Email Aliases

Field Marketing utilizes regional email aliases for pre and post tactic outreach. Please see [this section](/handbook/marketing/events/#email-alias-usages-for-outreach) for more details.

## Slack Rooms we use

- [#fieldmarketing](https://gitlab.slack.com/archives/CCWDAJ8PK) - open to all teams to ask questions to field marketing & where weekly stand-up reports get posted to.
  - If you're an employee at GitLab trying to reach Field Marketing, please head over to our slack channel.
    - **NOTE**: If you're requesting we sponsor an event, instructions can be found [here](/handbook/marketing/field-marketing/#whats-currently-scheduled-in-my-region).
    - If a region specific question is asked in the [#fieldmarketing](https://gitlab.slack.com/archives/CCWDAJ8PK) slack room, please tag the [regional Field Marketing leader](#whats-currently-scheduled-in-my-region), as that person is the DRI.
- [#fieldmarketing-fyi](https://gitlab.slack.com/archives/C01502JC5BK) - Official channel for Field Marketing Leadership to post announcements to the Field Marketing team.
  - Restricted permission levels to only FMM Leadership posting the announcements
  - Announcements can be submitted to your manager if you would like to something shared
  - All members have comment access to allow clarifications if needed on a thread
  - You are to react with an emoji (thumbs-up, eyes…) to signal to managers that you've seen an announcement
  - There should be no need to cross-post announcements (such as posting a link from another slack channel to the #fieldmarketing channel)
    - With a #company-fyi and the [#fieldmarketing-fyi](https://gitlab.slack.com/archives/C01502JC5BK), all relevant info should be successfully communicated by managers to team members.
  - Default to issues first, then public channels when possible to avoid siloing work information to private discussions.
    - Use DMs for personal, private conversation rather than work communication (unless you are certain it is only relevant to the 2 of you or you need immediate attention).
- #fieldofdreamsteam: private room only accessible to FMMs - funny GIFs, private questions for the team.
- Please keep in mind we have detailed instructions on [how GitLab uses slack](/handbook/communication/#slack).

## Async Status Updates

Since we are a [remote](/handbook/company/culture/all-remote/) company, we utilize a Slack plugin called [Geekbot](https://geekbot.io/) to coordinate status updates. Field Marketing world wide currently conducts 1 weekly standup. Geekbot shares this update in the public #im-hangout slack room.

## Weekly Status Update

The **Weekly Status Update** is configured to run at 9 AM local time on Monday, and contains a series of rotating questions. Below is an example of questions you may see:

1. ***What was your favorite part of the weekend?***
The goal with this question is for you to get to know your colleagues and for you to be able to share what excited you from the previous few days when you weren't working.
1. <i>**Are you traveling anywhere this week? If so, where and why.**</i> <--- This question is paused for the moment. :)
As Field Marketers, we travel up to 50% of the time. Sharing where you are is important, especially if are in a different timezone.
1. ***What are your top 1-3 priorities for the next week?***
These top 3 priorities should be focused on what you plan to accomplish that week.
1. ***Anything blocking your progress?***
Of those 1-3 items listed, do you need any roadblocks removed in order to accomplish the priorities?
1. A question that is related to which [GitLab Value](/handbook/values/) we are focusing on for the month.

You will be notified via the Geekbot plug in on slack at 9 AM your local time on Mondays, as stated above. It is important to note, that unless you answer all questions in the Geekbot plug in, your answers will NOT be shared with your colleagues, so please be sure to complete all questions!

## Out of Office Process

We follow the processes documented in the [Communicating your time off section](/handbook/people-group/paid-time-off/#communicating-your-time-off) of our handbook page.

Specifically:

1. Add your OOO to [Workday](/handbook/people-group/paid-time-off/#workday)
1. Notify both your manager and the person covering for you that you will be out of the office. Make sure the person covering for you has details for items to watch or take care of for you while you are OOO.
1. Add an OOO message for your email. Please ensure you are including a DRI in your OOO email response for people outside the company to contact.
1. Turn on [Google Calendar's "out of office" setting](https://support.google.com/calendar/answer/7638168?hl=en) (scroll down to "Show when you're out of office") to create an out of office event that will automatically decline new and existing meetings for you. Or, please ensure to manually cancel/decline/reschedule any meetings if you will not be in attendance.
1. Add an OOO to your Slack profile (this will occur automatically when you submit your OOO to Workday). If you're traveling for an event and not necessarily on PTO/vacation, please ensure you are manually updating your Slack status accordingly.
1. If your time off was added in Workday, Time off by Deel in Slack will prompt you to add a delegate who will be covering for you. Please fill in this information so it's clear in Slack who people can contact in your absense.
1. Add an OOO to your GitLab profile and mark yourself as `busy`
1. If you work in ZIP, please assign assign a delegate by going to ZIP - Settings - Personal Settings - Out of Office.
1. If you work in Coupa, please [assign a delegate in Coupa](/handbook/business-technology/enterprise-applications/guides/coupa-guide/#how-to-add-a-delegate-in-coupa) so you will not hold approvals while you're enjoying your time off.

## Field Marketing MR process

Everyone can contribute, although not everyone has merge rights. Within the Field Marketing team, when someone submits an MR, the submitter needs to assign to their direct line manager to review, and then their manager will assign to the VP of Regional Marketing to review. Once the VP has reviewed/approved, it is their responsibility to ensure all threads are addressed and resolved and all merge conflicts are resolved, then merge.

Should a Country Manager of Regional Marketing or VP of Regional Marketing submit a process change in the handbook, then all Country Managers should sign off via approving the MR or commenting their approval. At which point, the Director ensures all threads are addressed and resolved and all merge conflicts are resolved, then the VP will merge.

## Creating a spif for sales

At times, Field Marketers may want to create a SPIF (sales performance incentive fund) to help drive sales behavior in a campaign they are running. While this should not be our standard to offer a SPIF, should one need to be used, we do need to report back to payroll any incentive that was paid and to who. The process is as follows:

1. There is no payment threshold that would not need to be reported. All SPIFs must be reported.
1. The SPIF DRI should send the legal name of the winners to payroll
1. The SPIF DRI should include the amount of money (or value of the prize, if a prize was offered) to payroll
1. Contact info for payroll can be found [here on their handbook page](/handbook/finance/payroll/).

## Other pages to review for a full understanding of how Field Marketing at GitLab operates

- [Events at GitLab](/handbook/marketing/events/)
- [Marketing Operations](/handbook/marketing/marketing-operations/)
- [Sales Development](/handbook/marketing/sales-development/)
- [Marketo program/campaign support](/handbook/marketing/marketing-operations/campaign-operations/)

## Account Based Marketing

Account based marketing is separate but sits next to field marketing. For info on account based marketing, please head over to the [ABM page](/handbook/marketing/account-based-marketing/).

## Tiers of support from Field Marketing for Corporate lead events

In an effort to support the events the corporate marketing team runs, Field Marketing will rank the shows on an annual basis that corporate marketing runs.

### Tier 1

Field Marketing will:

1. Run a meeting setting program at this event - this means that sales leadership has agreed that they want their sales team spending time on driving these meetings.
1. Evangelize the event is taking place with all regional sales teams.
1. If not already being planned by the corporate marketing team, run an auxiliary event driving registration with the sales teams.
1. Be onsite to support the event as needed
1. Participate in Corporate Events lead stakeholder calls

### FY25 Tier 1

1. AWS re:Invent
1. Gartner Application Summits - AMER, EMEA, APAC
1. Gartner Security Summit - AMER
1. Google NEXT

### Tier 2

Field Marketing will:

1. Evangelize the event is taking place with all regional sales teams, but will have no specific ask of the sales team
1. Will not be on onsite to support the event.

### FY25 Tier 2

1. KubeCon US
1. Black Hat US

## Deprecated handbook content

We feel like this info is too good to delete, and while we currently aren't using either the tool that is descirbed or the process, we just aren't ready to delete.....its like that sweater you just can't seem to get rid of in case you may need it one day...

## Refined AMER Regional Marketing Event Planning Cycle

The schedule provided below presents a 20-week planning timeline meticulously designed for the seamless execution of our regional marketing events. These Service Level Agreements (SLAs) are strategically established for our Field Marketing Managers (FMMs), ensuring they have ample time to orchestrate and promote a robust event, while synchronizing the availability of other teams' SLAs, including Procurement, Marketing Operations, the SA teams, our Field Marketing Coordinators, etc. It is essential to remain adaptable, as adjustments and modifications may become necessary to align with the unique event objectives, target audience, and the resources at our disposal. Ultimately, the unwavering dedication of our team will serve as the cornerstone of success for each event.

## 17-20 Weeks Out: Strategize and Initiate Planning

<details markdown=1>

<summary><b>At this stage, we lay the groundwork for a successful event by creating a well-defined strategy and rallying key players.</b></summary>

- Initiate strategic collaboration with Sales to align event goals and strategies.
- Define clear event objectives, messaging, target audience, and desired outcomes.
- Secure unwavering buy-in from essential stakeholders to ensure full support.
- Develop a comprehensive campaign plan using Allocadia, continually monitoring the budget.
- Compile all available details into a comprehensive Main Issue.-* Secure required third-party vendors if necessary, and create vendor contract request issue(s).

</details>

## 14-17 Weeks Out: Resource Alignment and Team Coordination

<details markdown=1>

<summary><b>During this phase, we focus on coordinating resources and refining our strategies to meet evolving needs.</b></summary>

- Review and approve contract requests for event vendors.
- Request team member resources based on event needs.(SA,BDR, SDR, CS, Design, Internal - Speakers etc) when required use specific team request issues as needed..
- Continue collaborating with Sales to refine goals and strategies.
- Schedule meetings with relevant team members to outline their contributions to the plan.
- Please continue to revise the issue, providing comprehensive updates that capture all plan details and ensuring that all key stakeholders are appropriately tagged.
- Move to WIP.

</details>

## 12-13 Weeks Out: Draft Initial Content, Design and confirm all Key Stakeholders

<details markdown=1>

<summary><b>We delve into content creation, design, and finalizing key stakeholder involvement while maintaining a clear timeline.</b></summary>

- Review the Issues/Epics, adding estimated completion dates for each task.
- Confirm availability and roles of requested cross-functional team members and finalize team member assignments. Note: Internal team members must have permission from their managers to travel.  Once approved, send placeholders to their calendars for events.
- Work with the design team to conceptualize event branding and design if needed.
- Begin drafting the Copy document to form the events foundation.
- Collect  concise abstracts from speakers and presenters for their sessions, to enhance your landing page and agenda.
- Review initial content drafts and design concepts.
- Gather feedback from stakeholders and make necessary revisions if needed.
- If necessary, request approvals from internal stakeholders.

</details>

## 11-12 Weeks Out: Review, Refine Content, Develop Landing Page and Collateral

<details markdown=1>

<summary><b>During this phase, we polish content, initiate promotions, and ensure a seamless, finalized Copy Document for the event landing page, confirmation emails, and initial outreach (Email #1).</b></summary>

- Compile and organize essential Target lists: Target Accounts, Target Audience, DMA requests, Relevant Previous Campaign Subject Matter, etc., for Copy Doc.
- Explore opportunities for collaboration with Campaigns,  ABM or Social teams for event promotion.
- Thoroughly review and approve landing page design and the first email.
- Launch promotional efforts across social media and other channels.
- Finalize and approve the event landing page and initial email.

</details>

## 8-10 Weeks Out: Fine-tuning and Launch Preparation

<details markdown=1>

<summary><b>With preparations in full swing, we focus on executing the first wave of communications and readying assets.</b></summary>

- Confirm the timing of email #1, targeting the event's intended audience.
- Continue robust event promotion across multiple channels.
- Coordinate the creation and ordering of event-related swag and materials.
- Initiate event swag shipments and asset preparations.
- Continue to refine Main Issues/Epics, ensuring they capture all the intricate details of the comprehensive plan.

</details>

## 3-7 Weeks Out: Enriching Engagement and Preparing for Event Second Email Communication

<details markdown=1>

<summary><b>This period centers on deepening engagement, fine-tuning event logistics, and enhancing participant experiences.</b></summary>

- Monitor the response to email #1 and track engagement with the landing page.
- Develop email #2 with additional event details if needed and value propositions.
- Sustain promotion efforts across various channels to bolster excitement.
- Collaborate with speakers and participants to ensure seamless event coordination
- If applicable, create a booth schedule for effective participant interaction.
- Conduct a thorough review of event logistics and setup details.
- Verify the timely delivery of all event-related assets and swag.
- Send out email #2 target audience, highlighting event benefits
- Finalize copy document for reminder emails and post-event follow-ups including relevant call to action resources.

</details>

## 1-3 Weeks Out: Final Touches and Attendee Confirmations

<details markdown=1>

<summary><b>As we approach the event, we focus on last-minute preparations and ensuring a smooth execution.</b></summary>

- Verify attendance and manage any late registrations.
- Send calendar confirmations to registered attendees, including comprehensive key event details.
- Conduct a final walkthrough of the event venue or virtual platform.
- Collect finalized assets from presenters for their respective sessions.
- Ensure all event-related assets and swag have been received.
- Prepare an all-inclusive 'Know Before You Go' guide and distribute it accordingly.
- Conduct an all-encompassing event stakeholders' run-through

</details>

## 0 Weeks Out: The Event Unfolds

<details markdown=1>

<summary><b>On the event day(s), we execute flawlessly, ensuring every detail is attended to.</b></summary>

- Ensure seamless technical operations and troubleshoot any unforeseen issues.
- Confirm readiness of assets, presentations, and materials.
- Ensure seamless coordination among speakers and participants.
- Execute the planned event according to the established schedule.
- Monitor event progress, promptly resolving any unforeseen challenges.
- Collect valuable leads and notes from sessions, to better foster post-event engagement.
- Pack up and return any necessary assets

</details>

## 1 Week Post Event: Event Follow-Up Post-Event Analysis and Reflection

<details markdown=1>

<summary><b>Following the event, we analyze its performance, gather insights, and embark on improvement strategies.</b></summary>

- Analyze key event performance metrics, encompassing attendance, engagement, conversions, and participant feedback
- Conduct 360 Review with key stakeholders on the effectiveness of the event, lessons learned and to identify areas for improvement.
- Compile and prepare leads for upload to Marketo within 48 hours, , including detailed corresponding notes. Ensure all lead information is accurate and ready for upload
- Upload event leads
- Within 48 hours, ensure that a follow-up email is scheduled to be sent to attendees with relevant call-to-action resources."
- Wrap up and close campaign issue and archive relevant materials.

</details>

## 1-2 Weeks Post Event: Evolving for the Future

<details markdown=1>

<summary><b>With one event completed, it's time to reflect, plan, and optimize for the upcoming campaigns.</b></summary>

- Reflect on the successes and challenges of the planning process.
- Initiate discussions and brainstorming for the upcoming quarter's planning and strategy.
- Identify opportunities for enhancement and refinement in future endeavors.
- Begin planning for the next successful event, incorporating lessons learned

</details>

## Printfection Direct Mail Giveaways

<details markdown="1">

<summary>We will be deprecating usage of Printfection and will use Reachdesk or our selected swag vendor for direct mail. Expand below to see details regarding Printfection</summary>

The below steps can be followed to set up and run a giveaway campaign using Printfection for field marketing. If you come across any steps that you can't follow in Printfection, post in the [#swag Slack channel](https://app.slack.com/client/T02592416/C66R8N98F) so a Community Advocate can update your permissions levels.

1. Register and send the items you will be using to Printfection by following [these steps](/handbook/marketing/brand-and-product-marketing/brand/merchandise-handling/)
1. Bundle your items together by creating a [Giveaway Kit](https://help.printfection.com/hc/en-us/articles/360006335613-How-to-start-a-new-kit) in Printfection
    - The picture of the Giveaway Kit is what the customer will see. If you'd like a different image to show than what Printfection puts together as a preview, be sure to provide this to the support team
    - Select Standard packaging or choose to create a custom box (a new custom box will incur additional expenses). If you'd like to use already created custom packaging (such as the GitLab branded Poly Mailers), check with the advocates in the #swag slack channel to make sure it's okay for you to use
1. Set up a [Giveaway Campaign](/handbook/marketing/brand-and-product-marketing/brand/merchandise-handling/)
    - [Add the kit](https://help.printfection.com/hc/en-us/articles/360026589734-Using-kits-in-Giveaway-campaigns) you created as an item in the Giveaway Campaign
    - The name of the giveaway campaign will be visible to the customer
    - Change from Paused to Running when you're ready to run the campaign
1. Add a Printfection code column to your event spreadsheet with your leads. Copy over unique codes (generated above in the Printfection Giveaway Campaign) to assign a code to each lead
1. Work with your MPM to set up the Printfection URL & unique codes in your email copy (if desired, steps 5-7 are only relevant if sending a Marketo email rather than individually distributing the redemption links):
    - Place the Giveaway Campaign URL in your email copy (found on the Overview tab of the campaign in Printfection)
    - A custom Marketo field will be used to append the unique Printfection codes to the URL for each lead (example of how it works [here](https://gitlab.com/gitlab-com/marketing/field-marketing/-/issues/1195#note_325404319)) and to place the code under the URL
1. Complete list upload prior to the email send date (example list upload [here](https://gitlab.com/gitlab-com/marketing/marketing-operations/-/issues/2343))
1. Work with your MPM to determine post redemption email needs. The options are follow up email and an automated confirmation email. The confirmation email triggers upon redemption of codes, the follow up email is sent at one time to a group of recipients. If an automated confirmation email is needed, define what status in SFDC should trigger the follow up email
using the Direct Mail campaign status progressions. (for example, when a person's campaign status changes to `Queued` it could trigger a confirmation email and when the status changes to `Shipped` the SDRs will begin follow up sequence (example [here](https://gitlab.com/gitlab-com/marketing/field-marketing/-/issues/1195#follow-up-planned-from-field-marketing-fmc))
1. Once all above steps are complete, the Giveaway Campaign is ready to run. Make sure the Giveaway is changed from Paused to Running if you did not do this already in Step 3
1. When the campaign is running, monitor Redemptions, Shipping, and Costs under the Giveaway Campaign Overview in Printfection
    - Update redemptions/shipments in event spreadsheet if needed to notify SDRs (add additional columns to track)
    - Update SFDC status for leads once they redeem a code or item is shipped, depending on what was decided in Step 7
1. When a campaign is over and you no longer need the items in Printfection, follow [these steps](/handbook/marketing/brand-and-product-marketing/brand/merchandise-handling/) to remove items from Printfection. If inventory is not yet 0, you will need to ship the items back to yourself/desired recipient before archiving. Until this is done, $25/month will still be charged per item. If relevant, the MPM must be instructed as to when the Printfection codes are no longer needed on person records. This will signal that the MPM can now run a batch smart campaign to remove the Printfection codes from the person records, thus freeing up the custom field for use in the future.

**Fees Involved:**

- Cost of the items you are using in the giveaway
- Fulfillment and shipping fees for each order placed once the giveaway is running (there is a Cost Estimate under campaign settings but please note actuals have ended up higher than their estimate so far) These will be on a Printfection invoice, more details to come on the invoice process.
- $25/month per item stocked in Printfection. This will not hit your field marketing Allocadia ID, but is an overall cost to GitLab to consider and be mindful of (noted in Step 12 [here](/handbook/marketing/brand-and-product-marketing/brand/merchandise-handling/)

</details>

## Account-Centric Micro-Campaign

<details markdown="1">

<summary>Expand below to see details regarding Account-Centric Micro-Campaigns</summary>

The purpose of the regional integrated micro-campaign is to build and drive a specific strategy in a region (with a specific list of targeted accounts/look-a-like accounts). This could be based on intent data pulled from our ABM tool, DemandBase, or it could be based on accounts you've agreed to target with your SAE. A micro-campaign must include a minimum of 2 different account-centric tactics.

**For example:**

- If you are planning a virtual Lunch & Learn and want to utilize LinkedIn InMail as well, those 2 account-centric tactics together make up a micro-campaign. However, if you are planning a Lunch & Learn on its own without any additional tactics, that is just considered an [Individual Tactic](/handbook/marketing/field-marketing/#individual-tactics).

### What does Account-Centric mean?

At times, Field Marketing will run an account-centric approach to its in-region campaigns. Account-Centric is an approach where both sales and marketing are focusing their efforts on a very specific list of targeted accounts in order to increase engagement and ultimately pipeline creation within this list of accounts. The SAE/FMM/SDR are responsible for outlining which accounts are account-centric and accounts can easily pop in and out of being in the account-centric play based on the strategy that's being executed.
i.e. If a FMM is targeting to get 15 people into an interactive roundtable discussion, that will greatly impact the number of accounts that are targeted for that specific tactic vs if they were trying to 100+ people into that same discussion.

### How to track the ROI of your Account-Centric approach

In order to track engagement, you need to start with a baseline and over time, track the progress on how engaged that account is with us. Right now this is a manual process where this [SFDC report](https://gitlab.my.salesforce.com/00O4M000004e4Ll) should be modified by pulling in all the accounts that are in the account-centric GTM Strategy per rep and then you must take a snap shot in time (SFDC does not allow for historical data pulls) by exporting the data and saving to a gsheet. [Example of gsheet](https://docs.google.com/spreadsheets/d/1m7xxoKcXW3Lq8eXIPg5KIOMGXIItp7MEZeBXAFfszOI/edit#gid=206509375&range=A1). Depending on your campaign, you can export this data on a weekly or monthly cadence to monitor progress.

In order to change the GTM Strategy field for accounts in SFDC from `Volume` to `Account-Centric`, you can employ two options: a) Change the GTM Strategy field for each account manually if you have <20 accounts in the campaign, or b) Create a MOps request to have all accounts changed from `Volume` to `Account-Centric` in bulk. To request the bulk adjustment, please utilize [this MOps template](https://gitlab.com/gitlab-com/marketing/marketing-operations/-/issues/new?issuable_template=abm_bulk_update_request).

Account-Centric is different from Account Based Marketing in the sense that ABM focuses on accounts as markets of one versus account-centric targeting a group of accounts. At GitLab we run a 3-Tiered approach to ABM focused around our ICP and target 100-150 accounts in our ABM strategy at any given time. For complete details on how GitLab runs its Account Based Marketing, please head to the [GitLab ABM page](/handbook/marketing/account-based-marketing/).

At GitLab, we utilize Bizible for attribution tracking. In order to track the touchpoints of your campaign, modify [this linear IACV SFDC report](https://gitlab.my.salesforce.com/00O4M000004aDSN) . This report shows Opportunity: Incremental ACV and Linear iACV.

- If your campaign has a SFDC campaign with leads associated to it, then you will pull in the SFDC Field `Salesforce Campaign` equals .
- If your campaign does NOT have a SFDC Campaign with leads associated OR you also are wanting to track the opportunities from your digital spend, then you would add in the SFDC `Ad Campaign Name` equals . We use the same UTM per channel, so all channels (paid ads, LinkedIn Mail, DemandBase, etc.) will pull all influenced iacv. Stay tuned for more details on Bizible.

### Account-Centric Micro-Campaign Team

- Field Marketing Manager - overarching DRI responsible for opening [the micro-campaign issue](https://gitlab.com/gitlab-com/marketing/field-marketing/-/issues/new?issuable_template=Micro_Campaign_and_Individual_Tactics), reviewing the intent data from the ABM DRI, and building the strategy based on what the intent data is suggesting (i.e. are a lot of folks searching to Kubernetes? Is it digital transformation? What call to action do we have? Do you want a direct mail piece involved? Do you want to drive to an On-Demand or scheduled webcast?), owning, and driving the mico-campaign, including epic and issue creation and communicating timelines and actions needed of other team members with relevant SLAs from request to delivery.
- Account Based Marketing (ABM) Manager - will work with FMM to produce target account list based on intent data and known targets & will also lead strategy session with Demandbase Campaign Manager, should the FMM decided its part of the strategy to deploy ads via Demandbase.
- Sales Development Rep (SDR) - Will assist in building out the actual target people & build Outreach cadence to support agreed upon CTA.
- Digital Marketing Programs - Can assist in deploying paid digital strategies (ex: display ads, paid search, paid social, and/or paid publisher placement) and geo focused ads via our digital agency. They can also help get our digital agency involved should the FMM want to engage with the agency.
- Marketing Program Managers - Setup of Marketo and Salesforce campaigns with correct program type to support the tactic. Guidance on system tracking, and setup of Marketo email follow up. Facilitate new program types with MOps and other MPMs as necessary.

### Steps for the Creation and Organization of Micro-Campaign Epics & Issues

#### 1. FMM opens overarching issue

<i>FMM opens a field marketing issue using the [Micro-Campaign and Individual Tactics Template](https://gitlab.com/gitlab-com/marketing/field-marketing/-/issues/new?issuable_template=Micro_Campaign_and_Individual_Tactics)</i>, listing the tactics to be used from the list below in step 2. At this point, the issue is in `PLAN` stage.

**WHY? The purpose of opening the overarching micro-campaign issue is to discuss the plan with any teams that would require work and gain agreement on SLAs before opening epics and issues.** *Remember - as of today, epics cannot be made confidential, they cannot show up on issue boards, and there is no such thing as an epic template.*

**Here is what needs to be included before moving from `PLAN` to `WIP`:**

- Agreement on SLAs and scope between other teams involved in selected tactics - [SLA workback doc](https://docs.google.com/spreadsheets/d/1YXriQ1clvYyBn-TDbbCVvNP6NEbrAF-0w6tIHKhDeZM/edit#gid=1983708280)
- Formulation of a clear strategy and understanding of customer journey
- Completion of all fields in the `Details` section of the micro-campaign template

*For anything that's listed in the `Tactics included` section of the template the FMM needs to be clear about their specific ask & what the desired outcome will be. If the FMM does not know, it's ok to set up a call to talk through ideas and strategies.*

#### 2. FMM opens specific tactic issues

*FMM opens additional issues relevant to their micro-campaign, if required.*

**WHY? The purpose of opening the issue is so that each individual tactic shows up on the FMM boards.** *Remember - as of today, Epics cannot be made confidential, they cannot show up on issue boards, and there is no such thing as an epic template.*

**Issue Templates for Each Tactic:**
Please see the Field Marketing Issue Templates and Epic Codes list [**HERE**](/handbook/marketing/field-marketing/#field-marketing-campaign-issue-templates-epic-codes-and-progression-status) for a comprehensive list of templates to be utilized for each tactic.

#### 3. FMM creates tactic epics

*FMM follows the instructions for epic creation based on the tactics decided.*

**WHY? The purpose of opening the epics and issues is to organize the campaign in GitLab with the epic being equivalent to the project/campaign and issues being equivalent to the tactical execution steps to complete the campaign.**

**How to create the epic:**

- Where to create the epic: [Marketing Epic Repo](https://gitlab.com/groups/gitlab-com/marketing/-/epics?sort=created_desc)
- How to create the epic: Click "New Epic" at the top right of the screen
- What to name the epic: The naming convention is listed in the epic code for each specific tactic.
- What to choose as the due date: this should be the same as your micro-campaign issue due date. For example - If your micro-campaign involves 3 different tactics and the last tactic is set to close out on December 5, 2020, that should be your due date.
- How to link the epic to the issue: In your epic click on Epics + Issues - Add - Add an existing issue - Link your issue

**Micro-Campaign Epic Code**
This epic will include the general details of your micro-campaign.

```markdown
<--- Name this epic using the following format, then delete this line: [Micro-Campaign Tactic Name] - [3-letter Month] [Date], [Year] --->

## [Micro-Campaign Issue >>]()

## :notepad_spiral: Details
(copy and pasted from your micro-campaign issue)

/label ~"mktg-status::wip" ~"Field Marketing" ~"FMM-MicroCampaign" ~"FMM-Other Tactics"
```

**Epic Codes for Each Tactic:**
Please see the Field Marketing Issue Templates and Epic Codes list [**HERE**](/handbook/marketing/field-marketing/#field-marketing-campaign-issue-templates-epic-codes-and-progression-status) for a comprehensive list of epic codes to be utilized for each tactic.

#### 4. FMM creates relevant issues and assigns DRIs and due dates

*At this point the FMM has the main issue (for agreement by teams), the tactic issue(s) (to show up on boards), and the tactic epics (to capture overarching tactic plan and organize issues). Now FMMs will create the issues to request the work and timeline of teams involved in each tactic.*

In each epic code (from step 3), there are issue template links included that indicate what issues need to be created (example - follow up email, facilitate tracking, etc.) - if they do not say "optional" then they are required. The FMM will create each issue and link to the epic so that all tactical issues are organized together clearly in GitLab.

The FMM will designate DRI as indicated and set due dates based on SLAs for each item that is being requested. [SLA workback sheet](https://docs.google.com/spreadsheets/d/1YXriQ1clvYyBn-TDbbCVvNP6NEbrAF-0w6tIHKhDeZM/edit#gid=1983708280) is available to help you.

**Note: This is essentially creating the work-back execution plan using issues, DRIs, and due dates.**
If the date of the tactic is changed, the FMM is responsible for updating the due dates of all issues accordingly. It is also important to remember that the DRIs on the issues are not notified when due dates are added. If you create an issue and then add due dates at a later time (or change due dates), please remember to ping the DRIs in the issue so they are aware dates have been added or changed.

#### 5. Organizing Epics

Your micro-campaign issue and epic is an overview of your micro-campaign strategy and each individual tactic supporting the micro-campaign requires its own issue and epic. When you add individual tactic epics to the micro-campaign epic, the micro-campaign epic automatically becomes the [Parent Epic](https://docs.gitlab.com/ee/user/group/epics/#relationships-between-epics-and-issues). Each individual tactic epic, when nested under the micro-campaign epic, automatically becomes the [Child Epic](https://docs.gitlab.com/ee/user/group/epics/#relationships-between-epics-and-issues). Whichever epic you nest the other epics under will automatically become the Parent Epic, so remember to always add your individual tactic epics to the micro-campaign epic and not the other way around.

For example - You have created a micro-campaign that will include a self-service event with promotion, a survey, LinkedIn InMail, and DemandBase targeted ads.

- You will create an epic for your micro-campaign per the [above instructions](/handbook/marketing/field-marketing/#3-fmm-creates-tactic-epics).
- Your self-service event with promotion will require a separate issue with its own epic.
- Your survey will also require a separate issue with its own epic.
- Your LinkedIn InMail will require its own issue (the only DMP tactic that currently requires an epic is Content Syndication).
- Your DemandBase ads will require its own issue (ABM tactics do not currently require epics).

**To organize your various tactic epics under your micro-campaign epic:**

- Click into your micro-campaign epic
- Scroll down to Epics & Issues
- Click Add an Epic
- Paste the epics from your other tactics into this section and GitLab will automatically organize the tactic epics under your micro-campaign epic

### Micro-Campaign Training Video

[Video training on how to set up a Micro-Campaign](https://drive.google.com/drive/folders/1nTQOO5jszlwIivy_bCjqA0a6RXnKwQtt). This video walks you though how to set up a Self Service webcast with promotion and LinkedIn InMail. Two tactics = Micro Campaign.

### Example Micro-Campaign for Training

- [Micro-Campaign Epic](https://gitlab.com/groups/gitlab-com/marketing/-/epics/1072)
  - [Micro-Campaign FM Issue](https://gitlab.com/gitlab-com/marketing/field-marketing/-/issues/1396)
    - [Self-Service Virtual Event with promotion Epic](https://gitlab.com/groups/gitlab-com/marketing/-/epics/1073)
      - [Self-Service Virtual Event with Promotion FM Issue](https://gitlab.com/gitlab-com/marketing/field-marketing/-/issues/1397)
      - [Follow Up Issue](https://gitlab.com/gitlab-com/marketing/digital-marketing-programs/-/issues/2959)
      - [Invites and Reminders Issue](https://gitlab.com/gitlab-com/marketing/digital-marketing-programs/-/issues/2958)
      - [List Clean and Upload Issue](https://gitlab.com/gitlab-com/marketing/marketing-operations/-/issues/2712)
      - [Facilitate Tracking Issue](https://gitlab.com/gitlab-com/marketing/digital-marketing-programs/-/issues/2957)
    - [Paid Survey Epic](https://gitlab.com/groups/gitlab-com/marketing/-/epics/1074) (No separate FM issue since information is in overall Micro-Campaign Issue)
      - [Gated Content Request Issue](https://gitlab.com/gitlab-com/marketing/digital-marketing-programs/-/issues/2965)
      - [Follow Up Issue](https://gitlab.com/gitlab-com/marketing/digital-marketing-programs/-/issues/2962)
      - [Facilitate Tracking Issue](https://gitlab.com/gitlab-com/marketing/digital-marketing-programs/-/issues/2961)
    - [LinkedIn Inmail Issue](https://gitlab.com/gitlab-com/marketing/account-based-marketing/-/issues/136) (No epic required)
    - [DemandBase Targeted Ads Issue](https://gitlab.com/gitlab-com/marketing/account-based-marketing/-/issues/136) (No epic required)

### FAQ's - Micro Campaigns and Other Tactics

1. If I am only running 1 tactic, do I need to create the micro campaign issue? Answer: No, you do not. A microcampaign includes at least [2 account centric tactics](/handbook/marketing/field-marketing/#account-centric-micro-campaign).
1. If I want to run ads through our ABM vendor do I need to create a micro campaign issue? Answer: No, you do not. A microcampaign includes at least [2 account centric tactics](/handbook/marketing/field-marketing/#account-centric-micro-campaign). Ads with our ABM vendor is only 1 tactic.

### Reminders - Micro Campaigns and Other Tactics

1. **Labels** - be aware of your labels. Please be mindful that you're adding the correct labels.
1. Epic label issue - There is a glitch right now which may keep the labels from auto-assigning. In order to have the labels added to your epic, you'll need to copy the /label line from the epic code into a comment to pull over all labels. [Quick video how-to](https://drive.google.com/open?id=1gK8G4CBaqcgWgB6b2A1BRSQCma5GfJyt). 2 mins
1. If you create an epic & sub issues and DO NOT have a date, then when you go back and add dates then you MUST ping the assigners - could be FMC, MPM, OPS, etc.
1. When you go from plan to WIP that's when everything starts - from the SLA workback as well.
1. The details section is so important - what that tells the MPM/FMC how this program should flow. You can't move your issue to the WIP stage until the details are added - This is where if attention to detail isn't your BFF, you need to make it your BFF. ;)

</details>

### SimplyDirect

<details markdown="1">

<summary>Expand below to see details regarding SimplyDirect</summary>

#### Overview

SimplyDirect is a third party company that helps companies identify buyers and early adopters using the latest in big data tools and high-response surveys. The program from SimplyDirect includes surveying (through GatePoint Research), responder intelligence, and custom content creation in the shape of a Pulse Report highlighting the overall findings from survey responses.  These custom built surveys are developed via collaboration with GitLab sellers, Product Marketing, and Sales Development Reps, where the aim is to target accounts to create actionable sales intelligence which reveals an account's needs, pain, plans and trends. In addition, GatePoint Research provides an incentive of a free gift upon completing the survey.

Our strategy is to leverage the data from the survey responses as well as the Pulse Report provided to set meetings and create sales-accepted opportunities. The data gathered from the surveys will also help the Digital Marketing Team and Campaign Managers by providing insight into the respondents current state of DevOps use and strategy as well as pain points and challenges.

#### Regions that Utilize Simply Direct

At this time, SimplyDirect is only used by our AMER Field Marketing team.

#### Successful Usage

Strategic success is contingent upon close alignment and communication between Marketing and Sales. Marketing will work collaboratively with Sales, Product Marketing and Campaign Managers to develop the survey. Best practice for the survey is 10 questions max. SDR's will create a follow-up Outreach sequence to leverage when reaching out to those who've completed the survey.

Once the survey is complete, SDR's will leverage the individual results and work with their SAE to:

- Identify points of interest in the survey pertaining to each individual response (i.e. pain points, number of tools, etc)
- Create a strategy based on matching those issues with GitLab offerings
- Customize their outreach communications to initiate conversations towards setting a IQM

#### Personas

Our focus will be geared towards key-decision makers or fellow team members who can help push to key decision makers. This opens up our outreach to anyone in DevOps, DevSecOps, IT and other related fields with titles ranging from Developer Team Lead to Executives.

Examples of personas/titles include: Director/VP of Engineering, Director / VP of Machine Learning (or AI), Director/VP of Enterprise Architecture, Director/VP of Product Development/Engineering, VP of Digital Transformation, Director of Applications, Director of Security (Information Security, IT Security, Application Security), VP of Operations.

#### Phases for SimplyDirect

- **Phase 1:** Sales and Marketing create the survey and share the target accounts and personas with SimplyDirect. Upon completion, SimplyDirect sends out the survey and shares survey results with the GitLab team via the SimplyDirect portal. The account list shared with SimplyDirect has an SDR assigned to each account so the tool will send the assigned SDR an email notifying them when a survey is completed. FMM will share the portal website, username, and password in the issue for SDRs or SAEs to access survey results and analytics. FMM will also provide SDRs with training before launch on how to navigate the portal and share SimplyDirect's best practices. This phase is considered complete once the predetermined number of survey responses is achieved (number of responses will be identified in the SOW). Please note that a gift is sent to survey respondents by SimplyDirect as a thank you for completing the survey (Example: Columbia Jacket/Fleece). SimplyDirect also creates a detailed Pulse Report with survey results when the phase is completed and provides it to GitLab along with a list of high-intent targets who did not complete the survey (see Phase 3 details on how to utilize these additional targets). Access to the portal is not indefinite so a report should be pulled from the SimplyDirect portal in order to add survey responses to our own tracking sheet if needed.
- **Phase 2:** Leads are uploaded to SFDC automatically through our SimplyDirect<>Marketo integration and SDRs can set up an Outreach sequence to follow-up with these leads by sharing the Pulse Report. There is also an option of a swag giveaway at this phase if a meeting is booked/attended.
- **Phase 3:** SimplyDirect gathers a list of additional high-intent targets (also contracted in the SOW) that have not opted in to be contacted by GitLab directly. In order to try to capture these additional leads, we can create a Pathfactory track that requires visitors to enter in their contact information to view the track (which includes the Pulse Report and other assets). SimplyDirect includes this Pathfactory link in their follow-up email to the additional contacts. Anyone who enters their contact information in Pathfactory can be sent a follow-up by GitLab.

#### Reporting and Dashboards

SimplyDirect defines engagement by targets filling out the survey.  The SimplyDirect<>Marketo integration adds anyone who fills out the survey automatically into the Salesforce campaign.

#### ROI & Metrics

- Total number of meetings
- Total number of SAOs
- Pipeline progression

## Working with our Digital team

- For [paid social campaigns](/handbook/marketing/integrated-marketing/digital-strategy/digital-strategy-management/#paid-social), details on how we collaborate with the Digital team can be [found here](/handbook/marketing/integrated-marketing/digital-strategy/digital-strategy-management/#agency).
- We are not running ads for webcasts or workshops - as that is handled by our campaigns team.
- We will run paid ads to drive registration to regional in person events.

## Helpful Links

- [**Survey Details**](/handbook/marketing/field-marketing/#survey)
- [**Simply Direct Marketo & SFDC Instructions**](/handbook/marketing/marketing-operations/campaigns-and-programs/#steps-to-setup-surveys-in-marketo-and-sfdc)
- [**Pathfactory Request**](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=request-pathfactory-track)

</details>
