---
title: Growth Direction
canonical_path: "/handbook/marketing/growth/"
---

## Growth Section Overview

The GitLab Growth section is dedicated to making it easier for teams to find value and increased efficiency within the GitLab platform. We work across stages within the product experience to make the product as easy as possible to adopt and use.

 The Growth section lives within Marketing & Strategy to ensure we're aligned in our go-to-market strategy and we're as efficient as possible in finding the right prospects, convincing them to become product users, and assisting in converting them into paying customers. Since the work within the section occurs within the product experience our engineering and user experience counterparts are within the [Development division](/handbook/engineering/development/). This approach ensures that we have proper alignment on our priorities from a go-to-market and business perspective while ensuring our [development team](/handbook/engineering/development/growth/) is set up for success to operate within the development division.

## Growth Section's Principles

The Growth team works cross functionally within the organization to increase user and business value. We ground ourselves in four core principles.

1. Partner with stakeholders in Marketing, Sales, and Product to establish metrics informed by quantitative and qualitative data that meet the business needs while supporting our users
2. Empower teams to find value efficiency in the GitLab platform
3. Enable teams to quickly and intuitively adopt multiple stages with multiple users
4. Empower teams to find enterprise value within features that live in our Ultimate offering

## Core metrics, findings & experimentation results

### Metrics

* Acquisition - Valuable signup
  * Internal team members can view this metric [here](https://internal.gitlab.com/handbook/marketing/growth/growth/#valuable-signup-metric)
* Activation - Team activation
  * Internal team memmbers can view this metric [here](https://internal.gitlab.com/handbook/marketing/growth/growth/#team-activation-metric)

### Findings and experimentation results

Our core findings and experiment results are considered non-public information. Internal team members can reference the internal handbook growth page for a detailed review of our findings.

## Vision

Our vision is to make it seamless for teams to find, adopt, and discover value along with increased efficiency in the GitLab platform.

This includes

* Aligning internally with signups we want to prioritize as a business
* Ensuring the signup experience is balanced by collecting the information required for the business while collecting the needed user information (JTBD) to provide a tailored product experience
* Assisting users in finding product value (ah-ha moments) as quickly as possible including increasing access to enterprise value
* Assisting users in their product adoption experience that aligned with their defined JTBD
* Providing users with the purchase experiences that align with their business
  * For SMBs this means uncovering the value in the paid tiers through in-product experiences including trials married with related marketing and sales content related to their usage
  * For larger businesses, this encompasses empowering namespaces owners to understand what features their teams are using and which paid features they are requesting access to. While also providing them with the ability to connect directly with their dedicated point of contact within sales. This could include in-app messaging, and the ability to book time on their point of contact calendar directly within the app.

## Groups

The growth division is currently grouped under the Acquisition team that contains a shared growth backlog while we actively hire additional team members to build out a activation team.

### Acquisition

* Team description, dedicated handbook page and specific vision is a work in progress.

### Activation

* Team description, dedicated handbook page and specific vision is a work in progress.

## Product ownership

The Growth section owns the following areas of the product experience.

* The [free user](https://gitlab.com/users/sign_up/) and [trial registration](https://about.gitlab.com/free-trial/) experience
* The new user [onboarding experience](/handbook/product/groups/growth/#contributing-to-the-learn-gitlab-project)
* [GitLab Experiment Gem (also refered to as GLEX)](https://docs.gitlab.com/ee/development/experiment_guide/)
* [Instance review](https://docs.gitlab.com/ee/administration/instance_review.html)
* [Product Qualified Leads](https://docs.gitlab.com/ee/development/product_qualified_lead_guide/)

 While we own these areas our work is not limited to these specific areas as the teams work cross-functionaly with other product and business teams to improve the user experience the most efficient way possible.

## Engineering

[Growth engineering](/handbook/engineering/development/growth/) handbook pages.

## Growth Coffee & Learn Sessions

Growth requires constant learning, and many compaines face similar challenges or go through similar journeys. At GitLab, we believe hearing from growth experts and practitioners with diverse background is the best way to learn, and we want to share that with the community as much as possible. Therefore, we started a growth Coffee & Learn series since 2020. Below is a list of exerperts we invited to share their wisdom with us. We appreciate their time and insights, note that some videos/notes are viewable by internal team only.

|Expert |Background |Topic | Video |Notes|
| ---------     | ------ |----------------- |------ |------ |
|[Chris More](https://www.linkedin.com/in/chrismore/) |VP Growth @ Fusebit & Former Head of Growt@ Mozilla  | AMA on Open source & growth |NA|[AMA Notes](https://docs.google.com/document/d/1qhLH8D8vwRGe_PTOhhJwjuWsqPLF4pF1uuS5bK_t1E4/edit?usp=sharing) |
|[Holly Chen](https://www.linkedin.com/in/holly/)|Growth advisor, former head of global marketing @ Slack  |Growth Loop & Journey of Slack |[Video](https://www.youtube.com/watch?v=CFwKMUJv1Xo&list=PL05JrBw4t0Kr_-AowJmbhGk9yj_zIZySf) |[Summary](https://docs.google.com/document/d/12LK9MqPl-PbabJkGwhxS2Uv-gjlOHNZOAX5DUqgvXq8/edit) |
|[Linsha Chen](https://www.linkedin.com/in/linshachen/)|Head of Growth Data Science, Airbnb|How Airbnb does experimentation |[Video](https://youtu.be/RaS62OLHDVY) |[AMA Notes](https://docs.google.com/document/d/1-EV8PfMPqAEj344sqY2OkFbeg4JC204jFmK_7it9N44/edit) |
|[Jike Chong](https://www.linkedin.com/in/jikechong/)|Author, How to Lead in Data Science, former data science executive @ LinkedIn, Acorns|How to Lead in Data Science |[Video](https://youtu.be/4kI8ICt8ylk) |[AMA Notes](https://docs.google.com/document/d/1t7PjAGjEqMQn0bFPUYEKJrwH6sb85VxKi5rd0kuzKUA/edit?usp=sharing) |
|[Anuj Adhiya](https://www.linkedin.com/in/anujadhiya/)|Author, Growthhacking for Dummies, VP Growth|High Performing Growth Teams|[Video](https://youtu.be/a3VIrCSq_k8) |[AMA Notes](https://docs.google.com/document/d/1cu_NZ_kAv72uT6ffHbUSm71h1QTQDYpoFT40lAETerM/edit?usp=sharing) |
|[Robert Neal](https://www.linkedin.com/in/robert-neal-1bb9ba144/)|Director of experimentation @ LaunchDarkly|Experimentation system AMA|[Video](https://youtu.be/eV7hjA74_gQ) |[AMA Notes](https://docs.google.com/document/d/1kjWvFeVmpvsRIPuEtfTBNpiINUMlE10MLB4kkQIQ9yE/edit?usp=sharing) |
|[Carl Gold](https://www.linkedin.com/in/carlgold/)|Former Chief Data Scientist, Zuora| Fighting Churn with data|[Video](https://youtu.be/Ntbrp0Crbtk) |[AMA Notes](https://docs.google.com/document/d/1k2oMsxO6bI6dnFIpvsz8YJp5cQEcrnsFj3pGpIEJxEA/edit?usp=sharing) |

## Growth Definitions

* *Sign-up Experience:* Registering to be a user of GitLab. It generally starts on `about.gitlab.com` and ends when the user is registered and can log in to the application. We have free, trial and direct to paid sign-up options.
* *Registration Flow:* The "happy path" flow a new user goes through when registering for GitLab and landing in the app for the first time. This is a more confined user flow, as we narrow down options so they can experience GitLab without being overwhelmed by all the other features. It starts at `about.gitlab.com` and ideally ends with them using Create features.
* *Trial Experience:* The experience of selecting and starting a trial, as well as testing/trialing features in GitLab.com or a self-managed instance during the trial. This could be done by net new users of GitLab, or existing users of GitLab who are interesting in exploring paid features.
* *User Onboarding:* A general term that refers to experiences we create to support users during their first 90 days, or any time they engage with a new stage.
  * *Continuous onboarding:* Specifically our onboarding experience that allows users to choose when and if they want to continue onboarding tasks. It starts with simple tasks and builds to more complex ones.
  * *Onboarding Emails:* Refers to emails that are sent to Saas and self-managed users intended to drive stage adoption via the email service the instance sets up.
* *SaaS Purchase Flow* - We consider the SaaS purchase flow (or "funnel") to begin with the first screen of the checkout experience (the first page that displays the total cost of their GitLab subscription) and continues through the payment sequence with the last step of the flow being the successful first-time purchase of a GitLab paid tier. A potential customer can enter this experience directly within the SaaS app from the /billings page or on `about.gitlab.com/pricing`.

## Growth Shared Calendar

We use Growth PTO shared calendar to ensure all time off events are visible to everyone on the Growth team. To enable syncing your PTO from Time Off by Deel with this calendar follow these instructions:

1. In Slack open app *Time Off by Deel*
1. Ensure you are on *Home* tab and select *Calendar Sync* from the dropdown menu
1. Under the section *Additional calendars to include?* click *Add calendar*
1. Copy & paste this calendar ID: `c_5e5a9e4df8718fb25c518f165ca78fbccd42a7b6e1437a3caa6650e8e8dffbea@group.calendar.google.com`

Congratulations! :tada: From now on all your PTO events will be automatically synced to our shared calendar!

### Helpful Links

* [Engineering Growth Section](/handbook/engineering/development/growth/)
* [Growth Product Handbook](/handbook/product/groups/growth/)
