---
title: "GitLab SEO strategy"
description: "The Search Marketing team is repsonsible for the creation and execution of GitLab's SEO strategy."
---

GitLab's go-to-market success depends on people organically discovering our product and company. The two primary ways we achieve organic discovery are with our brand and search engine optimization (SEO). Our SEO strategy will take advantage of our existing strengths and improve critical areas to ensure our ideal visitors find GitLab through search engines.

Our goal is to gather relevant visitors from organic search with authoritative pages and engage them with next step content.

## Why SEO?

We live in a world where search is a natural motion. If you want to know when your favorite lunch spot opens, you Google it. When you're stuck on a problem at work, you look for the answer with Google. Trusted domains build brand authority over time and become a preferred destination for their target audience. Stack Overflow answers developer questions and GitHub for specific projects are two great examples of authoritative sites for developers.

It's our job to help GitLab become an authority on DevOps and the software development lifecycle.

Optimizing our site to answer questions about our product and market gives us a path to serendipitously meet the needs of our customers, prospects, and potential customers. We will tailor the content of pages to match the different stages of the buyer's journey.

## Optimization segments

There are three optimization segments for search at GitLab.

As of November 2020, you can rank our performance in these areas in that order. Branded search is a strong driver of visitors to our public sub-domains, and unbranded search is improving to join branded search as a source of significant traffic.

1. Branded search
1. Unbranded search
1. Product search

Branded search is typically the second optimization segment to send significant traffic, but in GitLab's case this is where we gain the bulk of our traffic. `GitLab CI` or `GitLab pricing` are a couple of examples of branded search terms where we win traffic in 2020.

## Challenges we face

about.gitlab.com is a user-generated content site managed by the GitLab team without the traditional controls UGC sites typically employ. We're working to address this by adding a CMS and other methods of control, and we'll need to continue to innovate to deliver search optimization as we scale.

## Visitor strategy

Blog visitors don't convert at the same rate as product page visitors

We will help the blog attract visitors and help those visitors discover product pages.

The Search Marketing team will focus our support on pages with the most valuable marketing motions and focus most of our on-page optimization efforts product pages.

## What we prioritize

Our goals are to **develop keyword targeting** that supports revenue growth, **implement technical improvements**, and to **create a culture of SEO** across our organization so everyone can contribute to search optimization.

We will focus on researching keyword targeting for content clusters, keyword groups of related terms that link to a pillar page.

We'll also improve technical SEO on all GitLab websites, starting with about.gitlab.com expanding outward to docs and our SaaS application.

As a small team, we cannot build or maintain every aspect of optimization. GitLab values everyone's contributions, so we will strive to create a culture of SEO to help everyone at GitLab contribute to our success by optimizing our website and SaaS application.

## What we won't prioritize

**We won't build links with large scale outreach.** Our link profile is robust and healthy thanks to our product on gitlab.com, and we don't need to spend our existing resources to grow links. We'll work to continue growing organic link growth with our Corporate Marketing focus on influencer strategy, but the Growth Marketing team won't spend any time on large-scale link building.

**We won't use underhanded tactics to win traffic.** GitLab will avoid grayhat or blackhat SEO techniques designed to trick search engines into sending us visitors. We won't hide content from visitors on page, spam keywords, or other tactics to prioritize short-term growth.

## Measuring success

**Keyword clusters**
Our goal is to move our target keywords to the top 3 positions as often as possible. We'll need proper keyword targeting, on-page optimization, and technical optimization across our sites to achieve this goal. We will measure keyword position over time, and our measure of keyword success will focus on the visibility of our keywords by content cluster.

For example, we want to increase the visibility of our CI keywords in [SEMRush](https://www.semrush.com/), a tool for tracking our SEO progress.

**Technical SEO**
We want to move the site health for marketing pages on about.gitlab.com above 90%. This excludes the handbook and jobs pages. We will measure our site health with the site audit score from SEMRush.

**Creating a culture of SEO**
We'll measure the success of our SEO culture by looking at the site health for the handbook and jobs pages on about.gitlab.com and the overall site health of our SaaS application.

We can use SEMRush site audit tool to measure handbook and jobs pages. We'll need to consider how to measure success in the application.

## Keyword clusters

### Goal

Our goal is to expand GitLab's presence in search results used by our target audiences.  

We are building keyword families that mirror the focus of Marketing at GitLab. We want to identify terms related to CI, SCM, and DevSecOps to help the content team build pages to raise awareness of our product-related use cases.

Our keyword families help us create content clusters to compete for top-level terms and grow visitors through a collection of lower volume keywords. Lower volume keywords function as cluster pages, often with similar terms, and these pages link to a pillar page with our primary keyword for each family.

Pillars are set by researching the current competitive marketplace and finding common patterns in how other companies talk about specific development practices.

Once we've determined the pillars, we do keyword research to find related terms and combine those related terms with common search modifiers that identify intent.

## Technical SEO improvements

### Goal

Our goal is to make sure our sites are built to surface the right information to search engines.  

Search engines do their best to deliver the right information to their users. To do this, they rely on sites using infrastructure and organization that meets their standards.

GitLab will give search engines relevant signals to help them understand when our product or website can help fulfill their needs. This means making it clear our URLs are authoritative, we avoid duplicate content, on-page factors match visitor intent, and all relevant resources are available to search crawlers.

We use site health tools and web analytics to understand how search engines and visitors navigate our site.

The Search Marketing team is responsible for the execution of technical SEO for marketing pages on about.gitlab.com and help identify and coach responsible teams for SEO execution in the handbook, docs site, and product.

## Creating a culture of SEO

### Goal

The Search Marketing team will create a culture of SEO to grow best practices with teams across GitLab to help manage SEO for the handbook, docs site, and product.  

At GitLab, we believe that everyone can contribute. This leads the Search Marketing team to focus on teaching what we know so that every aspect of GitLab's business can reach its full organic search potential.

For our initial focus, the Search Marketing team will create videos to share best practices for on-page content and long-term care of URLs, including managing internal redirects.

## How our SEO strategy impacts content strategy

We want to build content clusters that match the intent of our target visitors with relevant content with a depth designed to engage people as they land on a page.

Our pages should minimize keyword overlap in page titles and headings, and avoid keyword stuffing.

No pages should have duplicate titles, descriptions, or on-page content.

## The next level of GitLab organic growth

Focusing on these strategic goals will help GitLab reach a new level of recognition and authority. Achieving these goals will establish GitLab's place in the software community, and help us accelerate awareness of our solutions in the DevOps community.
