---
title: Lifecycle Marketing
description: Lifecycle Marketing Handbook
twitter_image: /images/tweets/handbook-marketing.png
twitter_site: '@gitlab'
twitter_creator: '@gitlab'
---

## Lifecycle Marketing

## Overview
<!-- DO NOT CHANGE THIS ANCHOR -->

[Lifecycle Marketing](/job-families/marketing/marketing-campaign-manager/#user-lifecycle-marketing) is responsible for strategizing, executing, and optimizing a data-driven user lifecycle communications strategy and overall email marketing plan, including ongoing nurture email campaigns.

This role works closely across Marketing for all things email, and directly with the Product Growth, Data, and Self-service Teams to collaborate, plan, and prioritize communication to better engage GitLab users and progress them through the buyer and customer lifecycle. The lifecycle marketing manager will focus on user paths to revenue, including engaging free .com users, trial users, and paid users of GitLab.

[Read the job family here >>](/job-families/marketing/marketing-campaign-manager/#user-lifecycle-marketing)

For more information on email marketing at GitLab, please visit the following pages:

* [Nurture programs](/handbook/marketing/lifecycle-marketing/emails-nurture/)
* [Best practices](/handbook/marketing/lifecycle-marketing/email-best-practices/),
* [Email processes and requests](/handbook/marketing/lifecycle-marketing/email-processes-requests/)

Please reach out to Allie Klatzkin or Alison Lee with any questions.

### Meet the Team
<!-- DO NOT CHANGE THIS ANCHOR -->

**Allie Klatzkin** _Manager and Team Lead, Lifecycle Marketing_

* **Buyer / User Persona Nurture**: DRI for organization of new content additions to the intelligent nurture, build of new streams within the nurture architecture in collaboration with marketing operations
* **Action Streams**: Develop and build lifecycle's strategy for interest based action streams
* **GitLab Ultimate + Duo Enterprise Trial User Campaigns**: DRI for trial nurture, focused on progressing trial users to paid
* **Calendaring and stakeholder conversations (DRI)**: Lead weekly email calendar conversations to ensure we are prioritizing our email sends per audience
* **Email Templates**: define needs, organize design, and manage development and testing of new email templates
* **Email Best Practices, Processes & Optimization**: enable teams across GitLab (mainly Marketing and Sales Dev) on email best practices, as well as streamlining, scaling, and improving email performance
* **GitLab Corporate Events**: Global templates and scaling process for promoting and following up from corporate events and conferences.
* **Email point of contact/support**: Reviewing and optimizing AMER & Global events (fmm & corp), campaigns, and newsletter email sends to ensure best practices and compliance with the GitLab brand
* **Localization**: Owning the translation and localization strategy for email, building new nurtures for prospects
* **PubSec Nurture**: Rebuild the nurture to educate leads on the value of GitLab for the Public Sector and ultimately generate MQLs

**Alison Lee** _Senior Customer Lifecycle Marketing Manager_

* Customer upsell / cross sell / retention
* Create and continuously optimize email marketing programs that leverage 3rd party signals (e.g. firmographic or demographic) as well as customer behavior data to drive revenue growth or prevent churn
* Partner with Customer Success to coordinate marketing and support touchpoints for maximum revenue impact
* Partner with Marketing Analytics to define customer lifecycle reporting and create dashboards to analyze tests, monitor performance against goals
* Map GitLab’s customer lifecycle stages and create strategic initiatives for each stage of the customer journey, which include onboarding, expansion, and retention
* Identify key measurable metrics (SKU upsell, license expansion, churn prevention, etc.) that these lifecycle programs can effectively influence
* Build and maintain relationships with Product Marketing, Developer Relations, and Sales. Establish feedback loops to ensure messaging in our campaigns is accurate, differentiated, and meaningful to our target personas
* **Free User Campaigns**: DRI for free user efficiency project, focused on progression of free users to trial to paid
* **Duo Pro & Duo Enterprise Campaigns**: DRI for email campaigns related to our AI product
* **Re-engagement nurture**: Develop and implement strategy for re-engagement email nurture
* **Email point of contact/support**: Reviewing and optimizing AMER & APAC events (fmm) and campaigns sends to ensure best practices and compliance with the GitLab brand

## Communication
<!-- DO NOT CHANGE THIS ANCHOR -->

In line with GitLab's overall [communication guidelines](/handbook/communication/), lifecycle marketing managers work through MRs first and issues second (in order to preserve documentation), and our slack channel [#lifecycle-marketing](https://gitlab.slack.com/archives/C02A0MT93DL) is used for team updated and quick questions.

The [#marketing_integratedmarketing](https://gitlab.slack.com/archives/C03HJQW0DLZ) channel is used for weekly check-ins and interaction with the larger integrated marketing team.

In between bi-weekly Lifecycle Marketing Team calls:

* **Updates** should be added to MRs when possible
  * Add to #lifecycle-marketing Slack
  * Begin with `UPDATE: <brief description>` (i.e. `UPDATE: Marketo segmentation live for sales segment`)
  * Include link to MR (preferred) or issue
* **Topics** that need input should be added as an MR when possible, with issues as a secondary option, and pinged in Slack with `DISCUSS`
  * Add to #lifecycle-marketing Slack
  * Begin with `DISCUSS: <brief description>` (i.e. `DISCUSS: Marketing tool champions`)
  * Include link to MR (preferred) or issue

### Meeting Cadence
<!-- DO NOT CHANGE THIS ANCHOR -->

* Bi-weekly - Lifecycle Marketing Team sync (lifecycle marketing)
* Weekly - Email Stakeholder call
* Bi-weekly - Digital Strategy sync
* Bi-weekly - Integrated Marketing sync
* Monthly - Marketing All-Hands (all marketing)

### The Handbook
<!-- DO NOT CHANGE THIS ANCHOR -->

Is our single source of truth (SSoT) for processes and relevant links

* Individual teams should link back to these SSoT sections to avoid confusion
* Collaborative tactics contain their own handbook pages
* The handbook will be iterated on as we establish and optimize processes for optimal efficiency

## Project Management
<!-- DO NOT CHANGE THIS ANCHOR -->

### Prioritization
<!-- DO NOT CHANGE THIS ANCHOR -->

1. [Lifecycle Marketing - Prioritization](https://gitlab.com/groups/gitlab-com/marketing/demand-generation/-/boards/2532209?&label_name[]=mktg-demandgen)
   * At start of milestone, ensure that issues are in the proper category of prioritization. Align them to the [priority definitions](/handbook/marketing/lifecycle-marketing/#prioritization-labels).
   * Consider the time you have available in a 2 week period, recognizing meeting commitments and planned PTO.
   * Only add issues to account for 70% of your available work hours. Don't max out at 100% since there will likely be things that arise and need immediate attention throughout milestone.
   * _Ask yourself: considering realistic time this milestone, am I overcommitting? The first to drop from a milestone should be "Low" priority issues based on [definitions](/handbook/marketing/demand-generation/campaigns/#prioritization-labels)._
   * Discuss milestone with Jackie and if you need help determining what to drop and how to communicate (potentially) to issue requestors.
1. [Lifecycle Marketing - Current Milestone](https://gitlab.com/groups/gitlab-com/marketing/demand-generation/-/boards/2574635?milestone_title=%23started&)
   * Minimize the "Low" and "Medium" columns. Your focus should first be on the "Top" and "High" priority issues.
   * Prioritize completion of "Top" priority issues, then "High" priority issues.

### Labels
<!-- DO NOT CHANGE THIS ANCHOR -->

#### Prioritization labels
<!-- DO NOT CHANGE THIS ANCHOR -->

* `DG-Priority::Top`: Immediate action needed, aligned to OKRs. This category will be limited because not everything can be a priority. Timeframe: Immediate action needed.
* `DG-Priority::High`: Not requiring immediate action, but aligned to OKRs, intelligent nurture, or free user journey. Timeframe: Within weeks.
* `DG-Priority::Med`: Requests submitted that align to OKRs, intelligent nurture, or free user journey. Process improvements to fix broken processes, or improve lifecycle marketing team efficiency. Timeframe: Within months.
* `DG-Priority::Low`: Requests submitted that would be helpful, but can be pushed for higher priority issues. Nice-to-have improvements for lifecycle marketing team processes. Timeframe: No specific timeline.
* `DG-Priority::ToBePrioritized`: Requests that have not yet been prioritized by the team.

#### Team labels
<!-- DO NOT CHANGE THIS ANCHOR -->

* `mktg-demandgen`: DRI is in Demand Gen team
* `dg-lifecycle`: DRI is in Lifecycle Marketing
* `dg-campaigns`: DRI is in Campaigns Team
* `dg-request`: Issue requesting Lifecycle Marketing support (did not originate from DRI team)

#### Status labels
<!-- DO NOT CHANGE THIS ANCHOR -->

* `mktg-status::blocked`: there were insufficient details in the issue for work to be completed
* `mktg-status::wip`: the issue is assigned and moved into appropriate time-based milestone
* `mktg-status::plan`: this is used for work that is in an earlier stage of planning and a specific request has not been made
  * This will likely be used mainly by campaign managers on issues that are not high priority but there is a desire to capture the idea/notes.

### Issue Templates
<!-- DO NOT CHANGE THIS ANCHOR -->

We ask that teams request work using the following issue templates in the campaigns project. These templates more clearly indicate what information and details are required in order for the request to be triaged.

Note on timelines: The campaigns team is focused on campaign strategy, execution, and optimization. Team member milestones focus on work to drive MQLs and SAOs, and requests will be committed to as bandwidth permits at discretion of Campaign Team Manager.

#### Request Issue Templates
<!-- DO NOT CHANGE THIS ANCHOR -->
Below are the issue templates to make a lifecycle request. For processes, please see our [processes handbook page](/handbook/marketing/lifecycle-marketing/email-processes-requests).

* [lifecycle-add-to-nurture](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=lifecycle-add-to-nurture)
* [request-email-followup](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=request-email-followup)
* [request-email-invitation](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=request-email-invitation)
* [request-email-newsletter](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=request-email-newsletter)
* [request-email-reminder](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=request-email-reminder)
* [request-email](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=request-email) - _only for general email requests_ _For customer communications, please work with Marketing Ops._
* [idea-campaign](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=idea-campaign)
* [request-corp-conference-email](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=request-corp-conference-email)

#### Campaign Team Issue Templates
<!-- DO NOT CHANGE THIS ANCHOR -->

The following issue templates are used by the campaigns team to organize their work, with appropriate labels applied for project management.

* **[campaign-manager-wip](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=campaign-manager-wip)**
  * to be used by Campaign Managers ONLY for simpler project management for their own initiated issues
  * puts straight in WIP status with pre-set for curent milestone and assignment to the person opening the issue
* [lifecycle-marketing-freeuser-plan](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=lifecycle-marketing-freeuser-plan)
* [lifecycle-milestoneplan](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=lifecycle-milestoneplan)
* [lifecycle-monthly-update](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=lifecycle-monthly-update)
* [lifecycle-onboarding](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=lifecycle-onboarding)
* [lifecycle-ooo](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=lifecycle-ooo)
* [lifecycle-reporting](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=lifecycle-reporting)
* [lifecycle-abtest](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=lifecycle-ab-test)

* [campaigns-mural](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=campaigns-mural)
* [campaigns-pathfactory-track](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=campaigns-pathfactory-track)
* [campaigns-pf-buyer-journey](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=campaigns-pf-buyer-journey)
* [campaigns-sdr-enablement](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=campaigns-sdr-enablement)

#### Fundamental principles of issue requests
<!-- DO NOT CHANGE THIS ANCHOR -->

The following issue templates are used by the campaigns team to organize their work, with appropriate labels applied for project management.

* `/assign @` - issues should have only DRI based on who will complete the work in the issue. If work needs to be completed by multiple people, consider breaking into separate issues with clear deliverables and due dates. (example: `/assign @aklatzkin`)
* `/due 2021-` - add due date based on workback schedules (example: `/due 2020-07-13` or `/due tomorrow` or `/due 07/13/2020`)
* `/milestone %` - add milestone based on the due date of the issue (example: `/milestone %"Mktg:` )
* `/weight` - add weight between 1-5, with 1 being easiest (between 1-4 hours of time) and 5 being most complex (a full week of work). The majority of issues should fall into 1-2. If estimation is weight of 3+, break into separate issues for more manageable pieces to fit into milestones. (example: `/weight 1`)
* `/epic` - add epic of the overarching campaign or project to keep things organized. In almost all cases, there is a larger initiative that the issue relates to, so it is best practice to associate issues to the most relevant epic for visibility. (example: `/epic [https://gitlab.com/groups/gitlab-com/marketing/-/epics/370](https://gitlab.com/groups/gitlab-com/marketing/-/epics/370)`)

#### Intake process daily/weekly steps
<!-- DO NOT CHANGE THIS ANCHOR -->

Team manager completes daily review of [lifecycle marketing issues in triage](https://gitlab.com/groups/gitlab-com/marketing/-/issues/?sort=milestone_due_desc&state=opened&label_name%5B%5D=lifecycle-mktg&label_name%5B%5D=mktg-status%3A%3Atriage&first_page_size=20) assessing the following standards:

* Are all details in the `Submitter Checklist` sufficiently complete in order to begin work?
  * if yes, check that due date is at least 5 business days from date submitter details provided, move to `mktg-status::wip`, assign based on triage diagram, and put in current milestone (to be adjusted as needed by assignee)
  * if no, comment to requester and move to `mktg-status::blocked`
* Does the request align to OKRs and key projects?
  * if no, consider realistic timeline given priorities (and share with requester in comments, set up time to discuss if needed)

#### Shortcut issue comments for project management
<!-- DO NOT CHANGE THIS ANCHOR -->

**When a team member is picking up an issue from the backlog:**

```text
/label ~"mktg-status::wip"
/assign @
/milestone %Mktg:2023-
```

This will change the status to wip (work in progress), allow quick assignment and add to the appropriate milestone.

### Key Resources

* [Overall Epic for Lifecycle Marketing](https://gitlab.com/groups/gitlab-com/marketing/-/epics/4795)
* [FY25 Trial](https://gitlab.com/groups/gitlab-com/marketing/-/epics/4797)
* [FY25 Persona Nurture](https://gitlab.com/groups/gitlab-com/marketing/-/epics/4798)
* [FY25 Email Template Work](https://gitlab.com/groups/gitlab-com/marketing/-/epics/5125)
* [Email UTM generator](https://docs.google.com/spreadsheets/d/12jm8q13e3-JNDbJ5-DBJbSAGprLamrilWIBka875gDI/edit?gid=2078854818#gid=2078854818)
* [Nurture documentation](https://docs.google.com/spreadsheets/d/1ra3jTCzYSZIE5nL_PsbDBSl9Bab9_Amr_sjLOJ-W1Ik/edit?usp=sharing)
