---
title: Email Best Practices
description: An overview of GitLab's email best practices.
twitter_image: '/images/tweets/handbook-marketing.png'
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

## Overview
<!-- DO NOT CHANGE THIS ANCHOR -->

This page focuses on email best practices and their implementation at GitLab. You'll also find information on important metrics to consider when sending an email and our email templates with image size guidelines.

## Email marketing best practices
<!-- DO NOT CHANGE THIS ANCHOR -->

**Please see our most up to date email best practices in our guide [here](https://docs.google.com/presentation/d/1j6F-3ZOFtFM9Tjz1srzbqLjSA56sK7lR2LPdKSl57Vo/edit?usp=sharing).**

### Subject line best practices (and preview text)
<!-- DO NOT CHANGE THIS ANCHOR -->

* Use subject lines to justify sending the email and connecting to a problem that the reader might have
* Ask yourself "why would I open this email"? - include the **value proposition**
* Keep it short and sweet - only include that is absolutely necessary
* Try 28 to 39 characters - studies suggest this is a "sweet spot" but that is always debatable and testable
* Front-load - put important information **first**
* Be specific - emphasize what the reader "gets" out of reading this email
* Test when you can!
* Chad White, email marketing strategist and book author created the **CUE-DIVE method**:
  * ❏ Contextual - personalized, localized, segmented, relevant, anticipated
  * ❏ Urgent - topical, events, deadlines, newsjacking
  * ❏ Emotional - aspirations, happiness, anxiety, duty, fear
  * ❏ Detailed - answers the question "what is this email about?"
  * ❏ Intriguing - questions, curiosity, mysterious, humor, puns
  * ❏ Visual - very long or very short, unusual spelling, emoji, unusual punctuation
  * ❏ Earned - testimonials, reviews, endorsements, media coverage
* SUBJECT LINES AFFECT OTHER METRICS TOO! Subject lines affect click through rates & conversions! Poor subject lines can damage the performance of future email campaigns. Do not underestimate their importance!
* The preview text is the first sentence displayed in an email client alongside the subject line (before opening the email), don't ignore it! Some email clients show 90 characters, so there is some flexibility with length

### Email content best practices
<!-- DO NOT CHANGE THIS ANCHOR -->

* Email copy should be clear and concise. Brevity is key. Think about conversion, not sharing every detail from the LP
* Focus on value-first content and CTAs. Ask yourself: "what's in it for the subscriber?"
* Avoid walls of text when possible - think facts, not fluff
* Lead with benefits and add details where appropriate
* Use extremely clear wording and remove words that don't provide value
* 1-2 CTAs per email is best practice (calls-to-action)
* Take advantage of content hierarchy
* Write for people not technology, this means you can use humor when it makes sense
* Buttons should be no longer than 25 characters - 14 characters as a standard

* Make sure that the size of your HTML file does not exceed 102kb, otherwise gmail will truncate your email and your email will be out of compliance.
* If linking to the GitLab marketing site, make sure that the URL has a slash at the end of the link. Marketing site pages will not render if there are URL params and there is no trailing slash.

### Design best practices
<!-- DO NOT CHANGE THIS ANCHOR -->

* Consider resposive design
* Code all text in HTML
* Minimize CTAs
* CTAs must be in sentence structure caps (ex: Register now)
* Images should add to the goal of your email and not take away from it
* An email is not a landing page
* Consider accessibility
* In order to accomodate different clients and modes (dark mode, etc) header image requests to the design team must be for transparent images. This means that the image will not look right without a solid background in the email header. We cannot use a non-transparent image because they do not render properly in all clients.

### A/B testing best practices
<!-- DO NOT CHANGE THIS ANCHOR -->

Add your tests to the [A/B testing tracker here](https://docs.google.com/spreadsheets/d/1-XQjw1A_m5N4NaW6Er2TUlMeWPS-vTPJ2cDE9ddFLpg/edit?usp=sharing)

* Each test group should include at least 1000 people
* You need a bigger test group if you're testing for click-through rate versus testing for open rate
* Have a goal and idea regarding what you want to improve and how your test is going to help with that
* Test _one_ variable at a time
* Due to our small sample sizes, we recommend a full 50/50 split versus a 10/10/80 or 20/20/60 split
* Remember your subject line or "from name" (testing open rates) could have an impact on click-through rate and conversion rate
* Let the Campaign Manager know at the beginning of the project if you're interested in running an A/B test and what your goals/hypothesis is
* Keep track of the split test learnings so we can learn and innovate!

### Email KPI's that matters
<!-- DO NOT CHANGE THIS ANCHOR -->

To view current benchmarks in Marketo, go to the [Email Insights Tab](https://ab-ee-api.marketo.com/).

**The Importance of Content in Email Marketing:**

Creating high-quality content within the body of the email is essential in email marketing for several important reasons:

Engagement and Audience Retention: Quality content captures the attention of your recipients and keeps them interested in what you have to say. An email with valuable and relevant content increases the likelihood that recipients will read the entire message and potentially interact with it.

**Converting Leads into Customers:** Good content can persuade your recipients to take action, such as clicking a link, registering for an event, downloading a resource, or making a purchase. Effective content can directly contribute to converting leads into customers.

**Differentiation and Positioning:** High-quality content sets you apart from the competition and positions you as a leader in your industry. You can share relevant information, updates, and insights that showcase your expertise.

In summary, developing good content within the body of the email is essential for attracting, retaining, and converting your recipients. A well-designed email filled with valuable content can make the difference between the success and failure of your email marketing campaigns.

**Delivery Rate:**
_GitLab benchmark: 97%_

Our delivery rate should be in the high 90s.  Anything below this number needs to be addressed. A low delivery rate could be indicative of two things: poor list quality or the wrong email service provider.

How to calculate delivery rate: Number of emails delivered / number of emails sent.

Example: 950/1000 = 95% Delivery Rate.

**Open Rate:**
_GitLab benchmark: 23%_

Importance of Subject Lines in Email Marketing:

Attracting Attention: The subject line is the first thing your recipients see when they receive an email. It should be compelling and relevant enough to immediately capture their attention and persuade them to open the email.

Increasing Open Rate: A good subject line can make the difference between an email being opened or ignored. A high open rate is essential for your message to reach your audience.

Conveying Value: The subject line should clearly and concisely communicate the value or benefit that the recipient will gain by opening the email. It should answer the question: "Why should I open this email?"

Creating Expectation: You can use the subject line to build anticipation or intrigue, which can motivate recipients to open the email to learn more.

Reflecting the Brand: Subject lines can also contribute to building your brand image. They should align with the personality and tone of your company.

Our email open rate is directly tied to our subject line and possibly our subheader. What is considered a good open rate will vary by industry, but on average, a healthy open rate may be anywhere between 15%-25%.

The KPI most directly impacted by the subject line is the Open Rate. This metric measures the percentage of recipients who opened your email compared to the total emails sent. An effective subject line can significantly increase this rate, indicating that more people are interested in your content and willing to engage with your messages.

For a software and web application company like GitLab, the average open rate percentage may vary, but a good benchmark is between 20% and 30%.

If our open rate is low, consider testing different subject lines or preheaders to see what style works best with our customers.

How to calculate open rate: Number of emails opened / number of emails delivered

Example: 200/1000 = 20% Open Rate

**Click Rate (CTR)**
 _GitLab benchmark: 2%_

 The click rate is the measure of how many people who received the email clicked on CTA, image, or links within the body of the email.

 The average click through percentages in email marketing campaigns for software and web application companies like GitLab can vary, but a good general benchmark is a CTR ranging from 2% to 5%.

This value can vary significantly depending on various factors, such as the quality of the subscriber list, content relevance, the effectiveness of calls to action (CTA), and proper audience segmentation.

That said, it's important to remember that the ideal CTR can vary from one company to another and largely depends on the specific goals of the campaign. Some campaigns may have a higher CTR if the content is highly relevant, and the audience is highly engaged, while others may have lower CTRs if they are sent to a broader and more diverse list.

How to calculate click-through rate: Number of clicks / number of emails delivered

**Click To Open Rate:**
_GitLab Benchmark: 7%_

There are several factors which could go into a low click-to-open rate, such as our email design, our content, our call to action — really any element in the body of our email.

It is a little more challenging to isolate what may be causing a low click-to-open rate, which is why we need to set up some A/B test splits to determine the cause.

How to calculate the Click To Open Rate: Unique Clicks / number of emails open.

Example: 50/200 = 25%

**Opt-Out Rate:**
_GitLab Benchmark: 0.3%_

Generally a good (low) unsubscribe (or opt-out rate) is below 0.2%. But anything above 1% is a problem. Determining why customers are opting out can be a challenge, so be proactive. Set up a brief survey for people who do opt out asking why.

How to calculate opt-out rate: Total Opt-outs / number of emails delivered.

Example: 5/950 = 0.5% Unsubscribe Rate.

## Email Templates
<!-- DO NOT CHANGE THIS ANCHOR -->

**Please see [this issue](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/3375) for more details and to see how the email templates look**

**What are email templates?** An email template is a reusable HTML file that is used to build email campaigns (according to Litmus).

**Why are email templates important?** Using an email template allows you to produce campaigns faster, since the underlying code is already written. Instead of having to rewrite an entire email from scratch for every send, you can simply add copy, images, and links to an existing template before testing and sending it to your subscribers (according to Litmus).

**What email templates are available for us to use?** In Marketo (Design Studio > Email Templates), the following email templates are available:

| Template Name in MKTO | Use For | Image Specs (px, w x h) | Notes |
| ------ | ------ | ------ | ------ |
| A - Event Invite v3.0  | Events or asset downloads | Header background image - Transparent background 600x345 |  Top button is removable, **The text version will need to be updated manually due to limitations with marketo variables** |
| B - Advanced modular template - light mode | Larger events/assets with more modules to add with speakers   | Header - Transparent background 600x345, Speaker images - 300x300 (2x the size) | Do not use all modules at once, **The text version will need to be updated manually due to limitations with marketo variables** |
| C - Simple email template | Assets/webcasts/events/anything | Background image - png 600x wide. Transparent background | Only use with 1 CTA |
| D - Letter format v1.0 | Any letter-like communication such as account update | N/A | N/A |
| E - Newsletter Dark Mode | DevOps Download developer newsletter only | The only image we swap out is the background image of the release section - 600px wide. The top image (infinity loop) is 600px wide also. | For DevOps Download newsletter only|
| F - Level Up Certification Invite Template | Level-up certification content | TBD | N/A |
| G - Event Invite with 2 buttons| Webcast invitations, events, ABM, anything really | Headline background image - 600x345; Speaker images - 300x300 (2x the size) | **The text version will need to be updated manually due to limitations with marketo variables** |
| H - Advanced modular template | Larger events/assets with more modules to add with speakers   | Transparent background 600x345, Speaker images - 300x300 (2x the size) | Do not use all modules at once, **The text version will need to be updated manually due to limitations with marketo variables** |

**Additional links/info:**

* A - Event Invite v2.0 -- [COPY DOC TEMPLATE](https://docs.google.com/document/d/1j43mf7Lsq2AXoNwiygGAr_laiFzmokNCfMHi7KNLjuA/edit#heading=h.tl82wncgutxu)
* B - Newsletter Dark Mode v1.0 **(Only for use by the DevOps Download newsletter)**
* C - Event Invite 2 buttons and speakers v1.0 -- [COPY DOC TEMPLATE](https://docs.google.com/document/d/1lZDXHh7OcyLdCz2rt7YPyfK8_bfQz757EBI-2GiIdEI/edit#)
* D - Letter format v1.0
* E - Newsletter Remote v1.0 **(Only for use by the All Remote team)**

**Template notes**

* ABM Email Template - please use "Event Invite 2 buttons and speakers v1.0"
* Nurture emails - please use "Event Invite 2 buttons and speakers v1.0"
* Event invites or reminders - please use "Event Invite 2 buttons and speakers v1.0"
* Privacy policy updates, account updates, or text-heavy emails - please use "Letter format v1.0"

If you don't have Marketo access and would like to see what the email templates look like, [please view the project Epic and corresponding issues](https://gitlab.com/groups/gitlab-com/marketing/-/epics/759).

**NOTE:** It is very important that you format your copy to align with the design of the email template you're using. This will improve efficiency of building emails, and ensure copy is best fit to the layout.

**What if I want a custom email template?** You may submit a request for a custom layout, but please note that the critical priority currently is to efficiently launch emails and nurtures into market. In your [request](https://gitlab.com/gitlab-com/marketing/lifecycle-marketing/-/issues/new), please tag @aklatzkin and clearly describe why the existing layout is not satisfactory, how often and broadly the requested template will be used, and quantifiable benefits we anticipate from the new layout. To reiterate: Upon implementation of the critical emails and nurtures, we plan to devote more time and energy to developing and testing new templates, however the launch of lifecycle emails takes precedence over these requests.
