---
title: "Marketing Career Development - Overview"
description: "This page details the marketing career development program."
---

## Overview

### Problem Statement

In the annual employee engagement and satisfaction survey, Marketing's lowest score was for career development within GitLab. Due to the team structure, hiring is made for specific roles and the team is kept as lean and efficient as possible. This makes mobility more difficult.

### Proposed Solution

Create a program for learning and development based on core competencies in the main areas all marketers should have. Working with the L&D team and resources available (ie. LinkedIn Learning) Marketing will curate a program with the goal of developing team members based on these competencies and make them eligible to move into internal roles.

### Welcome Video

Todd provides an overview of the purpose and goals of the Marketing Career Development Program as well as insights into the marketing organization and what each team does, in this welcome [video](https://gitlab.edcast.com/insights/welcome-video).

## Competencies

### Analytics

Know how to read and interpret the marketing analytics GitLab's marketing team uses to inform business decisions and strategy

- [Business Analytics: Marketing Data](https://www.linkedin.com/learning/business-analytics-marketing-data/what-is-the-value-of-marketing-data?u=2255073)  - LI provides a nice overview of why and how people analyze marketing data.
- For SFDC users:
- [Trailhead Reports and Dashboards for SFDC Classic](https://trailhead.salesforce.com/content/learn/modules/reports-dashboards-quick-look/learn-about-reports-and-dashboards)
- [DataStudio training on GitLab about.com](https://www.youtube.com/watch?v=7IFDCl_6SsM) - Empirical Path and Shane Rice sharing how to use DataStudio
- [OPTIONAL: Salesforce Custom Reports](https://www.linkedin.com/learning/salesforce-custom-reports) (LI video - all shown in Lightning UI vs Classic)
- [OPTIONAL: Salesforce dashboards](https://www.linkedin.com/learning/salesforce-dashboards) (Section 2 Chart Types may be of interest as to why you might choose one type over another and what each means, again in Lightning)

### Writing and communication

- [Understanding different types of content](https://www.linkedin.com/learning/seo-foundations-14828080) - Explore the basics of SEO, including how to read a results page and see how rankings affect businesses large and small. Discover how to implement foundational optimization strategies and techniques, including how to conduct keyword research, build internal and external links, optimize your pages and content, measure your successes and progress, and plan for a long-term SEO strategy. Additionally, learn specific SEO tips for ecommerce, local search, and mobile audiences to expand your reach.
- [Learning to write marketing copy](https://www.linkedin.com/learning/learning-to-write-marketing-copy/becoming-a-great-copywriter?u=2255073) - Copy is the heart and soul of almost every marketing endeavor. Get a great foundation for all your campaigns with this course. Learn how to write copy that tells your story and sells your product or brand. Learn about the different types of copywriting, the benefits of drafting on paper (yes, paper!), observing general rules, writing headlines, selling the page, and rewriting existing copy to optimize it for different outlets and platforms.
- [What is Content Marketing](https://www.linkedin.com/learning/content-marketing-foundations-3/what-is-content-marketing?u=2255073) - A well-crafted content marketing strategy can greatly increase visibility of your brand, help build credibility, and create an enduring relationship with your audience. Learn content marketing concepts and benefits, then explore a step-by-step approach for organizations of all sizes to succeed with this strategic marketing approach. Brian covers how to create a content plan, choose content types, and develop an editorial calendar. He then explores how to write, edit, and design content, as well as how to choose the right mix of content and curate it for maximum impact.
- [Introduction to Social Media Strategy](https://www.linkedin.com/learning/introduction-to-social-media-strategy/using-social-media-to-grow-your-business?u=2255073) - This presentation provides training that could reinforce our tone of voice. Reinstate our human principals: knowledgeable, relatable, honest, practical, aspirational, decisive, and clever.
- [Writing with Impact](https://www.linkedin.com/learning/writing-with-impact/strong-writing-big-results?u=2255073) - There's no such thing as generic "good" writing. Writing quality—and impact—comes from how well it fits its purpose. This course shows how to give all your writing more impact, regardless of its purpose.

### Design and communication

- [Designing a presentation](https://www.linkedin.com/learning/designing-a-presentation-24080266) - From helpful transitions to  layouts and themes- you will learn how to make an impactful slide deck.
- [Learning GitLab](https://www.linkedin.com/learning/learning-gitlab-14539757) - This training teaches markdown basics and even directs folks to GitLab flavored markdown. These simple tips can transform your epics and issues. It covers headings, bulleted lists, numbered lists, bold and italic text, and how to insert links and images.

### Revenue basics

- [Annual recurring revenue](/handbook/sales/sales-term-glossary/arr-in-practice/) (HB)
- [Customer lifecycle at GitLab](/handbook/sales/field-operations/gtm-resources/#customer-lifecycle) (HB)

### Product knowledge

- [Product Marketing Foundations](https://www.linkedin.com/learning/product-marketing-foundations-18780685)

### Project Management

- [Project Management Institute](https://www.linkedin.com/learning/topics/project-management-institute-pmi?u=2255073)
- [Project Management Foundations](https://www.linkedin.com/learning/project-management-foundations-15528659)
- [Project Management Foundations: Teams](https://www.linkedin.com/learning/project-management-foundations-teams-3/tools-for-successful-project-teams?u=2255073)
- [Leading Projects](https://www.linkedin.com/learning/leading-projects/project-management-simplified?u=2255073)

### Marketing Campaigns

- [Understand GitLab GTM Plans, Motions and Use Cases](/handbook/marketing/plan-fy23/)
- [What is Demand Generation at GitLab](/handbook/marketing/demand-generation/)
- [Email marketing from Tanuki Tech](https://gitlab.com/gitlab-com/marketing/sdr/-/issues/628)
- [Demand Generation metrics](https://app.periscopedata.com/app/gitlab/793304/Demand-Gen-Dashboard) [and how to understand the data](/handbook/marketing/demand-generation/#dashboard-metrics)
- [Mastering Digital Marketing](https://www.linkedin.com/learning/paths/master-digital-marketing?u=2255073)
- [Connecting with Customers Online](https://www.linkedin.com/learning/digital-marketing-foundations/connecting-with-customers-online?u=2255073)
- [Building an Integrated Online Marketing Plan](https://www.linkedin.com/learning/building-an-integrated-online-marketing-plan/welcome?u=2255073)
- [Understanding eCommerce](https://www.linkedin.com/learning/marketing-foundations-ecommerce-14401600)
- [Creating a channel marketing structure](https://www.linkedin.com/learning/sales-channel-management/creating-a-channel-marketing-structure?u=2255073)
- [Google Analytics Essential Training](https://www.linkedin.com/learning/google-universal-analytics-essential-training-2020/understanding-your-digital-customers-with-google-analytics) - how to use GA to track success

### Operations

- [Accrual vs. cash based accounting](https://www.linkedin.com/learning/quickbooks-online-essential-training-22304028) - GitLab runs an accrual based accounting method.

### Systems

- [Allocadia training](https://drive.google.com/file/d/1zjl1VATgCZEd4EojWcpcC_9D2kljz92S/view)
- [Allocadia handbook page](/handbook/marketing/strategy-performance/allocadia/)
- [Marketo](/handbook/marketing/marketing-operations/marketo/)
- [PathFactory](/handbook/marketing/marketing-operations/pathfactory/)
- [LeanData](/handbook/marketing/marketing-operations/leandata/)
- [Sigstr](/handbook/marketing/marketing-operations/terminus-email-experiences/)
- [Outreach](/handbook/marketing/marketing-operations/outreach/)
- [Salesforce](https://trailhead.salesforce.com/content/learn/modules/lex_implementation_basics/lex_implementation_basics_welcome) (Trailhead with Classic UI, but more admin level details)
