---
title: "PathFactory"
description: "PathFactory is an intelligent B2B content experience platform used to create personalized content journeys for your audience."
---

## What is PathFactory?

PathFactory is an intelligent B2B content experience platform used to create personalized content journeys for your audience. The [global content](/handbook/marketing/brand-and-product-marketing/content/) team is primarily responsible for all the of the content within the PathFactory. Campaign managers work with other teams in marketing to organize and curate assets into tracks that are then disseminated for use in Marketo, `about.gitlab.com`, and other campaign-related channels.

## What is PathFactory used for?

- PathFactory is used primarily for email nurture streams, landing pages, advertising, and virtual event follow-up.

- Assets are bundled together (around 5-7) in a "content track" and shared as one link. Instead of sharing multiple links to individual assets, **one link** provides a curated content experience.

### What PathFactory is _not_ used for

- **Sharing individual assets.** It's meant to encourage a visitor to "binge" the content and self-nurture towards MQL. For sharing individual assets, please direct to the GitLab website.

- **Creating web pages.** Pathfactory is a content library that curates experiences (think of it like Netflix for B2B content). Pathfactory is not a replacement for Marketo.

### PathFactory vs. Marketo

☝️ **PathFactory ≠ Email Nurture. PathFactory is a tool that - instead of driving to a single asset - drives to a related-content experience.**

Nurture is a channel to bring an individual to the content. Just like ads, social, website, etc. drive to CTAs, PathFactory link is the CTA - a _powerful_ CTA because it can lead the individual down a "choose your own adventure" path of consumption which we track.

**What are the differing goals of PathFactory and Marketo?**

- **Marketo nurture:** To keep the GitLab top of mind and deliver relevant content (via PathFactory)
- **PathFactory:** To increase consumption/engagement with GitLab content

**Can records be in Marketo nurture and PathFactory nurture at the same time? If not, is 1 prioritized over the other?**

Yes, the PathFactory track acts as a supplement to the existing Marketo nurture instead of a replacement. It allows us to provide related content in a seamless way for the end-user (better than simply providing a PDF link and to improve "binging" of content).

### PathFactory vs. CMS vs. DAM

PathFactory is not a single source of truth (SSoT) for all GitLab content, but rather content that has been activated in a marketing campaign.

**Content Management System (CMS)** - A content management system is a software application that can be used to manage the creation and modification of digital content.

**Digital Asset Management (DAM)** - Digital asset management (DAM) is a system that stores, shares and organizes digital assets in a central location.

**PathFactory** - Content experience software used to allow buyers to binge-consume content, remove friction, and create more qualified leads, faster.

## Access

The Marketing Operations team is responsible for managing access requests & provisioning the appropriate level of access for each role/function. PathFactory is not provisioned as a baseline entitlement. If you or your team require access, please open a [`Single Person Access Request` issue](/handbook/it/end-user-services/onboarding-access-requests/access-requests/) and provide business reason why access is needed. For certain permissions or roles, you may be required to go through training before access is provisioned.

### User Roles

There are four levels of access - `Admin`, `Author`, `Reporter`, `Viewer`, and `Uploader` - which are granted based on the persons' role and team function within GitLab. All access levels have the ability to view analtyics within the tool.

- `Admin` access is granted to Marketing Operations and at times, other teams such as sales or business operations to manage integrations between systems.
- `Author` access allows user to build, edit and publish content tracks applying existing tags to the assets.
- `Viewer` access provides general visibility to content within PathFactory but does not allow end user to create or modify any of the content, tracks or tags. This level of access is granted for the general GitLab team member both within Marketing and elsewhere who have a business need to have access.
- `Uploader` access allows users to create, edit, and delete content within tracks that have already been created, but does not allow users to create, edit, or delete tracks
- `Reporter` access allows users to view all analytics pages within our instance of PathFactory.
- `Sales User` is anyone who has a valid email domain associated with our PathFactory instance, but who does not have a login. These users are not able to login to PathFactory, but they will be able to share any content tracks that `Admins` select on the `Sales Configuration` page.

For more info on the capabilities of each role, [see the knowledge base article](https://support.pathfactory.com/kb/what-are-the-different-user-roles/).

### Rules of Engagement by Team

| Team | User Roles | Rules of Engagement |
| ---- | ---------- | ------------------- |
| Marketing Operations | `Admin` | Manage, quality assurance, user management, system integrations, training |
| Content Marketing | `Author` | Add content, quality assurance, participate in quarterly content audits |
| Campaign Managers | `Author` | Add content, create and edit tracks for use in campaigns, define form strategy for conversion on tracks, participate in quarterly content audits |
| Product Marketing | `Author` (select users), `Reporter` (select users) | Upload new content, participate in quarterly content audits, collaborate with `Authors` of tracks on content selection |
| Field Marketing | `Author` (select users), `Viewer` (select users) | Upload content from virtual workshops, clone existing workshop tracks for use in follow-up emails, view content performance |
| Account-Based Marketing | `Author` | Add content, create and edit content tracks for use in campaigns |
| Customer Reference Programs | `Author` | Upload new case studies and customer content |
| Developer Adbo | `Author` | Upload new technical content |
| Sales Development Representative (SDR) | `Sales user` (PathFactory for Sales only) | PathFactory for Sales (SFDC) |
| All Remote | `Author` | Upload new all remote content, create and edit content tracks for use in all-remote campaigns |
| Partner Marketing | `Author` (select users) | View content library, create and clone content tracks for partners, reporting |
| Customer Programs | `Author` (select users) | View content library, create content tracks for customer onboarding where a CSM is not assigned or requested, reporting |

## Support

1. [Knowledge base, _The Nook_](https://lookbookhq.force.com/nook/s/kb) (requires user in PathFactory and the email you use for PathFactory will be the same to access The Nook, however, the password is not.)
1. [Success Series Webinars](https://customer.pathfactory.com/l/success-series-recordings)
1. [Release Notes](https://support.pathfactory.com/?s=release+notes&ht-kb-search=1&lang=)

## Training

1. [The Path to Understanding: Onboarding Training](https://customer.pathfactory.com/customer-onboarding)
1. [Getting started video series](https://support.pathfactory.com/kb/video-tutorials-for-getting-started-with-pathfactory-templated-experiences/)
1. [Digital marketing brown bag session overview](https://drive.google.com/open?id=1Hzb6ard48k-11r5a8oBDD_NLjeZnkMK2) - [Slides](https://drive.google.com/open?id=1XxOIE2O-VW0I9z09kpLs5ops52oF6iDSP1a1MF8NkGY)
1. [Author role training (Do not share externally - PII data presented)](https://drive.google.com/file/d/1YdK96hzDj043iESfDXV7ejz5sgbIXKCv/view?usp=sharing)
1. [Reporter role training (Do not share externally - PII data presented)](https://drive.google.com/file/d/1U_QAkZoELITmJt7Jr_AMXZiQZBpAhaIj/view?usp=sharing)
1. [How to Create a Website Promoter](https://drive.google.com/file/d/1XcONoVj8Q9vhnHkdnsI-VfECDr0pFecF/view?usp=sharing)

## Issue Templates

**[Marketing Operations](/handbook/marketing/marketing-operations/)**

1. [PathFactory Author Onboarding](https://gitlab.com/gitlab-com/marketing/marketing-operations/-/issues/new?issuable_template=pathfactory_author_onboarding)
1. [Generic PathFactory request](https://gitlab.com/gitlab-com/marketing/marketing-operations/-/issues/new?issuable_template=pathfactory_request)
1. [PathFactory QA Review request](https://gitlab.com/gitlab-com/marketing/marketing-operations/-/issues/new?issuable_template=pathfactory_qa_review)
1. [New PathFactory form request](https://gitlab.com/gitlab-com/marketing/marketing-operations/-/issues/new?issuable_template=pathfactory_form)
1. [PathFactory Content Audit](https://gitlab.com/gitlab-com/marketing/marketing-operations/-/issues/new?issuable_template=pathfactory_content_audit)
1. [PathFactory Bulk Upload](https://gitlab.com/gitlab-com/marketing/marketing-operations/-/issues/new?issuable_template=pathfactory_bulk_upload)
1. [PathFactory Microsite Request](https://gitlab.com/gitlab-com/marketing/marketing-operations/-/issues/new?issuable_template=pathfactory_microsite_request)

**[Campaigns](/handbook/marketing/demand-generation/campaigns/)**

1. [Pathfactory Upload Request](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=request-pathfactory-upload) - per [rules of engagement](/handbook/marketing/marketing-operations/pathfactory/#rules-of-engagement-by-team), the content owner is DRI on uploading their new content
   - _The upload issue may be created in the content owner's GitLab project; this issue template may be helpful in outlining the steps, campaigns team is not responsible for uploads._
1. [Pathfactory Bulk Upload Request](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=request-pathfactory-upload-bulk)
   - _This issue template should be used sparingly, as content should be added to Pathfactory by content owners ongoing as it becomes available. This is helpful for examples like a number of videos produced during a Commit event with many sessions._
1. [Pathfactory Track Request](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=request-pathfactory-track)

## Important Note Using PathFactory

PathFactory has no built-in audit log or trail for changes that are made within the content library (only that it was updated and by whom) or content tracks. It is critically important that everyone with `Author` role access to PathFactory follow the instructions and documentation outlined in this handbook. Any changes made to the content library or content tracks can have a negative impact on those content tracks which are tied to campaigns, reporting, and attribution.

For instance, if an asset is deleted from the content library and that asset exists in campaign-related content tracks, the user that visits that asset within that track will be redirected to `about.gitlab.com`, which has the following impacts:

1. Breaks the content track experience for the user by de-railing them from their intended destination
1. Skews data in the campaign, reporting, and attribution
1. Potentially loses out on further nurturing that user, or making an unknown user known through gating

The same impacts above can happen if an `Author` role makes changes to an existing content track without collaborating with the `Author` of that track.

**Before making any of these impactful changes, please collaborate with the `Author` of a content track _before_ making any changes or asking in `#mktgops` before deleting any assets in the content library.**

If these changes are made, it is also critically important to input them to the [PathFactory changelog](#changelog) so that we can correct them accordingly.

## Changelog

Periodically, significant changes are made or added to PathFactory and processes that affect overall data and reporting. As such we have a [changelog](https://docs.google.com/document/d/1qd9X-V0WNBTklCKNYVRmjJtiOcPu6dZYkfJ2uuQt_Co/edit?usp=sharing). Everyone with `Author` access that is making significant changes in PathFactory should add their changes to the changelog with a linked issue and/or relevant PathFactory links.

**Scenarios for adding to the changelog:**

1. Creation or launch of a new content track and where it will be used
1. Creation or launch of a new website promoter
1. Additions or changes to a form strategy within a `[LIVE]` content track
1. Additions or changes to assets within a `[LIVE]` content track
1. Expiration of an asset from the content library
1. Change of a custom URL slug for an asset or content track and why
1. Change of promote settings within a `[LIVE]` content track and why

**Instructions**

1. Open the [PathFactory changelog doc](https://docs.google.com/document/d/1qd9X-V0WNBTklCKNYVRmjJtiOcPu6dZYkfJ2uuQt_Co/edit?usp=sharing).
1. Add the date you made the change if it doesn't already exist.
1. Add a bullet with your GitLab username and document the changes you made, making sure to include links to issues or relevant PathFactory links.

## Content Library

The [content library](/handbook/marketing/marketing-operations/pathfactory/content-library/) is where all content uploaded to PathFactory is added and tagged for use in content tracks and experiences. An asset must exist in the content library first before it can be utilized in a PathFactory experience.

## PathFactory Campaign Tools

There are multiple types of PathFactory experiences that you can create under `Campaign Tools`:

1. Content Tracks (target or recommend)
   - Target Tracks - Target Tracks are collections of content that you have selected and organized in order to give your visitors a specific content journey.
   - Recommend Tracks - Recommend Tracks are collections of content specifically selected by you, and which rely on machine-learning to suggest the ideal content to show your prospects based on what they are already viewing.
1. Explore Pages - Explore Pages allow your visitors to quickly view all content assets in a content track. Each `Explore Page` you create is built on top of an existing `Target` or `Recommend` Content Track.
1. Website Promoters - Website promoters allow you to harness the power of PathFactory's content promoters directly on your website. They provide more opportunities for interested parties to find and enter your Content Tracks by connecting eye-catching CTAs to content tracks.

## Naming Conventions

### Assets

When adding assets to the [content library](/handbook/marketing/marketing-operations/pathfactory/content-library/), please ensure both the public and internal titles match the title of the asset. Do not add any extra prefixes to the asset title (ex: `[BLOG] - Title of blog`). Content types are already indicated by the content type field. Remove any extra SEO meta title information such as `|GitLab` that is appended to the title once PathFactory pulls in the information about the asset from the URL. Follow the [editorial team's guidelines](/handbook/marketing/brand-and-product-marketing/content/editorial-team/) for formatting and [case](/handbook/marketing/brand-and-product-marketing/content/editorial-team/#case) (sentence case).

When adding localized content to Pathfactory, enter the localized title and description in the `Public Configuration` section. This is what external viewers of the content will see. Under `Internal Configuration`, enter the language with the English asset name (example: [Japanese] GitLab in Action Overview Demo). `Internal Configuration` is only viewable internally in Pathfactory.

### Tracks

When creating and editing content tracks, please use the following naming convention to let others know the status of your track. These track names are not shown to the visitor of the track. Name the track so that other `Author` roles understand the use of your track. Add start and end dates for your campaign if relevant so it can be archived/deleted at a later date. Add [persona](/handbook/marketing/marketing-operations/pathfactory/content-library/#personas) in the track title if the track is for a specific persona. [Add a GTM motion](/handbook/marketing/marketing-operations/pathfactory/content-library/#how-to-upload-content) to the title if the track assets are focused toward a specific GTM motion.

1. `[WIP] - [Campaign Name]` - work in progress track; not live
1. `[LIVE] - [Campaign Name]` - live track; traffic is flowing to track
1. `[ARCHIVED] - [Campaign Name]` - arhived track; not in active use; traffic may or may not be flowing to track

### Track Labels

Track labels are used to document the channels that a content track is distributed on. These track labels are arbitrary and do not tie to any functionality within PathFactory. They are simply used to indicate to other `Author` roles within PathFactory how you intend to use your content track.

| Label | Use |
| ------ | ------ |
| archived | content track no longer in use and marked for archiving, possibly future deletion |
| email | content track to be sent from a Marketo email or nurture stream |
| event | content track is shared as part of a corporate event or partner event |
| external | content track is shared externally (ex: third-party website) |
| in-app | content track sent from an in-product message or notification |
| integrated campaign | content track is part of an integrated campaign |
| internal use only | content track is distributed to GitLab team members only |
| landing page | content track is sent to a visitor after filling out a form on a landing page |
| organic social | content track is shared in an organic social media post |
| outreach | content track is sent via [Outreach](/handbook/marketing/marketing-operations/outreach/) |
| paid search | content track is part of a paid search campaign |
| paid social | content track is part of a paid social campaign |
| SAE inbound | content track is enabled for PathFactory for Sales for SAEs to share inbound |
| SAE outbound | content track is enabled for PathFactory for Sales for SAEs to share outbound |
| SDR inbound | content track is enabled for PathFactory for Sales for SDRs to share inbound |
| SDR outbound | content track is enabled for PathFactory for Sales for SDRs to share outbound |
| survey/quiz | content track is shared in a survey or quiz |
| web promoter | content track is used in a website promoter within PathFactory |
| website | content track is linked on a web page on `about.gitlab.com` |

### Track Folders

Track folders are set up by team as different teams within marketing use and distribute content tracks for various use cases. This helps to ensure that team members only make change to content tracks within their team folder.

### Forms

Forms should not be served based on the amount of time spent in a track, but rather after a visitor consumes 2-3 pieces of content. When a visitor progresses to the next piece of content (after the initial 2-3), they'll be asked to complete a form.

When naming forms, please follow the naming convention:

1. WIP forms: `[WIP] Language - Purpose - Marketo Form ID` (example: `[WIP] Korean - Contact Us - 2963`)
1. Live forms: `[LIVE] Language - Purpose - Marketo Form ID`  (example: `[LIVE] Korean - Contact Us - 2963`)
1. Test forms (MktgOps only): `[TEST] Language - Purpose - Marketo Form ID` (example: `[TEST] English - PF<>Bizible - 2715`)

## Content Tracks

Before creating a new content track, decide what type of content track (target vs. recommend) you want to create. Use the criteria below to decide the best option:

### Best Practices

**Target track**

1. Curated content
1. Known audience
1. Personalized journey (email, website, targeted display)
1. 5-7 pieces of content
1. Use target in webinar reg and follow-up
1. Use target to GUIDE

**Recommended track**

1. Dynamic content sequence (it will automatically move content to the top of the track that is performing well)
1. Anonymous audience
1. Personalized journey (web, general display, social)
1. Tracks the most popular journey (which pieces are being viewed, can be exported into a target track)
1. Use recommend to DISCOVER

### Create a Content Track

1. When you're ready, login to PathFactory SSO via Okta.
1. Go to `Content Activation` on the top navigation bar >>  Select `Standard Experiences` (formerly `Campaign Tools`) >> Select the content track type you want to create (`Target` or `Recommend`).
1. Click the `Create track` button on the top right.
1. Name your content track. Be descriptive about the topic or campaign that your track will be used for. If you're unsure, review the names of other content tracks to get an idea. The content track name is for internal use only and will not be shown to visitors. Each content track has to have a unique name. You cannot use duplicate names for content tracks.
1. Choose to clone an existing content track, which will copy all assets from that content track into yours, or simply start from scratch.
1. Choose the folder where your content track will live. Follow the current folder hierarchy for organization which is currently set up by team.
1. Tag your content track with labels that will tell everyone accessing the content track which channels it will be used on (internal use only).
1. Click `Create Track`.
1. On the left panel, change the custom URL slug to be descriptive of the track with no stop words (and, the, etc.) - ex. `ci-aware`
1. Add assets to your track by clicking the `Add content` button at the top right. A window will pop up with the content library. Use the sorting options at the top to quickly add content by topic, type, funnel stage, etc. PathFactory content tracks are meant to encourage content binging (visitors reading more than 1 asset to accelerate them in the pipeline by helping them self educate faster in one visit). So as best practice, have more than 1 asset in a track.

#### Configure Content Track Settings

1. **DO NOT SKIP THIS STEP!** Set the `custom URL slug` for the content track. [Follow the instructions](/handbook/marketing/marketing-operations/pathfactory/content-library/) for creating a custom URL slug for an asset.
   - **Important:** All content tracks should be set up with custom URL slugs to prevent any future changes to the track from breaking the link and thus the user experience.
   - If you change the custom URL slug after a PathFactory link has been implemeneted, those links have to be updated wherever they were used (ads, emails, website, etc.).
1. Ensure that the Search Engine Directive is set to `No Index, No Follow`.
1. Set the appearance for the track.
1. Set the language for the track.
1. Leave `Links & Sharing` set to default.
1. Leave `External Code` and `External ID 1` set to default (`None`).
1. Turn on the `Cookie Consent` before providing the approved content track link for live use.

#### Promoters

[Promoters](https://support.pathfactory.com/kb/introduction-to-promoters/) are the tools that allow visitors to navigate the Content Tracks and encourage them to view additional recommended content. Think of promoters as the guides through a content track; the promoters you use determine how and when content will be presented to visitors. Note the different functionality of each below. Before going live, you can test each promoter to find the one that works best for the goals of your PathFactory experience.

- You can only use the `Header` feature with the `Sign Posts` and `Bottom Bar` promoters.
- The `Header` is used to add additional branding to your content track.
- The `Flow`, `Sign Posts`, and `Bottom Bar` cannot be used together. Choose 1 of the 3.
  - **Flow:** Scrollable content menu allows visitors to jump ahead in their Content Track, or simply use the Next buttons to move forward.
  - **Sign Posts:** Customizable Next and Previous buttons allow visitors to navigate through content. Used for more of a linear journey through the content.
  - **Bottom Bar:** Collapsible content menu along page bottom.
- The `End Promoter`, `Exit`, and `Inactivity` promoters can be used in conjunction with either the `Flow`, `Sign Posts`, or `Bottom Bar` promoters.
  - **End Promoter:** Opens final asset in a new tab.
    - Available overrides:
      - Link
      - CTA Label
      - Delay (seconds)
  - **Exit:** Suggested content window appears when visitor tries to navigate away from the Content Track. **In order to provide a popup-free web experience, please do not enable an Exit promoter without explicit approval from Craig Mestel (CMO) and Michael Preuss (Director, Digital Experience)**
    - Available overrides:
      - Headline
      - Message
      - Items to show (choose from assets within the current track)
      - Delay (seconds)
  - **Inactivity:** Message flashes on tab when left inactive.
    - Available overrides:
      - Inactive tab title
      - Delay (seconds)

#### CTAs

[Call-to-action (CTA)](https://support.pathfactory.com/kb/use-cta-buttons/) buttons encourage further engagement from your visitors within your Content Tracks. CTAs can be added to any Target or Recommend Content Track. These CTA buttons can link to either a form or a URL.

**Create a CTA**

1. Click the settings (gear icon) and navigate to `CTAs` under `User Experience`.
1. Click the `Add CTA` button.
1. Enter a name for the CTA (internal purposes only). Be specific so others know what the main goal of the CTA is.
1. Enter a button label for your CTA. This is what the user will see. Copy for CTAs should typically be 2-3 words max (18 characters) and include action words such as `Watch a demo`.
1. Choose your CTA type (form, link, email).
   - If choosing **form** as your CTA type, **it must include** proper capture tags and script. Do not choose a `WIP` form as your CTA.
   - If choosing **link** as your CTA type, **it must include** UTM parameters for proper tracking (ex: `utm_source=pathfactory&utm_medium=cta-name`)
   - For **email**, simply input the email address you want users to contact from clicking the CTA.
1. Click `Save`.

#### Form Strategy

Form strategy is used on content tracks to collect data from unknown visitors. This is done by "gating" an asset within a track or by creating a track rule with an engagement threshold (example: spent at least 60 seconds in the track and viewed 2 assets). Not all content tracks will or should have form strategy turned on - it depends on the goal of your campaign. Form strategy should only be used when a track entry point is a direct link from a digital ad bypassing a webform or gated landing page. Please bypass from strategy entirely when linking to PathFactory from emails since we are sending to known users. In the event the recipients (known users) forwards the emails to unknown users, we chose to forgo capturing their information for better user experience.

**Please Note:**  PathFactory activity is tied into the [MQL scoring model](/handbook/marketing/marketing-operations/marketo/#scoring-model). This means that you do not need to add form strategy to a content track if entry point is from a landing page.

- [Form strategy best practices](https://support.pathfactory.com/kb/form-strategy-best-practices/)
- [Form strategy FAQ](https://support.pathfactory.com/kb/forms-strategy-faq/)

**GDPR Considerations:** When using time-based form strategy, aim for at least 15-30 seconds in order for the user to have plenty of time to accept the cookie consent pop-up prior to filling out the form.

#### Add Form Strategy to a Content Track

1. In the content track settings sidebar (left), toggle "Forms Strategy" to `On`.
1. Click `View Form Strategy` located below the `Add Content` button.
1. Determine whether the form strategy will be applied to individual assets or the entire track. For individual assets, you'll choose `Content Rules`; for form strategy on the entire content track, you'll choose `Track Rule`.

**Form strategy by asset:**

1. Click `Add Rule` in the `Content Rules` row.
1. Select the `General Form (2074) LIVE` form unless otherwise required according to campaign needs. Do not select a form marked `[WIP]`.
1. Under `Display Behavior`, click the dropdown and choose the assets where you want the form to show. (**Please Note:** only assets that you have added to the content track will show in the dropdown. If you want the form to show on an asset that _is not_ in the track, you will need to add it first.)
1. Select the amount of seconds you want to delay before the form shows on the asset. `10 seconds` is the default selection.
1. Select additional options for the form behavior. If you will be using the content track or individual asset links in an email, you are working with a known audience and therefore should only select `Show to unknown users`. This prevents forms being shown to users who are already known in Marketo. However, if you are using the form on the web or other channels, you'll want to select `Show to unknown users` only.
1. Ensure `Show to Known Visitors` is toggled off.
1. Leave `If submitted, allow form to show again` toggled off.
1. You can `allow visitors to dismiss the forms` if it is not crucial to its use to have them submit their info.
1. The option `Keep promoters active when form is shown` is up to the `Author`. For example, if the `Flow` promoter is used on a content track, they will still be able to see the sidebar of avialable content while the form is shown to them. If this option is toggled off, the visitor _will not_ be able to click on any content in the sidebar until they fill out the form.

**Form strategy for content tracks:**

1. Click `Add Rule` in the `Track Rule` row.
1. Select the `General Form (2074) LIVE` form unless otherwise required according to campaign needs.
1. Under `Display Behavior` you can choose to serve the form based on the number of content assets viewed or the total time spent on the track.
1. All other options for content track rules are the same for individual assets (see above).

#### Testing a Track Link

1. Click through the experience to ensure assets, CTAs, and forms load properly and that promoters are working as intended.
1. Remove any extraneous `?` (there should only be one immediately after the end of the URL).
1. Watch for extra `&` when [appending UTMs](/handbook/marketing/integrated-marketing/digital-strategy/digital-strategy-management/#utm-tracking).
1. Test and ensure the experience is working as intended.

**When a track is LIVE (in use):**

1. Change the target track title in use to `[LIVE] Name of track`.

**When a track has been archived (no longer in use):**

1. Change the target track title that's no longer in use to `[ARCHIVED] Name of track`.

#### Adjustments to Live Content Tracks

- You can add assets and adjust the position of assets to a `[LIVE]` content track.
- Removing an asset or changing the custom URL slug of an asset in a `[LIVE]` track can disrupt the user experience for the visitor and activate the `#all` track or fallback URL (`about.gitlab.com`) instead of the intended content track. Please ensure that the link to the asset is not being used in any other marketing channels before deleting.

### Prescriptive Buyer Journey Content Tracks {#pbj-content-tracks}

**DRI for track creation: Campaign Managers**

- [This GDoc](https://docs.google.com/spreadsheets/d/1MYGePezz7666yXJJNRkif0ekJwxnIoJMBgFPshOm1IY/edit#gid=1504719228) tracks progress toward all prescriptive buyer journeys being built out in Pathfactory, _including live links_.
- These tracks live under [Target Tracks](https://gitlab.lookbookhq.com/authoring/content-library/target) > Demand Gen > `Segment Campaigns` (subject to change if the folders get massive - HB to update as needed)
- These tracks align to the [Prescriptive Buyer Journeys ("PBJs")](/handbook/marketing/prescriptive-buyer-journeys/) which will be iterated on collaboratively across marketing
- The Campaigns Team will iterate and test out different styles, form strategy, end promoter settings, and .
- The [Example "PBJ" Track](https://gitlab.lookbookhq.com/authoring/content-library/target/57384) has the following elements and settings applied (for easy cloning) but only contains one asset when the future ones would have 3-4 assets:
  - _Reminder Campaigns Team: The example below is just a starting point. Experimentation and testing recommended!_
  - Track settings: (FYI) set to default according to [these instructions](/handbook/marketing/marketing-operations/pathfactory/#configure-content-track-settings)
  - Track Settings: Custom URL Slug (REQUIRED): `[motion]-[stage]-[persona][#]` (i.e. `ci-awareness-prac1` or `vcc-`) - [see more](/handbook/marketing/marketing-operations/pathfactory/#configure-content-track-settings)
  - Flow: `ON` > `Start Free SaaS Trial`
  - End Promoter: `ON`
  - End Promoter Link: Set this to point to the next track in the prescriptive buyer journey. (i.e. if you're on `CI Awareness Practitioner 1`, set the end promoter to go to `CI Awareness Practitioner 2` to move them to the next stage and continue binging)
  - End Promoter CTA Label: Add an enticing CTA, but keep it short... max characters TBD
  - End Promoter Delay: 5 seconds
  - Forms Strategy: Set to trigger to **Unknown Visitors** after EITHER 30 seconds on main offer OR 30 seconds overall on track.
  - Forms Strategy: Not dismissable.

## PathFactory Forms

The forms used in PathFactory are hardcoded Marketo form script. They are added to PathFactory using the Marketo script, but they should also include the PathFactory capture tags and custom parameters to capture additional information behind the form fill. If a new form is created, the PathFactory capture tag and custom parameters **must be hardcoded in the script**.

### Request a new PathFactory Form

To request a new form to use in PathFactory, the form must first exist in Marketo. If one does not exist, first create an issue in the marketing ops project using the [`form_request.md` template](https://gitlab.com/gitlab-com/marketing/marketing-operations/-/blob/master/.gitlab/issue_templates/form_request.md). Once the Marketo form is completed, then create an issue in the marketing ops project using the [`pathfactory_form.md` template](https://gitlab.com/gitlab-com/marketing/marketing-operations/-/blob/master/.gitlab/issue_templates/pathfactory_form.md).

### Capture Tags

A `Capture Tag` is a snippet of code added to a Marketo form code itself. The `Capture Tag` sees the visitor's email address on submitted form, and sends it to PathFactory. This allows PathFactory to associate the email address of a visitor to their engagement data; the visitor will then be a known visitor rather than anonymous.

We use external forms (added by External URL or Custom HTML generated from Marketo) in PathFactory. The information submitted in the form is sent directly to Marketo. In order for PathFactory to associate the submitted email address with the visitor's engagement data, you must use a `Capture Tag`. This is what allows PathFactory to identify the individual as a known visitor.

## PathFactory Links

- Only content track links are meant to be used and shared. Do not share individual asset links from the content library.
- You can use a content track link for multiple use cases as long as you apply UTMs appropriately. Applying UTMs helps us differentiate how the track performed across different channels.
- If the link breaks or an asset is deleted, the user will be redirected from your content track to the `#all` track, which includes all assets uploaded to PathFactory. In a case where the user is not redirected to the `#all` track, they will be redirected to the `Fallback URL` which is set to `about.gitlab.com`.
- **Do not use the `lb_email=` parameter when sharing `about.gitlab.com` links in Marketo emails. This parameter is used on `learn.gitlab.com` links to identify anonymous track visitors.**

### Target Track Links

1. Use the `Get Share URL` feature next to the title of the track. `Share links` are to be used in locations such as the website whereas `Email tracking links` are only for use in email. **Note:** If it's in email, it's a known audience so don't gate any assets in the track. Only use `share links` on the web and those tracks _can have_ gated assets within PathFactory.
1. If you want a particular asset to show first, that asset should be located in the first position of the target track.

### Recommend Track Links

1. To use a recommend track link, click on any of the assets in the track and copy the link from the asset window on the right. The asset you choose to share the link will be shown to the user first.

### Appending UTMs to PathFactory Links

1. First check and see if there is a question mark `?` already existing in the PF link. Typically there is one. The only time it won't have a `?` is when you set a custom URL.
1. If there is a question mark `?`, first add an ampersand `&` at the end of the PF link, followed by the UTMs.
    - For example:
    - PF Link: `https://learn.gitlab.com/c/10-strategies-to-red?x=53kuPb`
    - PF Link with UTMs: `https://learn.gitlab.com/c/10-strategies-to-red?x=53kuPb&utm_source=email&utm_campaign=test`
1. If there is no question mark `?`, first add a question mark `?` at the end of the PF link, followed by the UTMs.
    - PF Link: `https://learn.gitlab.com/c/10-strategies-to-red`
    - PF Link with UTMs: `https://learn.gitlab.com/c/10-strategies-to-red?utm_source=email&utm_campaign=test`

**Marketo links**

1. For a PF Marketo link, it will typically already include a question mark "?". To add UTMs, first add an ampersand `&` at the end of the PF link, followed by the UTMs.
    - Example: `https://learn.gitlab.com/c/devops-explained-git?x=GVFK3F&lb_email={{lead.Email Address}}&utm_source=email&utm_campaign=test`
1. Remove any extraneous `?` (there should only be one immediately after the end of the URL).
1. Watch for extra `&`.
1. Test the link before implementation for quality assurance purposes.

**PathFactory links behind a form fill on a landing page**

1. When using a PathFactory link as the redirect behind a form fill on a landing page, the link format should be as follows:

`https://learn.gitlab.com/c/gcn-dev-sec-ops-how-?x=XOIXTl&lb_email=`

**Using a content track with a custom URL**

1. If your content track has a custom URL, you will notice the `?` in a different location than with content tracks that don't have a custom URL.
    - With no custom URL: `https://learn.gitlab.com/c/gcn-dev-sec-ops-how-?x=XOIXTl&lb_email=` (`x=XOIXTl` = content track ID)
    - With custom URL: `https://learn.gitlab.com/cicd/cloud-ci-tools-matur?lb_email={{lead.Email Address}}`

**Hiding Top Navigation When Adding Pages from the Marketing Site to a Track**

1. Add `?menu=hide` to the end of the asset's source URL. For example, `https://about.gitlab.com/blog/2021/04/28/devops-platform-supply-chain-attacks/?menu=hide`

*Note: for simplicity in tracking, we strongly urge you to use a custom URL slug on all tracks. [Video regarding custom URL slugs](https://www.youtube.com/watch?v=VHgR33cNeJg)

## Custom Query Strings

PathFactory's custom query string manager allows you to manage and append query strings when sharing a link to a content track or explore page.

1. Select `Organization Settings` in the dropdown menu in the top right corner.
1. Select the `Custom Query Strings` tab.
1. Create your custom query. When you save the new query string, it will be available whenever you access a content track in PathFactory and click the `Share` button or icon.

**Note:** Do not delete or edit the default query string for Marketo as that query string is an important way to integrate with PathFactory.

## Microsites

PathFactory's [Microsite Builder](https://support.pathfactory.com/kb/how-to-create-and-customize-a-microsite/) enables marketers to display multiple types of Content Tracks within a custom-designed landing page or multi-page microsite with navigation. Microsites should be used when you want to educate users about a specific topic or topics. Microsites are NOT a catchall nor a replacement for other types of landing pages. If you are unsure whether a Microsite is right for your campaign, please free to reach out in the #mktgops slack channel.

### Use Cases

- Resource center
- Event or webcast follow-up
- Personalized/co-branded resource hub

### Explore Pages vs. Microsites

Microsite builder expands on how Explore Pages are used and improves on Explore Pages with a more robust and advanced feature set.

With Microsite builder you can:

- Include more than one Content Track on a page.
- Tie multiple pages together with navigation
- Use your own custom code to add page sections and elements

### Creating a Microsite

You can request a new microsite, or an update to an existing microsite via [this issue](https://gitlab.com/gitlab-com/marketing/marketing-operations/-/issues/new?issuable_template=pathfactory_microsite_request).

Microsite templates:

- Personalized/co-branded content hub: `[Template] Partner Custom Microsite`
- Resource center: TBA
- Event or webcast follow-up: TBA

## Explore Pages

[Explore pages](https://support.pathfactory.com/kb/introduction-to-explore/) allow your visitors to quickly view all content assets in a content track. Each explore page you create is built on top of an existing target or recommend content track.

### Use Cases

- Resource center
- Event or webcast follow-up
- Co-branded resource page
- Personalized information hub

### Create an Explore Page

**Before you make an explore page ensure that you have already built a content track (target or recommended) that you will use as the base.**

1. Select `Explore` from the left navigation.
1. Click on the `Create Explore Page` button.
1. Enter a name for your explore page and select a content track to use as your base. You can either create an entirely new explore page built on an existing target or recommend content track, or clone an existing explore page.
1. Select which folder the explore page will live in, then click `Create Explore Page`. Please follow the hierarchy of folders by dept. from the content tracks.
1. The colors, fonts, imagery, and layout of your explore page can be customized in `Appearances`. Select your desired appearance from the left navigation in your explore page under `Page Settings`.
1. Under `Page Settings`, ensure that the `Search Engine Directive` is set to `No Index, No Follow`.
1. Choose your desired layout under `Layout Settings`.
1. Choose your desired content settings under `Content Settings`.
1. Be sure to test your explore page fully.

### Explore Page FAQs

**Why can't I change the background color behind my cover image?**

The cover background color only shows when the cover image is set to "Fixed Width." Because of this, the color selection square is only available when "Fixed Width" has been selected.

**I don't want this header on my Explore page, how do I get rid of it?**

The header is applied to an Explore experience from the base content track you chose for the explore page. If you don't want the header on your explore page, go to the base content track and turn the header off.

**I don't like the order that my content is arranged on the Explore page; how do I move my content around?**

All changes to the content in an explore page has to be done in the base content track that the explore page is built from. This includes the order of your content, so if you want to reorder your content you have to do so in the base content track.

**Can I create a custom hero for a header on my page?**

Yes! You can add a custom hero image by navigating to `Appearances Configuration` and selecting the appearance you would like to modify. Then click on the `Explore` tab and select `cover image` for Hero layout and upoad your custom image under `Hero Image`. Make sure you click `save` on both the explore image upload and then again to save the appearance edits you have made (recommended size for a hero image is 1600x500).

## Appearances

[Appearances](https://support.pathfactory.com/kb/introduction-to-appearances/) allow you to control the look and feel of your content tracks. By creating different appearance groups you are able to quickly and easily apply different colors, fonts, and logos to content tracks without having to configure them each time you build a new track. Appearance settings allow you to control how your promoters look, select favicons for your tracks, and configure the appearance of your cookie consent messaging.

You are able to change the appearance of the following components of a content track:

1. Promoters
1. Cookie Consent and Cookie Message
1. Favicon
1. Header

[Walkthrough of appearances](https://support.pathfactory.com/kb/introduction-to-appearances/)

**Create a new appearance group**

1. Click the gear icon at the top right of the page. Select `Appearances` from the drop-down menu.
1. Click `Add Appearance`.
1. Name the appearance group.
1. Select the color of the text and the primary color by clicking on the colored boxes.
1. Change the font of the text by selecting from the drop-down menu. Click the `B` button to bold the text. Click on the `A` buttons to change the text size.
1. When you are done making changes click `Add Appearance`.
1. Once you've created your `Appearance` groups, you can apply this styling to any of your content tracks. Simply select the appearance group from the drop-down menu under `Experience Settings`.

## PathFactory Localization

The [Languages feature](https://support.pathfactory.com/kb/introduction-to-languages/) gives you complete control over the text displayed to visitors on your promoters within content tracks and on website promoters. This feature also allows you to create language groups for languages other than English, and to customize the text that will be displayed for those languages.

There is no native integration between [Smartling](/handbook/marketing/localization/smartling) and PathFactory. To create a new language configuration in PathFactory and submit the default English source text available in PathFactory's language configuration menu, you must create a CSV. You can only include/exclude columns for translation in CSV. [See the help center article](https://help.smartling.com/hc/en-us/articles/360008000593-CSV-Files) for more info on formatting CSV files to submit for translation.

1. We currently have English, French, German, Korean, and Japanese configurations for `Languages`.
1. [Languages PathFactory currently supports](https://support.pathfactory.com/kb/using-languages/)
1. [Asset types (content types) support localization](https://support.pathfactory.com/kb/2020-release-notes-release-f/)
1. Explore Pages now have a dedicated tab within Language Settings where you can set localized text for the Featured Label, Search Button Title, Search Input Field Placeholder, Filter By Content Type Title, and Filter By Topic Title. [See more info](https://support.pathfactory.com/kb/2020-release-notes-release-e/).
1. You can see a list of the number of assets by language in the content library using the content tag filters.

### Create a New Language Config

1. In PathFactory, click the gear icon in the top right navigation and select `Languages` under `User Experience`.
1. Click the `Add Language` button in the top right or in the left sidebar under the other language configurations.
1. Select the language from the drop down menu.
1. If there are sections of the langauge configuration that are not translated in your selected language, [please open an issue](https://gitlab.com/gitlab-com/marketing/marketing-operations/-/issues/new?issuable_template=pathfactory_request).

## PathFactory Tracking

### PathFactory Webhook

Webhooks allow PathFactory to automatically connect with a third party system and send data every time someone visits or interacts with a PathFactory experience. There are 3 types of PathFactory webhooks (form capture, visitor session, visitor activity).

We currently use the `Visitor Session Webhook` to connect to Marketo. The `Visitor session` webhook is triggered off of session data. A `visitor session` begins when a visitor arrives on a content track and ends when that visitor has stopped engaging with content for thirty minutes. This webhook is triggered when a visitor session ends. This means that the webhook will trigger and send data to Marketo thirty minutes after the visitor has finished engaging with content. The data sent though this webhook provides an overview of the level of engagement the visitor had with your content track and the content assets inside them during the session.

### PathFactory Scoring

PathFactory applies a score to a person based on how much time they spent viewing an asset by its content type. The PathFactory score is incorporated into the [Behavior score in Marketo](/handbook/marketing/marketing-operations/marketo/#behavior-scoring).

| Content Type | Content Engagement Score | Engagement Time Threshold (seconds) |
| ------ | ------ | ------ |
| Analyst report | 1 | 120 |
| Assessment | 1 | 60 |
| Case Study | 1 | 45 |
| Data sheet | 1 | 45 |
| Demo | 1 | 60 |
| Infographic | 1 | 15 |
| Landing page | 1 | 45 |
| Presentation | 1 | 120 |
| Pricing | 1 | 30 |
| Product Article | 1 | 60 |
| Research report | 1 | 120 |
| Solution Article | 1 | 90 |
| Technical Blog Post | 1 | 60 |
| Testimonials | 1 | 30 |
| Thought leadership Blog Post | 1 | 60 |
| Topic Article | 1 | 120 |
| Video | 1 | 60 |
| Webcast | 1 | 600 |
| Whitepaper | 1 | 60 |
| eBook | 1 | 60 |

### Bizible

External forms in PathFactory will apply a Bizible touchpoints using JavaScript.

`MOps: Form Submit-Bizible`: Applies a Bizible touchpoint upon form submit within a PathFactory track

Learn more about [Bizible attribution with PathFactory](/handbook/marketing/marketing-operations/bizible/#amm-attribution-with-pathfactory)

## Custom PathFactory Fields

There are custom PathFactory fields available in Salesforce and Marketo.

| **Field Name** | **Purpose** |
| ---------- | ------- |
| PathFactory Asset Type | A tag to help categorize types of content (whitepaper, video, eBook, etc) |
| PathFactory Assets Viewed | Cumulative number of assets viewed. **This is not associated to time consumed! See Content Count for difference** |
| PathFactory Content Count | Cumulative count of assets consumed. Example: if person consumes 2 whitepapers, 1 video and blog post for _minimum of 20 seconds each_ in a **single session** this field would show 4. |
| PathFactory Content Engagement Threshold | The engagement threshold time setting (in seconds) of the content asset. |
| PathFactory Content Journey | Shows users path through a PathFactory experience (next asset viewed from previous asset based on slug) |
| PathFactory Content Language | The language of the content asset. |
| PathFactory Content List | Cumulative list of each assets content id/slug for each asset consumed. |
| PathFactory Content Slug | The custom slug of the content asset. |
| PathFactory Content Source URL | The URL of the underlying source content of the content asset. |
| PathFactory Content Title | The public title of the content asset. |
| PathFactory Content URL | The current public URL of the asset being rendered in the content track. |
| PathFactory Engagement Score | Each asset in content library can be assigned an engagement score; this score is passed from PF to SFDC and used to determine meaningful engagement with content. |
| PathFactory Engagement Time | Cumulative time a person spends consuming assets in session. |
| PathFactory Experience Name | The PathFactory track name - [more details](#content-tracks) |
| PathFactory External ID | A non-unique ID that can be added to tracks &/or assets, which can be leveraged to organize content and configure it in Marketing Automation Platform (i.e Marketo) |
| PathFactory Funnel State | Each asset is tagged with stage of funnel most applicable to asset - Top of Funnel, Middle of Funnel or Bottom of Funnel |
| PathFactory Query String | Returns any values captured by a query string which you have added to the content experience URL. |
| PathFactory Query String Value | The value of a key in the query string. |
| PathFactory Topic List | Assets are tagged by **topic**. This is manually set & aligns with the [tracking content](#content-tracks) list. |
| PathFactory Track Custom URL | The custom URL of the content track. |
| PathFactory Track ID | The automatically generated PathFactory ID of the content track. |

## PathFactory Analytics

There are a variety of analytics and reports available in PathFactory that show the overall effectiveness of content. See more info [here](/handbook/marketing/marketing-operations/pathfactory/pathfactory-analytics).

## About iFrames

An iframe, or inline frame, is a tag `<iframe> </iframe>` that is used to embed an HTML document inside another HTML document on a website. The iframe HTML element can be used to insert content from another source, such as an advertisement, into a web page.

PathFactory uses iframes to serve content inside content tracks. Some web pages have restrictions that prevent their content from displaying in an iframe.

- [About iFrame Blocking](https://support.pathfactory.com/kb/about-iframe-blocking/)

## Google Chrome Extension

The [Google Chrome Extension for PathFactory](https://support.pathfactory.com/kb/chrome-extension-faq/) lets PathFactory users share content tracks and explore pages via Gmail. This functionality lets you embed content thumbnails and titles when sending emails using Gmail. [See FAQ in The Nook](https://support.pathfactory.com/kb/chrome-extension-faq/).

### How to install

1. Download the PathFactory Chrome extension [here](https://chrome.google.com/webstore/detail/pathfactory-chrome-extens/mhhpkoilfamiipddihngolbcjboodcjf). Once you download the app, the PathFactory logo will appear in the top right corner of your Chrome address bar.
1. The PathFactory icon in your browser will appear greyed out unless you are in Gmail. Click the PathFactory icon when in the Gmail tab of your Google Chrome browser.
1. Sign in with your Google credentials.

### How to include PathFactory content in Gmail

1. Compose a new email in Gmail.
1. After composing your message, click the PathFactory icon next to the `Send` button.
1. Navigate to the desired content track or content asset using the folder system. Use the search bar to find a specific track or content asset, and/or the filter to find content with specific topics.
1. There are two ways for you to include content in your email:
   - Embed content thumbnails in an email: select a content asset, then click the `Insert` in the bottom right.
   - Hyperlink to either a content track or to a specific content asset within a track: click `Copy Link` next to the content track or content asset. Close the modal to return to the email, select the text you want to link from, click the `Insert Link` button, then paste the copied link.

Only `Admins` can enabled content tracks in the organization settings for use in the Chrome extension. Open an issue in the marketing operations project if you would like a specific content track enabled.

### Tracking

The PathFactory Google Chrome Extension will only de-anonymize users who view content sent in emails if the following is true:

1. The email is only sent to 1 recipient
   - This means only 1 recipient in total, if using To, CC, or BCC
1. You use the Embed content thumbnail option (not the copy link option)

## Access Protection

[Access protection](https://support.pathfactory.com/kb/access-protection-set-up-and-configuration/) protects content and events so only a select group of people can access it, based on them having a valid email address or email domain based on an _allowed list_. This allows you to share more confidential information with prospects, customers and employees in a content track or a VEX Event without the worry of someone viewing it who shouldn't be.

### Set Up Access Protection

1. Select the cog menu, and select `Access Protection`.
1. Select an existing group you wish to modify or create a new group. Each group is an _allowed list_ that you can apply to experiences you build in PathFactory. You can apply one or more groups as _allowed lists_ to specific content tracks or Explore pages. Ensure the name and description of the group is clear for other users.
1. Add the email addresses or email domains of the individuals you would like to grant access to. You can do this by manually typing it in or pasting a comma or space separated list into the input field.
1. Press enter to lock them in and then press `Add Email` to save. You can edit or delete these values at any point.

**Note:** Anyone who has an email address in the Domains list or the Email Address list will be able to access the content.

### Localized Access Protection

1. In the cog menu, click `Languages`.
1. Select the language group on the side and navigate to `Access Protection`.
1. Configure all the messages a user might receive when access protection is applied to a track:
   - **Title:** The title a visitor will see when they try to access a protected track
   - **Email Success Message:** The message a visitor will see when they have entered an email address that is in the list of email address/domains entered in the group
   - **Email Failed Message:** The message a visitor will see when they enter an email address that doesn't exist in the group list
   - **Email Confirmed Message:** The message a visitor will see when they have already gained access to the track and need to go to their email to click the link to access
   - **Email Instruction Message:** The message a visitor will see when they try to access a protected track
   - **Email Body Content:** The message a visitor will get in the email they receive for successfully gaining access to the track
   - **Helper Message:** The message that appears when a visitor is trying to access a track under the button to help them through the process

**Note:** These messages willl apply for all users who use access protection in PathFactory. Ensure the messages are generic to apply to all use cases.

### Change Access Protection Appearance

1. In the cog menu, navigate to the `Appearances` tab.
1. Select the appearance your content track will be using.
1. Under the `General` tab, configure the styling that will apply when someone is trying to access the content track. The fonts and colors will apply to messages within the windows that appear while trying to gain access to the content track, and the logo configured here is also displayed in the first message someone sees when they try to gain access.

### Adding Access Protection to a Content Track

1. Navigate to your content track.
1. In the track settings on the left-hand side, set the language and access protection applicable for that track.

### How Access Protection Works

1. When someone tries to access the content track, they will be prompted to enter their email address.
1. When they submit an email address which is in the group, they will get the confirmation message and will need to navigate to their email inbox where they will find an email from support (`support@pathfactory.com`) with the link to access the content track.
1. The visitor must click this link to validate that they are the owner of the email address. Once they click the link in the email they will gain access to the content track.
1. If they enter an email address that is not in the access protection group(s) you've selected, they will get the warning message you set in the configuration and will have the ability to try again.
