---
title: "YouTube uses and access"
description: "We use YouTube as our single source of truth for video content including live streaming group conversations, marketing videos, demos, and more."
---

## Channels

There are two YouTube channels we use at GitLab:

1. [Branded](https://www.youtube.com/channel/UCnMGQ8QHMAnVIsI3xJrihhg): used for content intended for people in the wider community, including marketing and event content, customer, community and user stories, employment branding, and polished sales videos and demos. For example [our GitLab infomercial](https://www.youtube.com/watch?v=gzYTZhJlHoI).
1. [Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A/): used for content intended for team and community members, including (but not limited to) team meetings, discussions, monthly release kick-offs, office hours, CEO 101 meetings, and casual demos. For example [a weekly meeting of the Plan group](https://www.youtube.com/watch?v=xXGAcFyBupA).
1. [Community coders](https://www.youtube.com/channel/UCVxPq_cVcZ5-ga9OTHKmuOg): A **community run channel**, used for content intended for team and community members, including (but not limited to) community coding and pairing sessions.

Everything posted to our **Branded** channel should pass through digital production for quality control on branding and production standards. If you are wondering if your video should go on the Branded channel, reach out to the [Digital Production team in Slack](https://gitlab.slack.com/archives/C01LRUKFQTB).

## Public or Private Streaming

Everyone within the GitLab team is encouraged to live stream their meetings and events on GitLab Unfiltered. First time livestreaming? Find out how below!

### Why livestream?

We prefer livestreaming over uploading because:

1. it allows more people to participate in real-time.
1. You don't have to upload the video to YouTube later on (extra step).
1. You can't forget about uploading the video.
1. It is clear to all participants that the content will be public.

But it can happen that you're not in a livestream and something interesting comes up.
In that case, you can [upload it to YouTube](#uploading-conversations-to-youtube).

### Considerations for livestreams

1. Please remember to [follow the guidelines on starting a recorded video](/handbook/tools-and-tips/zoom/#recording-in-zoom).
1. If you're not a host, you can't livestream direct from zoom, but the current host can promote another attendee to host.
1. If there is more than one host for the meeting **the host that joins the meeting first** is the only host that can livestream direct from zoom. From the Zoom meeting, the host can promotion someone else to host if another team member has been designated to start the live stream. Instructions to change the host:
    - Host will mover over the name of the participant you are passing host controls to
    - Select 'More'
    - Click 'Make Host' and select 'Yes'
    - The new host will now have the ability to livestream the call from Zoom
1. Generally, for a livestream, it's helpful to have a separate person handling [promoting people to panelist](https://support.zoom.us/hc/en-us/articles/115004834466-Managing-Participants-in-Webinar).
1. To improve accessibility, [enable live transcription](/handbook/tools-and-tips/zoom/#enable-captions-and-live-transcription).
1. **Please don't include any confidential information in the description of your YouTube video since there is a bug that can cause [private video descriptions to propagate over to public ones](https://gitlab.com/gitlab-com/business-ops/team-member-enablement/issue-tracker/-/issues/809)**

### Livestream with Zoom

1. Ensure you have access to the GitLab Unfiltered YouTube Channel. Check this by confirming you can sign in with the [GitLab Unfiltered Account](/handbook/marketing/marketing-operations/youtube/#unable-to-view-a-video-on-youtube). If you cannot access private videos on GitLab Unfiltered follow the [Access Instructions](/handbook/marketing/marketing-operations/youtube/#access) and double check that the user you are signed in with at the top left-hand corner is GitLab Unfiltered and not your work or personal email address.

1. Configure your Zoom [advanced meeting options](https://zoom.us/profile/setting#advanced_meeting_options) to enable livestreaming for YouTube.

![click the more button](/handbook/marketing/marketing-operations/youtube/zoom_livestream_settings.png)

1. Click the \[ More ] button and click `Live on YouTube`

![click the more button](/handbook/marketing/marketing-operations/youtube/zoom_live_on_youtube.png)

1. Select the `GitLab Unfiltered` or `GitLab`

![choose your account](/handbook/marketing/marketing-operations/youtube/choose_your_account.png)

1. Grant permissions to the YouTube account by clicking the `[Allow]` button

![grant permissions](/handbook/marketing/marketing-operations/youtube/grant_permissions.png)

1. Follow the instructions for [starting a recorded video](/handbook/tools-and-tips/zoom/#recording-in-zoom).

![configure stream](/handbook/marketing/marketing-operations/youtube/stream_settings.png)

1. Click the down arrow next to "Live on YouTube" in the top left once the streaming has begun. Then click "Copy Streaming Link" and paste in the agenda for easy reference post meeting.

![stream link](/handbook/marketing/marketing-operations/youtube/youtube-stream-link.jpg)

#### Video walkthough of how to Livestream to YouTube

The following 5-minute video shows how to start a livestream from a Zoom Meeting to YouTube Unfiltered.

<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/mWWWdbS2q9U" frameborder="0" allowfullscreen="true"> </iframe>
</figure>

If you receive a permission error when attempting to start a livestream (i.e. "Please grant necessary privilege for live streaming"), you may need to first select your `user@gitlab.com` account in step 4 above. It will prompt you to grant permissions, and you should do so. After that, return to step 3 but this time select GitLab / GitLab Unfiltered at step 4. If the problem persists, reach out in #it-help.

### Livestream with OBS

1. Install and launch [OBS Studio](https://obsproject.com/download)

1. Allow OBS to automatically configure your settings:
    ![OBS Auto-Config](/handbook/marketing/marketing-operations/youtube/obs_run_autoconfig.png)

1. Accept the recommended video settings:
    ![OBS Recommended Settings](/handbook/marketing/marketing-operations/youtube/obs_default_video_settings.png)

1. Select "Custom" service and configure OBS to livestream to [GitLab's Unfiltered channel](https://www.youtube.com/live_dashboard?nv=1#):
    ![OBS Configure Service](/handbook/marketing/marketing-operations/youtube/obs_configure_stream.png)

1. Add your webcam as a "Video Capture Device" from the Sources tool:
    ![OBS Add Webcam](/handbook/marketing/marketing-operations/youtube/obs_video_source.png)

## Post everything

We post everything that doesn't contain confidential information to YouTube.
We found that it helps with:

1. **Hiring** because candidates can get a feel for the company by seeing meetings.
1. **Retention** because sharing reinforces our value of transparency.
1. **Community** because people feel more part of what is happening at the company.
1. **Sales** because people see our training materials they sell themselves.
1. **Enablement** because people can find detailed content about certain subjects.
1. **Awareness** because lots of time is spent on YouTube and our videos get lots of views in aggregate.
1. **Training** because content on YouTube is easier to consume even for team members, see [why not Google Drive](#why-not-google-drive)

## No quality bar

You don't need to be worried that something is not of the high enough quality because:

1. The [GitLab Unfiltered YouTube account](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A/) is our casual space for communicating and sharing with the public. Content on the Unfiltered channel includes, but is not limited to, team meetings, discussions, monthly release kick-offs, office hours, CEO 101 meetings, and informal demos.
1. Algorithms will ensure that a video will be distributed to the right-sized audience.
1. We can embed videos if and where they are relevant, for example in docs.
1. Enhance videos later if we need to ([trim it so it starts immediately](https://support.google.com/youtube/answer/9057455?hl=en), add transcript, extensive description, links to relevant materials).
1. Follow up later if we need to (rerecord, do an interview).

## No extra work

Creating content for the Unfiltered channel shouldn't be extra work.
You should do what you normally do.
But when a meeting is possibly interesting for more people, make it a livestream for the Unfiltered channel.
Or when you start talking about something possibly relevant to more people, hit the record button.

## Make private quickly

In case there are any concerns raised about a video on the Unfiltered channel, everyone has the authority to make it private.
You don't have to wait for any permission, just go to the channel specific YouTube Studio, [here is the one for unfiltered](https://studio.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A/videos/upload) and mark the video private.
Please note that there is another tab for live videos.
If you mark a video private when it doesn't need to be, it is be easy to undo: simply mark the video public.

### Don't share secrets

Secrets (e.g. access tokens, private keys, passwords, and credentials to systems running on GitLab infrastructure) and GitLab team member personal data (phone numbers, home address) should never be shared in public. Any video that exposes secrets or team member personal data should not be shared as a public YouTube recording.

Similarly, internal-only documents and private or confidential issues should not be shared publicly in YouTube videos.

If a video contains secrets or sensitive information:

1. Do not publish the video on YouTube or any other public platform.
2. Immediately revoke any secrets that were exposed in the video.
3. For other sensitive information like personal data, redact the information using the [Blur feature in YouTube Studio](https://support.google.com/youtube/answer/9057652?hl=en).
4. Only after all secrets have been revoked and sensitive information redacted, you may proceed with publishing the video.

Remember that blurring is not a substitute for revoking exposed secrets. Always prioritize revoking secrets over relying solely on blurring.

If a video containing secrets or non-public information is accidentally uploaded to the Unfiltered channel, [make it private quickly](#make-private-quickly) and use `/security` in Slack to [engage the security engineer on call](/handbook/security/security-operations/sirt/engaging-security-on-call/#engage-the-security-engineer-on-call) to follow up on the leak.
Videos which initially exposed secrets or internal information can be made public again only after ensuring that all secrets have been revoked and sensitive information redacted.

## Why not Google Drive

Google Drive is not intended to process video distribution and, as a result, lengthy uploading and processing times are common. Google drive can create a number of issues including the following:

1. Long upload times (in some cases up to 10 hours for longer content) that risk failing before completion.
1. Extended processing time, as Google Drive is not intended to quickly turn around video for playback.
1. Compromised playback quality.
1. Not inclusive (for example, no caption support)
1. Not indexed for searching.
1. Less transparent to both other employees and to the public.
1. Difficult to view across multiple devices.
1. No support for other critical features such as playlist, chaptering, descriptions, embedding, or time codes.

Always use YouTube and never use Google Drive, even for [private videos](#visibility), because YouTube videos:

1. are streamed [more reliably](https://peering.google.com/#/infrastructure).
1. have mouse-over thumbnails.
1. can be played at a higher speed.
1. can be fast forwarded and rewound in 10-second blocks.
1. can be time-shifted by adding them to a watch later list.
1. can be embedded, for example in the handbook.
1. restart at the right spot after being reloaded.
1. can be easily viewed on other devices, like TVs or streaming devices, with YouTube support.
1. allow links to a [specific time in the video](https://www.h3xed.com/web-and-internet/link-to-a-specific-time-in-a-youtube-video).
1. can have subtitles added automatically.
1. are [zero rated by some mobile providers](https://www.t-mobile.com/tv-streaming/binge-on)
1. will be served to people when it is relevant, automatically, since YouTube is a distribution channel.
1. allows anyone to contribute by leaving comments.
1. public videos show up in Google search.
1. easy to make public if the video is suitable for that.
1. have playlists that allow for better organization of the video content.
1. show the number of views, so you can see what resonates
1. have the ability to comment, so people can contribute
1. have voting so you can review what videos aren't meeting expectations

## Visibility

There are three types of visibility:

1. Main
2. Public
3. Private

The level of visibility should be displayed clearly in the titles of calendar invites.
For example, when you do a livestream to the public channel say: "Public stream" at the start of the invite.
You can skip live in livestream since every stream is live.
Do not say Unfiltered stream since it is ambiguous.
Do not say just livestream since people don't know what the level of access is.

We don't post:

1. Unlisted videos (see the "[never unlisted](#never-unlisted)" section below).
2. Private videos on our branded channel, all videos on that channel are intended for a wider audience.
3. Use Google Drive for any video, since it has [many drawbacks](#why-not-google-drive).

### Never unlisted

We never post [unlisted](https://support.google.com/youtube/answer/157177#zippy=%2Cunlisted-videos) videos on any channel: it is too insecure for sensitive materials and not findable enough for public materials.
Sometimes, some videos are still posted as unlisted, they can be spotted with this [link](https://studio.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A/videos/upload?filter=%5B%7B%22name%22%3A%22VISIBILITY%22%2C%22value%22%3A%5B%22UNLISTED%22%5D%7D%5D&sort=%7B%22columnType%22%3A%22date%22%2C%22sortOrder%22%3A%22DESCENDING%22%7D) (while using the `GitLab Unfiltered` account).
You can change the visibility of videos by clicking on the `Details` buttons when you hover a video in the list linked above.

## Unable to view a video on YouTube

If you get a "Video unavailable This video is private." error on youtube, the error may be caused because the video is private to GitLab Unfiltered and you are accessing the video with your individual YouTube account.
In order to see the video,

1. Click your photo or icon in the upper right corner of YouTube.

1. Then Click > Switch Account

![Switch-Account](/handbook/marketing/marketing-operations/youtube/Switch_account.png)

1. Now Select > GitLab Unfiltered. Do not select the account with your name. If GitLab Unfiltered is not an option, see [Access](/handbook/marketing/marketing-operations/youtube/#access)

![Select-User](/handbook/marketing/marketing-operations/youtube/YouTube_account.png)

1. Once you are on GitLab unfiltered, **reload** the page and you can view the video

Check out [this video](https://www.youtube.com/watch?v=dZtCuOf5aGk) for a visual walk through of how to access private videos on GitLab Unfiltered.

## Access

1. GitLab branded channel: To request access, create a [Single Person Access Request issue](/handbook/it/end-user-services/onboarding-access-requests/access-requests/#individual-or-bulk-access-request) and assign the listed provisioner (column G) from the [Tech Stack YAML](https://gitlab.com/gitlab-com/www-gitlab-com/-/blob/master/data/tech_stack.yml).
1. GitLab Unfiltered: Everyone should get access to YouTube Unfiltered during onboarding. If you do not see an invitation in your Inbox, please check the [Pending Invitations](https://myaccount.google.com/brandaccounts) section of your Google Workspace account. If your invitation is not there, please request a new invitation with the People Connect Team via HelpLab.

For People Connect troubleshooting:

1. If a team member reaches out that they have not received their GitLab Unfiltered invite, resend the invite via the `Manage Permissions`
1. Should the team member still not see the invite under `Pending Invitations`, revoke the original invite by doing `command f` in the `Manage Permissions` section for the team members email address. You can revoke by clicking the `X` next to the email address.
1. Once you have revoked the invite, close the YouTube Unfiltered page and reopen.
1. Once reopen, select `Manage Permissions` and reinvite the team member by clicking on the `Add` option and enter the team members email address.
1. This should now appear in the `Pending Invitations` section [here](https://myaccount.google.com/brandaccounts).

## Commenting

Please remember that if you find a user comment to respond to on one of our channel videos, that it will be perceived as official communication from the company. **In almost all cases, unless your job specifically requires you to interact in a community manager role or capacity, it is best to switch to a personal account prior to engaging with a video or user on YouTube.**

Consider switching to your personal account, responding to the comment, and identifying yourself as a GitLab employee offering help.

Please do not comment on videos from non-GitLab YouTube accounts using any company related YouTube profile. Commenting as GitLab is reserved for responses to our owned videos on our channels only.

## Subscribing to Channels

The GitLab Unfiltered YouTube account **should not** be subscribed to any channels except:

- [`@Gitlab`](https://www.youtube.com/@Gitlab).

## House cleaning

The GitLab Unfiltered YouTube account is a shared space. Sometimes team members might accidentally [comment](#commenting) or [subscribe to channels](#subscribing-to-channels) thinking they are on a personal account.

If you see a channel subscription or comment that violates the rules of this handbook, please take a bias-for-action to keep the GitLab Unfiltered
YouTube account pristine. Delete any accidental channel subscription or comment to return the YouTube account to a pristine state. If you are unable
to remove the relevant comment or subscription, please notify the People Connect Team immediately via HelpLab.

## Organizing

Our YouTube channels contain a lot of content.
As a result, it can often be hard to find videos once they are published, particularly on the Unfiltered channel.
Make liberal use of [tags](https://support.google.com/youtube/answer/146402) and [playlists](https://support.google.com/youtube/answer/57792) to organize the video content you publish.
For published recordings of recurring meetings, which should be posted on the Unfiltered channel, please search for a playlist to put the video in. If there is no applicable playlist. please create one. You can also create a playlist that would automatically add new videos containing certain text in their titles, descriptions or tags to avoid manual steps ([instructions](https://support.google.com/youtube/answer/6084053?hl=en))

## Audience on YouTube

When publishing, YouTube will ask if the content is made for kids. GitLab content should be marked as "No, it's not made for kids".

## Never call it a livestream or just a recording

It is essential that we always know if something is public or private.
Always mention that in the calendar invite title.

Therefore say:

- Public stream
- Private stream
- Public recording
- Private recording

Never say: livestream or recording since those are ambiguous. See [top misused terms](/handbook/communication/top-misused-terms/#livestream).

### What if your aren't sure whether the stream is Public or Private?

There are some recordings where it is not clear whether they should be Private or Public or they require a review by the Legal team before posting publicly on YouTube. It would be disingenuous to tell our team that the recording is Private and then change the recording to Public.  In this scenario, we should state that this a `Reviewed Stream` or a `Reviewed Recording`.  This stream will be initially Private and upon Legal review could be changed to Public.

## Starting a Livestream

The below instructions apply to livestreams to YouTube.

1. The moderator asks host, 'I am getting ready to start the public/private stream. Are you ready to begin speaking as soon as you see the YouTube Icon in the top left corner of Zoom?'. Please make sure you mention public or private.
1. After the hosts confirms the Moderator clicks `Live to YouTube` and start the livestream.
1. The host should do an introduction stating who they are, what their role is, and what the meeting is about, e.g. "I am Jane Doe, the VP of Widget Production, and today's Group Conversation is about the molding phase of widget production."
1. Please note that if the recording starts a 'this meeting is being recorded' message the host should talk over that because otherwise the recorded video will needed editing to prevent an awkward pause. Livestreaming doesn't trigger this message, only recording does.

### Useful links

- [My Live Events: schedule and review upcoming live events](https://www.youtube.com/my_live_events)
- [YouTube live streaming introduction page](https://support.google.com/youtube/answer/2474026?hl=en) - Here you can check if your channel meets all requirements for live streaming
- [YouTube tutorial on setting up a live stream](https://support.google.com/youtube/answer/2853700?hl=en) - If you need extra help or information on setting up a YouTube live stream in general
- [YouTube live dashboard](https://www.youtube.com/live_dashboard#) - Here you can find your encoder setup variables, manage your stream and see your chat

## Uploading conversations to YouTube

<iframe width="560" height="315" src="https://www.youtube.com/embed/xGwX9zjNr2E?rel=0" frameborder="0" allow="autoplay; encrypted-media" allowfullscreen></iframe>

1. Default to [public or private streaming](#public-or-private-streaming) instead of uploading.
1. Please follow the process for [starting the recorded video](/handbook/tools-and-tips/zoom/#recording-in-zoom).
1. Unless stated or arranged otherwise, our expected behavior is that the meeting organizer is responsible for distributing the video after the meeting.
1. Log in to the [Zoom](https://zoom.us/) account of the meeting and go to the menu on the right and choose "My Recordings" (it can take up to 30 minutes before the recording is available to be shared).
1. Select the meeting and download the recording to your computer (if you can't find the recording because it was a while ago check "Trash" in the menu on the top left and "Recover" the recording).
1. Go to the [YouTube upload page](https://www.youtube.com/upload) and log into the [channel](#channels). If you're logged into your personal YouTube account, you may need to first log into your GitLab YouTube account to access the channel. If you're already logged into your GitLab YouTube account and have access to the channel, you need to switch accounts to that channel. To switch accounts, click on the account icon in the top right corner and then click "Switch account".
1. Drag and drop your recording into the window to upload it. Keep the privacy dropdown on the default 'Public' setting (unless there is confidential material). Use the dropdown menu to set the video to private if it the video contains confidential material.
1. While it's uploading, edit the title and description. Place "Confidential:" at the beginning of the video's title if the video will be kept private on our YouTube channel.
1. Be sure to include relevant links (for example a handbook page or presentation) in the description, and add the video to any relevant playlists.
1. In the "Comments and ratings" section, select "Hold potentially inappropriate comments for review" - this allows all valid comments to be posted, allowing everyone to contribute, but holds spam or derogatory comments for review. There may be videos where we do not wish to open the comments section or need to moderate each comment. If you think your video would potentially need to go this route, add your question to the #marketing Slack channel.
1. When it is done uploading, press publish, then click on the Embed tab and copy the code, and insert that in the relevant part of the handbook or documentation.
1. After uploading a video to the GitLab Unfiltered channel, be sure to add a link to the new video in the #content-updates channel in Slack.

## Don't worry about the quality

1. There is no minimum quality, so please share it on our [GitLab Unfiltered YouTube channel](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A?view_as=subscriber), as long as there is nothing inappropriate or confidential.
1. Everyone at the company probably has at least one conversation every week that is relevant to more people, so please share it.
1. We always list videos publicly instead of [having them unlisted](#never-unlisted), unless there is confidential material. This allows more people to find the content. If the material is confidential, set the video to private.
1. Don't worry about whether or not it will be interesting to absolutely everyone. Just give it a descriptive title so people know what it is about, and let _them_ decide whether or not they should watch it.
1. Make sure that all participants are aware that you're recording.
1. You don't have to be sure it is interesting and OK to share when you start recording; you can make that decision after the fact.
1. If you record an in-person conversation with your mobile phone please hold your phone in landscape (horizontal) mode.

## Advanced setups

Depending on your needs, you might want use software to provide overlays and/or reroute audio.
99% of the people at GitLab don't use this, but see below for instructions if you do want to use it.

### Encoder

- [OBS Studio Win/Mac/Lin Open Source](https://obsproject.com/) or install with 'brew install --cask obs' on mac

### Audio Rerouting

- [Soundflower Mac Open Source](https://github.com/mattingalls/Soundflower) or install with `brew install --cask soundflower`
- [Loopback Mac Closed Source](https://www.rogueamoeba.com/loopback/) - Great closed source alternative
- [Windows alternatives](https://www.reddit.com/r/audioengineering/comments/3geqse/soundflower_alternative_on_windows/)
- [Linux alternatives](https://askubuntu.com/questions/602593/whats-a-good-soundflower-replacement-for-ubuntu)

### Setup

- Install both OBS Studio (encoder) and an audio rerouting software.
- [Check](https://support.google.com/youtube/answer/2474026?hl=en) if your channel is ready to live stream.
- Copy your encoder variables en setup your live streaming environment with the [YouTube live dashboard](https://www.youtube.com/live_dashboard#)
- Open up OBS Studio and open preferences
- Input your encoder variables under "Stream"

![obs studio preferences](/handbook/marketing/marketing-operations/youtube/OBS_Studio_Stream.jpeg)

- Configure your to-be-recorded software's audio to be rerouted to an alternative audio source/output.
- Under "Audio" in OBS Studio preferences, select the alternative audio source/output under Mic/Auxiliary Device 2. See [this page](https://code-zest.blogspot.nl/2016/02/setting-up-obs-with-audio-output-in-mac.html) for more help
- Under "Video" select your preferred resolution and fps settings. Please take note that these should optimally reflect video aspect ratio such as `1920x1080`.
- Optionally you can set up some output options under "Output"
- In the normal window of OBS Studio you should now see 2 audio sliders, including "Mic/Aux 2". Configure these to your liking.
- Select "Start Streaming": _You are now streaming_
- Go to your [YouTube live dashboard](https://www.youtube.com/live_dashboard#) to see your live stream and interact with your viewers.

## When to record and publish to YouTube

<iframe width="560" height="315" src="https://www.youtube.com/embed/RB8OC70RAfo?rel=0" frameborder="0" allow="autoplay; encrypted-media" allowfullscreen></iframe>
