---
title: Team Member Social Media Policy
description: This is the GitLab employee social media policy
twitter_image: "/images/opengraph/handbook/social-marketing/team-member-social-media-policy.png"
twitter_image_alt: GitLab Social Media Policy

---

## Introduction

We recognize that many team members engage in social media activity. This policy establishes a set of rules and guidelines for any activity and participation on social media channels when commenting about GitLab or GitLab-related topics.

**These rules are intended to be adaptable to the changes in technology and norms of online communication and behavior and may be amended by GitLab at any time, for any reason, without notice to team members. However, we will work to be as transparent as possible when communicating changes, what those changes are, and when they are expected to go into effect.**

This policy also applies to social media activity when on or off duty, while using the Company's or personal electronic resources, and whether the team member posts anonymously or using a pseudonym.

Be diligent, and if it's questionable, don't say it. You are personally responsible for the social posts, likes and shares, and replies you post on social media while representing GitLab. Everything you publish is publicly viewable and will be available for a long time, even if redacted. Remember that you represent GitLab and our culture. When commenting on posts, please keep in mind: "Don't argue but represent".

## Social Media Policy for Team Members

You'll be asked to confirm reading this section during your onboarding to the company. We'll ask everyone to review and sign off on review in partnership with legal for existing employees.

If you've been identified as a spokesperson for the company or a specific function within GitLab, you may have unique circumstances. Please refer to your team guidelines or the communications team for more information about your work as a spokesperson and the social media policy.

### Definition of social media

The GitLab Social Media policy for team members applies to traditional social media channels, like Twitter, LinkedIn, Facebook, and Instagram, as well as "social-like" sites, like YouTube, HackerNews, Reddit, blogs (on the GitLab website, Medium, or any other online journals or diaries), message boards, forums (including the GitLab Forum, private groups or forums on public sites like Facebook Groups), and private/direct messages on public social media channels (Twitter DMs, Instagram Directs, etc.).

The term "social media" applies to any online technology in use now or in the future that enables you to send or receive information and communicate or interact with others. Any site where you can share a post or comment on a post would be considered a social media website for the purposes of this policy.

#### Exclusions for anonymous review sites

This policy is not intended to limit team members from sharing their feedback or reviews of their experiences at GitLab on sites like Glassdoor, Fishbowl, Indeed, or similar sites. While we encourage you to share feedback with your manager and the people ops team, we celebrate our value of transparency and welcome feedback from team members on these sites, as long as the feedback follows our [SAFE Framework](/handbook/legal/safe-framework/).

### All other GitLab codes of conduct and policies also apply to our social media policy

Please adhere to the [Community Code of Conduct](https://about.gitlab.com/community/contribute/code-of-conduct/), [Anti-Harrassment Policy](/handbook/people-group/anti-harassment/), which includes sexual harrassment and discrimination policies, and our [Code of Business Conduct and Ethics](https://ir.gitlab.com/static-files/7d8c7eb3-cb17-4d68-a607-1b7a1fa1c95d). These policies all apply to team member behavior within social media and in public online spaces.

#### Social Media sometimes generates press and media attention or legal questions

**Please refer all inquires to the Communications Team in the #external-comms Slack channel**

### What you should do

_Click each recommendation below for more details_

<details>
  <summary markdown='span'>
    Do disclose that you're a team member
  </summary>
If you talk about work-related matters within your job responsibility area, you must disclose your affiliation with GitLab. If you have a vested interest in something you're posting on social, point it out. You can identify yourself as a team member in your profile bio, list GitLab as your employer, or mention that you're a team member in the post itself. You can also add #LifeAtGitLab to the end of your social posts about GitLab-related topics. How you choose to disclose is up to you.
</details>

<details>
  <summary markdown='span'>
    Do state that it's your opinion
  </summary>
When commenting <b>on</b> the business, you're not commenting <b>for</b> the business. Unless authorized to speak on behalf of GitLab and through comms training. However, don't add your opinion to content from a news source that includes financial figures or forecasts. If you would like to share content that includes financial figures or a forecast, please only share it without adding your commentary. Not sure if you should share? Ask in the #safe Slack channel.
</details>

<details>
  <summary markdown='span'>
    Do protect yourself
  </summary>
Consider what information you're sharing online and how it can be used to identify you. Everyone has a different level of privacy they want to abide by, have you thought about yours? Some of the things folks opt-out of to protect their privacy include: not tagging specific locations in posts while you're still on-site, not including phone numbers or email addresses in plain text because bots sweep for contact info, and not showing the faces of their children on public channels. You aren't required to follow any of these specifics, but consider what kind of information will be available to the public when publishing on your social media profiles.
</details>

<details>
  <summary markdown='span'>
    Do act responsibly and ethically
  </summary>
Don't misrepresent yourself. If you're not a director in your role, don't say you are. Don't imply that you're a member of a team if you're not. Share your thoughts, but disclose your role. Furthermore, <a href="https://about.gitlab.com/community/contribute/code-of-conduct/">our team members are bound by the same code of conduct we provide to the community</a>.
</details>

<details>
  <summary markdown='span'>
    Do try to live our values
  </summary>
Easier said than done, but consider our values when engaging online. The same space and respect we grant each other is needed with strangers on social media.
</details>

<details>
  <summary markdown='span'>
    Do share GitLab content that is already published
  </summary>
If it's written in a blog, presented at a public conference, or simply on GitLab's website, it's publicly available to share on social media. GitLab's social media advocacy tool will have a lot of preapproved content, including links, images, and copy, available to all team members. Anything already in the public domain, posted in the #newswire Slack channel, or in the company social media advocacy tool can and should be shared freely. Some items in the #newswire Slack channel may say "shareable internal only", so please do not share those stories on social media.
</details>

#### Examples of what you should, and are encouraged, to share on social media

- GitLab [blogs](https://about.gitlab.com/blog/) and [press releases](https://about.gitlab.com/press/releases/)
- Positive news media that mentions GitLab and is shared in the #newswire Slack channel (team member adds no commentary/copy to the post) or is available to share in the social media advocacy tool (with commentary/copy to share)
- Industry reports that are publicly available and are ungated
- Videos from either our [brand](https://www.youtube.com/channel/UCnMGQ8QHMAnVIsI3xJrihhg) or [Unfiltered](https://www.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A) YouTube Channels
- Third-party articles that don't bash competitors (mentioning them or comparing GitLab and competitors is fine)
- Retweeting or sharing GitLab brand social channel posts from [Twitter](https://twitter.com/gitlab), [LinkedIn](https://www.linkedin.com/company/gitlab-com/), [Facebook](https://www.facebook.com/gitlab/), or [Instagram](https://www.instagram.com/gitlab/)
- All of the above from our eco and alliance partners
- Items that are not connected to your job or GitLab at all! Social Media is best when you bring your true-self to the mix. DevOps isn't the only thing you're interested in, so consider posting about other passions and topics.

[Learn more about what is encouraged and how GitLab helps to enable you to become great at using social media on our team member advocacy page.](/handbook/marketing/integrated-marketing/digital-strategy/social-marketing/team-member-social-advocacy/)

### It's your job to protect GitLab, our customers, and our team members

Whether you're an intern or our CEO, protecting the GitLab brand, the company, and our entire team is a part of your job description.

#### You can protect GitLab by not sharing the following data with the public on your social media profiles

_Click each recommendation below for more details_

<details>
  <summary markdown='span'>
    Don't speculate or add forward-looking statements
  </summary>

<ul>
<li>Forward-looking statements predict, project, or use future events as expectations or possibilities. Team Members mustn't speculate or add forward-looking statements to their opinions written on social media. Forward-looking statements could include company valuation, details on customer volume, subscription growth, and more. This would include forecasting, or when data is presented to argue for or against future trends. Sometimes an article from a news source will use speculative information in their story. While this is okay to share, it is not okay to share your commentary with speculative information. Not sure if it's public? Ask in the #safe Slack channel or <a href="https://handbook.gitlab.com/handbook/legal/safe-framework/">review the SAFE handbook page</a>.</li>
<li><b>Some language indicators that you're talking about forward-looking statements would be using one of the following words: "will," "may," "should," "expects," "intends," "plans," "aims," "anticipates," "believes," "estimates," "predicts," "potential," "looking to," or "continue,".</b></li>
</ul>

</details>

<details>
  <summary markdown='span'>
    Don't share customer or Team Member personal information
  </summary>

Team Members are prohibited from using social media to post or display comments about co-workers or supervisors/managers of GitLab that are knowingly false, vulgar, obscene, threatening, intimidating, disparages GitLab's products or services, depicts the team member engaging in conduct that is unlawful or in violation of GitLab's workplace policies against workplace violence or discrimination and harassment based on any protected status under federal, state or local law. Allow the team member(s) to own the decision on what is and isn't public about them.

For customers, any [customer with a published case study](https://about.gitlab.com/customers/) is available to share publicly. If you would like to share information about a customer please reach out to the customer reference team first before sharing any content on social media.

</details>

<details>
  <summary markdown='span'>
    Don't bash competitors
  </summary>
While sharing your opinion is a critical part of being authentic on social media, it's equally important to limit overly negative responses to competitor posts. We don't like trolls, and neither do our competitors. Providing constructive feedback is read very differently than trolling. Trolling occurs when you respond to social media posts with intentionally provocative or offensive messages.
</details>

<details>
  <summary markdown='span'>
    Don't share legal information
  </summary>
Never share anything to do with a legal issue, legal case, or attorneys without first checking with legal in the #legal Slack channel. Note, that if you're looking to connect on whether or not you should publicly disclose legal issues, the answer is probably a no.
</details>

<details>
  <summary markdown='span'>
    Don't share confidential information
  </summary>
<ul>
<li>Don't share information that is considered personal or GitLab proprietary confidential. If it's related to work in an issue, consider reviewing whether or not the issue was made confidential. It is inappropriate to use or disclose confidential personal information about another individual or use or disclose GitLab's proprietary confidential information in any form of social media.</li>

<li>Confidential personal information refers to information that could be used to commit identity theft such as an individual's Social Security Number, financial account numbers, driver's license number or personal medical information (including family medical history).</li>

<li>GitLab's proprietary confidential information refers to internal information regarding GitLab's finances, future business performance and business plans, business and brand strategies and information which is or relates to GitLab's trade secrets.</li>
</ul>

</details>

<details>
  <summary markdown='span'>
    Don't use third-party materials (including images, videos, or text) without permission from the owner
  </summary>
<ul>
<li>Images, videos, and text, even if posted publicly on the internet, are copyright-protected materials and should not be used without the permission of the owner.</li>

<li>If you're unable to obtain permission from the owner, hyperlink to the relevant material rather than copying it.</li>

<li>Consider using a source of permissively-licensed images, like <a href="https://unsplash.com/">unsplash.com</a>, which provides free to use materials which <a href="https://unsplash.com/license">do not require attribution</a>.</li>

<li>You can (and are encouraged to)share GitLab-made assets even if these contain third-party materials</li>

 <li>If you're unsure what's permissible, reach out to the #legal Slack channel.</li>
</ul>

</details>

<details>
  <summary markdown='span'>
    Don't create images with, or manipulate, third-party logos without the permission of the owner
  </summary>
<ul>
<li> Logos (including those indicating companies, and products and services) are registered trademarks. You must obtain the consent of the owner before using, for any purpose, any third-party logo.</li>

<li>If you're wanting to share content from GitLab's website or social channels and it has logos or trademarks from other companies, this is okay to use. The various marketing teams at GitLab are responsibile for confirming the company's use of these logos and trademarks and sharing links or images that GitLab produced does not violate this policy.</li>

<li>You can refer to other companies, or products and services, by name (without using a logo) provided that (i) the company, product or service in question could not easily be identified without using its name; and (ii) your use does not imply endorsement by, or affiliation with, the trademark owner.</li>

<li>You can (and are encouraged to)share GitLab-made assets even if these contain third-party logos</li>

<li>If you're unsure what's permissible, reach out to the #legal Slack channel.</li>
</ul>

</details>

<details>
  <summary markdown='span'>
    Don't use social media, blogs, or other digital channels for GitLab-related communications with other team members
  </summary>
<ul>
<li>While GitLab is a transparent company, we like to keep negative feedback 1:1. Team members should not discuss work-related situations in public forums. For all communications that can be public-facing, please use issues and epics and mark them as not confidential.</li>
</ul>

</details>

### Connecting with Team Members on Social Media

In case you want to connect with fellow team members of GitLab on social media, you have to keep it professional. With this communication, we would like you to consider GitLab's [Communication Guidelines](/handbook/communication/) at all times. Aligned with our [Anti-Harassment Policy](/handbook/people-group/anti-harassment/), it is expected that everyone will contribute to an inclusive and collaborative working environment and respect each other at all times.

### Mimicking the GitLab brand

Keep your identity clear on social media channels by not using the GitLab logo as your profile image, not adding GitLab to your @handle, and not adding the company name to your display names.

Upon first glance of your social media profile, there should be immense clarity that you are a team member of GitLab and not GitLab the company. Use common sense when selecting pictures and names to use. We'll always work to get profile names and visuals updated to reflect who runs the account. If the corporate marketing team comes across profiles that don't respond to these requests, we will report them for impersonating our brand.

### Unauthorized GitLab brand social media accounts

As a Team Member of GitLab, you aren't authorized to create company/brand social media profiles to use for your work. If promoting content should come from the company, you'll need to [open a request issue with the organic social team](/handbook/marketing/integrated-marketing/digital-strategy/social-marketing/admin/#requesting-social-promotion-). If the corporate marketing team encounters unauthorized profiles, they will be treated as external threats and reported for impersonation. There is no formal method for requesting new brand channels, nor is there an outline for managing to do so. It's best to use personally identified social media profiles to share your posts.

### Contests or sweepstakes on your social media profiles

As part of your role at GitLab, you may be responsible for a contest or a sweepstakes with social media elements. It's important to follow legal guidelines. Essentially, as a representative of GitLab, if you're promoting the contest on your social media channels, it will need to follow the same rules as what the GitLab brand channels will need to follow. You can [learn more about legal and contests in the handbook here](/handbook/legal/marketing-collaboration/#contests-and-sweepstakes).

### Follow website terms of use

Most social media websites/services have rules concerning the use of and activity conducted on their sites. These are sometimes referred to as "Terms of Use." Team Members must follow the established terms and conditions of use that have been established by the website, social media network, or channel and not do anything that would violate those rules.

## Ramifications of not following the social media policy

If the company finds any statements or claims that are false or misleading, or we discover an activity that does not follow the policy, we will contact you to correct the situation.

If you are consistently disregarding the social media policy, especially if you fail to disclose your relationship to GitLab, make false or misleading statements about GitLab or our products and services, GitLab retains the right to discipline, up to termination of employment with anyone that does not comply with this policy.

## Conflicts with local laws

In the event there is any conflict between this social media policy and local laws and/or regulations for your region, the local laws and/or regulations prevail over our policy and must be followed. However, if the conflict is simply because of practice or customs varying between regions, our social media policy must still be followed.

Any conduct which is impermissible under the law if expressed in any other form or forum is also impermissible if expressed through social media.

See section below for location-specific details that are necessary to review.

## Location-specific social media policy details

### United States

Confidential proprietary information does not include information lawfully acquired by non-management employees about wages, hours or other terms and conditions of employment, if used for purposes protected by Section 7 of the National Labor Relations Act such as joining or forming a union, engaging in collective bargaining, or engaging in other concerted activity for their mutual aid or protection.

GitLab will not enforce the social media policy in a manner that would interfere with team members' rights under the National Labor Relations Act to discuss the terms and conditions of employment.

### United Kingdom

You may not use data obtained in the course of your employment with GitLab in any way which breaches the provisions of the Data Protection Act 1998.

## Transform this policy into action with a social media training and certification

Take this policy and turn it into a social media certification in less than 45 minutes with the [social media 101 training and certification](/handbook/marketing/corporate-communications/resources-trainings/#social-media-101-training--certification). You'll find details on the training and what to expect [here](/handbook/marketing/corporate-communications/resources-trainings/#social-media-101-training--certification).
