---
title: Virtual Events
description: An overview of virtual events at GitLab including webcasts, virtual workshops, and external virtual events.
twitter_image: '/images/tweets/handbook-marketing.png'
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

## Overview {#overview}

At GitLab, we believe everyone can contribute. Because nearly anyone with an internet connection and a device can participate in virtual events, as a speaker or an attendee, virtual events are an important part of fulfilling that mission. While our expertise in this area is still developing, this page documents the best practices we have studied and established for virtual events at GitLab.

## Calendar {#calendar}

**To see all upcoming marketing activities, view the [All-Marketing SSoT Calendar](https://docs.google.com/spreadsheets/d/1c2V3Aj1l_UT5hEb54nczzinGUxtxswZBhZV8r9eErqM/edit#gid=571560493)**

<figure>
<iframe src="https://calendar.google.com/calendar/embed?height=600&amp;wkst=1&amp;bgcolor=%23B39DDB&amp;ctz=America%2FLos_Angeles&amp;src=Z2l0bGFiLmNvbV9uMnNibXZmMjlqczBzM3BiM2ozaHRwa3FmZ0Bncm91cC5jYWxlbmRhci5nb29nbGUuY29t&amp;src=Z2l0bGFiLmNvbV8xcXZlNmc4MWRwOTFyOWhldnRrZmQ5cjA5OEBncm91cC5jYWxlbmRhci5nb29nbGUuY29t&amp;src=Z2l0bGFiLmNvbV8xOGVqOHN0NmlxajZpYXB1NTNrajUzNHBsa0Bncm91cC5jYWxlbmRhci5nb29nbGUuY29t&amp;color=%23039BE5&amp;color=%239E69AF&amp;color=%23009688&amp;title=All%20GitLab%20Virtual%20Events&amp;showCalendars=1" style="border:solid 1px #777" width="1000" height="600" frameborder="0" scrolling="no"></iframe>
</figure>

We have 3 separate Google calendars to manage different types and platforms of virtual events in GitLab:

* [GitLab-Hosted On24 Webcasts/Workshops](https://calendar.google.com/calendar?cid=Z2l0bGFiLmNvbV8xcXZlNmc4MWRwOTFyOWhldnRrZmQ5cjA5OEBncm91cC5jYWxlbmRhci5nb29nbGUuY29t)
* [GitLab-Hosted Zoom Webcasts/Workshops](https://calendar.google.com/calendar?cid=Z2l0bGFiLmNvbV8xcXZlNmc4MWRwOTFyOWhldnRrZmQ5cjA5OEBncm91cC5jYWxlbmRhci5nb29nbGUuY29t)
* [External/Sponsored Virtual Events](https://calendar.google.com/calendar?cid=Z2l0bGFiLmNvbV8xOGVqOHN0NmlxajZpYXB1NTNrajUzNHBsa0Bncm91cC5jYWxlbmRhci5nb29nbGUuY29t)

All 3 calendars are consolidated into a single GitLab virtual events calendar view (above - calendars are not public because they contain secure login for presenters). **The purpose of the consolidated view is to help event organizer(s) minimize topic overlap with other GitLab virtual events happening around the same time and to provide executive visibility into ALL virtual events that GitLab is running/participating in.**

### Glossary of calendar event naming convention {#calendar-glossary}

* `[Hold WC Hosted] Webcast title` - GitLab hosted webcast still in planning
* `[WC Hosted] Webcast title` - Confirmed GitLab hosted webcast
* `[DR WC Hosted] Webcast title` - Dry run for GitLab hosted webcast
* `[Hold WC sponsored] Webcast title` - Sponsored webcast still in planning
* `[WC sponsored] Webcast title` - Confirmed sponsored webcast
* `[Hold VC sponsored] Conference title` - Sponsored virtual conference still in planning
* `[VC sponsored] Conference title` - Confirmed sponsored virtual conference

## Adding external virtual events into the calendar {#calendar-external-virtual-events}

The [external virtual events](https://calendar.google.com/calendar?cid=Z2l0bGFiLmNvbV8xOGVqOHN0NmlxajZpYXB1NTNrajUzNHBsa0Bncm91cC5jYWxlbmRhci5nb29nbGUuY29t) calendar will be used to log all planned and scheduled sponsored webcasts and virtual conferences. **The purpose of this calendar is to provide visibility and help the sponsoring team minimize topic overlap with other GitLab virtual events happening around the same time and to provide executive visibility into all GitLab external virtual events.**

**DRI adding to external virtual events calendar: Sponsor owner**

### Planned external virtual events {#calendar-planned-external-virtual-event}

As soon as you create the epic for the sponsored virtual event, add the event to the external virtual events calendar by creating an event on the day the sponsored virtual event will be live.Make sure to also include the link to the epic in the calendar description.

* For sponsored webcast please use the following naming convention `[Hold WC sponsored] Event title` (e.g: `[Hold WC sponsored] Securing your pipeline with GitLab and WhiteSource`).
* For sponsored virtual conferences, please use the following naming convention  `[Hold VC sponsored] Event title` (e.g: `[Hold VC sponsored] Predict 2021`).
* For executive round tables please use the following naming convention `[Hold ER sponsored] Event title` (e.g: `[Hold ER sponsored] DevOps 101`).
* For vendor arranged meetings, please use the following naming convention  `[Hold VA sponsored] Vendor Name Region` (e.g: `[Hold VA sponsored] Captive Eight APAC`).

### Confirmed external virtual events {#calendar-confirmed-external-virtual-event}

Once the sponsorship has been confirmed, go to your calendar event and remove `Hold` from the event title. **Note:** In the spirit of efficiency and to avoid creating multiple calendar invites, please include the epic or issue, add the marketing DRI, any GitLab speakers and/or attendees (SAEs, SAs, etc.), as well as any other team members who would benefit from being included in the calendar invite as this invite will provide a hold for team members participating in the event. The 3rd party sponsor will send out additional event details separately.

* For sponsored webcasts, change the event title to `[WC sponsored] Event title` (e.g: `[WC sponsored] Securing your pipeline with GitLab and WhiteSource`).
* For sponsored virtual conferences, change the event title to  `[VC sponsored] Event title` (e.g: `[VC sponsored] Predict 2021`).
* For executive round tables, change the event title to `[ER sponsored] Event title` (e.g: `[ER sponsored] DevOps 101`).
* For sponsored virtual conferences, change the event title to  `[ER sponsored] Vendor Name Region` (e.g: `[ER sponsored] Captive Eight APAC`).

## Rescheduling external virtual events

For the most up-to-date rescheduling instructions, please visit [this handbook page](/handbook/marketing/field-marketing/#rescheduling-or-canceling-events).

## Cancelling external virtual events

For the most up-to-date rescheduling instructions, please visit [this handbook page](/handbook/marketing/field-marketing/#rescheduling-or-canceling-events).

## Virtual events decision tree {#decision-tree}

We have developed a [decision tree on FigJam](https://www.figma.com/file/Imb5xNnRryAPs59A79fseu/Virtual-Events-Decision-Tree_2023-09-14_18-05-13?type=whiteboard&node-id=0%3A331&t=jxFHr7UTeRBDPXq7-1)to help you determine what type of GitLab-hosted virtual event is the best fit for you.

## Virtual event types {#types}

### Webcast {#webcast}

This is a GitLab-hosted virtual event with `Webcast` type configuration, which **requires registration** to enable Marketo sync. There are two tech platforms used for webcasts (based on the audience/goal):

* On24 (Campaigns Team): goal is net new customer acquisition, aligned to campaign motions to drive MQLs in target accounts and broader prospect database. Requires registration on On24.
* Zoom (Field Marketing): goal is to increase conversion/velocity of MQLs to SAO, and/or SAO to Closed Won, aligned to campaign motions. Capped registration at 1000 attendee, requires registration on Marketo landing page.
* We had a virtual event type called self-service events. This type has been deprecated, but you can run them as a webcast by working with either Marketing Campaigns or Field Marketing.

[Webcast handbook](/handbook/marketing/virtual-events/webcasts/)

#### Webcast Subcategory - Virtual Hands-on Workshops {#workshops}

Field Marketing runs hands-on workshops virtually. Regardless or not if there will be money spent to advertise these workshops, marketers are to use the webcast event type. A few more points to note:

* Our GitLab demo environment cannot support more than 250 people, therefore we need to be able to cap registration at no more than 400-500 people. The Self-Service option does not allow for registration to be capped. You can require approval, but Zoom doesn't allow customization of the rejection email (and it isn't clear if a rejection email is even sent).
* By using Zoom webcast for these workshops we are able to more easily track and manage the Q&A coming in from the larger audience. With the chat feature in the Self Service Zoom offering, the chat runs long and can become confusing.
* There is a more professional look and feel of a Webcast run event vs a self-service run event.

For details regarding Virtual Workshops, please visit the [Field Marketing Page](/handbook/marketing/field-marketing/field-marketing-owned-virtual-events/#virtual-workshops).

### Virtual Conference {#virtual-conference}

Please work with the Corporate Marketing Events team on planning these large scale events. [Virtual Conference handbook](/handbook/marketing/virtual-events/external-virtual-events/#virtual-conference) This event type is only intended if you need more tracked attendees than is capable with zoom and/ or you need multiple simultaneous tracks. It also allows for a partner expo hall. The tool we have in place allows for a cleaner experience for the end user than switchign between zoom calls. It more mirrors a physical event experience, with a keynote stage, tracks, expo halls and networking options.

### External virtual events {#external}

Note: these events are not included in the above decision tree as they are not GitLab-hosted events. [External virtual events handbook](/handbook/marketing/virtual-events/external-virtual-events/)

* **Sponsored demand gen webcast:** This is webcast hosted on an external partner/vendor platform (e.g: DevOps.com). The partner/vendor is responsible for driving registration, moderating and hosting the webcast on their platform. Mktg-OPs will be responsible for uploading the list to our database and MPMs will be responsible for sending post-event follow-up emails. *[Link to Marketo program template.](https://app-ab13.marketo.com/#PG5523A1)*
* **Sponsored Virtual Conference:** This is not a webcast but rather a virtual conference where we pay a sponsorship fee to get a virtual booth and sometimes a speaking session slot. Campaigns Team will primarily be responsible for sending the post-event follow-up emails. *[Link to Marketo program template.](https://app-ab13.marketo.com/#ME5121A1)*

### GitLab-hosted Virtual events details by type {#detail-by-type}

|                           |  Webcast | Virtual Conference  |
|---------------------------|------------------|----------|
| Attendee Size             | 201-1000 | 500+ |
| SLA                       |  45 BD   |45 BD+  |
| Type                      |  Webcast |Conference  |
| Tracking                  | Yes     | Yes  |
| LP/Registration           |  Yes     | Yes  |
| Mktg<br>Promotion         |  Yes     | Yes  |
| Mktg<br>Moderate          | Yes     | Yes |
| Mktg <br>Followup         |  Yes     | Yes  |
| Breakout<br>Rooms         | No      | Yes  |
| Polls/Q&A                 | Yes/Yes | Yes |
| Confirmation/<br>Reminder  | Yes/Yes | Yes  |

**FAQ & Notes:**

* Breakout rooms CANNOT be selected by attendees. Only the host can add attendees to rooms. Within each breakout room, Co-hosts can record when given permission by the host.

## How to go live? {#going-live}

### Webcasts {#go-live-webcast}

Currently, only the Campaigns Team team can run GitLab hosted virtual event with `Webcast` type configuration in zoom since this configuration requires a special Zoom license and integration with Marketo. To begin a webcast request, visit the [webcast page](/handbook/marketing/virtual-events/webcasts/) and follow the instructions.

## How to promote your virtual event? {#promotion}

### Webcasts {#promotion-webcast}

Below is a summary of the promotion plan for webcasts. MPMs will be responsible for creating all promotion request issues as part of the webcast project management process. The requestor will start with a [virtual event request issue](https://gitlab.com/gitlab-com/marketing/digital-marketing-programs/blob/master/.gitlab/issue_templates/MPM_VirtualEvent_Request.md) and MPMs will create the necessary epic and related issues.

* **Blog merchandising:** 1 post, -30 days prior to live event, DRI = Content team
* **Organic Social:** 1-2 post, -14 to -7 days prior to live event, DRI = Social team (requires image for sharing)
* **Paid Ads:** n/a, -21 days prior to live event, DRI = DMP (requires GitLab owned pages - about.gitlab or pages.gitlab)
* **Targeted Email:** 2-3 sends, -14 and -7 days prior to live event, DRI = MPM (copy provided by requestor)
* **Newsletter:** 1 post, -15 to -1 day prior to live event, DRI = MPM (only support English language)

## Virtual event operations {#operations}

### Zoom capabilities {#zoom-capabilities}

When scheduling an event, this table can help guide you towards the right event type to select based on the features you would like to use during the event. GitLab hosted virtual events will need to fit into either: Zoom Webcast type or Zoom Meeting type.

|                                       | Zoom Webcast                | Zoom Meeting                                  |
|---------------------------------------|-----------------------------|-----------------------------------------------|
| Screen share                           | Yes                         | Yes                                           |
| Video/Audio sharing                   | Host/Panelist only          | All participants                              |
| Participant<br>List                   | Visible to<br>host/panelist | All participants                              |
| Multiple Hosts                        | Yes                         | Yes                                           |
| Attendee Limit                        | 1,000                       | 200                                           |
| Registration<br>Zoom                  | Yes<br>(Optional)           | Yes<br>(Optional)                             |
| Registration<br>Marketo               | Yes                         | No                                            |
| Marketo<br>Integration                | Yes                         | No                                            |
| Automated Tracking<br>and Lead Flow   | Yes                         | No                                            |
| Confirmation Email                    | Yes <br>(from Zoom)         | Yes<br>(from Zoom)                            |
| Auto Reminder<br>Email Send           | Yes<br>(from Zoom)          | No*                                           |
| Practice Session                      | Yes                         | Yes*<br>(requires activating<br>waiting room) |
| Breakout Rooms /<br>Max participants  | 0 / 0                       | 50 / 200                                      |
| Polls                                 | Yes                         | Yes                                           |
| Q&A                                   | Yes                         | No                                            |
| Chat                                  | Yes                         | Yes                                           |
| Raise Hand                            | Yes                         | No                                            |
| Livestream                            | Yes                         | Yes                                           |

### Participant engagement {#participant-engagement}

#### Resources {#zoom-resources}

* [Managing participants in webcast](https://support.zoom.us/hc/en-us/articles/115004834466-Managing-Participants-in-Webinar)
* [Managing participants in a meeting](https://support.zoom.us/hc/en-us/articles/115005759423-Managing-participants-in-a-meeting)

#### Chat {#zoom-chat}

* [In-meeting chat](https://support.zoom.us/hc/en-us/articles/203650445-In-Meeting-Chat) / [Save in-meeting chat](https://support.zoom.us/hc/en-us/articles/115004792763-Saving-In-Meeting-Chat)
* [Webcast chat](https://support.zoom.us/hc/en-us/articles/205761999-Webinar-Chat)

**Chat announcements**

Chat announcements allow specific users to send one-way announcements to everyone in the same account. Account owners and admin can add up to 50 users who can send announcements.

[Using chat announcements](https://support.zoom.us/hc/en-us/articles/360037120072-Using-Chat-Announcements)

#### Q&A {#zoom-questions}

The question & answer (Q&A) feature for webcasts allows attendees to ask questions during the webcast and for the panelists, co-hosts and host to answer their questions. With the public Q&A feature, attendees can answer each other's questions and if enabled, they may also upvote each others questions.

* [Getting started with question & answer](https://support.zoom.us/hc/en-us/articles/203686015-Getting-Started-with-Question-Answer)

#### Polling {#zoom-polling}

You can enable polling in your meeting or virtual event to survey your attendees. See the [prerequisites](/handbook/marketing/virtual-events/self-service-virtual-events/#prerequisites) for how to enable polling.

You can also download the results of your poll - see [reporting](/handbook/marketing/virtual-events/#reporting).

* [Polling for webcasts](https://support.zoom.us/hc/en-us/articles/203749865-Polling-for-Webinars)
* [Polling for meetings](https://support.zoom.us/hc/en-us/articles/213756303-Polling-for-Meetings)

#### Networking {#zoom-networking}

There are currently no networking features available in Zoom outside of the participation features listed above. However, there are some creative ways to continue the conversation after your event is over:

* Create a custom Twitter hashtag for your event and encourage participants to join the conversation
* Create a LinkedIn group and invite participants prior to the event
* If you're doing a self-service event, use the breakout rooms to create a more intimate setting for discussion and opportunity for 1:1's

### Security {#zoom-security}

Please follow the [prerequisites](/handbook/marketing/virtual-events/self-service-virtual-events/#prerequisites) when setting up your virtual event. The [prerequisites](/handbook/marketing/virtual-events/self-service-virtual-events/#prerequisites) include steps for ensuring your virtual event and account are secure.

### GDPR and privacy compliance {#zoom-compliance}

In order to stay compliant with all regulatory policies as it relates to marketing, please adhere the following guidelines when working with registration or attendee lists and event confirmation emails:

* Password protect sheets for lists (use under GitLab ID only, GitLab only access)
* Delete info in Zoom after event
* Copy of spreadsheet should be deleted after use
* Add opt-out link in confirmation email

Please add the following language when creating your Zoom registration landing page:

>By registering for this event, you agree that GitLab may email you about its products, services and events. You may opt-out at anytime by unsubscribing in emails or visit our [communication preference center](/handbook/company/preference-center/).

If you are creating a self-service partner virtual event, please add the following language when creating your Zoom registration landing page and replace `[partner name]` with the name of the partner:

>By registering for this GitLab and `[partner name]` event, you agree that GitLab and `[Partner name]` may email you about their products, services and events. You may opt-out at anytime by unsubscribing in emails or visiting the relevant company's preference center.

### Reporting {#reporting}

#### Resources {#reporting-resources}

* [Getting started with reporting](https://support.zoom.us/hc/en-us/articles/201363213-Getting-started-with-reports)

There are two types of reports you can export for virtual events from Zoom:

1. **Usage:** view meetings, participants, and meeting minutes within a specified time range
1. **Meeting:** view registration reports and poll reports for meetings

For registration lists:

1. Navigate to `Reports` > `Meeting`
1. Select your report type. For a registration report, select `Registration Report`. If you had polling enabled for your virtual event or meeting, you can select `Poll Report` to download the results of your poll.
1. Select the date of your event. Maximum report duration is one month.
1. Select the checkbox next to your event and click `Generate`.
1. A pop-up box will appear for you to choose the type of registrants (all, approved, or denied).  Choose `all` and click `Continue`.
1. After processing, you are redirected to the `Report Queue` where you can download your results as a .csv file.

For attendee lists:

1. Navigate to `Reports` > `Usage`
1. Select the date of your event and click `Search`. Maximum report duration is one month. The report displays information for meetings that ended at least 30 minutes ago.
1. You can toggle the visible columns you want shown in the results from the `Toggle columns` drop down on the right-side of the screen (optional).
1. Once your event is shown in results, scroll right to the `Participants` column to view the number of participants hyperlinked in blue. Click the linked number of participants.
1. A pop-up box will appear called `Meeting Participants`. From here, you can select the checkbox whether you want to export this list with meeting data or not. Meeting data includes the meeting ID, duration (minutes), # of participants, topic, start time, end time, and user email.
1. Click `Export`. It exports the list as a .csv file.

### List uploads {#list-uploads}

If you have a **minimum of 20 leads** to upload from a virtual event, you can utilize the [same list upload process](/handbook/marketing/marketing-operations/list-import/) through marketing operations. Please create an issue in the marketing operations project using the [`event-clean-list-upload.md`](https://gitlab.com/gitlab-com/marketing/marketing-operations/-/blob/master/.gitlab/issue_templates/event-clean-upload-list.md) issue template and assign it to `@jburton`.

### Zoom landing page registration source tracking {#zoom-registration}

When driving webcast registration to a Zoom landing page, Zoom registration source tracking can be useful for tracking where the registrants are coming from.

[Registration source tracking on zoom landing page](https://support.zoom.us/hc/en-us/articles/360000315683-Webinar-registration-source-tracking) is only available for MPM run `Webcast` type and not the self-service virtual events `Meeting` type set up.

Currently, we do not use Zoom's landing page for webcast registration as MPMs manage the webcast registration process by creating an about.gitlab landing page and integrating form fills to Zoom via Marketo. The Zoom integration tracks sources that drove the registration using UTM parameters. See [full documentation on when and how to use utms](/handbook/marketing/integrated-marketing/digital-strategy/digital-strategy-management/#utms-for-url-tagging-and-tracking).

### Live streaming {#live-streaming}

Due to current security concerns, live streaming to YouTube from Zoom has been [temporarily shut down](https://gitlab.com/gitlab-com/gl-security/secops/operations/-/issues/871). There is also a security concern regarding Zoom meetings that are [recorded to the cloud](https://gitlab.com/gitlab-com/gl-security/secops/operations/-/issues/833). If you wish to record your virtual event and upload to YouTube later, record to your local machine (not to the cloud) and open an issue in the [digital production project](https://gitlab.com/gitlab-com/marketing/growth-marketing/global-content/digital-production) to have the digital production team review your recording prior to being uploaded to YouTube.

## Virtual Event Best Practices {#best-practices}

You may also want to review the [GitLab Video Playbook](/handbook/communication/video-playbook/), which offers guidance on creating engaging video content, much of which also applies to virtual events.

### Event Planner Best Practices {#best-practices-event-planners}

* Choose tech based on your event goals and structure of event/ presentations.
* Consider your narrative - people will be more likely to tune in if you are telling a story throughout the day vs. it being one of talks that aren't related.
* Have all presenters test their A/V setup in advance of event.
* Ask speakers who will be presenting live to test (and if necessary troubleshoot) their wifi connection prior to the event. Especially important for live demos and coding.
* If you have time, do speaker run through with all speakers to review slides and give feedback and answer any flow questions.
* Have a final check in meeting with MC's, moderators, and speakers. If you can have moderator meet their speaker on video call before the event to build rapport.
* Give moderators extensive instructions, especially if coordinating in-person as well as online presenters.
* Do the same for the speakers. What do they have access to that's different than the attendees?
* Give quick video instructions on how attendees can use the platform. Also provide written instructions.
* Have presenters sign in at least 20 min before to retest their audio and setup. Once they are all set, allow them to go off and make the most use of their time and ask that they rejoin 5 mins before starting. This will give proper time to troubleshoot if needed.
* Enable live captioning to make the videos more accessible.
* Make sure no one other than specific people can close the stream as people might accidentally otherwise.
* Prep back up plans for speakers who have technical issues, don't show, or other things that pop up. Have a back up for all live demos.
* If possible make sure people don't need to re-join (i.e. it's one long hangout/zoom) through the day, attrition greatly increases if they keep needing to re join.
* Have intermissions/ transition slides with tips for the audience. You've got your audience, make the best use of it!
* Keeping the audience engaged:
  * Survey the audience.
  * Add a giveaway or chance to get swag - be sure to build the process on the back end on how you can execute this in advance. i.e. if your swag vendor will allow you to ship out 25 items at no cost, then do a raffle for 25 or use a swag platform where people can enter in their own contact information.
  * Create a Slack channel or something similar for attendees to build community & keep the convo going there -- Remember your CTA?
  * If possible allow community/ attendees engage with speakers post talk.
* Find ways to keep the discussion going- the event shouldn't end with the camera stops. Decide on a CTA. Let folks know next steps and how to continue to engage and educate themselves.
* Have a plan for content use and distribution post-event. Be sure to communicate to the audience if they will receive the slides/recording and also a timeframe in which they will receive the content.
  * For both GitLab-owned and external events, speakers and content DRIs should build in steps for legal approvals from necessary parties on pubic-facing presentations before materials are due.

### Event Planner Best Practices (Virtual Sponsored Conferences/Events) {#best-practices-sponsored-events}

* Unlike in-person events, there are not usually drink receptions, food and other activities that drive traffic to a virtual booth. If there is gamification, it also is not a guarantee someone will actually talk to someone in the booth. Do not expect to get the same type of traffic you would at an in person event.
* To help drive traffic, staff and schedule SDRS and others to attend and network outside of the booth as well, whether that be through direct messages, in sessions, or any other networking features the event provides. Be mindful and encourage SDR's to direct messages strategically, avoiding mass messaging everyone at the conference. This is often not an appreciated outreach and will be disregarded.
* In AMER, Solution Architects will not join regional virtual sponsored conferences unless otherwise specified. If technical questions arise during the event, please list the question(s) into the `#cs-questions` slack channel. SA Manager is to be included on the event issue and a heads-up will be given in the `#cs-questions` Slack channel so the SA team knows an event will be occurring and to expect questions.
* Have staff reach out to booth leads as soon as they connect with you to help drive engagement and conversations during the event. Aim to set post event appointments.
* Create a list of sessions/tracks relevant to GitLab and encourage staff to attend.
* Post incremental updates in the internal event slack channel or have a daily sync about progress on the event goals, any updates, what to expect that day such as speaking slots or other relevant sessions.
* If you are the event planner, you may want to create an event profile as "GitLab Moderator" so you can create more brand awareness and manage more aspects of the event without being tied to yourself. It also gives another opportunity for people to interact with the brand if they don't know where to start.
* If the event is free or inexpensive, you will likely get people who reach out about hiring. Have a script ready for these questions.

### Speaker Best Practices {#best-practices-speakers}

* Test your technology in advance - including any applications you will be using (ex: Zoom, WebEx).
* Have backup headphones and a phone available in case you need to dial in.
* Have a dedicated microphone (as oppossed to using your laptop mic). We recommend a wired microphone (can be connected to your headphones) as many Bluetooth microphones suffer from latency and quality issues.
* If you can, have someone fielding questions for you.
* Have slides or visuals to supplement your talk if it is just you so that it doesn't feel like just a meeting or lecture.
  * Share slides in advance when possible and at the beginning of your session. This can help people follow along in the event of any technical difficulties.
* Wear camera-ready colors- [see doc](https://docs.google.com/document/d/1rPvewsTWm8uqGv-6Wr4-_j4ZmBVjL75fU5_YGV98d24/edit?ts=5e74125a)
* Remember your background: this will be recorded and published online.
  * Recommend using [GitLab branded virtual backgrounds](https://about.gitlab.com/press/press-kit/).
* Slides: use a large clear font. You do not know what device the viewer will be on.
* Don't move around a lot.
* Look at the camera.
* Dress as if you were at an actual conference.
* If someone will be introducing you, ensure they know how to pronounce your name, title, and GitLab correctly.
* Ask for a copy of the recording and post the recording on the relevant channel.
* If there is a chat function on the speaking session:
  * Have designated staff to attend and show up before the speaking slot starts.
  * Have staff post in the chat that they are a representative of GitLab and happy to answer any questions.
  * Know what links or topics are mentioned in the presentation and have UTM links to them ready to post. Good ones to have on hand in addition are the company handbook, our all-remote guide, link to the free trial
  * If at a sponsored event with a booth- At the end, encourage participants to stop by the virtual booth if they still have questions, with a link to the booth.

### Attendees: How to get the most out of attending a virtual event {#best-practices-attendees}

* Guide and enable people to share on social .
* Remind them how they will be able to access content post-event.
* Teach them how to use the platform you are doing the event on.
* Add "- GitLab" and the end of your name or "- your title" to your event profile depending on what is displayed in the event when in chat rooms or other interactive areas. If the event platform accepts emoji (often possible if there is a mobile app) feel free to use the fox emoji or something else that shows your personality.
* Add a profile picture to your virtual profile if you have the option. It adds a more humanistic touch. If you do not feel comfortable using your image, please use one of the company logos instead.

### Attendee/Staff Best Practices (Virtual sponsored conferences){#best-practices-attendees-staff}  

* One of the biggest advantages of virtual conferences is that you can often search the attendee list by company and title. Sales should especially take advantage of this as an easy way to find and connect with other attendees from your account. Be mindful to use a custom outreach that is relevant to that contact, as sending a generic message to thousands of attendees does not yield a positive image or create meaningful connections.
* Attend and participate in discussions at sessions, in chat rooms, and other areas the event platform provides in topics that are relevant to you. This helps show us as thought leaders beyond just our own speaking slots and helps gain connections across the event.
* Treat commitments to virtual events like you would to in-person events. While virtual events offer more flexibility to be able to avoid long flights and always having a quiet place to take a phone call, you should still be devoting your time to working the event like you would at an in person event. Block off a majority of your schedule during the event to really be engaged and participate.

### Partners Best Practices {#best-practices-partners}

* Best practices for managing a virtual booth- suggestions to get the most out of your investment, have the most personable interactions and give best attendee experience.
  * Always have a virtual offering, discount or giveaway.
  * If you can have a person or multiple people staff the booth and be there to answer questions.
  * have a video or digestible slide deck ready for viewing.
