---
title: Self-Service Virtual Events
description: An overview of self-service virtual events at GitLab.
twitter_image: '/images/tweets/handbook-marketing.png'
twitter_site: "@gitlab"
twitter_creator: "@gitlab"
---

## Overview {#overview}

The self-service virtual event type has been deprecated and is no longer in use.

If you would like to host a webcast, please work with either Marketing Campaigns or Field Marketing to determine the right set-up and tracking for your event.

Although this event type is no officially available, the details below do provide helpful information related to running an event using Zoom and are provided as a quick reference guide.

## Best Practices {#best-practices}

This section pulls all the pertinent best practices from the step-by-step instructions into a quickly reviewable format, separated by various stages of the process.

**General Best Practices:**

* Users expect a great experience and have a lot of options to choose from. We need every event to be immersive and pack a punch to keep people attending and coming back for future events. Customers are getting Zoom fatigue so take time to really strategize on the right subject, right speakers and right time. If planning a 2-3 hour virtual event, add some fun, sprinkle some silly questions into the learning to keep people feeling positive.
* Deliver a visually strong landing page that provides professional looking graphics, event overview and agenda.
* Block calendars for all hosts and panelists starting 30 minutes before the event start time.
* Ensure there are 2 co-hosts for a Zoom webcast to avoid any recording disruptions (i.e should one person lose internet connection).
* Presenters and Q&A moderators to log in as host so everyone can see them.
* If possible, keep sessions to a maximum of 2 hours long to decrease the drop-off rate.
* Monitor your registration numbers throughout your promotion. Attendance rates can range from 30-50%, meaning you should not exceed 400 registrants for self-service style events to avoid a large number of people from being blocked.
* Identify a strong moderator who is comfortable interrupting speakers to keep them on time or interject questions from the audience. Work within your teams to find engaging speakers who can deliver the content in a clear and exciting manner.
* Develop an outline of the content, identify the presenters and create milestone dates for content development. Schedule a practice session for all hosts and panelists in the week prior to the event. Make a copy of the [dry run template/script](https://docs.google.com/document/d/1uo6Hghm4cPqzAWjvPyIWSpNVn0ulYC4DcpAKCj4j5Pk/edit#heading=h.qv152nkfuvce) to facilitate and ensure everyone knows the flow and technology being used. Preparation is key, test everything.
* Enabling the chat, Q&A and polling features in smaller events to fuel questions, distribute collateral and field questions is a great way to keep engagement high. If there is a large audience, ensure there are dedicated team members monitoring the chat so questions can be answered while speakers are presenting. Schedule adequate time for Q&A.
  * Have a minimum of 2 Q&A moderators (1 verbalizing questions and the other typing answers) who are efficient, knowledgeable and have an understanding of the most important questions to verbalize during the sessions and the questions to dismiss (inappropriate in nature).
  * Route questions to the Q&A queue and create an internal google doc to allow the team supporting the event to collaborate on the question to make sure we have the right answers. Then paste the answers from the doc back into the Zoom Q&A queue for the attendees to see.
  * Suggest shutting down chat during presentation (not labs) for larger events but ensuring that the chat feature is still enabled for the panelists to speak back and forth.
  * Chat feature could be used to help gamify event.
  * Provide information (on a slide) on how attendees should use Zoom chat and the Q&A feature.
* Provide a slide featuring the team and their contact details.
* Add a feedback survey on the last slide when thanking people for coming, capturing them right away may yield more responses.
  * when planning the feedback survey/form ensure you have clear objectives/goals
  * limited the amount of questions
  * the survey should be anonymous
* Posting event bundle with prezos, recording and thank you tends to stir up new meetings/conversations.
* Download the usage report within 24 hours of event close and deliver to Marketing Ops via list upload [issue](https://gitlab.com/gitlab-com/marketing/marketing-operations/issues/new?issuable_template=general-list-import-request).

Review GitLab's general [virtual events best practices](/handbook/marketing/virtual-events/#best-practices) for additional suggestions on how to make your virtual event a success.

**Basic Zoom Settings:** *These settings should be updated in your personal zoom account settings by logging into the [Zoom](https://zoom.us/) web client*

* Deactivate `play sound when participants join or leave`
* Activate `mute participants upon entry`
* Enable livestream feature (advanced settings) `allow live streaming the meeting and enable YouTube`
* Activate `polling` (basic settings)
* Activate `breakout room` (advance setting)

**Setting up Zoom event:** *Basic recommendations when setting up your self-service Zoom event*

* Mute participants upon entry
* Enable `join before host` option
* Enable `waiting room`
* Check `record meeting automatically` if the event is being recorded
* `REQUIRE` registration for any event that you'd like to add registrants/attendees to Marketo/SFDC after the event
* Add alternate hosts to help support your event
* `Close registration after event date`
* Check `Only authenticated users can join`
* To allow the ability to run a practice session, check `enable waiting room`. NOTE: This means you have to accept people into the meeting on the live event date unless you toggle this off after your practice session
* Once your event is created, scroll to the bottom of the event and see Polls tab *Pro-tip: you should only one question per poll. If you add multiple questions per poll, you must answer all questions at once*

**Pre-Event / Live Event / Post-Event**

* Only the host and co-host can start/stop the recording
* Only the host and co-host can mute/unmute participants

### Self-service virtual event promotion guide

Using personal channels to self-promote your event comes with many benefits: it's an authentic way for you to build your personal audience, reach people beyond GitLab's corporate channels, and boosts your credibility online. This page outlines everything that you'll need to promote your own virtual event. `This checklist should take less than 2 hours`.

Please consider reviewing and applying our [GitLab Team Member Social Media Guidelines](/handbook/marketing/team-member-social-media-policy/) prior to promoting your own event. Specifically, review our [GitLab Voice information](/handbook/marketing/team-member-social-media-policy/#gitlab-voice).

#### Checklist of deliverables to get your self-service virtual event started (details below)

* [ ]  Copy to promote your event
* [ ]  Designs for creative/images
* [ ]  Getting the word out

#### How to write copy for your self-service virtual event

1. Gather a list of handles and hashtags to include in your social copy
   * Your event topic is already a hashtag: #DevOps, #security, #RemoteWork, etc. Integrate these into your sentences naturally.
   * Do you have a guest speaker? Talking about a company, person, or brand that would have a Twitter or LinkedIn page? Include the handle (@name) in the Twitter post - and tag the appropriate page on LinkedIn.

* Do's
  * DO use 1-3 hashtags in your posts, across social channels
    * Example: I'm so excited to announce that I'll be speaking about #remote #DevOps at my webcast later this week! Join me and learn how @GitLab can help.
  * DO write in your own voice, be creative, and use emoji
    * Example: 🗣Everyone is talking about #remote #DevOps and at @GitLab it's all I work on. 💻 Join me for a webinar to learn how we make it all work.
* Don'ts
  * DON'T hashtags the predicate, object, or complements in a sentence unless it's a direct topic of your event.
    * Example: So #excited to #announce our new #event on #remote #DevOps… #GitLab #Tech #Webcast

1. Top-Level messaging to aid in copy
   * Write 3 sentences answering these questions:
      * What topic is your virtual event about?
      * What is something that attendees will walk away with that provides them value? / Why should someone attend your virtual event?
      * Why are you the person to listen to about this topic? / What makes you the authority?
   * Use the answer to these three questions to write all copy for your promotions.
      * A "tweetable" (280 characters or less) event description - add this to your event landing page and use this as your copy for all social promo for your first post on Twitter and LinkedIn
      * Write actual social copy with your hashtags, handles, and the answers to the questions above. (If there are no handles that's okay. But there is always a hashtaggable topic. Lost? Ask #social_media on Slack)

#### How to make images for your self-service virtual event

Because this is a self-service virtual event, you'll also be creating your own image for promotion. Don't worry! We have everything you need.

Here's what you'll need to do:

* Use [GitLab's Virtual Events Promotional Templates on Canva](https://www.canva.com/design/DAEOD5yTT_8/Vp8aqPPHdLVuvpNLlv9jzA/view?utm_content=DAEOD5yTT_8&utm_campaign=designshare&utm_medium=link&utm_source=sharebutton&mode=preview). Select which of these two styles you'd like to use and follow the instructions in the template.
* Follow the directions on the first slide of the template.
* Once your image is made, click the "share" button, followed by the "download" button, and you've made your promotional image!

The GitLab Canva Virtual Events Promotional Templates are a small series of "blanks" to use to promote your event! You may choose any or all of these for your virtual events. You will need to learn basic photo editing tactics if you don't know them already, but Canva is user-friendly software. Lost? Ask #social_media on Slack for assistance.

#### Getting the word out - Launching your self-service virtual event promotion

Now that you've put together the copy and creative needed to promote your event, it's time to get the word out. Depending on how much time there is until your webcast, you may be able to promote your event more than what we've outlined in this section. There are more details below on a more sustained promotion for events with more than 3 days of time between promotion launch and webcast.

We recommend doing all of the following:

##### 1. Share your event on your social media channels

Promote your event on Twitter and LinkedIn. You may also do this on Facebook or other channels, but know that Twitter and LinkedIn are key. Take the copy + creative you made and send them out to your social followers. Be sure to "convert" your @handles from Twitter to tagging people and companies on LinkedIn. While you start with "@" like all social channels, you'll want to make sure that you select the right person or company on LinkedIn. Here is how to try this out (https://www.linkedin.com/help/linkedin/answer/34936/mention-people-in-your-posts?lang=en).

##### 2. Share your social media posts on GitLab Slack Channels related to your topic

Ask for team members to amplify your posts.

Building personal credibility and extending reach for your event promotions is a critical part of success. Team members who work in the same space as your topic would be more likely to share on their channels than others. Here's how to do it while living up to our values around informal communication:
Example: Your webcast is the same from our examples above, about remote DevOps. One of the topics to focus on is `remote work`. In addition to being a hashtag in your social posts, `remote work` is also the topic for a GitLab Slack channel, `remote`. Team members in this channel share stories and opinions on your webcast topic.

After sending out your first social media posts on Twitter and LinkedIn, copy the links to both posts. Here's how to copy a link to your post on LinkedIn (https://www.linkedin.com/help/linkedin/answer/108024/finding-the-url-for-shared-content?lang=en). Here's how to copy a link to your tweet on Twitter (https://help.twitter.com/en/using-twitter/tweet-and-moment-url).

Take the links to your social media posts and add them to a Slack channel message. Send a variation of this message to the channel:

> Hi Everyone,
>
> I'm hosting a webcast on remote DevOps later this week. I would appreciate your support by retweeting or sharing my social posts.
>
> Retweet My Tweet (make this a clickable link to your tweet)
>
> Share My LinkedIn Post (make this a clickable link to your LinkedIn post)
>
> Please let me know if you have any questions or would like to contribute to the webcast.

While sharing on your social media channels and other digital spaces should occur more than once if time allows, please do not message GitLab Slack channels more than once about your webcast promotion. Please feel free to provide an update to the slack channel about what worked well or how many people attended following the end of your webcast.

##### 3. Consider your other affiliations for promotion

Are you a part of a tech-focused nonprofit? Do you have former coworkers who would be interested in your webcast? Are you a part of group chats, Facebook or LinkedIn groups, or some other channel where members might be interested in your topic? Share it with them as well.

It's important to note that you should be aware of sharing practices in your groups - some groups have a strict "no advertising" policy. For all Facebook and LinkedIn groups, consider reviewing any group rules and don't get in trouble with the moderators.

##### Extra: Add to the events page

Add your virtual event to about.gitlab events page by following [instructions](/handbook/marketing/events/#how-to-add-events-to-aboutgitlabcomevents) for adding to event master.yml

##### Extra: Specific Twitter options

While we're not suggesting that you spam your audiences, Twitter is not used in the same way LinkedIn is. On the day of your webcast, consider tweeting a photo of you prepping the webcast, tweeting a "thank you" to everyone that attended, and even consider linking to a recording (if available) for those who could not join live. It's completely acceptable for a list of tweets on the day of your webcast to include 3-5 tweets. Ultimately, if you have something else to say, say it on Twitter.

##### Extra: Getting the word out - More than one-day of promotion

If you're planning a webcast and have more than 3 days between your first day of promotion and the actual webcast, you have time to add additional posts to your promotion.

Do not promote your event more than once a day, at most. Remember, this is your network, don't spam them.

Consider posting about non-webcast or work-related topics between webcast promotional posts.

Take the same copy you wrote in step 1 and remix it for future posts.

### Logistical Set up

#### Setting up the event in Zoom

##### Prerequisites

Make sure these settings are enabled in your personal zoom account settings as needed. In your zoom web interface go to `Settings`.

1. To prevent meeting disruptions when participants join and leave by making sure:
     * Under In Meeting (Basic section), `Play sound when participants join or leave` is deactivated
     * Toggling `Mute participants upon entry` to active.
2. To enable Livestream feature:
    * Under In Meeting (Advanced) section, toggle `Allow live streaming the meetings and enable YouTube` to active
3. To enable Polling feature:
    * Under In Meeting (Basic) section, toggle `Polling` to active.
4. To enable Breakout sessions feature:
    * Under In Meeting (Advanced) section, toggle `Breakout room` to active.
    * To enable pre-assigning for zoom users, check  `Allow host to assign participants to breakout rooms when scheduling`.
5. Optional but [useful best practice set up from Zoom](https://www.zoom.com/en/blog/keep-uninvited-guests-out-of-your-zoom-meeting/?cms_guid=false&lang=en-US) to prevent [Zoom Bombing](https://www.forbes.com/sites/kateoflahertyuk/2020/03/27/beware-zoom-users-heres-how-people-can-zoom-bomb-your-chat/#26745c14618e) (hackers hijacking your meeting).

**Creating the event in Zoom**

1. Login to zoom via the web interface.
2. Click `schedule a meeting` on the top right navigation.
3. Fill in the `Topic` in the recommended format (this will be in the subject line for confirmation emails):
     * For One-time (non-recurring) event: `Event title` - DD Month, 2020 - Local time (e.g: Deploy AWS Lambda applications with ease - April 9, 2020, 9 am PT).
     * For Recurring event: `Event title` (e.g: Deploy AWS Lambda applications with ease).

4. Fill in the `Description` with a description of what the event is about. *Note: this will be in the body for confirmation emails and landing page (if you set registration as required in step 9).
5. Fill in `When` with the event date and time.
6. Fill in `Duration` with the duration of the event.
7. Select the  `Timezone` where the event will be held.
8. (Optional) If your event is going to be recurring, click recurring meetings and set up `Recurrence` and specify the `End date` of the recurring event.
9. For events where you will need to track registration and attendance, make sure you check the `Registration` field as `Required`. Doing this will automatically trigger a landing page to be created for your event.
10. (Optional) If you set the event as recurring in step 8, specify which registration process will work best for your target audience:
     * Attendees register once and can attend any of the occurrences - This will automatically register the registrants to ALL sessions upon form fill.
     * Attendees need to register for each occurrence to attend - This will allow registrants to only select ONE session per form fill.
     * Attendees register once and can choose one or more occurrences to attend - Registrants are presented with checkboxes to select which session they want to attend on the landing page prior to filling out the form.

11. (Optional) You can make the meeting private/ensure only those that registered attend by checking the `Require a meeting password` option  and including the auto generated password in your invite (for events not requiring registration)/confirmation (for events requiring registration). This is useful so only the people you intend to invite attends the meeting and can help prevent hackers from taking over your meeting (Zoom Bombing).
12. Specify if you want the Host and/or Participant's video `on` or `off`.
13. Make sure audio is set to `BOTH` telephone and computer audio.
14. For meeting options configurations:
15. Check `Enable join before host` option if you want to allow participants to join before the host(s).
16. **(Recommended)** Check `Mute participants upon entry` to prevent disruption whenever someone joins mid-presentation.
17. **(Recommended)** Check the `Enable waiting room` option if you'd like to choose some participants to join prior to others . This is useful to allow a final dry run between host and the other presenters right before the event. Activating this is recommended by zoom to prevent [Zoom Bombing](https://www.zoom.com/en/blog/keep-uninvited-guests-out-of-your-zoom-meeting/?cms_guid=false&lang=en-US).
18. Check `Only authenticated users can join` to restrict meeting only to participants that have logged in to zoom using their email address. Activating this is recommended by zoom to prevent [Zoom Bombing](https://www.zoom.com/en/blog/keep-uninvited-guests-out-of-your-zoom-meeting/?cms_guid=false&lang=en-US) but may impact registration due to its restrictive nature (forcing registrants to sign up for zoom before completing registration).
19. Check the `Breakout room pre-assign` if you'd like to pre-assign participants to the breakout sessions prior to the meeting. Please note that only participants/hosts with @gitlab email domain can be pre-assigned via the web interface. Participants with non @gitlab email addresses need to have zoom installed in their machine to be pre-assigned, and pre-assigning for this scenario can only be done through a CSV upload.
20. **(Recommended except for meetings that are private in nature)** Check `Record the meeting automatically` either on your local computer or in the cloud to automatically record the meeting when the host join.
21. Add alternate host as needed (need to be a GitLab employee). For  presenters that are not a GitLab employee, ask them to register as a regular participant and grant them co-host access during the meeting.
22. SAVE your meeting.
23. Once your event is created, scroll to the bottom of your event, click the registration (if it was selected as required), click edit, under `other options`, check the box for `close registration after event date`.
24. :star2: **(Optional) Pro tip:** If you'd like to save the same  set up for a future meeting `Save your meeting as a Meeting template`.

**[Recommended for meetings requiring registration] Customize your registration form**

1. In the registration tab for the meeting that you have set up, click edit beside registration options.
2. Click the `Questions` Tab and select `Job Title` and `Country` (Do not select `Number of Employees` as we will add that as a custom field in the next step.
3. Click `Custom Questions` tab and click `New Question` button to add `Number of Employees` custom field.
    * For `Type` select `Single answer`
    * Make sure `Required` is checked
    * In the `Question` field,  fill in  `Number of Employees`
    * In the answer field, fill in `1-99`, `100-499`, `500-1,999`, `2,000-9,999`, `10,000+`
    * Click create
4. Click `Custom Questions` tab and click `New Question` button to add email opt-in language
    * For `Type` select `Single answer`
    * In the `Question` field,  follow [this example](https://docs.google.com/document/d/1UEfWo26DP7nRPrWRWo7O7oSrNp_rRuVqyN_vC7SwXME/edit#heading=h.i3bpdb8vrwb).
    * In the answer field, fill in `Yes` or `No`
    * Click create
5. (Optional) Click `New Question` and follow the steps outlined previously to add more custom fields. Selecting type `Short Answer` vs. `Single Answer` will allow registrants to enter a free text response vs. selecting from a picklist.
6. Click `Save All`.

**[Recommended for meetings requiring registration] Customize your confirmation email & trigger a reminder email**

1. In the meeting that you have set up, click the `Email settings` tab.
2. Beside the `Confirmation Email to Registrants` section choose the email language (if not the default of `English`) , click edit and modify the editable `Subject`, `Body`, and `Footer` sections. Note: Zoom emails are text only and the layout is not editable.
3. **(Recommended)** Reminder emails have to be triggered manually for this set up. ±1 or 2 hour prior to the event, change the subject line of the Confirmation email to `[Meeting Topic] Confirmation/Reminder`, then click over to the `Registration tab`. In the `Registration tab` click `View` , select all the registrants on that page by selecting the top left checkbox and click `Resend Confirmation Email`. If the registration list spans across multiple pages you must repeat this for each page.
4. **NOTE:** We do not send Marketo reminder emails for self-service with promotion events since the Zoom registration is not integrated and the registered attendees are not pulled into Marketo until your lead list is uploaded after the event.

**[Optional for meetings requiring registration] Customize your landing page and email headers**

1. In the meeting that you have set up, click the `Branding` tab.
2. Upload your custom image to the `Banner` section or use the basic GitLab [image](https://gitlab.com/gitlab-com/marketing/corporate_marketing/corporate-marketing/-/blob/master/design/web-design/about-gitlab-com/webcast/zoom/png/zoom-email-banner-1200x200.png). Image requirements are as follows:
    * GIF, JPG/JPEG or 24-bit PNG
    * The suggested dimensions: 640px by 200px
    * The maximum dimensions: 1280px by 400px

**[Optional] Add a poll to your meeting**

1. Make sure you have [enabled `Polling` in your account settings](/handbook/marketing/virtual-events/self-service-virtual-events/#prerequisites).
2. In the meeting that you have set up, click the `Poll` tab.
3. Click `Add`.
4. Put a descriptive title for the Poll.
5. Specify whether you want to allow the attendees to remain anonymous when submitting a poll.
6. Enter your poll question.
7. Specify if the answer will be a `Single choice` or `Multiple Choice` (allows for participant to select more than one answer).
8. `Save`.

#### During the event

**[Optional] Starting Livestream for your event**

1. Make sure you have enabled `Livestream` in your account settings.
2. During the virtual event, follow this [step by step instructions](/handbook/marketing/marketing-operations/youtube/#livestream-with-zoom) to start LIVESTREAM.

**[Optional] Playing pre-recorded video during the meeting**

1. Make sure you have your video pulled up in a video player (quicktime/youtube) on your computer
2. On your Zoom panel, click share screen and select the video you want to share
3. At the bottom left of the pop up screen, select `Share computer sound` and `Optimize Screen Share for Video Clip`. Click `Share`.
4. Play the video.

Note: Although we can leverage this functionality for a semi-live virtual event, the audience will be able to tell that you are playing a video for them so it is good to share that information (be transparent) with them upfront.

#### Post event

**[Optional] Downloading the registration list**

1. Login to zoom via the web interface.
2. On the left navigation, click `Reports`.
3. Click `Meeting`.
4. For`Report Type`, select `Registration Report`.
5. For `Search by time range` input the date of your event, click `Search`.
6. Select your event and click `Generate`
7. For `Registration Type` select `All Registrants`, click `Continue`.
8. Once the report finished processing, click `Download`.

**[Optional] Downloading the attendees list.**

1. Login to zoom via the web interface.
2. On the left navigation, click `Reports`.
3. Click `Usage`.
4. For `From` input the date of your event, click `Search`.
5. Find your event, scroll right to the `Participants` column, click the number of participants in blue fonts, select `Show unique users` checkbox on the top left of the pop up page, click `Export`.

**[Optional] Upload recording to the [appropriate youtube channel](/handbook/marketing/marketing-operations/youtube/#channels).**

[Instructions on how to upload](/handbook/marketing/marketing-operations/youtube/#uploading-conversations-to-youtube).

**[Optional] Gating self-service virtual event recording**

To maximize the return on time investment spent for creating gated webcasts landing pages, we will only gate post event recording for a self-service virtual event if it garners a min of 550 youtube views within the first 7 days.

If your video meets the gating criteria, please open the following issues for the marketing campaigns team (and provide screenshot of views for clarity):

* Please note: requester is responsible for submitting issue details in all issue templates below in order to triage.
* [ ] [Pathfactory Upload Issue](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=request-pathfactory-upload)
* [ ] [Pathfactory Track Issue](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=request-pathfactory-track)
* [ ] [Marketo Landing Page & Automation Issue](https://gitlab.com/gitlab-com/marketing/demand-generation/campaigns/-/issues/new?issuable_template=request-mkto-landing-page)

*Note: The 550 min threshold is based on the avg of top 10 videos on GitLab branded youtube channel between 8/11/20 - 8/18/20.*

### Results

#### Responses by month

This [SFDC report](https://gitlab.my.salesforce.com/00O4M000004aL5Y) tracks responses produced by self-service virtual events in real time. We will link full funnel reporting with opportunities and pipeline data as they become available in Sisense.
