---
title: 360 Feedback
description: >-
  360 Feedback is an opportunity where managers, direct reports, and cross
  functional team members will give feedback to each other.
---

## 360 Feedback

Cross-functional feedback provides critical insights into strengths and improvement areas to support ongoing performance in role and career development. 360 Feedback can be a valuable tool in providing those insights, especially when specific growth areas are not already clear.

There are various ways to support team members' performance and growth. Timely and direct [feedback]({{< ref "guidance-on-feedback" >}}) is often the best way to course correct efficiently and improve performance on an ongoing basis.  360 feedback is a useful tool to support specific development goals or surface blind spots, often for those in leadership positions.  A 360 is not the best investment of time for team members who already have a clear understanding of their strengths and weaknesses, and an actionable development plan underway. Team members should take ownership of and leverage the tools that are most relevant and beneficial to them.

The optional 360 feedback cycle is timed *after* the [Mid-Year Check In](/handbook/people-group/talent-assessment#mid-year-check-in) and *after* [promotion calibrations]({{< ref "promotions-transfers#promotion-process--timeline" >}}) to maintain the focus on development. Managers should check in with cross functional stakeholders informally when preparing for a Mid Year check in or Promotion Calibration vs waiting for a 360 feedback cycle.

## Is The 360 Process Right For Me?

A 360 can be a very helpful development tool, but it should not be a replacement for regular, ongoing feedback that team members receive throughout the year. There may be situations and points in team member development where a 360 can supplement development and individual growth plans, and times when development areas are clear and 360 feedback may not be needed.

Below are a few key points to think through when determining in which situations the 360 tool may or may not be useful:

- **Development Oriented:** The 360 process is meant to support the team member's development and to provide feedback supporting individual growth and development. 360s *should not be used as performance management tools*.
- **Ongoing Feedback:** Managers and team members should seek cross functional feedback throughout the year to inform performance discussions. A 360 should not serve as a replacement for asking stakeholders and peers how things are going.
- **Focused Goals:** 360 feedback is most useful when a team member is committed to working towards certain development goals, as the 360 can provide more specific feedback and focus towards those development goals, and also reveal some blind spots or hidden strengths.
- **Individual Growth Plan:** In order for the 360 to lead to action, it is important to document and commit to a development plan that outlines the key findings and development actions. As [noted above](#360-feedback), before launching a 360, ensure an [Individual Growth Plan (IGP)]({{< ref "career-development#individual-growth-plan" >}}) is in place. This ensures the 360 is aligned with development areas.
- **Single Data Point:** It is important to remember that the 360 represents a single, anonymous point in time. While it can be helpful to supplement existing IGPs, it should not be the core data point.
- **Uncover Blind Spots:** A 360 is best used when trying to uncover blind spots. If team members and their managers already have a good understanding of the growth areas, direct, transparent feedback is the most productive way to support continued growth and development.

### Eligibility

For 360 feedback cycle we will only include team members with at least 6 months of tenure (start date on or before January 28th, 2023).

Participants should also ensure that they meet the [requirements to participate](#360-feedback-requirements) in the process.

## 360 Feedback Requirements

Team members who opt-in for the 360 feedback review cycle will be asked to:

- **(required)** Complete an [Individual Growth Plan]({{< ref "career-development#individual-growth-plan" >}})  in partnership with your manager *prior to the 360 nomination phase launch*. 360 feedback should support your growth plan to ensure the investment of time drives results.
- **(required)** Contact team members who you are requesting feedback from to state your goals for the 360 process. For ex/ 1) why you are seeking feedback and 2) what you hope to achieve from the feedback. This will help the reviewer think about how to provide the right kind of information to support you. This can be done via Slack or email.
- **(optional)** We have a [Feedback Training enablement issue](https://gitlab.com/gitlab-com/people-group/Training/-/blob/master/.gitlab/issue_templates/feedback_training.md) available for all team members interested in learning more about giving and providing feedback, in addition to our 360 feedback process. We recommend team members that are requesting feedback or providing feedback complete this training.
- **(optional)** Following the 360, share the themes you heard and resulting actions you plan to take with stakeholders who can support your growth throughout the year.  Update your [Individual Growth Plan]({{< ref "career-development#individual-growth-plan" >}}) with your new development items and actions that you will take as a result of the feedback received in the 360 process.

## Timeline FY25 (Pending)

We are currently reviewing the process for 360 and peer-to-peer feedback and will pause our program for mid-year FY25.

## Timeline FY24 (Completed)

The 360 feedback process will be ongoing from July 31, 2023 - September 22, 2023.

| Dates  | Event   |
|------------|------------|
| 2023-07-10 through 2023-07-28 @ 5pm PT | Sign Up Window |
| 2023-07-31 | Feedback Cycle Launch |
| 2023-07-31 through 2023-08-11 @ 5pm PT | Nomination Phase |
| 2023-08-14 through 2023-09-01 | Feedback Phase |
| 2023-09-04 through 2023-09-22 | Review & Discussion Phase |

`IMPORTANT`: Each phase needs to be completed by the due dates indicated in the table above. To keep this process on track, extensions won't be accommodated.

- **Sign Up Window** - The period of time during which team members can sign up to participate in the 360 Feedback process. Information on how to sign up for the cycle can be found in the Sign Up Process section below.
- **Nomination Phase** - Team member nominates peers, manager, and any direct reports they have. Managers have the opportunity to adjust/review team member's feedback nominations during this window.
- **Feedback Phase** - Team member, managers, and peers complete reviews for themselves and each other. Managers will have visibility into all self and peer reviews for their direct reports as they are completed.
- **Review Phase** -  At the close of the 360 feedback session CultureAmp will open the feedback report to the team member and their coach (direct manager) for review.
- **Discussion Phase** - Manager and team member schedule a 360 [feedback meeting](360-feedback#360-feedback-conversation).

### Sign Up Process

The FY'24 360 Feedback Cycle will be optional company-wide. To sign up, **all team members must complete [this Google Form](https://docs.google.com/forms/d/e/1FAIpQLSfxIji54UF-u4cRXF80obTJ6VoaylrrbLqjDuxzStzNmjoCCA/viewform?usp=sf_link) to participate**. There are a few important things to keep in mind before signing up:

- You must sign up before the or you will not be able to participate in the cycle.
- This is to ensure we are able to launch the review cycle on time**
- Ensure you meet the [tenure el**igibility](#eligibility) requirement
- Make sure that you [fulfill the requirements](#360-feedback-requirements) for participation and that you have an [Individual Growth Plan]({{< ref "career-development#individual-growth-plan" >}}) (or equivalent) in place prior to the 360 Feedback launch
- Review [the guidelines](#is-the-360-process-right-for-me) to determine whether the 360 Feedback process is right for you
Team members that sign up and meet the eligibility requirements will receive an invtation from CultureAmp at the start of the Nomination Phase. Team members that sign up and **do not** meet the eligibility requirements will be notified by their People Business Partner.

## 360 Structure

We utilize [Culture Amp](https://gitlab.cultureamp.com/) to administer 360 Feedback. The 360 Feedback cycle in CultureAmp consists of a Self review, Manager review and Peer reviews.

Managers will be assigned as the coach for their direct reports. Managers should review and send out the 360 feedback within 48 hours once the feedback cycle closes and you are sent the results. For more information on the role a manager will play as the team member's coach, please review [Culture Amp Resources for Coaches](#culture-amp-resources-for-coaches)

- If a team member is in the process of migrating to a new role, the current manager and new manager should arrange a successful handover of the feedback, whether sync or async.
- If your manager changes throughout the 360 process, please contact [People Connect]({{< ref "people-connect" >}}) to make this change on Culture Amp.

We have recorded a training overview of the 360 process via Culture Amp for your review and created a slide-deck to provide [guidance on 360-Feedback](https://docs.google.com/presentation/d/1YxnAWDO0GPSWX5hDepgwMOohT0ZsGzqmUHxvBpaHf7E/edit#slide=id.g77644d9eff_0_0), kindly review before you give feedback.

<figure class="video_container"><iframe src="https://www.youtube.com/embed/zQvNeUX-x5I"></iframe></figure>

### 360 Questions

During this 360 Feedback cycle we will be using the Individual Effectiveness 360 Feedback. This follows a Start, Stop, Continue format. The questions included are:

- Start: What is one thing that (X or you) could start doing to help your team to succeed?
- Continue: What do you believe (X or you) excel(s) at that should be continued?
- Stop: What do you believe are (X's or your) biggest opportunities to improve that could make a real difference?
- Open question: Please add anything else, not listed above, that you'd like to continue, improve or do more of. Or use this opportunity to provide additional feedback.

#### Multiselect Options

To help guide team members in giving feedback, CultureAmp is offering options under the Start, Continue and Stop questions. When giving feedback you can select up to three options that you would say are applicable. If there are no options that match your feedback please use the option "Other". From there, you can elaborate in the comments section.

The options shown align with [GitLab Competencies](/handbook/people-group/competencies/#list):

- Collaboration: Working effectively with a range of people from across the business.
- Results: Producing high quality work. Providing practical solutions to problems and finding ways to make improvements. Taking the lead and showing ownership of issues. Demonstrating a bias for action.
- Efficiency: Prioritizing work and managing time well.
- Diversity: Recognizes and avoids unconscious biases.
- Inclusion: Recognizing the difference among teams and inviting people to contribute to remove barriers.
- Belonging: Is an ally, willing to take action in support of another person in order to remove barriers.
- Iteration: Experimenting with innovative ideas and approaches / being open to new ways of doing things.
- Transparency: Actively keeping people informed about what is happening. Being open to contribution and collaboration.
- Feedback: Actively giving, seeking and responding positively to thoughtful feedback.
- Growth mindset: Eager to learn and committed to ongoing development.
- Technical Competence: Demonstrating a high level of domain, functional and/or technical capability.
- Manager of One: Develops their daily priorities to achieve goals. Sets the tone for their work, assigns items and determines what needs to get done as a self-leader.
- Effective Communication: Uses our asynchronous communication guidelines; communicating with transparency and respect to stay connected and work efficiently.
- Handbook First: Actively contributes to the handbook, references the handbook to answer questions and clarify direction, uses judgment to contribute and leverage public and internal handbooks.
- Using GitLab: Uses GitLab effectively for day-to-day work, opening, commenting and moving issues, submitting merge requests, and leveraging epics when appropriate.
- Other.

#### Manager Feedback

Direct reports of managers that participate in the 360 feedback process will be asked to rate where their manager should better focus their efforts in order to support the team. Specific areas for rating are related to GitLab's [manager and leadership competencies](/handbook/people-group/competencies/#manager-and-leadership-competencies). The rating scale is a normalized, 5-point scale from "much less focus" to "much more focus," with an option for additional comment.

### Culture Amp Resources For Coaches

1. [360 feedback overview for coaches](https://support.cultureamp.com/en/articles/7048473-guide-to-managing-the-360-review-process-as-a-coach)
1. [Coach's guide to taking action on Effectiveness 360 feedback](https://support.cultureamp.com/hc/en-us/articles/208687485-Coach-s-guide-to-taking-action-on-Effectiveness-360-surveys)

#### Checklist For Coaches

Utilize this checklist to ensure all necessary steps are accomplished during the 360 process.

1. **Reviewers** - Check with the team member to see who they have nominated for reviewers
1. Provide **Feedback** - As a coach, you may have been nominated to give feedback to your team member
1. [**Review Feedback**](#reviewing-the-report-as-a-manager) - As a coach and manager you should review the feedback with a growth mindset
1. Conduct [**Feedback Conversation**](#360-feedback-conversation)
1. **Take Action** on the feedback
1. **Complete** the 360 process

### Reviewer Nomination Process

In Culture Amp, a reviewer is anyone who is requested to provide feedback for a team member.

**If you are unsure who to nominate as a reviewer, consider saving your nominations as a `Draft` in CultureAmp.** This will allow you to sign back in and add or delete your nominations.

Reviewers can be managers, direct reports or co-workers(no participants outside of GitLab). Here are some best practices for selecting reviewers:

- Nominate your manager, all of your direct reports (if applicable) and a selection of around three peers. Three peers is not a hard limit but we want to make sure the process remains manageable for all.
- If you are in heavily cross-functional or in leadership roles, ensure you have cross-functional representation in line with your level of collaboration.
- Ensure to nominate team members who are operating at the same level as you to not overburden your skip-level leaders.
- Search for team members using their email or last name, as CultureAmp does not support listing Preferred Name, only Legal Name and Email.
- Reviewers need to be in a position to provide meaningful feedback, supported by examples, that will help you find a focus.
- Choose people who you have worked closely with for at least 3 months. An exception is where you may have worked very closely with someone, say on a project, but for a shorter amount of time.
- Select reviewers who will provide you with honest and perhaps even "difficult to hear" feedback.
- Due to licensing, provisioning and security concerns we cannot include external stakeholders that are not GitLab team members in the 360 feedback process.

Example of a reviewer selection of a Backend Engineer:

1. 1x Manager
1. 3x fellow team members (peers)
1. 1x Software Engineer in Test (cross-functional collaborator on a project for 3+ months)

Remember you want to hear honest feedback so select reviewers you know will provide you meaningful data. In general, comments should be to the point and include specific examples. Helping your team member understand the impact of what they are, or are not doing, is an important part of making that feedback actionable. Feedback will be anonymous, however each team member is given a unique email link to provide feedback so please do not share. In Culture Amp reviewers are listed in 3 categories:

- Manager
- Direct Reports
- Co-worker

Feedback will not be tied back to a specific reviewer, however you only have 1 manager so you know that any feedback in that section came from directly from your manager. If you nominated 10 team members to provide feedback all 10 will be listed however any feedback is not tied directly back to a specific team member.

## Feedback Training Material

In addition to our [Guidance on Feedback]({{< ref "guidance-on-feedback" >}}) handbook page, we have a [Feedback Training issue available](https://gitlab.com/gitlab-com/people-group/Training/-/blob/master/.gitlab/issue_templates/feedback_training_issue) for all team members interested in learning more about giving and receiving feedback, in addition to our 360 Feedback process.

We encourage all team members to complete this training, and recommend it specifically for those participating in the 360 Feedback process either requesting feedback for themselves or providing feedback to others.

### Giving Feedback in 360s

**General Tips:**

- It is ok to skip a question by typing N/A if you don't have meaningful feedback in that area. Don't create a "story" where there is none.
- Prepare - Think about the individual beforehand. What do you value in them as a co-worker? Where do you think are their biggest opportunities to improve?
- Speak from your own experience - avoid "I've heard..." statements.
- Be specific - provide examples wherever possible and avoid general statements like "really good" or "difficult to work with". We recommend using the [SBI Model]({{< ref "guidance-on-feedback#s-b-i-model" >}}) to ensure clarity and specificity in feedback.
- Keep it actionable- always describe behaviors, not traits. Focus on what the person can actually do something about going forward (i.e. more of, less of, keep doing - "it would be good to see more of X as it leads to Y".)
- Be respectful AND honest - feedback on improvement areas can at times be challenging to give. Keep in mind the purpose of the feedback is for development and not to judge or evaluate performance. Team members cannot improve and grow if they don't know where to focus, so this type of feedback is also important and encouraged.
- Try to avoid comparing different team members and rather look at a person's progress, comparing them against themselves only.
  - Ex: Person X's performance in January compared to their performance in May, as opposed to person X's performance compared to person Z's performance.

Below are a couple of tips for team members who may have received a significant number of feedback requests to contribute to.

- Try to complete feedback for 1 or 2 people a day, versus waiting until the last minute. Spending 10-20 minutes a day on this can make thinking through and writing the feedback process less overwhelming. For those that may have a significant number of review requests.
- If you receive an overwhelming amount of feedback requests, prioritize the requests based on the team members you work most closely with (I.E. the people you feel you can provide the most meaningful and holistic feedback to). Feedback is a gift and you should try to provide meaningful feedback to as many requesters as possible, but be mindful of your own bandwidth as well. Start with your core group, and expand from there as capacity allows.

#### Managing Feedback Requests

If you feel overwhelmed by the number of team members that have requested feedback from you, keep in mind that you are providing your team members with a gift: the ability to learn and grow from the feedback they receive.

However, you may not have feedback related to each of the questions asked. That is ok. If you don't have anything meaningful to provide, you can put not-applicable. Focus on the team members and the questions for which you have meaningful and helpful feedback.
If you feel like you are not in a position to complete a meaningful review in general, please let the team member know, so they can possibly select another reviewer instead. Be mindful of your own bandwidth when providing reviews: Start with your core group, and expand from there as capacity allows.

#### Bias

- At this moment in time we do not have any integration tools in Culture Amp to help us combat bias. As an alternative and to help with this we have 2 Culture Amp training courses. One for [team members](https://www.cultureamptraining.com/participate-in-a-performance-cycle-for-employees/481210) and the other for [managers](https://www.cultureamptraining.com/performance-for-managers/437360). These training courses will combat bias.

### Receiving Feedback in 360s

Be open to engaging in the conversation. Your peers have taken the time to provide you with their feedback. And the purpose of this feedback is to help you develop and reach your full potential. The perception they have of you is important information for you to have and to build into an action plan.

Before going into the conversation and reviewing feedback, check out the page on [receiving feedback]({{< ref "guidance-on-feedback#receiving-feedback" >}}).

Be accepting of positive feedback. Instead of deflecting compliments, hear and internalise them. They are strong indicators of where you have successfully developed your skills. Remember to maintain a focus on them so you can continue to develop the skill.

During the 360 Feedback meeting:

- Breathe!
- Assume positive intent
- Avoid your first response as chances are it may be defensive
- Ask lots of questions to fully understand the feedback
- Ask for time to process the feedback and come back with any follow up questions & / or action
- Say thank you for their time

If you would like to learn more, we held a [Receiving Feedback Live Learning course]({{< ref "guidance-on-feedback#receiving-feedback" >}}) on 2020-02-25.

### Guidance for Managers

The feedback that your team member receives may reinforce excellent or under performance you have already observed, but shouldn't be the only data point you use in evaluating performance. In cases where you've identified your top performer, we should learn from what makes that person successful to share with others. In cases where unsatisfactory performance is identified, you should also address that timely and honestly. The feedback included through the 360 process may help in talking through examples of strengths or improvement areas, but you should not wait for the 360 Feedback process to address performance matters.

### Reviewing the Report as a Manager

Once the feedback cycle closes, managers and team members will be able to review the feedback prior to meeting to discuss.  Giving and receiving feedback can be hard for both the manager and the team members. Remember to be open-minded and calm. Be open-minded to the fact that others may see something that you do not. If you disagree with the feedback, others may be seeing something that you are not aware of- we called these blind spots earlier. Allow for the fact that others may be right, and use that possibility to look within yourself. Managers, feedback should never be a surprise! It is meant to guide, mentor, support, enhance, and help the team member grow. Try and maintain the model that feedback is a gift- it is data. More data is always better because it provides us with choices we wouldn't otherwise have.

### 360 Feedback Conversation

This section outlines the conversation for a manager to have with their direct report after the cycle has closed. This dicussion should focus on leveraging peer feedback to accelerate the team member's growth and development goals.

The high level recommended process is as follows:

1. *Before the meeting:* Review the 360 feedback before meeting your team member and summarize the key findings (possible recurring themes, patterns etc.)
1. *In the meeting:*
    - When discussing the feedback, ask open ended questions such as: What do you think of the feedback? Were there any surprises?
    - Give feedback using the S-B-I- model: situation - behavior - impact
    - Identify 1-2 development opportunities based on the feedback to focus on and identify concrete development actions. Ask open ended questions like "what would success look like?" which also engage the team member to take accountability for their own growth and development
    - Update the IGP based on the 360 findings and development actions.
1. *After the meeting:* periodically (quarterly) in 1:1s, review progress against the development goals and offer support as needed

Some general guidance and tips for the conversations can be found below:

- No surprises. Team members should not hear about positive feedback or performance in need of improvement for the first time at the 360 feedback meeting. Team members should have regular [1:1s](/handbook/leadership/1-1/) where this is discussed. However, if new information is uncovered during the 360 Feedback process, you should discuss that new data.
- The overall aim is providing meaningful feedback. Don't allow the feedback meeting (document and conversation) to (d)evolve into a "todo" list.
- Managers should send the results within 48 hours of the feedback cycle closing so they can prepare and come to the meeting with questions and discussion points.
- Make sure you (Manager) are also prepared for the discussion, write down some notes and key points you want to make. What are the major themes coming out of the feedback?
- Make time to talk about the future [career development]({{< ref "1-1#career-development-discussion-at-the-1-1" >}}) and development opportunities.
- This should be a conversation - remember to be an active listener. As a manager, you can help your team member process and understand the feedback, helping to avoid over/under reactions or defensiveness. Ask questions such as:
    1. Is there feedback that you received that is surprising or upsetting to you?
    1. After reading your feedback, what are the areas you would like to focus on and how can I help?
    1. How can I be a better manager for you?
    1. What are you hoping to achieve at GitLab this coming year?
- Follow Up. Did you discuss pathways to career progress, or specific points of attention for improving performance? Make sure you add them to the top of the 1:1 doc so as to remind yourselves to follow up every so often.
- Managers are encouraged to share their key learnings with their teams. Making yourself open and vulnerable can help the rest of the team understand that it is ok to get hard feedback and we can grow from it. It also enlists the team is helping you grow.
- Consider asking each team member to share the top 2-3 Themes from their feedback, what they plan to do now, and how the team can help.
- If there are areas that were indicated over the 360s that need immediate improvement, are not aligned with our values or go against our [Code of Business Conduct and Ethics for Directors, Officers, Employees and Contractors](https://ir.gitlab.com/static-files/7d8c7eb3-cb17-4d68-a607-1b7a1fa1c95d), please reach out to our [Team Member Relations Specialist](/handbook/people-group) via teammemberrelations@gitlab.com.

### Action Plans

Once feedback has been delivered, we recommend the manager and team member agree on a resulting action plan which can be captured in the Individual Growth Plan for ongoing reference and accountability.

### Sharing 360 Feedback outside of the 360 Feedback Cycle

If a team member becomes a manager to direct reports after the 360 Feedback cycle has completed, and would like to see their new direct reports' 360 Feedback reports, the new manager must reach out to the direct reports directly to ask permission for either the previous manager to download and send the reports, or for the direct reports to download their own reports and send them directly to the new manager. Any approval should be in writing by email, not Slack.

Detailed instructions for sharing this report can be found [here](https://support.cultureamp.com/hc/en-us/articles/115005797129-Share-feedback-report-in-Individual-effectiveness-360-).

## Common Questions

Troubleshooting for common questions during the 360 process.

1. I had a manager update during the 360 process, and I would like them to be my coach, how can I update this?
    - Reach out in `#people-connect` and request a coach update. Please provide the new coach's email address.
1. I will be out on PTO during the nomination period; what can I do?
    - You have two options
        1. Your manager/coach can update your nominations in CultureAmp -Or-
        1. You can email `#people-connect` with the email addresses of your nominations.
1. I submitted my 360 nominations but I want to make an adjustment, what can I do?
   1. First, sign into CultureAmp to see if you submitted your nominations or if you saved them as a draft. If it is in draft mode you can adjust the nominations yourself.
   1. If it has been submitted - reach out to your coach/manager. They are able to make these adjustments within CultureAmp.
1. Where can I give feedback about the 360 feedback process?
   1. Team members are encouraged to contribute to [this issue](https://gitlab.com/gitlab-com/people-group/people-operations/General/-/issues/1595) with feedback based on their experience in the 360 feedback process.
