---
title: "Anti-Harassment Policy"
description: "Everyone at GitLab has a responsibility to prevent and stop harassment. Learn more about our Anti-harassment policy."
---

{{% panel header="**This is a Secure Document**" header-bg="orange" %}}
Per the stated [Roles & Responsibilities](/handbook/people-group/anti-harassment/#roles--responsibilities), changes to this page must be approved or merged by a code owner. All contributions are welcome and encouraged.
{{% /panel %}}

## Introduction

Everyone at GitLab has a responsibility to prevent and stop harassment. Working remotely means that the majority of our interactions are by video call or written communication, such as email or shared documents. The exceptions to this are team summits, attending conferences together, and local team meetups. No matter the method of communication, it is expected that everyone will contribute to an inclusive and collaborative working environment and respect each other at all times. Team member behavior is not limited to internal interactions with each other.  Our Anti-harassment policy applies to GitLab team members interaction with customers, vendors and community members. Should you become aware of or witness any form of harassment or behavior that violates this policy or our [company values](/handbook/values/), please report the incident directly to the Chief People Officer, [Team Member Relations](/handbook/people-group/team-member-relations/#discussing-private-concerns), or a [People Business Partner](/handbook/people-group/#people-business-partner-alignment-to-division) immediately for thorough investigation.

## Perspective

GitLab is a global organization and our team is distributed all over the world, so we strive to ensure our team is fully aligned with GitLab's no tolerance harassment policy despite their location. We want everyone to feel confident and comfortable communicating concerns. GitLab respects, appreciates, understands and supports every aspect of diversity. We aim to continuously foster a globally aware team.

## Scope

This policy applies to all team members of GitLab, whether contractor or employee, in all locations. There are local labor laws in every country and in the case of the United States, state laws, that must be followed when handling, reporting and investigating incidents of harassment. The People Business Partner team and legal counsel, if required, in each of those countries will be called upon to ensure compliance and the appropriate legal processes and procedures are followed. Specific country requirements for employees (subject to changes in employment law) are listed in the [Country & US State-Specific Requirements](#country--us-state-specific-requirements) section and will be updated regularly. All individual contributors, managers, and leaders will be subject to disciplinary action, up to and including termination, for any act of harassment they commit.

## Roles and Responsibilities

| Role | Responsibility |
|-----------|-----------|
| GitLab Team Members | Responsible for following the requirements in these policies |
| People Ops | Responsible for implementing and executing these policies |
| Legal & People Ops Management (Code Owners) | Responsible for approving significant changes and exceptions to these policies |
| Ethics & Compliance, Legal Ops | Responsible for administrating related training |

## Types of Harassment

The following are considered forms of harassment and will not be tolerated by GitLab:

### Sexual Harassment

Sexual harassment is considered unwelcome conduct of a sexual nature that is sufficiently persistent or offensive enough to interfere with the receiver's job performance or create an intimidating, hostile or offensive working environment.

Sexual harassment encompasses a wide range of conduct. Examples of misconduct include, but may not be limited to, the following actions:

1. Physical assaults or the attempt to commit an assault of a sexual nature. This physical conduct can include touching, pinching, patting, grabbing, brushing against or poking another team member's body.
1. Unwelcome sexual advances, propositions or other sexual comments, such as sexually oriented gestures, noises, remarks, jokes, or comments about a person's sexuality or sexual experience.
1. Preferential treatment or promises of preferential treatment to a team member for submitting to sexual conduct, including soliciting or attempting to solicit any team member to engage in sexual activity for compensation or reward.
1. Subjecting, or threats of subjecting a team member to unwelcome sexual attention or conduct or intentionally making performance of the team member's role more difficult because of that team member's sex.
1. Creating displays, communications, or publications that include content of a sexually offensive nature.
1. Purposely misgendering people, such as consistently referring to someone as 'he' after repeated requests to use 'she' or vice versa.

Sexual harassment is unlawful and is considered a form of team member misconduct. Sanctions will be enforced against individuals engaging in sexual harassment and against supervisory and managerial personnel who knowingly allow such behavior to continue. Any retaliation against an individual who complains of sexual harassment or who testifies or assists in any proceeding under the law is unlawful.

### Discrimination

Having a diverse workforce, made up of team members who bring a wide variety of skills, abilities, experiences and perspectives, is essential to our success. We are committed to the principles of equal opportunity, inclusion, and respect. All employment-related decisions must be based on company needs, job requirements, and individual qualifications. Always take full advantage of what our team members have to offer; listen and be inclusive.

We do not tolerate discrimination against anyone, including team members, customers, business partners, or other stakeholders. Any form of discrimination towards an individual is strictly prohibited, including:

- On the basis of race (includes national origin or ancestry, ethnicity, national origin or ethnic characteristics; interracial marriage or association; traits historically associated with race, including hair texture, protective hairstyles, and any other national origin or ancestry "as specified by a complainant in a complaint"), color, religion (including all aspects of religious observance and practice, as well as belief or lack of religious belief), sex (including pregnancy, childbirth and related medical conditions; breastfeeding; sex assigned at birth; gender identity or gender expression; affectional or sexual orientation, including heterosexuality, homosexuality, bisexuality, and asexuality; and differences of sex development, variations of sex characteristics, or other intersex characteristics), age, disability, HIV status, marital status, past or present military service, life expectancy, or any other status protected by the laws or regulations in the locations where we operate.
- We comply with laws regarding employment of immigrants and non-citizens and provide equal employment opportunity to everyone who is legally authorized to work in the applicable country.
- We provide [reasonable accommodations](/handbook/people-policies/inc-usa/#reasonable-accommodation) to individuals with disabilities and remove any artificial barriers to success.

Report suspected discrimination right away and never retaliate against anyone who raises a good faith belief that unlawful discrimination has occurred.

If you believe you have been discriminated against or witnessed discriminatory practices, please contact the Chief People Officer, a [People Business Partner](/handbook/people-group/#people-business-partner-alignment-to-division), or the [Team Member Relations Specialist](/handbook/people-group/team-member-relations/) to initiate an investigation into the behavior. GitLab has also engaged Lighthouse Services to provide anonymous reporting methods, as described in the [How to Report Violations](/handbook/people-group/#how-to-report-violations) section.

### Bullying / Workplace Violence

GitLab does not tolerate violent acts or threats of violence. The company will not tolerate fighting, bullying, coercion, or use of abusive or threatening words directed to, about, or against a co-worker, lead, manager, executive, candidate, client/customer, vendor, contributor, or any other person. No individual employed by GitLab should commit or threaten to commit any violent act or discuss committing such offenses, even in a joking manner.

### Retaliation

Retaliation of any sort for filing a claim of harassment will not be tolerated. If you believe you have been retaliated against, please contact the Chief People Officer, [Team Member Relations](/handbook/people-group/team-member-relations/#discussing-private-concerns) or a [People Business Partner](/handbook/people-group/#people-business-partner-alignment-to-division) to initiate an investigation.

## Speaking up during a public situation

If someone messes up, people are encouraged to speak up publicly and within the moment, in order to let that person and others know that what happened was not inclusive behavior.

This makes for a situation from which all parties can learn, and is one which promotes understanding. Additionally it makes it possible for that person to de-escalate the situation by correcting themselves and apologizing.

This does not ensure there will be no consequences. However, it will greatly reduce the chance of escalation and has the potential to help a situation become comfortable and inclusive again.

## Reporting a Physical Threat

If a threat is made against you or someone else that makes you or another team member question their safety due to an issue, merge request, email or other work related matters do not hesitate to initiate the following process:

1. Contact local law enforcement. Note the proper number to contact in your locality and whether the emergency, or non-emergency number should be called.
1. Notify the People Connect Team via a HelpLab request. A private slack channel may then be opened with your People Business Partner, People Connect Team member, Team Member Relations, Manager, and the security team helping with the situation.
1. The following steps may be taken based on the threat:
    - Internal threat assessment
    - Temporary accommodation (friends, family, hotel, etc.)
    - Transportation to alternate location (stay with family/friends for example)
    - Time off from work/LOA
    - Personal Security Detail
1. The above can be triggered by the People Connect Team, Manager, Team Member Relations, or People Business Partner based on their knowledge of the threat.  Whenever it is safe to do so, please go through the normal permissions work flow, however if a threat is credible and potentially imminent, immediate action may be taken before the approvals have been put in place.
1. The Sr. Director of Security will advise when it is best to halt any of the above tasks.

## Reporting Alleged Harassment

1. Any individual who believes they have been the target of harassment of any kind is encouraged to immediately and directly address the harasser, letting them know that their behavior is unwelcome, offensive, and must stop immediately.
1. If they do not wish to address the harasser directly or the behavior doesn't cease, they should report the misconduct to the Chief People Officer, [Team Member Relations](/handbook/people-group/team-member-relations/#discussing-private-concerns) or a [People Business Partner](/handbook/people-group/#people-business-partner-alignment-to-division).
1. Once reported, an impartial investigation will be conducted by a People Business Partner or by an independent third party, depending on the severity and circumstances of the complaint.
1. Individual(s) reporting an incident or pattern of behavior will be asked to provide a written account, including any action(s) causing concern, the dates and times such actions occurred, and the names of anyone involved, including the participants and witnesses. All complaints or concerns of alleged harassment or discrimination will be taken seriously and handled confidentially.

### The Role of Managers

If managers become aware of misconduct, they must deal with any allegations expeditiously, seriously, confidentially, and fairly, whether or not there has been a written or formal complaint made to People Business partner. Informed managers are expected to:

1. Take all complaints or concerns of alleged harassment seriously no matter how minor or who is involved.
1. Ensure that any form of harassment or misconduct is immediately reported to People Business Partner.
1. Take appropriate action to prevent retaliation, or the alleged misconduct from recurring, during and after an investigation.

Managers who knowingly allow or tolerate any form of harassment or retaliation, including the failure to immediately report such misconduct to People Business Partner, are in violation of this policy and subject to disciplinary action, including termination.

### The Role of Individual Contributors

All employees have the responsibility to help create and maintain a work environment free of bullying and harassment and can help by:

1. Being aware of how their own behavior may affect others, and changing it if necessary.
1. Treating their colleagues with dignity and respect.
1. Taking a stand if they think inappropriate jokes or comments are being made to others.
1. Making it clear to others where they find their behavior unacceptable.
1. Intervening, if possible, to stop harassment or bullying from occurring.
1. Reporting promptly to their manager or the People Business Partner any incident of bullying or harassment witnessed by them.

### The Role of People Business Partners

The Chief People Officer and People Business Partners are responsible for:

1. Ensuring that any individual filing a complaint and any accused individual(s) are made aware of the seriousness of misconduct.
1. Explaining GitLab's no tolerance harassment policy and investigation procedures to all individuals included in a complaint.
1. Arranging for an immediate investigation of alleged misconduct and the preparation of a written report summarizing the results of the investigation and making recommendations for remediation to designated company officials.
1. Notifying appropriate authorities (police, FBI, country specific bureaus) when criminal activities are alleged.
1. Exploring informal means of resolving potential harassment if a written (formal) complaint is not made when verbal allegations are shared.

## Classification of disciplinary action

All individual team members, managers, and leaders will be subject to disciplinary action, up to and including termination, for any act of harassment they commit. Although disciplinary action will be specific to each case, it can generally be classified into 4 levels:

### Level 1

First time occurrences of inappropriate behavior. An act out of character. After formal investigation, coworkers still feel comfortable working with the offender.

- Suspension (Paid/Unpaid based on country)
- Formal apology towards inflicted parties

### Level 2

Recurring socially inappropriate behavior.

- Suspension (Paid/Unpaid based on country)
- Mandatory course on Inclusivity
- Formal apology towards inflicted parties
- Written admonition
- Potential transfer to another team
- Potential of termination

### Level 3

Major infraction, including retaliation, or recurring socially inappropriate behavior after a written admonition.

- Termination of employment

### Level 4

Serious cases, including any criminal offence.

- Termination of employment
- Reported to the Police/Authorities

## Training & Guidance

Training and guidance on understanding, preventing, and dealing with discrimination and sexual harassment will be provided to both managers and individual team members. The courses and the related enrollment logic can be found [here](/handbook/legal/legalops/navex/#courses). This training will be provided on a regular cadence, consistent with local requirements, and/or when new legal requirements are introduced.

## Country & US State-Specific Requirements

### GitLab BV (The Netherlands)

**Complaint Procedure**

If attempts to resolve the problem in an informal manner prove insufficient or if these attempts were refused or proved to be ineffective, the victim may follow the procedure below:

1. Write a formal complaint and send it to the Chief People Officer or the People Business Partner. When the Chief People Officer or the People Business Partner receives the complaint, they must immediately handle the written complaint.
1. The Chief People Officer or the People Business Partner shall ensure that the complaint is included in a dated document within a reasonable period of time, and includes the statements of the victim and any witnesses, as well as the outcome of any mediation.
1. The victim and the witnesses receive a copy of their statement.
1. A copy of the complaint will immediately be handed over to the responsible person within GitLab.
1. After submission of the complaint to the responsible person within GitLab, an investigation will be initiated. This investigation may be conducted by a third (independent) party, depending on the complaint itself.
1. After the investigation, the conclusion and a proposal for appropriate measures will be handed over to the responsible person within GitLab.
1. GitLab will take the appropriate measures.

**Sanctions**

Without prejudice to the provisions that may arise from a judicial process instituted by the victim, one or more of the following sanctions shall be imposed on the person guilty of undesirable conduct:

- A written admonition.
- Transfer to another department.
- Termination of the agreement.

GitLab shall impose, by registered letter and within five working days, the sanctions imposed upon the person who has been guilty of undesirable behavior. In case an employee abuses this complaint procedure, the above sanctions may also apply for the employee.

### GitLab BV (Belgium)

**Psychosocial Intervention**

GitLab has engaged with an external health and safety service called [Mensura](https://www.mensura.be/en/about-mensura) who are responsible for handling any complaints of harassment that are received but can not be resolved informally and internally. Team members in Belgium may contact this service if they wish and make a request for an informal or formal psychosocial intervention. A request for a formal intervention should include the following:

- a precise description of the constituent facts of violence, or psychological or sexual harassment at work, according to the Employee,
- when and where each of the events took place,
- the identity of the person(s) involved,
- the request to the Employer to take appropriate measures to put an end to the events.

The psychosocial intervention advisor will investigate further and provide a report to the employee and People Business Partner with a recommended course of action.

### GitLab GK (Japan)

**Protection from Power Harassment**

"Power harassment" is defined as any act by a person using his/her authority in the workplace, such as job position or human relationship with a team member, beyond the appropriate scope of business conduct, which causes such team member mental distress or physical pain or degradation of the working environment.
The law defines power harassment as "remarks or behaviour by people taking advantage of their superior position that go beyond business necessity, thereby harming the workplace environment.  GitLab expressly prohibits any behaviour toward team members that falls within the definition of power harassment.

Depending on the individual, a person may feel dissatisfaction when given the instructions, advice, or guidance necessary in the ordinary course of business.  In such cases where the actions are conducted within the scope of appropriate business practice, they should not fall under the category of power harassment.  Examples of power harassment include, but may not be limited to:

- assault or injury (physical abuse)
- threats, defamation, insult or slander (mental abuse)
- isolation, ostracization or neglect (cutting them off from human relationships)
forcing a team member to perform certain tasks, which are clearly unnecessary for the business or impossible to be performed or interrupting their normal duties (excessive work demands)
- ordering a team member to perform menial tasks which are far below the team member's ability or experience and do not provide any work at all for the team member relevant to the business (insufficient work demands)
- excessively inquiring into the private affairs of a team member (invasion of privacy)

Team members who feel that they may have been subjected to power harassment may bring their complaints to their People Business Partner, who will engage the appropriate internal consultation services and respond to claims.  GitLab is prohibited from dismissing or treating unfairly any team members who report harassment cases or cooperate in an investigation or consultation process.

**Prohibition of Sexual Harassment**

Team members are prohibited from any activities that cause disadvantage or discomfort to other employees or that are damaging to the work environment by way of speech or behaviour of a sexual nature.  GitLab shall take all necessary measures in managing employment to prevent sexual harassment at the workplace.

**Prohibition of Harassment Due to Pregnancy, Childbirth, Child Care Leave, or Family Care Leave**

Team members are prohibited from any activities that are damaging to the work environment of other employees by way of speech or behaviour related to pregnancy, childbirth, etc., or use of systems or measures related to pregnancy, childbirth, child care, family care, etc.  GitLab shall take necessary measures in managing employment to prevent harassment due to pregnancy, childbirth, child care leave, family care leave, etc. at the workplace.

**Prohibition of Any Other Forms of Harassment**

In addition to the prohibitions listed above, team members are prohibited from any other forms of harassment at the workplace that are damaging to the work environment of other team members such as by way of speech or behaviours related to sexual orientation or gender identification.

### GitLab LTD (The UK)

**Complaint Procedure**

1. If the employee does not wish to address the harasser directly, or the behavior does not cease, then the employee (accompanied by a colleague/union representative if they wish) should report the misconduct to their line manager or a member of the People Business Partner. Wherever appropriate the line manager and or the People Business Partner may attempt to resolve the situation on an informal basis.
1. If the informal approach does not resolve matters or the situation is too serious to be dealt with informally, the employee will need to make a formal complaint to the line manager and/or the People Business Partner.
1. Once reported, a formal investigation will be conducted impartially by People Business Partner or by an independent third party, depending on the severity and circumstances of the complaint. Individual(s) reporting an incident or pattern of behavior will be asked to provide a written account of any action(s) causing concern, dates and times such actions occurred, and names of anyone involved, including participants and witnesses. All complaints or concerns of alleged harassment or discrimination will be taken seriously and handled promptly, sensitively and confidentially.
1. Wherever possible the Company will try to ensure that the employee and the alleged harasser are not required to work together while the complaint is being investigated. This may involve the alleged harasser being suspended or transferred to another work area. In very serious cases, a criminal offence may have been committed and the employee may wish to report the matter to the police/authorities.
1. Employees will be kept informed of the general progress of the investigation and the outcome of any disciplinary proceeding.
1. If, following investigation, the complaint is upheld, appropriate disciplinary proceedings will be brought against the alleged harasser up to and including dismissal for gross misconduct. GitLab will work to prevent recurrence of the behavior.
1. If, following investigation, the complaint is not upheld, then the company will support both the employee and the alleged harasser in rebuilding their working relationship and may consider making arrangements to avoid the employee and the alleged harasser working together.
1. Where the employee is unhappy with the outcome of the formal investigation, they have the right to appeal against the outcome if they can demonstrate why they believe a particular aspect of the investigation has materially affected the outcome. Appeals must be submitted within 10 working days of receiving the outcome of the complaint.
1. If an appeal is submitted, the People Business Partner will arrange a meeting to take place with the appeal chair within a reasonable time period. The appeal chair's decision will be final and there is no further right of appeal. The appeal chair will be independent of the investigation.

### GitLab Ireland Ltd

**Complaint Procedure and Contacts**

The Company is aware of and recognises the effect that bullying, harassment and sexual harassment can have on its team members.

- "Contact Person" – Team Member Relations: teammemberrelations@gitlab.com
- "Designated Person" - For each formal complaint that is reported through Lighthouse, a Designated Person will be appointed by the Company to deal with the specific issue.

*Informal Procedure*

1. The Company is of the view that an informal approach to solving matters can often be effective. In the first instance, an attempt should be made to address an allegation of bullying, harassment and sexual harassment on an informal basis through the procedure set out below.
1. If you believe you are being bullied, harassed or sexually harassed you should explain clearly to the alleged perpetrator(s) that you find the behaviour in question to be unacceptable. If you would find it difficult to approach the alleged perpetrator(s) directly, then you may seek the advice or assistance of Team Member Relations. You may then request the assistance of Team Member Relations in raising the issue with the alleged perpetrator(s). Any approach made by Team Member Relations on your behalf to the alleged perpetrator(s) will be on a confidential, non-confrontational basis and will seek to resolve the issue in an informal low-key manner.
1. If you decide that it would not be appropriate for the Company to deal with your complaint under the informal procedure, or having done so you are not satisfied with the outcome, you should proceed to the Formal Procedure.

*Formal procedure*

1. To begin with, you should make a formal complaint in writing via Lighthouse, giving concrete examples of the alleged bullying, harassment and/or sexual harassment, the dates of any such incidents and details of witnesses, where possible. You may make your complaint anonymously if you wish.
1. The alleged perpetrator(s) will then be notified in writing that an allegation of bullying, harassment and/or sexual harassment has been made against them. A meeting will be arranged at which the alleged perpetrator(s) will be told that they will be given a fair opportunity to respond to each and every allegation of bullying, harassment and/or sexual harassment and they will be given a copy of your written complaint together with a copy of this policy.
1. A copy of this policy will also be provided to the complainant.
1. One or more designated members of the People Group (the Designated Person) will be responsible for carrying out an initial investigation into your complaint. The investigator may agree on terms of reference of the investigation with both you and the alleged perpetrator(s) in advance, and you and the alleged perpetrator(s) will be notified of the likely timescale for completion. This initial meeting will take place as soon as reasonably practicable following receipt of your complaint. If the Company considers it appropriate to do so, the Company reserves the right, at its discretion, to appoint or engage an external third party to conduct the investigation.
1. Where the allegations made are of a severe nature, the Company reserves the right to suspend the alleged perpetrator(s) on full pay pending an investigation.
1. The investigator will meet you, the alleged perpetrator(s) and any witnesses or other relevant persons on an individual basis to gather information surrounding the allegation. You and the alleged perpetrator(s) may be accompanied to such meeting by a colleague. The Company reserves the right to refuse your chosen representative attendance at the meeting where appropriate. You will be given the opportunity to change your chosen representative.
1. Every effort will be made to carry out and complete the investigation as quickly as possible and preferably within the agreed timeframe. Once the investigation is complete, the investigator will present a written report to management. Both the complainant and the alleged perpetrator(s) will be informed in writing of the investigator's report and both parties will be given the opportunity to comment on the report before any action is decided on by the Company.
1. If, on foot of the report, the Company decides that it is appropriate, a People group representative and applicable manager will meet formally with the alleged perpetrator(s) to determine an appropriate course of action. This may include counselling, monitoring, mediation and/or invoking the disciplinary procedure.
1. If the investigation concludes that based on the evidence, bullying, harassment or sexual harassment may have been perpetrated by an individual who is not a team member of the Company, the Company will decide what appropriate actions should be taken against such individuals including exclusion from Company premises or systems, suspension or termination of service/contract etc.
1. If the Company decides that the complaint is not well founded, a People group representative and applicable manager will formally meet with the complainant, again to determine an appropriate course of action. It may be that some kind of counselling or mediation session(s) is required between the complainant and the alleged perpetrator(s).
1. Either party may appeal the findings of an investigation under this procedure by submitting, in writing, within 5 working days of the Company's decision in respect of the complaint outlining the reasons for the appeal. The appeal will be heard on the points raised and will not involve reinvestigation of the complaint.

*Mediation*

1. Mediation is an alternative method of resolving issues relating to bullying, harassment and sexual harassment. Mediation involves the parties seeking to arrive at a solution through mutual agreement, rather than through an investigation and decision.
1. Mediation provides a confidential opportunity for the person who feels that they have been bullied, harassed or sexually harassed and the person(s) accused of carrying out this inappropriate behaviour to discuss the matter and to reach an agreement on their continuing working relationship.
1. Mediation is conducted in private, and is directly between the parties concerned, with the support of a mediator, who will act as an independent facilitator. Either party may withdraw from the process at any time by notifying the mediator, in writing, that they wish to do so.
1. If both parties agree to resolve the issue by mediation, the Company will arrange the mediation process. An appropriate person, acceptable to both parties, from within or outside the Company will be assigned as mediator. The Team Member Relations specialist may serve as the internal mediator, if acceptable to both parties.
1. If the mediation process results in an agreement acceptable to both parties, the mediator will draw up a written record of the terms of the settlement for signature by both parties.
1. If mediation breaks down or fails to achieve its goal, the matter can be processed through the other stages of this procedure. The person involved in the mediation process will not be involved in the investigation process.

### GitLab Inc and GitLab Federal LLC

In addition to [EthicsPoint](https://secure.ethicspoint.com/domain/media/en/gui/74686/index.html) and [Lighthouse](/handbook/people-group/#how-to-report-violations), please review the [Team Member Relations Specialist](/handbook/people-group/#team-member-relations-specialist) section. GitLab also offers a [Harassment Complaint Form](https://docs.google.com/document/d/1Xk5SXvh2kpO-w-TdykiczjhXNrEBjbMwDQHEt6lMhIk/edit?usp=sharing) that any team member may use to document any instance of any type of workplace harassment. Simply copy the form, fill it out with your information and send it to our Team Member Relations Specialist at teammemberrelations@gitlab.com.

### California Law Requirements

Every team member located in the state of California will be required to read, review, and understand the following three documents during their onboarding:

- [State requirements policy](https://docs.google.com/document/d/1n6tOlhAOJ-wtVjV8Iq-nGa5XgiDfolbHSqmmyE-XQas/edit)
- [California Law Prohibits Workplace Discrimination & Harassment](https://calcivilrights.ca.gov/wp-content/uploads/sites/32/2023/01/Workplace-Discrimination-Poster_ENG.pdf)
- [Sexual Harassment & Civil Remedies](https://drive.google.com/file/d/10-dnH-M8v4LSqBWhu4bVYk_qwvsqQtyd/view?usp=sharing)

### Connecticut Law Requirements

Every team member located in the state of Connecticut is required to take the 2 hour Anti Harassment Training for Supervisors. This training is to be completed by all individual contributors as well as managers.

### Maine Law Requirements

Team members who reside in Maine have the right to file a complaint through the [Maine Human Rights Commission](https://www.maine.gov/mhrc/laws-guidance/employment/sexual-harassment) within 300 days of the date of the alleged discrimination. You may contact the Commission by phone at (207) 624-6290, TTY Maine Relay 711, or by visiting the office located at 51 State House Station, August Maine, 04333-0051. It is unlawful under the Maine Human Rights Act for an employer to retaliate against you because you filed a complaint of discrimination or because you aided in an investigation.

### Massachusetts Law Requirements

Team members who reside in Massachusetts have the right to file a complaint to the [Massachusetts Commission Against Discrimination (MCAD)](https://www.mass.gov/orgs/massachusetts-commission-against-discrimination): 1 Ashburton Place, Suite 601, Boston, MA 02108, tel: (617) 994-6000, TTY:(617) 994-6196.

### Oregon Law Requirements

*Nondisclosure or Nondisparagement Agreements*

Under this policy, a nondisclosure agreement is any agreement by which one or more parties agree not to discuss or disclose information regarding any complaint of work-related harassment, discrimination, or sexual assault.

A nondisparagement agreement is any agreement by which one or more parties agree not to discredit or make negative or disparaging written or oral statements about any other party or the company.

A no-rehire provision is an agreement that prohibits a team member from seeking reemployment with the company and allows a company to not rehire that individual in the future.

The company will not require a team member to enter into any agreement if the purpose or effect of the agreement prevents the employee from disclosing or discussing conduct constituting discrimination, harassment, or sexual assault.

A team member claiming to be aggrieved by discrimination, harassment, or sexual assault may, however, voluntarily request to enter into a settlement, separation, or severance agreement which contains a nondisclosure, nondisparagement, or no-rehire provision and will have at least seven days to revoke any such agreement.

*Time Limitations*

Nothing in this policy precludes any person from filing a formal grievance in accordance with a collective bargaining agreement [if applicable], the [Bureau of Labor and Industries' Civil Rights Division](https://www.oregon.gov/boli/civil-rights/Pages/default.aspx) 800 NE Oregon St., Suite 1045 Portland, OR 97232, tel: (971) 673-0761, TTY Relay 711, or the Equal Employment Opportunity Commission. Note that Oregon state law requires that any legal action taken on alleged discriminatory conduct (specifically that prohibited by ORS 659A.030, 659A.082 or 659A.112) commence no later than five years after the occurrence of the violation. Other applicable laws may have a shorter time limitation on filing.

### Rhode Island Law Requirements

Team members who reside in Rhode Island have the right to file a complaint with the [Rhode Island Commission for Human Rights](http://www.richr.ri.gov/) located at 180 Westminster St., 3rd Floor, Providence, RI 02903. Phone: (401) 222-2661, Voice Relay: 7-1-1.

### Vermont Law Requirements

If the a team member who resides in Vermont is dissatisfied with this employer's action, or is otherwise interested in doing so, they may file a complaint by writing or calling the Vermont Attorney General's Office, Civil Rights Unit, 109 State Street, Montpelier, VT 05609, ago.civilrights@vermont.gov, tel:(888)745-9195 (Toll Free VT) or (802)828-3657 (voice/TDD). Complaints should be filed within 360 days of the adverse action.

## Resources

We are continuously gathering country specific references to review regulation and obtain guidance on the management of harassment or misconduct at work. Here are a few authorities we referred to in the creation of this policy:

- [Equal Employer Opportunity Commission (EEOC)](https://www.eeoc.gov/eeoc-guidance)
  - Contact [EEOC](https://www.eeoc.gov/filing-charge-discrimination): John F. Kennedy Federal Building, 475 Government Center, Boston, MA 02203, , tel:1-800-669-4000 (voice), 1-800-669-6820 (TDD). Complaints must be filed within 300 days of the adverse action.
- [Society of Human Resource Management (SHRM)](https://www.shrm.org/topics-tools#verticalTabs-39c94d1460-item-e2208bcacd-tab)

## Further Guidance (Country-Specific)

- [UK: Acas (advisory service for employees and employers)](https://www.acas.org.uk/discrimination-and-bullying)
- [The Netherlands: Inspectorate SZW](https://www.nlarbeidsinspectie.nl/)
- [Belgium: Unia: For equality, against discrimination](https://www.unia.be/en)
