---
title: "Employment Solutions - Overview"
description: GitLab's Employment Solutions.
---

This page contains an overview of how we have scaled team members Globally.
The DRI for all Employment Solutions is the [Employment Solutions Partner](/job-families/people-group/global-workforce-strategy). Any changes to any contracts should be requested to the Employment Solutions Partner and will require approval from our Director of Tax & our Director of Legal, Employment.

## Country Hiring Guidelines

The GitLab team has members in countries and regions all over the world and from all walks of life. Diversity, Inclusion & Belonging is one of our [core values](/handbook/values/). Maintaining operations in a large number of countries, some of which have complex rules, laws, and regulations, can affect our ability to conduct business efficiently. Unfortunately, this affects the employability of the citizens and residents of those countries. We are continuously exploring our hiring capabilities in a variety of geographies.

All of our roles are remote, however, some roles may carry specific location-based eligibility requirements. Our Talent Acquisition team can help answer any questions applicants may have about location after starting the recruiting process.

In the past GitLab would hire in any country except those we had already determined were not feasible due to certain restrictions. At present, we are focussing our hiring in countries where we have an [entity]({{< ref "employment-solutions#gitlab-entities-and-branches" >}}) or a [PEO]({{< ref "employment-solutions#peo-professional-employer-organization-employer-of-record-and-not-a-gitlab-entity-or-branch" >}}), that do not carry any hiring restrictions. More details can be found in our internal [compensation calculator](https://comp-calculator.gitlab.net/users/sign_in) under country hiring status.

Compared with our former approach of hiring contractors in any country and later planning to implement an entity/PEO, we see four instant benefits with this approach:

- Delivers consistent global team member experience (e.g. payroll, benefits, support, etc.)
- Reduces operational complexity
- Provides a stable footprint and makes it easier to grow in particular countries
- Closes the gap in building a scalable employment solution for 100% of team members

We can consider an exception to hire outside of these countries through the use of a PEO for future team members when supported by business needs, on a case-by-case basis. This approach enables a scalable solution from the onset and allows us to continue to hire diverse global talent whilst providing a consistent and positive team member experience. This approach will require a formal business need justification and will be addressed on a case-by-case basis.

Countries that do not have an entity/scalable PEO will be converted as part of our [country conversion process]({{< ref "employment-solutions#country-conversions" >}}).

## Team Member Types at GitLab

| Team Member Type | Abbreviation | Location |
| ---------------- | ------------ | -------- |
| Employee | Employee | Global |
| Contractor : IND | Cont-IND | Non-US |
| Contractor : C2C | Cont-C2C | Non-US |
| Employee : PEO | Emp-PEO | Non-US |
| Contractor : PEO | Cont-PEO | Non-US |
| Consultant | Cons-US | US Only |
| Intern | Intern | Global |

- C2C means Company to Company
- IND means Independent
- For more information on Consultants/Independent Contractors (those that are **US-based only**), please review the [Procurement](/handbook/finance/procurement/) handbook page.

## Team Member Types by Country

GitLab has a few different team member types. The following tables each show how we hire and scale around the world, where we have entities, where we use Professional Employer Organisations, and how we add new countries to our list.

To ensure the accurate entry of information in Workday, we created this table as guidance of what is applicable in which location. When adding new team members to Workday, please ensure you use this terminology for accurate reporting.

More information related to payroll processes can be found on the [Payroll handbook page](/handbook/finance/payroll/).

### GitLab Entities and Branches

Note: In countries with a star (*) hiring is limited to only certain roles, more detail can be found in our internal compensation calculator under [Country Hiring Status](https://comp-calculator.gitlab.net/hiring_status/index), found in the top right menu.

| Country                                                     | Team Member Type(s) | Entity                                                 | Pay Frequency | Paid By             | Workday Profile (Y/N) |
|-------------------------------------------------------------|---------------------|--------------------------------------------------------|---------------|---------------------|-----------------------|
| Australia                                                   | Employee            | GitLab PTY Ltd                                         |            12 | GitLab Payroll Dept | Y                     |
| Belgium *                                                   | Employee            | GitLab BV                                              |         13.92 | GitLab Payroll Dept | Y                     |
| Canada                                                      | Employee            | GitLab Canada Corp                                     |            26 | GitLab Payroll Dept | Y                     |
| Finland *                                                   | Employee            | GitLab BV                                              |            12 | GitLab Payroll Dept | Y                     |
| France *                                                    | Employee            | GitLab France S.A.S.                                   |            12 | GitLab Payroll Dept | Y                     |
| Germany                                                     | Employee            | GitLab GmbH                                            |            12 | GitLab Payroll Dept | Y                     |
| Ireland                                                     | Employee            | GitLab Ireland Ltd                                     |            12 | GitLab Payroll Dept | Y                     |
| Israel                                                      | Employee            | GitLab Israel Ltd.                                     |            12 | GitLab Payroll Dept | Y                     |
| Japan                                                       | Employee            | GitLab GK                                              |            12 | GitLab Payroll Dept | Y                     |
| Netherlands                                                 | Employee            | GitLab BV                                              |         12.96 | GitLab Payroll Dept | Y                     |
| New Zealand *                                               | Employee            | GitLab PTY Ltd NZ (Branch of GitLab PTY Ltd Australia) |            12 | GitLab Payroll Dept | Y                     |
| Singapore                                                   | Employee            | GitLab Singapore PTE. LTD                              |            12 | GitLab Payroll Dept | Y                     |
| South Korea                                                 | Employee            | GitLab Korea Limited                                   |            12 | GitLab Payroll Dept | Y                     |
| Spain *                                                     | Employee            | GitLab Iberia S.L.                                     |            12 | GitLab Payroll Dept | Y                     |
| United Kingdom (England, Scotland, Wales, Northern Ireland) | Employee            | GitLab UK Ltd                                          |            12 | GitLab Payroll Dept | Y                     |
| United States                                               | Employee            | GitLab Inc                                             |            24 | GitLab Payroll Dept | Y                     |
| United States (Public Sector)                               | Employee            | GitLab Federal LLC                                     |            24 | GitLab Payroll Dept | Y                     |

### PEO (Professional Employer Organization/ Employer of Record and not a GitLab entity or Branch)

This table reflects the countries in which we utilize PEO's. These countries are open for hiring but there may be times where we pause, close or are unable to hire in a given location due to the limitations or requirements of a particular role, or as a result of key projects or business needs. Our Talent Acquisition team can help answer any questions applicants may have about location once the recruiting process has begun:

Note: In countries with a star (*) hiring is limited to only certain roles, more detail can be found in our internal [compensation calculator](https://comp-calculator.gitlab.net/users/sign_in) under Country Hiring Status.

|     Country    |  Agreement Type(s) |  Hiring Partner  | Entity to Invoice (for AP only) | Pay Frequency | Paid By | Currency paid in | Workday Profile (Y/N) | Scalable PEO (Y/N) | Open for hiring (Y/N) |
|:--------------:|:------------------:|:----------------:|:-------------------------------:|:-------------:|:-------:|:----------------:|:---------------------:|:------------------:|:---------------------:|
|    Austria *   | Employed via a PEO | Global Expansion |       GitLab Services Inc       |       12      |   PEO   |        EUR       |           Y           |          Y         |           Y           |
|     Chile *    | Employed via a PEO | Global Expansion |       GitLab Services Inc       |       12      |   PEO   |        CLP       |           Y           |          Y         |           Y           |
|  Costa Rica *  | Employed via a PEO | Global Expansion |       GitLab Services Inc       |       12      |   PEO   |        USD       |           Y           |          Y         |           Y           |
|     India *    | Employed via a PEO |   Global Upside  |           GitLab IT BV          |       12      |   PEO   |        INR       |           Y           |          Y         |           Y           |
|     Kenya *    | Employed via a PEO | Global Expansion |       GitLab Services Inc       |       12      |   PEO   |        KES       |           Y           |          Y         |           Y           |
|    Latvia *    | Employed via a PEO | Global Expansion |       GitLab Services Inc       |       12      |   PEO   |        EUR       |           Y           |          Y         |           Y           |
|  Luxembourg *  | Employed via a PEO |    Remote.com    |           GitLab IT BV          |       12      |   PEO   |        EUR       |           Y           |          Y         |           Y           |
|    Mexico *    | Employed via a PEO |    Remote.com    |           GitLab IT BV          |       12      |   PEO   |        MXN       |           Y           |          Y         |           Y           |
|  Philippines * | Employed via a PEO |   Global Upside  |           GitLab IT BV          |       24      |   PEO   |        PHP       |           Y           |          Y         |           Y           |
| South Africa * | Employed via a PEO | Global Expansion |       GitLab Services Inc       |       12      |   PEO   |        ZAR       |           Y           |          Y         |           Y           |
|  Switzerland * | Employed via a PEO |    Remote.com    |           GitLab IT BV          |       12      |   PEO   |        CHF       |           Y           |          Y         |           Y           |
|    Sweden *    | Employed via a PEO |    Remote.com    |           GitLab IT BV          |       12      |   PEO   |        SEK       |           Y           |          Y         |           Y           |

This table reflects the countries in which we have utilized PEO's but are currently NOT open for hiring.
There are no current plans to open these countries for future hiring.  If we do open for hiring, it will be based on business needs.
More detail can be found in our internal [compensation calculator](https://comp-calculator.gitlab.net/users/sign_in) under Country Hiring Status.

| Country        | Agreement Type(s)    | Hiring Partner   | Entity to invoice (for AP only) | Pay Frequency | Paid By | Currency Paid in | Workday Profile (Y/N) | Employer of Record | Open for hiring (Y/N) |
|----------------|----------------------|------------------|---------------------------------|---------------|---------|------------------|-----------------------|--------------------|-----------------------|
| Armenia        | Contracted via a PEO | CXC              | GitLab IT BV                    | 12            | PEO     | USD              | Y                     | N                  | N                     |
| Czech Republic | Contracted via a PEO | CXC              | GitLab IT BV                    | 12            | PEO     | CZK              | Y                     | N                  | N                     |
| Greece         | Contracted via a PEO | CXC              | GitLab IT BV                    | 12            | PEO     | EUR              | Y                     | N                  | N                     |
| Poland         | Contracted via a PEO | CXC              | GitLab IT BV                    | 12            | PEO     | PLN, EUR, USD    | Y                     | N                  | N                     |
| Portugal       | Contracted via a PEO | CXC              | GitLab IT BV                    | 12            | PEO     | EUR              | Y                     | N                  | N                     |
| Romania        | Contracted via a PEO | CXC              | GitLab IT BV                    | 12            | PEO     | EUR, USD         | Y                     | N                  | N                     |
| Serbia         | Contracted via a PEO | CXC              | GitLab IT BV                    | 12            | PEO     | EUR              | Y                     | N                  | N                     |
| Slovenia       | Contracted via a PEO | CXC              | GitLab IT BV                    | 12            | PEO     | EUR              | Y                     | N                  | N                     |
| Turkey         | Contracted via a PEO | CXC              | GitLab IT BV                    | 12            | PEO     | USD              | Y                     | N                  | N                     |
| Ukraine        | Contracted via a PEO | CXC              | GitLab IT BV                    | 12            | PEO     | USD, EUR         | Y                     | N                  | N                     |
| Hungary        | Employed via a PEO   | Remote.com       | GitLab IT BV                    | 12            | PEO     | HUF              | Y                     | Y                  | N                     |
| Denmark *      | Employed via a PEO   | Remote.com       | GitLab IT BV                    | 12            | PEO     | DKK              | Y                     | Y                  | N                     |
| Brazil *       | Employed via a PEO   | Remote.com       | GitLab IT BV                    | 12            | PEO     | BRL              | Y                     | Y                  | N                     |
| UAE *          | Employed via a PEO   | Global Expansion | GitLab Services Inc             | 12            | PEO     | AED              | Y                     | Y                  | N                     |
| Italy *        | Employed via a PEO   | Remote.com       | GitLab IT BV                    | 14            | PEO     | EUR              | Y                     | Y                  | N                     |

Contact information for our PEO representatives is found in the `Entity & PEO Contacts` note in the PeopleOps vault in 1Password. If a team member, manager or PBP has a question relating to a PEO, their process, or any related procedure for a PEO-employed team member, please reach out to the Employment Solutions Partner (@hdevlin) who will liaise and find a solution with the PEO's support.

### Team Members Hired as Contractors via our GitLab IT BV Entity

Where we do not have an entity or a PEO, team members contract with our GitLab IT BV entity as independent or C2C contractors. We are not currently hiring in locations that do not have an entity or PEO. Some PEO's are not open for hiring, see table above for details.

## International Expansion

### Country Conversions

As GitLab continues to scale, we will be converting all team members to an employment scalable solution. Team members are hired in the following ways:

- Contractor through a PEO (Professional Employer Organization with a local presence)
- Employees through a PEO (Professional Employer Organization)
- GitLab entity

The Employment Solutions Partner is responsible for managing the country conversion processes outlined [here](https://gitlab.com/gitlab-com/people-group/people-operations/General/-/blob/master/.gitlab/issue_templates/country_conversions.md).

### Compensation Review for Country Conversions

As part of the country conversion and benefits review process, the Total Rewards and Employment Solutions Partner will review the gross value of cash compensation and benefits while also ensuring alignment to the employee rate in the compensation calculator.

The Total Rewards and People Connect Team member should also review alignment to the compensation ranges based on the new employee status and the range of the compensation calculator. Whenever we change salaries as part of a country conversion, these should be consistently applied among all team members in that country.

### WBSO (R&D tax credit) in the Netherlands

For roles directly relating to Research and Development in the Netherlands, GitLab may be eligible for the [WBSO (R&D Tax Credit)](https://english.rvo.nl/subsidies-financing/wbso).

#### Organizing WBSO

**Applications**

As of 2019 GitLab must submit three applications each year and the deadlines for those are as follows:

1. **31 March 2019**, for the May - August 2019 period (Product Manager for Create Features)
1. **31 August 2019**, for the September - December 2019 period (Product Manager for Gitaly)
1. **30 November 2019**, for the January - April 2020 period (Product Manager for Geo Features)

There is a [translated English version of the application template](https://docs.google.com/document/d/15B1VDL-N-FyLe84mPAMeJnSKjNouaTcNqXeKxfskskg/edit) located in the WBSO folder on the Google Drive. The applications should be completed by a Product Manager, responsible for features or a service within GitLab, who can detail the technical issues that a particular feature will solve. Assistance on completing the application can also be sought from the WBSO consultant (based in the Netherlands). The contact details for the consultant can be found in a secure note in the People Ops 1Password vault called WBSO Consultant. The People Connect Team member will assist with co-ordinating this process. It is currently owned by Finance.

**Hour Tracker**

Each year a spreadsheet with the project details and hours logged against the work done on the project(s) will need to be created. This is for the entire year. The current hour tracker is located in the WBSO folder on the Google Drive, and shared only with the developers that need to log their hours (located in the Netherlands), Total Rewards Analysts, Finance and the WBSO consultant. Once the projects have been completed for the year, the WBSO consultant will submit the hours and project details to claim the R&D grant from the [RVO](https://english.rvo.nl/). The WBSO consultant will contact Total Rewards Analysts should they have any queries.

## Engineering internships

Engineering is currently hiring interns. The [engineering internships handbook page](/handbook/hiring/emerging-talent/) has more information on this.

Interships require a fixed term contract during the internship, which is not possible in all countries.

The countries where we currently can hire interns are:

- Australia
- Austria
- Canada
- Chile
- Costa Rica
- Germany
- Ireland
- Japan
- Kenya
- Latvia
- Mexico
- Netherlands
- New Zealand
- Philippines
- Singapore
- South Africa
- South Korea
- United Kingdom
- United States
