---
title: Engagement Surveys and Employer Awards
description: >-
  GitLab uses engagement surveys to allow team members to provide feedback and
  leadership to gain insight.
---

### Surveys Overview

As an all-remote company, there are several surveys we run to better understand the GitLab culture, team member engagement, and overall health of the organization.

Seeking inputs from team members by surveying people is a key part of [GitLab's engagement strategy](https://docs.google.com/presentation/d/1obW5VTKywVyMXRd8no783BfnJJ8wzLVNcsFBC94-rAc/edit?usp=sharing) and helps the People Group to align our priorities to the areas team members care about most.

There are different survey types that we run at different times throughout the year, each with different intended outcomes:

- *Employer Award surveys:* we ask team members to complete employer award surveys (i.e. Great Place to Work) to understand how GitLab compares against our talent competitors and to give future candidates insight into what it would look like to work here. The process for selecting and participating in [employer award surveys]({{< ref "awards-process" >}}) is outlined in the Talent Brand section of the handbook.
- *Engagement survey:* We partner with CultureAmp to host and run our engagement surveys. We ask all team members to complete this survey at least once a year to understand how engagement is tracking over time.
- *Organizational Health survey:* we will sometimes run a survey to understand our company and culture more fully (i.e. McKinsey OHI survey) and classify these efforts as Organizational Health surveys.

## Employer Award surveys

### Great Place to Work

[Great Place to Work](https://www.greatplacetowork.com/) recognizes companies for their outstanding workplace culture, benefits and performance through successful completion of a regional team member survey and culture brief application. They partner with Fortune to produce the Fortune 100 Best Companies list annually. The survey is based off of the following components:

1. US-based respondents only
1. Surveyed over a 2-week period
1. 61 Statements
1. 14 On-Survey Demographic Questions
1. 2 Open-Ended Questions

<details><summary>FY25 Great Place to Work Survey Results</summary>

GitLab received [Great Place to Work Certification](https://www.greatplacetowork.com/certified-company/7013799) for the 4th year in a row in the US in May 2024 and was recognized as a top employer where team members are proud to work.

1. 87% average of all statements
1. 93% of team members say GitLab is a Great Place to Work

[Read more about the survey results](https://docs.google.com/presentation/d/1Sh9Q_rPBz3vO4HgvIkC574esC2F7UI5C_g3tOjddwm0/edit#slide=id.g123a13deda8_0_405).

</details>

<details><summary>FY24 Great Place to Work Survey Results</summary>

GitLab received [Great Place to Work Certification](https://www.greatplacetowork.com/certified-company/7013799) for the 3rd year in a row in the US in May 2023 and was recognized for our outstanding company culture.

1. 85% average of all statements
1. 89% of team members say GitLab is a Great Place to Work

[Read more about the survey results](https://docs.google.com/presentation/d/1lT6E46aDmMM8JGAdXmNJFnhoSeCBx9DstsOq-y6yFH0/edit#slide=id.g123a13deda8_0_405).

</details>

<details><summary>FY23 Great Place to Work Survey Result</summary>

GitLab received [Great Place to Work Certification](https://www.greatplacetowork.com/certified-company/7013799) for the 2nd year in a row in the US in December 2021 and was recognized for our outstanding company culture.

1. 93% average of all statements
1. 96% of team members say GitLab is a Great Place to Work

[Read more about the survey results](https://gitlab.com/gitlab-com/marketing/corporate_marketing/corporate-marketing/-/issues/5803).

</details>

## CultureAmp Engagement Survey Overview

Team Member Engagement is important to the continued success of GitLab making the Engagement Survey an important element within the annual `People Group` calendar. Engagement strategies have been shown to reduce attrition; improve productivity and efficiency; further embed the company values and ultimately enhance role satisfaction.

We partner with [CultureAmp](https://www.cultureamp.com/) to run our Engagement Surveys. CultureAmp provides a platform to gather feedback confidentially, benchmark against external comparables, and uses algorithms to highlight which areas matter most to our team members.

Engagement surveys are geared toward giving team members an opportunity to provide feedback in terms of their experience within GitLab touching on pertinent elements such as `Company Culture`, `Teamwork`, `Management` and `Inclusion` among others.

Feedback from the survey in turn allows Leadership within GitLab to gain insight into what is most important to team members, in particular what the business is doing well and what may need future iteration with the intention of improving the underlying team member experience and ensuring healthy levels of attrition are maintained.

### Survey Confidentiality

In an effort to ensure team member confidentiality is upheld, only managers with >5 respondents will be able to view quantitative results - this is carried across to demographic filtering in teams with population sizes which exceed the minimum too. The survey is wholly administered by Culture Amp on a secure external website and the survey data will not be stored on any local computer. If you'd like to know more, check out CultureAmp's [FAQ guide](https://support.cultureamp.com/en/articles/7048327-engagement-attributed-survey-guide-for-participants).

### Survey Participation

To make sure we hear from as many team members as possible, the People Group will provide Divisional leaders and People Business Partners with access to participation rates at the Divisional level and to managers with 5 or more direct reports.

We will share with individual managers how close they are to recieving enough responses to view a detailed report noting that managers can only see individualized results for their teams if 5 or more of their direct reports complete the survey. We will not report participation statistics for managers with fewer than 5 direct reports.

### Survey Sections and Factors

The GitLab Team Member Engagement Survey is comprised of eleven sections each of which is aligned to a specific area of focus otherwise known as a factor.

The survey factors we primarily focus on:

1. Overall Sentiment and Inclusivity
2. Confidence in GitLab and Management
3. Your Role & Connecting at GitLab
4. Team and Company Values
5. Action
6. Open text questions

Overall survey ranges anywhere from 40 to 50 questions. The format of the survey was predominantly Likert or Rating Scale with a handful of free text questions or comments toward the end. The favorable score is the percentage of participants who selected 'agree' and 'strongly agree'.

## FY'25 Engagement Survey

Our Engagement Survey for FY'25 is scheduled to run from 2024-06-17 to 2024-06-28. Survey will be open to all team members hired before 2024-05-31.

### FY'25 Annual Engagement Survey Timeline

- 202-06-17: Survey launch @ 8am PT
- 2024-06-28: Survey close @ 5pm PT
- 2024-07-08: High-level summary shared with People Leadership Team
- 2024-07-10: High-level summary shared with E-Group
- 2024-07-15: Vice President, Sr. Director, and Director level reports shared in CultureAmp*
- 2024-07-16: Sr. Manager and Manager level reports shared in CultreAmp*
- 2024-08-19: High-level summary release (company-wide) and followed by handbook updates
- 2024-07-18 through 2024-08-30: Division-level results summary shared by division leaders
- Q3 - Finalize Division specific action plans

*Only leaders with 5 or more respondents will receive a report in CultreAmp

### FY'25 Engagement Survey Results

Our FY'25 Annual Engagement Survey ran from 2024-06-17 to 2024-06-28. The survey was open to team members hired before 2024-05-31.

- We reached 83% participation which is 8% higher than the Post-Summit Survey and 5% lower than the FY24 Engagement survey.
- Overall engagement score of 78% favourable, 14%  neutral and 8% unfavourable.
- We scored 3% higher than we did in the FY'24 Engagement Survey overall, and 7% higher than our New Tech peer group, which consists of ~200 fast growing and disruptive tech companies who have ~1000+ total team members.
- GitLab remains in a strong position from an overall engagement score perspective with several opportunities highlighted in the detailed results section.

Below you will find a summary of our overall results, as well as key insights and opportunities. A huge thanks to everyone who completed the survey and made their voices heard. Your feedback helps us to continually improve the experience of working at GitLab.

#### Company Results (Overall)

| **Favourable** | **Neutral** | **Unfavourable** |
| ---------- | ------- | ------------ |
| 78% | 14% | 8% |

### Detailed Results (Overall)

We've documented our detailed FY25 Annual Engagement Survey results in a [presentation](https://docs.google.com/presentation/d/1LnUaYi52EcAFululv6ok2z1VdAGKIl4F1aRZvTbxQrU/edit#slide=id.g1d24c3e4ddd_5_252) that is available only for GitLab team members.

Those detailed results highlight the strengths and opportunities shared below in greater detail.

#### Top Three Scores

In addition to Engagement, we asked questions about other factors regarding our workplace and culture. A factor score is the average score of all questions within that factor.

| **Factor** | **Favourability Rating** |
| ------ | -------------------- |
| Psychological Safety | 90% |
| Your Manager | 83% |
| Values | 82% |

| **Top Scores - Individual statements** | **Favourability Rating** |
| ------ | -------------------- |
| I enjoy engaging with my peers at GitLab | 94% |
| It is easy to ask other members of your team for help | 92% |
| No one on my team would deliberately act in a way that undermines my efforts | 91% |

#### Top Three Opportunities

| **Factor** | **Favourability Rating** |
| ------ | -------------------- |
| Action | 60% |
| Benefits & Compensation | 63% |
| Company Confidence | 64% |

| **Opportunities - Individual statements** | **Favourability Rating** |
| ------ | -------------------- |
| I believe action will take place as a result of this survey | 58% |
| GitLab effectively directs resources (funding, people and effort) towards company goals | 59% |
| Most of the systems and processes here support us getting our work done effectively | 59% |

#### Using Epics and Issues to Create an Action Plan

All divisions are recommended to create an Epic to store Engagement Survey Action Issues. Every Division should create an Epic that gives an overview of the engagement survey results that includes: highlights, lowlights, recommended actions, and resources. Epics can be created in division issue boards or projects that are applicable to the organization.

In addition, Managers can create an Engagement Survey Action Issue that links to the division wide Epic. In the Issue, managers can link team wide actions to the division. Here is the recommended [action planning tips](https://docs.google.com/document/d/17C41zQRSRBfI-8_mzHYu91svF94b00DMNCfy6gW-hFI/edit#heading=h.cbt5f5ipulcx) for managers.

#### FY25 Engagement Survey Action Planning Epics

- [Company wide focus areas](https://gitlab.com/groups/gitlab-com/people-group/-/epics/109)
- [Product](https://gitlab.com/groups/gitlab-com/-/epics/2402)
- [Engineering](https://gitlab.com/groups/gitlab-com/engineering-division/-/epics/1)
- [Sales](https://gitlab.com/groups/gitlab-com/sales-team/-/epics/114)
- [Marketing](https://gitlab.com/groups/gitlab-com/-/epics/2419)
- [Finance](https://gitlab.com/groups/gitlab-com/-/epics/2416)
- [People](https://gitlab.com/groups/gitlab-com/-/epics/2420)
- [LACA](https://gitlab.com/groups/gitlab-com/-/epics/2414)
- [CISO](https://gitlab.com/groups/gitlab-com/-/work_items/2399)

### Summit Pulse Surveys Overview

The goal of the Summit is to build trust through social connections. This trust should lead to higher individual and team motivation, leading to higher productivity and retention. Higher trust between individuals and teams fuels collaboration and leads to stronger results.

To best determine how effective we are at achieving the goal of Summit is to gauge team member perceptions before and after the event.

#### We ran two surveys

- Pre-Summit: January 9, 2024 to January 19, 2024
- Post-Summit: March 15, 2024 to April 5, 2024

This will helped us gain valuable insights into any shifts in sentiments among team members, allowing us to assess the true impact of the summit, satisfaction and engagement.
This is an abbreviated version of our engagement survey, and it also includes a few Summit related questions.

### Survey Results

Team members can access Summit Pulse Survey results [here](https://docs.google.com/presentation/d/1OPOwu9JZxq4CoAiUAOMPZ-yXH99TPMPXObfzVMIWlto/edit#slide=id.g1d24c3e4ddd_5_252)

## FY'24 Engagement Survey

### FY'24 Engagement Survey Timeline

- 2023-05-16: Engagement Survey launch
- 2023-06-07: Engagement Survey close
- 2023-06-16: Results shared with e-group
- 2023-06-21: Results shared with VPs
- 2023-06-22: Managers with 5+ responses receive reports via Culture Amp
- 2023-06-22: Initial results at the Q2 Assembly
- 2023-06-22 through 2023-07-04: Leaders/Managers review their reports and discuss/brainstorm action plans in Staff/team meetings
- 2023-07-21: Target date for full results shared company-wide
- 2023-07-30: Finalize Action items and document in epics/issues
- 2023-08-01: Division action plans added to FY'24 Q3 OKRs and Division epics
- 2023-08-31: Department action plans (if applicable) complete

### FY'24 Q2 Engagement Survey Results

Our Engagement Survey FY'24 Q2 ran from 2023-05-22 to 2023-06-07. The survey was opened to team members hired before 2023-04-30.

- We reached 88% participation which is 6% higher than the FY23 Pulse Engagement survey.
- Overall engagement score of 75% favorable, 17%  neutral and 8% unfavourable.
- We scored 6% lower than we did in the FY'23 Q2 Engagement Survey overall, but this score is still 2% higher than our New Tech peer group, which consists of ~200 fast growing and disruptive tech companies who have ~1000+ total team members.
- Amongst our SaaS Talent Peers of 1000+ team members, Culture Amp shared that engagement scores are decreasing by 5-10% due to macroeconomic conditions and uncertainty in the industry.
- GitLab remains in a strong position from an overall engagement score perspective with several opportunities highlighted in the detailed results section.

Below you will find a summary of our overall results, as well as key insights and opportunities. A huge thanks to everyone who completed the survey and made their voices heard. Your feedback helps us to continually improve the experience of working at GitLab.

#### Company Results (Overall)

| **Favourable** | **Neutral** | **Unfavourable** |
| ---------- | ------- | ------------ |
| 75% | 17% | 8% |

#### Detailed Results (Overall)

We've documented our detailed FY24 Culture Amp Engagement survey results in a [presentation](https://docs.google.com/presentation/d/1fs5mPdQUdZXR6blK-5cFZL_N-Qr2Y8eta_EhKQAYa64/edit?usp=sharing) that is available only for GitLab team members.

Those detailed results highlight the strengths and opportunities shared below in greater detail.

#### Top Three Scores

In addition to Engagement, we asked questions about other factors regarding our workplace and culture. A factor score is the average score of all questions within that factor.

| **Factor** | **Favourability Rating** |
| ------ | -------------------- |
| Psychological Safety | 88% |
| Your Manager | 84% |
| Connectedness | 78% |

| **Top Scores - Individual statements** | **Favourability Rating** |
| ------ | -------------------- |
| I enjoy engaging with my peers at GitLab | 94% |
| It is easy to ask other members of your team for help | 92% |
| No one on my team would deliberately act in a way that undermines my efforts | 91% |

#### Top Three Opportunities

| **Factor** | **Favourability Rating** |
| ------ | -------------------- |
| Action | 58% |
| Company Confidence | 60% |
| Our Leaders | 62% |

| **Opportunities - Individual statements** | **Favourability Rating** |
| ------ | -------------------- |
| I believe action will take place as a result of this survey | 55% |
| GitLab effectively directs resources (funding, people and effort) towards company goals | 57% |
| When there are career opportunities at GitLab, I am aware of them | 58% |

Additional analysis associated with these opportunities is included in our detailed FY24 Culture Amp Engagement survey results [presentation](https://docs.google.com/presentation/d/1fs5mPdQUdZXR6blK-5cFZL_N-Qr2Y8eta_EhKQAYa64/edit?usp=sharing) that is available only for GitLab team members.

#### Using Epics and Issues to Create an Action Plan

For the FY24 Engagement Survey, all divisions are recommended to create an Epic to store Engagement Survey Action Issues. Every Division should create an Epic that gives an overview of the engagement survey results that includes: highlights, lowlights, recommended actions, and resources. Epic's can be created in division issue boards or projects that are applicable to the organization.

In addition, Managers can create an Engagement Survey Action Issue that links to the division wide epic. In the Issue, managers can link team wide actions to the division.

##### FY24 Division-Wide Engagement Survey Action Epics

- [Product](https://gitlab.com/groups/gitlab-com/-/epics/2195)
- [Engineering](https://gitlab.com/groups/gitlab-com/-/epics/2217)
- [Sales](https://gitlab.com/groups/gitlab-com/sales-team/-/epics/82)
- [Marketing](https://gitlab.com/groups/gitlab-com/marketing/-/epics/4199)
- [Finance](https://gitlab.com/groups/gitlab-com/-/epics/2216)
- [People](https://gitlab.com/groups/gitlab-com/-/epics/2220)
- [Legal & Corporate Affairs](https://gitlab.com/groups/gitlab-com/-/epics/2223)
- [CISO](https://gitlab.com/groups/gitlab-com/-/epics/2196)

### Summit Pulse Surveys Overview

The goal of the Summit is to build trust through social connections. This trust should lead to higher individual and team motivation, leading to higher productivity and retention. Higher trust between individuals and teams fuels collaboration and leads to stronger results.

To best determine how effective we are at achieving the goal of Summit is to gauge team member perceptions before and after the event.

#### We ran two surveys

- Pre-Summit: January 9, 2024 to January 19, 2024
- Post-Summit: March 15, 2024 to April 5, 2024

This will helped us gain valuable insights into any shifts in sentiments among team members, allowing us to assess the true impact of the summit, satisfaction and engagement.
This is an abbreviated version of our engagement survey, and it also includes a few Summit related questions.

### Survey Confidentiality

In an effort to ensure team member confidentiality is upheld, only managers with >5 respondents will be able to view quantitative results - this is carried across to demographic filtering in teams with population sizes which exceed the minimum too. The survey is wholly administered by Culture Amp on a secure external website and the survey data will not be stored on any local computer. If you'd like to know more, check out CultureAmp's [FAQ](https://support.cultureamp.com/en/articles/7048327-engagement-attributed-survey-guide-for-participants) guide.

### Survey Results

Team members can access Summit Pulse Survey results [here](https://docs.google.com/presentation/d/1OPOwu9JZxq4CoAiUAOMPZ-yXH99TPMPXObfzVMIWlto/edit#slide=id.g1d24c3e4ddd_5_252)

<details>
  <summary markdown="span">FY'23 and prior Years Engagement Surveys</summary>

### FY'23 Pulse Engagement Survey

#### FY'23 Pulse Engagement Survey Timeline

- 2022-05-16: Pulse Survey launch
- 2022-05-25: Pulse Survey close
- 2022-06-14: Results shared with e-group
- 2022-06-21: Managers with 5+ responses receive reports via Culture Amp
- 2022-06-21 through 2022-07-04: Leaders/Managers review their reports and discuss/brainstorm action plans in Staff/team meetings
- 2022-06-28 and 2022-06-29: Results shared company-wide at GitLab Assembly
- 2022-07-30: Finalize Action items and document in epics/issues
- 2022-08-01: Functional action plans added to FY'23 Q3 OKRs and Division epics

#### Taking Action

Once the GitLab Team Member Engagement Survey has been closed out, reports will be dissementated to the E-Group and Divisional Heads for review i.e. only those with team populations >5. These will form the basis of discussion when collaboratively compiling the people strategy for year ahead in conjunction with additional data such as attrition reports etc.

##### Timeline for Action Planning

- Each E-Group member will in collaboration with their respective People Business Partner (PBP) to identify one or two acton items to initiate coming out of the results review - these will be tracked and managed via a dedicated [Epic in GitLab per Division]({{< ref "engagement#using-epics-and-issues-to-create-an-action-plan" >}}).
- After action items have been identified at the E-Group level, all managers who received an engagement survey result report (AKA: managers with 5+ direct reports who responded to the survey) will also be asked to create an action plan in Culture Amp.
- A manager may choose to align their action planning to their leader or division or they may choose to add a specific and separate action for their team. This will likely depend on the size/structure of the organization.

#### Using Epics and Issues to Create an Action Plan

For the FY23 Engagement Survey, all divisions are recommended to create an Epic to store Engagement Survey Action Issues. Every Division should create an Epic that gives an overview of the engagement survey results that includes: highlights, lowlights, recommended actions, and resources. Epic's can be created in division issue boards or projects that are applicable to the organization.

In addition, Managers can create an Engagement Survey Action Issue that links to the division wide epic. In the Issue, managers can link team wide actions to the division.

See the [example epics]({{< ref "engagement#taking-action" >}}) from FY22 for inspiration.

##### FY23 Division-Wide Engagement Survey Action Epics

- [Engineering](https://gitlab.com/groups/gitlab-com/-/epics/1887)
- [Product](https://gitlab.com/groups/gitlab-com/-/epics/1883)
- [Sales](https://gitlab.com/groups/gitlab-com/sales-team/-/epics/55)
- [Marketing](https://gitlab.com/groups/gitlab-com/marketing/-/epics/3130)
- [Finance](https://gitlab.com/groups/gitlab-com/Finance-Division/-/epics/7)
- [People](https://gitlab.com/groups/gitlab-com/people-group/-/epics/98)
- [Legal & Corporate Affairs](https://gitlab.com/groups/gitlab-com/-/epics/1898)

#### Resources for Managers

[Engagement Survey Manager Toolkit - GitLab Learn pathway](https://gitlab.edcast.com/pathways/engagement-survey-manager-toolkit)

[Managers Guide to Taking Action](https://support.cultureamp.com/en/articles/7048670-manager-s-guide-to-taking-action-on-engagement-survey-results)

[Take Action with Action Framework](https://support.cultureamp.com/en/articles/7048673-take-action-with-the-action-framework)

## FY'23 Q2 Pulse Engagement Survey Results

Our Pulse Engagement Survey FY'23 Q2 ran from 2022-05-16 to 2022-05-25. The survey was opened to team members hired before 2022-04-30.

1. We reached 82% participation and an overall engagement score of 81% favorable.
1. We scored 4% lower than we did in the FY'22 Q4 Engagement Survey overall, but this score is still 8% higher than our New Tech peer group, which consists of ~150 fast growing and disruptive tech companies who have ~1000+ total team members.
1. Amongst our SaaS Talent Peers of 1000+ team members - engagement scores are decreasing by 5-10% from pre to during-pandemic times.
1. GitLab remains industry-leading from a scoring perspective.

Below you will find a summary of our overall results, as well as key insights and opportunities.

A huge thanks to everyone who completed the survey and made their voice heard. Your feedback helps us to continually improve the experience of working at GitLab.

### Company Results (Overall)

| **Favourable** | **Neutral** | **Unfavourable** |
| ---------- | ------- | ------------ |
| 81% | 13% | 6% |

### Top Three Scores

In addition to Engagement, we asked questions about other factors regarding our workplace and culture. A factor score is the average score of all questions within that factor.

| **Factor** | **Favourability Rating** |
| ------ | -------------------- |
| Your Manager | 87% |
| Inclusion | 82% |
| Growth & Development | 81% |

GitLab was rated between 5%-8% percent higher than the industry benchmark i.e. New Tech (1,000+) 2022 across all three factors detailed above.

| **Question** | **Favourability Rating** |
| -------- | -------------------- |
| I am proud to work for GitLab | 94% |
| I would recommend GitLab as a great place to work | 91% |
| My manager keeps me informed about what is happening | 90% |

GitLab was rated between 6-8% higher than the industry benchmark i.e. New Tech (1,000+) 2022 across all three questions detailed above.

### Top Three Opportunities

| **Factor** | **Favourability Rating** |
| ------ | -------------------- |
| Action | 59% |
| Your Role | 70% |
| Our Leaders | 77% |

GitLab was rated up to 3% higher than the industry benchmark i.e. New Tech (1,000+) 2022.

| **Question** | **Favourability Rating** |
| -------- | -------------------- |
| I have seen positive changes taking place based on recent team member survey results | 54% |
| I believe my Compensation (Base, Bonus, etc.) is competitive relative to similar roles at other companies | 62% |
| I believe action will take place as a result of this survey| 64% |

GitLab scored 4% higher than the industry benchmark i.e. New Tech +1,000 2022 for the lowest scoring question surrounding positive actions, 9% higher than the benchmark regarding compensation and 2% higher regarding actions taken from the survey.

### FY'22 Pulse Engagement Survey

#### How We Determine "Pulse" Survey Questions

In FY'22 Q4 we launched our first "pulse" survey. To determine these questions we leveraged a combination of Culture Amp's "impact" feature + recommended focus areas + key themes related to the [Great Resignation](https://www.cultureamp.com/blog/the-great-resignation-turnover) (according to Culture Amp's People Scientist teams) to determine which rating questions to include in the pulse survey.

Per CultureAmp's insights related to the Great Resignation, we added questions related to:

- Focus on "Your Manager" (feedback from Manager, and overall manager performance)
- Inclusion
- The 5 overall Engagement factor questions

Culture Amp determines which questions are "focus recommendations" based on: impact on overall, favorable score, comparison to benchmarks. [Here](https://support.cultureamp.com/en/articles/7048700-focus-agent-feature-in-survey-analytics) is more information on how Culture Amp determines "focus" recommendations.

"Impact" is a word we use to refer to a statistical technique called a driver analysis. People Intelligence relies on a lot of data and analysis techniques, and one of the most powerful is Driver Analysis. Driver Analysis lets you focus on the most important drivers of outcomes for your culture. The questions that are identified as the top drivers are the questions that are most likely having the biggest impact on Engagement (or whatever measure you have set up as your outcome). So if you were able to improve your scores on these questions, you are likely to improve your Engagement score. You can find more information on how "impact" is determined [here](https://support.cultureamp.com/hc/en-us/articles/208026545-Impact-and-driver-analysis-FAQs).

In addition to leveraging insights from our Engagement Survey tool, Culture Amp, the People Group may add in a couple of additional questions particularly relevant to current business priorities, changes, and/or challenges.

#### FY'22 Pulse Engagement Survey Questions

The FY'22 Pulse Engagement Survey included 19 rating questions and 3 open ended text questions. A complete list of questions can be found [here](https://docs.google.com/document/d/1i25j1t55NK48bkT2MJh-05pSOcKKU3QMrU5D4wknS5w/edit#).

#### FY'22 Pulse Engagement Survey Timeline

- 2021-11-04: Pulse Survey launch @ 8am PT
- 2021-11-18: Pulse Survey close @ 11pm PT
- 2021-11-22: High-level summary shared with CPO and PBPs
- 2021-11-29: High-level summary shared with e-group
- 2021-12-01: High-level summary release (company-wide)
- 2021-12-03: E-group division-level summary release
- 2021-12-08: Training video (updated as needed) and results handbook update
- 2021-12-10 through 2021-12-31: Functional group action planning
- 2022-01-31: Functional action plans added to FY'23 Q1 OKRs and Division epics

*Note: Only team members hired on or before October 15, 2021 will be eligible to participate in the Pulse Engagement Survey.*

#### Taking Action

Once the GitLab Team Member Engagement Survey has been closed out, reports will be dissementated to the E-Group and Divisional Heads for review i.e. only those with team populations >5. These will form the basis of discussion when collaboratively compiling the people strategy for year ahead in conjunction with additional data such as attrition reports etc.

##### Timeline for Action Planning

- Each E-Group member will in collaboration with their respective People Business Partner (PBP) to identify one or two acton items to initiate coming out of the results review - these will be tracked and managed within CultureAmp moving forward using the [Action Framework](https://support.cultureamp.com/en/articles/7048673-take-action-with-the-action-framework).
- After action items have been identified at the E-Group level, all managers who received an engagement survey result report (AKA: managers with 5+ direct reports who responded to the survey) will also be asked to create an action plan in Culture Amp.
- A manager may choose to align their action planning to their leader or division or they may choose to add a specific and separate action for their team. This will likely depend on the size/structure of the organization.

##### Using Epics and Issues to Create an Action Plan

For the FY22 Engagement Survey, all divisions are recommended to create an Epic to store Engagement Survey Action Issues. Every Division should create an Epic that gives an overview of the engagement survey results that includes: highlights, lowlights, recommended actions, and resources. Epic's can be created in division issue boards or projects that are applicable to the organization.

In addition, Managers can create an Engagement Survey Action Issue that links to the division wide epic. In the Issue, managers can link team wide actions to the division.

See the examples from FY21' for the [Product](https://gitlab.com/gitlab-com/Product/-/issues/1986) and [Development](https://gitlab.com/gitlab-com/www-gitlab-com/-/issues/10743) groups for inspiration.

**FY22 Division-Wide Engagement Survey Action Epics:**

- [Engineering](https://gitlab.com/groups/gitlab-com/-/epics/1679)
- [Product](https://gitlab.com/groups/gitlab-com/-/epics/1682)
- [Sales](https://gitlab.com/groups/gitlab-com/sales-team/-/epics/48)
- [Marketing](https://gitlab.com/groups/gitlab-com/marketing/-/epics/2513)
- [Finance](https://gitlab.com/groups/gitlab-com/Finance-Division/-/epics/7)
- [People](https://gitlab.com/groups/gitlab-com/people-group/-/epics/89)
- [Legal & Corporate Affairs](https://gitlab.com/gitlab-com/legal-and-compliance/-/issues/717)

#### Resources for Managers

[Engagement Survey Manager Toolkit - GitLab Learn pathway](https://gitlab.edcast.com/pathways/engagement-survey-manager-toolkit)

[Managers Guide to Taking Action](https://support.cultureamp.com/en/articles/7048670-manager-s-guide-to-taking-action-on-engagement-survey-results)

[Take Action with Action Framework](https://support.cultureamp.com/en/articles/7048673-take-action-with-the-action-framework)

## FY' 22 Q4 Pulse Engagement Survey Results

Our Pulse Engagement Survey FY'22 Q4 ran from 2021-11-4 to 2021-11-18 and was open to all team members who started prior to 2021-10-15. We reached 87% participation and an overall engagement score of 85% favorable.
This score is 9 pts higher than our New Tech peer group, which consists of ~150 fast growing and disruptive tech companies who have ~1000+ total team members.
We also scored 4 pts higher than we did in the 2020 Engagement Survey overall.

Below you will find a summary of our overall results, as well as key insights and opportunities.

A huge thanks to everyone who completed the survey and made their voice heard. Your feedback helps us to continually improve the experience of working at GitLab.

### Company Results (Overall)

| **Favourable** | **Neutral** | **Unfavourable** |
| ---------- | ------- | ------------ |
| 85% | 11% | 4% |

### Top Three Scores

In addition to Engagement, we asked questions about other factors regarding our workplace and culture. A factor score is the average score of all questions within that factor.

| **Factor** | **Favourability Rating** |
| ------ | -------------------- |
| Company Confidence | 94% |
| Inclusion | 88% |
| Our Leaders | 83% |

GitLab was rated between 4%-12% percent higher than the industry benchmark i.e. New Tech (1,000+) 2021 across all three factors detailed above.

| **Question** | **Favourability Rating** |
| -------- | -------------------- |
| I am proud to work for GitLab | 96% |
| GitLab is in a position to really succeed over the next three years | 94% |
| I would recommend GitLab as a great place to work | 94% |

GitLab was rated between 7-12% percent higher than the industry benchmark i.e. New Tech (1,000+) 2021 across all three questions detailed above.

### Top Three Opportunities

| **Factor** | **Favourability Rating** |
| ------ | -------------------- |
| Action | 55% |
| Your Role | 67% |
| Growth & Development | 79% |

GitLab was rated between 1%-10% percent higher than the industry benchmark i.e. New Tech (1,000+) 2021 across all three factors detailed above.

| **Question** | **Favourability Rating** |
| -------- | -------------------- |
| I have seen positive changes taking place based on recent team member survey results | 48% |
| I believe action will take place as a result of this survey | 61% |
| I believe there are good career opportunities for me at GitLab | 72% |

GitLab scored 1-2% below the industry benchmark i.e. New Tech +1,000 2021 for the two lowest scoring questions surrounding positive actions however GitLab scored 6% higher than the benchmark regarding career opportunities.

### FY' 22 E-Group Focus Areas

For the FY'22 Q4 Pulse Engagement Survey results, we will be leaning into epics and issues for tracking and planning.

You can find full detail on the process and guidance [here]({{< ref "engagement#taking-action" >}}).

All links should be added by 2022-01-21 aligned with our [timeline]({{< ref "engagement#fy22-pulse-engagement-survey-timeline" >}}).

#### Actions taken since the last survey

**Growth & Development**

1. 2 L&D team members trained to deliver Crucial Conversations and so far delivered 3 cohorts in 2021
1. Hosted multiple live learning sessions
1. Organized Skill of the Month
1. Added LinkedIn Learning benefit for team members
1. Iterated and delivered multiple sessions of Manager Challenge
1. Implemented new GitLab Learn LXP
1. Built out mentorship handbook resources
1. Piloting LifeLabs Learning for Manager Enablement
1. Launched GitLab Team Members Certification
1. Learning & Development Team expansion with 2 new team members
1. Facilitated over 15 CEO Handbook Learning Sessions
1. Launched Functional Learning Hubs on GitLab Learn

**Compensation**

1. Implemented regions in the location factors.
1. Moved to annual refresh grants from 3.5 year refresh with the first cycle taking effect March 2021.
1. Moved from options to RSUs in September 2021.
1. Reduced the vesting for RSUs to new hire cliff of 6 months and no cliff for promos/refresh.
1. Implemented industry leading ESPP / Alternate ESPP for all team members at GitLab.

**Resource Allocation**

1. Increased headcount from 1267 team members in December 2020 to 1574 team members in December 2021.
1. Our average promotion rate in 2021 is 16.77%, which is higher than the average market promotion rate

#### Questions and Support

The GitLab Team Member Engagement Survey is managed by the People Connect Team. If you require support or have any questions around the survey please be sure to reach out via HelpLab.

## Previous Engagement Survey Results

### FY' 21 Engagement Survey

The GitLab Team Member Engagement Survey for 2020 (FY21) ran from 2020-11-16 to 2020-12-15 - questions and fine details can be found in the [following planning issue](https://gitlab.com/gitlab-com/people-group/General/-/issues/931).

Bar those who joined on or after 2020-11-01 the survey was extended to all GitLab Team members for completion. Participation for the FY21 survey closed out at 92% with 1,127 team members having taken part.

#### Benchmarking and Reporting

The FY21 survey was benchmarked against New Tech 1,000+ 2020 in addition to being reviewed against the preceding years results. Preliminary reports were released on 2021-01-08 painting a broad overview afterwhich individual divisional reviews will take place in collaboration with the [People Business Partners (PBPs)](/job-families/people-group/people-business-partner) and respective Group Leaders.

#### Company Results (Overall)

| **Favourable** | **Neutral** | **Unfavourable** |
| ---------- | ------- | ------------ |
| 81% | 14% | 5% |

The benchmarked favourability score for New Tech 1,000+ 2020 was 73% placing GitLab 8% higher than the norm for this particular bracket.

#### Top Three Scores

| **Factor** | **Favourability Rating** |
| ------ | -------------------- |
| Your Manager | 88% |
| Well-being COVID-19 | 85% |
| Culture | 84% |
| **Question** | **Favourability Rating** |
| -------- | -------------------- |
| I am proud to work for GitLab | 93% |
| I feel supported when I need to take time off or make use of flexible working arrangements | 93% |
| I know how my work contributes to the goals of GitLab | 93% |

GitLab was rated between 5-13% percent higher than the industry benchmark i.e. New Tech +1,000 2020 across all three questions detailed above.

#### Bottom Three Scores

| **Factor** | **Favourability Rating** |
| ------ | -------------------- |
| Our Leaders | 79% |
| Growth & Development | 70% |
| Action | 54% |
| **Question** | **Favourability Rating** |
| -------- | -------------------- |
| I have been provided an opportunity to see and discuss prior engagement survey results | 60% |
| The Learning & Development programs provided by GitLab help me grow my career | 47% |
| I have seen positive changes since the previous engagement survey | 39% |

GitLab scored 5% below the industry benchmark i.e. New Tech +1,000 2020 for the lowest scoring question surrounding positive changes however there was no comparative for the other two questions.

#### FY' 21 E-Group Focus Areas

- Action (though action is our lowest score we have seen improvement year over year and will continue to focus on this area)
- Growth & Development
- Compensation
- Resource Allocations

#### Questions and Support

The GitLab Team Member Engagement Survey is managed by the People Connect Team. If you require support or have any questions around the survey please be sure to reach out via HelpLab.

### FY' 20 Engagement Survey

The GitLab Team Member Engagement Survey for 2019 (FY20) ran from 2019-10-14 to 2019-11-04 - questions and fine details can be found in the [following planning issue](https://gitlab.com/gitlab-com/people-group/General/-/issues/503).

Bar those who joined on or after 2019-10-01 the survey was extended to all GitLab Team members for completion. Participation for the FY20 survey closed out at 87% with 812 team members having taken part.

#### Benchmarking and Reporting

The FY20 survey was benchmarked against New Tech Size >500 2019 in addition to being reviewed against the preceding years results. Preliminary reports were released in the week of 2019-11-07 painting a broad overview afterwhich individual divisional reviews will take place in collaboration with the [People Business Partners (PBPs)](/job-families/people-group/people-business-partner) and respective Group Leaders.

#### Company Results (Overall)

| **Favourable** | **Neutral** | **Unfavourable** |
| ---------- | ------- | ------------ |
| 88% | 9% | 3% |

A benchmarked favourability score for New Tech Size >500 2019 was not available for this particular survey.

#### Top Three Scores

| **Factor** | **Favourability Rating** |
| ------ | -------------------- |
| Culture | 87% |
| Your Manager | 87% |
| Teamwork | 86% |
| **Question** | **Favourability Rating** |
| -------- | -------------------- |
| I would recommend GitLab as a great place to work | 95% |
| GitLab is in a position to really succeed over the next three years | 94% |
| I am proud to work for GitLab | 94% |

GitLab was rated between 11-17% higher than the industry benchmark i.e. New Tech Size >500 2019 across all three questions detailed above.

#### Bottom Three Scores

| **Factor** | **Favourability Rating** |
| ------ | -------------------- |
| Your Role | 84% |
| Growth & Development | 80% |
| Action | 46% |
| **Question** | **Favourability Rating** |
| -------- | -------------------- |
| I believe action will take place as a result of this survey | 64% |
| I have been provided an opportunity to see and discuss prior engagement survey results | 46% |
| I have seen positive changes since the previous engagement survey | 29% |

GitLab scored 15% below the industry benchmark i.e. New Tech Size >500 2019 for the lowest scoring question surrounding positive changes however there was no comparative for the other two questions.

#### FY' 20 E-Group Focus Areas

- Taking action from areas guided by the GitLab Team Member Engagement Survey Results.
- Managerial encouragement of Team Member development.
- Total Compensation.

### FY' 19 Engagement Survey

The GitLab Team Member Engagement Survey for 2018 (FY19) ran from 2018-10-14 to 2018-11-04 - questions and fine details can be found in the [following planning issue](https://gitlab.com/gitlab-com/people-group/General/-/issues/240).

Bar those who joined on or after 2018-08-17 the survey was extended to all GitLab Team members for completion. Participation for the FY19 survey closed out at 94% with 308 team members having taken part.

#### Benchmarking and Reporting

The FY19 survey was benchmarked against 2018 New Tech Size - Large Companies (500+). Preliminary reports were released in the week of 2018-11-06 painting a broad overview afterwhich individual divisional reviews will take place in collaboration with the [People Business Partners (PBPs)](/job-families/people-group/people-business-partner) and respective Group Leaders.

#### Company Results (Overall)

| **Favourable** | **Neutral** | **Unfavourable** |
| ---------- | ------- | ------------ |
| 83% | 12% | 5% |

The benchmarked favourability score for 2018 New Tech Size - Large Companies (500+) was noted at 70% i.e. 13% lower than that of GitLab overall.

### Top Scoring Factors

| **Factor** | **Favourability Rating** |
| ------ | -------------------- |
| Company Confidence | 84% |
| Management | 84% |
| Collaboration and Communication | 84% |
| Work / Life Balance | 84% |
| **Question** | **Favourability Rating** |
| -------- | -------------------- |
| I am proud to work for GitLab | 95% |
| I know how my work contributes to the goals of GitLab | 94% |
| GitLab is really in a position to succeed over the next three years | 93% |

GitLab was rated between 4-14% percent higher than the industry benchmark i.e. 2018 New Tech Size - Large Companies (500+) across all three questions detailed above.

### Bottom Three Scores

| **Factor** | **Favourability Rating** |
| ------ | -------------------- |
| Alignment and Involvement | 74% |
| Feedback and Recognition | 63% |
| Action | 41% |
| **Question** | **Favourability Rating** |
| -------- | -------------------- |
| I believe my total compensation (base salary+any bonus+benefits+equity) is fair relative to similar roles at other companies | 43% |
| My manager or someone else has communicated clear actions based on recent team member survey results | 33% |
| I have seen positive changes taking place based on recent employee survey results | 32% |

GitLab scored 12% below the industry benchmark i.e. 2018 New Tech Size - Large Companies (500+) for the lowest scoring question surrounding positive changes however there was no comparative for the other two questions.

#### FY' 19 E-Group Focus Areas

- Taking action from areas guided by the GitLab Team Member Engagement Survey Results.
- Managerial encouragement of Team Member development.
- Total Compensation.

## People Operations Procedures

### How to add sub-departments or other demographics not found in Workday

1. Open CultureAmp > Settings > Data Intergrations
1. Select the blue `Sync Data` button
1. Select Partial Upload
1. Click on Export Users > Export
1. Update the information on the spreadsheet
1. Upload the spreadsheet into CultureAmp
1. Select Next (bottom right corner)
    - If you select Sync it will only Sync with Workday, regardless if you uploaded a file.
1. Select Import Data

You have now updated a demographic in CultureAmp!

</details>

<details>
<summary>Organizational Health Surveys</summary>

In Q3 FY'23, our Talent & Engagement team ran our first organizational health survey.

GitLab used McKinsey & Company's [Organizational Health Index "OHI"](https://www.mckinsey.com/solutions/orgsolutions/overview/organizational-health-index) survey to help us understand where we have opportunities to help our organization and team members execute better and increase their impact. The OHI survey is separate from our CultureAmp Engagement survey; learnings from the former will complement the latter and also help inform workplace practices beyond GitLab.

### FY'23 Q3/Q4 McKinsey OHI Survey Results

We've summarized high level results of the OHI survey for all GitLab team members in [this document](https://docs.google.com/presentation/d/1B-T8TUcuidyIwbcpih01id2-TxZpE6D91Xt6w3z0uIw/edit?usp=sharing).

The document linked above is only available to GitLab team members.
