---
title: "GitLab Onboarding"
description: "Onboarding at GitLab and Onboarding Issue Templates"
---

Onboarding is [incredibly important](/handbook/company/culture/all-remote/onboarding/) at GitLab. We don't expect you to hit the ground running from day one.

We highly recommend taking at least two full weeks for onboarding and only in week three starting with team specific onboarding and training. Please feel free to participate in your team's work in your first two weeks, but don't feel like you have to contribute heavily.

All onboarding steps are in the [onboarding issue template](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/blob/main/.gitlab/issue_templates/onboarding.md) which is owned by the People Connect team. The onboarding process for the new team member is [self-driven and self-learning](/handbook/values/#self-service-and-self-learning), whilst also remaining as [asynchronous](/handbook/values/#bias-towards-asynchronous-communication) as possible settling into the remote life at GitLab.

At GitLab we take great pride in [dogfooding](/handbook/values/#dogfooding) our own product, that is why all onboarding tasks are completed in a GitLab issue. First of all, what is an issue? You can learn more about what an issue is [here](https://docs.gitlab.com/ee/user/project/issues/).

The People Connect Specialist assigned to the team members specific onboarding will [open](https://internal.gitlab.com/handbook/people-group/people-operations/people-connect/onboarding_process/#onboarding-issue-creation) the onboarding issue at least 4 days prior to the hire date.

Each onboarding issue has a main section that contains tasks relevant to all GitLab team-members and a due date of 30 days. Below the main section are department and role-specific tasks. Some roles and departments have tasks that link to a supplemental issue template or an additional onboarding page.  Reach out to your [onboarding buddy](/handbook/people-group/general-onboarding/onboarding-buddies) or other GitLab team members if you need help understanding or completing any of your tasks.

Through onboarding issues, you should gain access to our team member [baseline entitlements](/handbook/security#baseline-role-based-entitlements-access-runbooks--issue-templates). On Day 2 of onboarding an [Access Request](/handbook/people-group/engineering#access-request-issue-creation) will be generated, if a template has been created for the role. Access requests are owned by the IT team. If you have any access requests related questions, please reach out to `#it-help` in Slack.

In certain instances, the People Connect team may not be able to assist with onboardings due to a national holiday or Family and Friends Day. These specific dates are documented in the People Connect team [availability](https://internal.gitlab.com/handbook/people-group/people-operations/people-connect/people_experience_team/#people-experience-team-availability).

## TaNewKi Welcome Call

The People Connect team hosts a pre-onboarding call known as the Ta-New-Ki call (a play on the abstract Tanuki i.e. Japanese raccoon dog you will find in our logo). The purpose of this call, which is hosted in Zoom, is to give soon to onboard team members the chance to meet / socialise and to provide an opportunity to ask any lingering questions ahead of their start date. Internally we refer to this as an AMA (Ask Me Anything) call. **This call is open to all current team members, hiring managers.**

This call occurs every two weeks on Thursday at two times to account for timezones.

- 11:00/23:00 **PM** PT
- 08:30 **AM** PT

- For current team members: To add the invite to your calendar, review the GitLab Team Meeting Calendar.
- For future team members: You will receive an email with the future dates.

Please note that this call will take a place a week or two before your actual start date.

### Agenda

General Topics Covered

- Review the onboarding process on Day 1
- Encourage team members to take their time
- Self Driven and self service
- Questions from the new team members

### Sending out the TaNEWki Call Invite

- Invites are sent by the People Connect Specialist in the respective rotation. This email should be sent out at least one week before the call.
    1. Open the Ta"NEW"ki Folder located People Experience/Ops Shared Drive>People Experience>Ta"NEW"ki Call
    1. Update the google form to include the next two TaNEWki call dates (EMEA and AMER times)
    1. Use this [email template](https://gitlab.com/gitlab-com/people-group/General/-/blob/master/.gitlab/email_templates/tanewki_welcome_call.md)
    1. Add the new team members emails to the BCC line and CC the People Connect team.
    1. The People Connect team can check who will be attending the call by looking at the Google Form.
    1. Once new hires have completed the form an auto-response (via Document Studio) will reply with the zoom link and the date selected.

## Slack Channel Support for New Team Members

By default, all new team members are added to the below Slack channels from day 1 to ensure that they are able to ask any questions or for assistance in the correct channels upfront:

- `#new_team_members` (go say hi and introduce yourself)
- `#diversity_inclusion_and_belonging` (connect with other team members to find out more about what we do in Diversity, Inclusion and Belonging)
- `#it_help` (any IT related support needed, such as issues with laptop, 1Password, Okta, JAMF, etc)
- `#expense-reporting-inquiries` (need some info on your expenses, what can be expensed, approving expenses, etc)
- `#payroll` (have any questions on your salary payments, payslips, etc)
- `#questions` (anything that the Handbook can't help with)
- `#donut-be-strangers` (need some help setting up a coffee chat)
- `#team-member-updates` (new team member, anniversaries, goodbyes)
- `#thanks` (want to acknowledge and thank someone at GitLab, this is the channel)
- `#whats-happening-at-gitlab` (all important updates/reminders/notifications related to GitLab)

## Managers of New Team Members

An issue is created for new team members at least 4 business days prior to their start date. The Manager and a People Connect Team member will be assigned to this issue. **Managers, People Connect and IT Ops** all have tasks that need to be completed **prior to the start date** to ensure a smooth and successful onboarding process. For questions or help with any of these tasks feel free to reach out in the issue or by creating a request via HelpLab.

### <i class="fas fa-tasks fa-fw color-orange font-awesome"></i>Compliance

The [Senior People Connect Specialist](/job-families/people-group/people-connect) completes a monthly audit of all open onboarding issues to ensure that the new team member, manager and People Connect team tasks are completed. More importantly, there are certain tasks which need to be completed  in line with our company compliance (security, payroll, etc).

If any tasks are still outstanding, the People Connect Specialist will ping the relevant members on the issue requesting action on the items or checking whether the issue can be closed.

*It remains the responsibility of the People Connect Specialist to close the issue and remain compliant.*

The employment bot will automatically close any onboarding issues still open after 60 days.

### <i class="fas fa-tasks fa-fw color-orange font-awesome"></i>Completing Onboarding Issue

First of all, what is an issue? You can learn more about what an issue is [here](https://docs.gitlab.com/ee/user/project/issues/).

To ensure a successful completion of the onboarding issue, it is important that all tasks are checked off, whether the task is applicable to the onboarding team member or not. Checking the box indicates one of the following:

- I have completed this task
- I have checked and this task is not applicable to me

### Onboarding Issue Template Links

These templates are used by the People Connect team to onboard new team members.

- [All GitLab team-members](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/blob/main/.gitlab/issue_templates/onboarding.md)
- [Intern](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/blob/main/.gitlab/issue_templates/onboarding_intern_engineering.md)

#### <i class="fas fa-suitcase fa-fw color-orange font-awesome"></i>Role Specific Templates

All onboarding related employment templates (country and role based) can be found in the [public repository](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/tree/main/.gitlab/issue_templates/onboarding_tasks)

### Supplemental onboarding issue templates

- [Interviewing training issue](https://gitlab.com/gitlab-com/people-group/Training/blob/master/.gitlab/issue_templates/interview_training.md)
- [Monitor group onboarding issue](https://gitlab.com/gitlab-org/monitor/onboarding/blob/master/.gitlab/issue_templates/Monitor_Onboarding.md)
- [Becoming a GitLab manager issue](https://gitlab.com/gitlab-com/people-group/Training/-/blob/master/.gitlab/issue_templates/becoming-a-gitlab-manager.md)
- [Production engineering onboarding issue](https://gitlab.com/gitlab-com/gl-infra/infrastructure/blob/master/.gitlab/issue_templates/onboarding_template.md)
- [Security products technical onboarding issue](https://gitlab.com/gitlab-org/secure/onboarding/blob/master/.gitlab/issue_templates/Technical_Onboarding.md)
- [Support engineer onboarding issue](https://gitlab.com/gitlab-com/support/support-training/blob/main/.gitlab/issue_templates/New%20Support%20Team%20Member%20Start%20Here.md)

### Temporary Service Provider (Contractor/Consultant) Onboarding

The People team is not involved in the process for hiring, onboarding, or offboarding temporary service providers. You can work with the Procurement team on these onboardings and review the [temporary service provider internal handbook page](https://internal.gitlab.com/handbook/it/end-user-services/access-request/temporary-service-providers/?search=temporary+service) for templates and other helpful information.

### Additional onboarding pages

- [Developer onboarding](/handbook/engineering/developer-onboarding/)
- [GitLab onboarding buddies](/handbook/people-group/general-onboarding/onboarding-buddies)
- [Merge Request buddies](/handbook/people-group/general-onboarding/mr-buddies)
- [Onboarding Processes](https://internal.gitlab.com/handbook/people-group/people-operations/people-connect/onboarding_process/)
- [Test Platform Onboarding](/handbook/engineering/infrastructure/test-platform/onboarding/)
- [Sales team onboarding](/handbook/sales/onboarding/)
- [Support team onboarding](/handbook/support/training)
- [SRE onboarding](/handbook/engineering/infrastructure/team/reliability/sre-onboarding/)
- [UX Researcher onboarding](/handbook/product/ux/ux-research/)
