---
title: GitLab Onboarding Buddies
description: Onboarding Responsibilities and Process
---

Onboarding buddies are crucial to making the onboarding experience for a new GitLab team-member a positive one. [New Job Anxiety](https://www.classycareergirl.com/new-job-anxiety-conquer/) is a reality for many people, and the adjustment to GitLab might be particularly challenging for new GitLab team-members who may not be used to our [all-remote](/handbook/company/culture/all-remote/) culture. That's why it's important that all new GitLab team-members be assigned a buddy who is ready, willing, and excited to assist with the onboarding process.

Not only are buddies helpful to someone that has just started with GitLab, but also to a team member transitioning to a new role within GitLab. When someone migrates to a new team / department, it is highly recommended that managers assign a Career Mobility buddy in the issue to help support the team members that are busy migrating.

## Buddy Responsibilities

1. **The first and most important thing a buddy should do is schedule a call with the GitLab team-member.** You can do this in the days leading up to a new team member starting at GitLab by asking their manager for the new starter's personal email address. Introduce yourself and ask them when a good time to schedule an initial coffee chat would be. Consider picking a time towards the end of their first day so they have time to digest some of the onboarding issue and can come to the coffee chat with questions. We attempt to match (as best as possible, anyway) time zones between the GitLab team-member and their buddy so that as soon as the GitLab team-member logs on, you, the buddy, can be there ready and waiting to welcome them to the team.
1. **Check how far the new GitLab team-member has gotten in their onboarding / career mobility issue.** The onboarding / career mobility issue that all new/transitioning GitLab team-members are assigned can be overwhelming at first glance, particularly on the first day of work. Check to see how much, if any, the GitLab team-member has done by the time your call happens, and offer some direction or advice on areas the team member may be having trouble with.
1. **Suggest helpful handbook pages.** Chances are that you've discovered some particularly helpful pages in the handbook during your time at GitLab. Point them out to the new GitLab team-member, and help them get used to navigating the handbook. Some examples might include:
    - [GitLab's guide for starting a remote role](/handbook/company/culture/all-remote/getting-started/)
    - [The tools page](/handbook/tools-and-tips)
    - [The team page](/handbook/company/team/) that feeds in to the un-audited [internal-only org chart](https://comp-calculator.gitlab.net/org_chart)
    - The Organization chart in Workday, which is our SSoT for organizational structure
    - [The positioning FAQ](/handbook/marketing/positioning-faq/)
1. **Remind them about introducing themselves.** Remind the new team member to introduce themselves in the Slack channel `#new_team_members` or relevant team channel. Encourage them to write a little personal note, and if they're comfortable, include a photo or two!
1. **Encourage them to organize a group call with other new hires.** New GitLab team-members who are used to (or prefer) a more conventional new hire orientation — frequently hosted in group settings in colocated organizations — [may feel a lack of early bonding](/handbook/company/culture/all-remote/learning-and-development/). Encourage them to organize a group call with other new hires in order to walk through onboarding together, while learning about new personalities and [departments of the company](/handbook/company/structure/).
1. **Introduce them to Slack.** Slack may seem like it's ubiquitous, but that doesn't necessarily mean the new GitLab team-member will have had experience using it before. Since it's a central part of how we communicate at GitLab, consider showing them around, and give them some pointers about [how we use it]({{< ref "communication" >}}).
   - Be sure to suggest [location channels]({{< ref "chat#location-channels-loc_" >}}) and [Social Slack Groups]({{< ref "chat#social-groups" >}}) where they can immediately plug in with other team members who appreciate similar things.
1. **Ask where they need help and connect them with the experts**. Buddies should make the effort to connect new GitLab team-members with subject matter experts if your assigned team member requests additional help in a given area. Examples are below.
   - For new GitLab team-members who have not worked in a [remote organization](/handbook/company/culture/all-remote/) before, they may need assistance in thinking through an ideal [workspace](/handbook/company/culture/all-remote/workspace/) and embracing [informal communication](/handbook/company/culture/all-remote/informal-communication/). Consider asking seasoned remote colleagues in the `#remote` Slack channel to reach out and answer questions.
   - If they're new to [Git](https://about.gitlab.com/learn/), consider asking experts in the `#git-help` Slack channel to reach out and offer a tutorial.
   - If they're new to [Markdown](https://about.gitlab.com/blog/2018/08/17/gitlab-markdown-tutorial/), consider asking experts in the `#content` Slack channel to reach out and offer support.
1. **Help with the team page.** For less technical new hires, adding themselves to the [team page](/handbook/company/team/) might feel like the most daunting task on the onboarding issue. Offer to help with the process. This doesn't necessarily have to happen on day one, but you should let them know that you're available to help if and when they need it. Consider scheduling a second meeting later in the week to walk them through [the process](/handbook/about/editing-handbook/#add-yourself-to-the-team-page)
   - In particular, help them to create their SSH key as this tends to be a sticking point for many new hires. You can also show them [Lyle's walkthrough](https://youtu.be/_FIOhk03VtM).
1. **Check in regularly.** You may very well be the first friend the new GitLab team-member makes on the team. Checking in with them regularly will help them feel welcome and supported. Reach out via Slack, and schedule at least two follow-up calls for the week after their start date, and at least one follow-up call for the rest of the first month. But since it differs from one person to another, you may also ask them if they prefer more or less frequent calls per week.
1. **Provide backup if needed**. If you plan to be out (e.g. [vacation]({{< ref "paid-time-off" >}}), [company business](/handbook/finance/travel/), [events](https://about.gitlab.com/events/), etc.) during a new GitLab team-member's first few weeks, please ensure that a backup onboarding buddy is available to offer support.
1. **Consider a long-term mentorship program**. It can take a long time before new team members are comfortable in their new role, and having a mentor during that process goes a long way to help the transition into their role's responsibilities go as smooth as possible. Consider setting up a weekly, or bi-weekly one-hour mentorship session, which your buddy can use to bring up any matter they are struggling with along the way.

## How Can I Become An Onboarding Buddy?

Buddy assignation is the new team member's manager's responsibility as outlined in the [onboarding issue](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/blob/main/.gitlab/issue_templates/onboarding.md) as the very first `Before Starting at GitLab` manager task. If you have been at GitLab 3+ months and are interested in participating in the Onboarding Buddy Program, please express your interest to your manager.

## Managers: Who should I pick as an Onboarding Buddy?

Ideally an onboarding buddy:

- has been at GitLab longer than 3 months
- shares the same department or division with the onboarding team member
- shares a similar timezone
- available during the first two weeks (no major PTO events or leave)
- is someone who can support the adjustment to GitLab and knows a bit about the applications / tools the new team member may be using in the course of their role

These guidelines have been developed from the feedback we receive in the Onboarding Survey and feedback from onboarding buddies. It is not always possible to achieve all of these guidelines depending on the team or location.

## Example Email Template

This is an example template you can use to introduce yourself to a new team member as their onboarding buddy.

> Hi {Name}, and welcome to GitLab!
>
> My name's {Buddy name} and I'm your [Onboarding Buddy](/handbook/people-group/general-onboarding/onboarding-buddies)! I wanted to introduce myself and explain what my role will be in terms of your onboarding. We're really excited to have you join us.
>
> {Talk about some of the things you've worked on at GitLab, a bit about your role and what you do for fun! Link to your personal README if you have one.}
>
> This welcome email is one of my first onboarding buddy tasks. It is sent to your personal email address because your GitLab email is meant to be accessible to you starting on your first day only. Also, sometimes a new hire may have questions that they would feel more comfortable asking their onboarding buddy versus their manager or recruiter. Other than this email thread and a Zoom invitation to say hello, I won't send you any other messages to your personal email address, as we truly believe in a healthy work/life balance at GitLab!
>
> On the morning of your first day, whenever you wish to start (there is no required start time!), you'll find a welcome email from GitLab in your personal email inbox. It should have been sent around 06:00 local time in your country. Please check your spam folder if you don't see it right away. The email starts with:
>
> *Hi {Name},*
>
> *Welcome to GitLab! We're so excited that you've joined our team!*
>
> *To ensure the seamless setup....*
>
> Please follow all steps in this email. There is a video that you'll be asked to watch to better explain all steps to get started.
>
> Once you've logged in on your first morning you'll be able to access your GitLab Onboarding "issue" (your onboarding checklist).
>
> During your onboarding I'll be your point of contact for any questions you have about onboarding, your role, or where to find information that you might need. In addition to this email, I'll send an invitation for a Zoom call on your first day to welcome you to GitLab and answer any questions you may have. Join the call with your personal Zoom account, since you might not have configured your GitLab Zoom account by the time we speak. I'm in the {Buddy time zone}, so feel free to suggest a different time if you need to.
>
> I can also help with any technical issues like setting up the GitLab Development Kit. {Delete this line if new starter is not in Engineering Division}
>
> I'll also point you in the direction of some fun social channels in Slack to help you meet as many people as possible! (My personal favourites are #dog, #dad_jokes and #all-caps.)
>
> In preparation for your first day, here are a few handbook pages that are very useful:
>
> - Guide for starting a remote job
> - {Any other applicable links}
>
> Don't hesitate to ask any questions that you might have before your start date. I'm happy to help and thrilled to have you joining us!
>
> Looking forward to meeting you and working together!

## That's it

That's all there is to it! Thanks for your help welcoming the newest GitLab team-member to the team and getting them on board. If you have questions that are not answered on this page, please [reach out to the People Connect Team](/handbook/people-group/people-connect)!
