---
title: Guidance on Feedback
description: "GitLab's views and directions on how to give and receive feedback."
---

Giving and receiving feedback is an important part of building strong relationships and high performing teams. Feedback aligns to GitLab values in the following ways:

1. **Collaboration:** Forms strong and trusting relationships
1. **Results:** Enables leaders to set the standard
1. **Efficiency:** Addresses small challenges early to avoid major mistakes later
1. **DIB:** Creates a safe work environment
1. **Iteration:** Motivates people and establishes a growth mindset
1. **Transparency:** Keeps teams aware of team strengths and challenges

Feedback can come in the form of **"praise"** for things team members do well, and **"tips"** pertaining to improvement areas. We encourage sharing and documenting both types of feedback on a regular basis via:

1. [360 Feedback]({{< ref "360-feedback" >}}) via Culture Amp
1. Regularly during [1-1's]({{< ref "1-1" >}})
1. "365 feedback": Giving verbal, direct feedback 365 days a year in the [#thanks Slack channel](https://app.slack.com/client/T02592416/C038E3Q6L), direct message, or other personal communication

## Documenting Feedback

**Why it's important to document:**

1. Ensures both giver and receiver are on the same page; No Surprises!
1. Provides focus and helps track progress
1. Lays the ground for self reflections and performance discussions
1. Supports decision making

## Impact

Feedback conversations are core to personal and professional growth. According to research conducted by [TruQu](https://truqu.com/en/blogs/the-importance-of-a-feedback-culture-and-how-you-can-build-it-in-the-workplace/):

1. Constructive and timely feedback can **improve performance up to 39%**
1. When people receive appreciative feedback or recognition, they are **69% more motivated to deliver high performance**
1. 4/10 employees are **actively disengaged when they get little or no feedback**
1. When we engage in and document feedback more frequently, we **reduce the anxiety** of feedback and **reduce the potential for "surprises**"

## Guidance on Giving and Receiving Feedback

Sid (GitLab CEO and Co-founder) and the Learning & Development team discussed guidance on giving and reciving feedback during a [CEO Handbook Learning Session](https://docs.google.com/presentation/d/1u6k4ILLBjLOaGk1ZyuNa2U2qr-XiGZL0AhUjOQRtvVI/edit#slide=id.p1). The covered topics like:

1. How do you create an environment where team members can approach each other with feedback?
1. Why it is important to give regular feedback?
1. Why you should give feedback right away?
1. How iteration enables feedback?
1. How do you create an environment built for feedback?

{{< youtube "vL864Zg2sm4" >}}

> Give constructive feedback in the smallest group as possible, be specific by discussing an example. Make the discussion improvement orientated and make sure you deliver feeback when your not upset. (Sid Sijbrandij, GitLab CEO and co-founder)

### Embracing Feedback

"In teamwork, silence isn't golden, it's deadly." ~Mark Sanborn

The habit of seeking feedback may not be easy to develop, but failing to seek honest input from your team can have a significant impact on GitLab's culture. Patrick Lencioni, author of [The Five Dysfunctions of a Team (2002)](https://www.tablegroup.com/product/dysfunctions/), cites these consequences of ignoring feedback:

1. Inattention to Results
1. Avoidance of Accountability
1. Lack of Commitment
1. Fear of Conflict
1. Absence of Trust

Watch as [Dr. Jeb Hurley](https://linkedin.com/in/jebhurley), Co-founder of Xmetryx, analyzes why leaders choose to avoid feedback, even when they have ample evidence that shows its benefits.

{{< vimeo "546933765" >}}

### Hard Conversations

Difficult and constructive feedback is valuable when delivered with compassion. It's important to consider the individual recieving the feedback and anticipate how they might react. As explained in [Crucial Conversations](/handbook/leadership/crucial-conversations), if the person feels threatened, they might shift into Silence or Verbal Violence.

To optimize for a open, honest, and effective conversation, reflection on the following before sharing difficult feedback:

1. What do I really want for myself?
1. What do I really want for the other(s)?
1. What do I really want for the relationship?
1. How would I behave if I really wanted these results?

Preparing for hard conversations is important, tips [in this article](https://psyche.co/guides/use-mediation-techniques-to-overcome-the-muck-of-blame-and-anger) about using mediation techniques can help you prepare to have these conversations in an authentic and honest manner.

### Radical candor

Radical Candor is a framework about HOW to deliver feedback. It's a powerful, assertive, and caring place that demonstrates to an individual that you both care about them personally and that you're willing to challenge them directly. When you're not caring personally or challenging directly, it can lead to Ruinous Empathy, Manipulative Insincerity, or Obnoxious Aggression.

- [Radical Candor — The Surprising Secret to Being a Good Boss First Round Review](https://www.youtube.com/watch?v=4yODalLQ2lM)
- [How To Use Radical Candor To Drive Great Results](https://www.forbes.com/sites/roncarucci/2017/03/14/how-to-use-radical-candor-to-drive-great-results/?sh=39085db24e23)
- [Brutal Honesty and Radical Candor: 6 Ways You're Getting Radical Candor Wrong and 6 Ways to Get It Right](https://www.radicalcandor.com/blog/radical-candor-not-brutal-honesty/)

### Cross-Cultural Feedback Considerations

GitLab has 2000+ team members from diverse [cultures and backgrounds](/handbook/company/culture/inclusion/identity-data/). We should get to know our team members well enough to understand how best to share feedback. It's important to adapt tone and style according to each individual and relationship. Consider:

1. Do you need to build relationship before candor is comfortable?
1. Consider comfort with direct vs indirect feedback
1. Is their communication generally explicit or implicit?
1. Influence of hierarchy in direct feedback?

### What Comes First, Honesty or Trust?

It's safer to give and receive feedback from those with whom you have already established trust. Trust makes it easier to assume good intent and to be boldly honest with each other.

| Strategy for Building Trust | Description |
| ----- | ---------- |
| **Start with task based trust** | Giving feedback can build trust. Start with task based feedback, like  sharing a typo in something they have written. Starting with the task based feedback can lead to more transformational behavior feedback. |
| **Build relational trust** | Trust enables safety and productive conversations about feedback. Review the [building trust handbook page]/handbook/leadership/building-trust/) for guidance. |
| **Be candid** | Being candid builds trust. Willingness to give feedback shows honesty. |

## Giving Feedback

![Feedback Image](/images/handbook/Training/Feedback_Image.png)

1. Have positive intent
   - If you have the intent to hurt someone and not to help them, reconsider giving the feedback.
   - Harsh feedback does not help people thrive and excel.
1. Make it a frequent event and do it in real time
   - Don't wait until performance reviews to deliver
1. Avoid using absolutes
   - For Example: "You always." "You never show up to meetings on time."
1. Feedback should be both positive and constructive
   - It is recommended to use a 4:1 ratio of positive to constructive
1. Use the [Situation-Behavior-Impact (S-B-I) Model](#s-b-i-model)
1. Allow the feedback receiver time to reflect
1. Focus on the root cause
   - What are the behaviors you've experienced?
   - What would improve the relationship between you and the other person/ team?
1. Understand the impact
   - What is the effect/impact of the behaviors on you/others (positive or negative)?
   - How is the behavior not aligned with GitLab's values?
   - What are the cost/benefits to the person or team?
1. Focus on actions and outcomes
   - What actions can be taken after getting feedback?
1. Recognize how communication styles differ
   - Could the individual's background affect the way they prefer to receive feedback?
   - Read The [Culture Map](https://erinmeyer.com/book/) to understand communication and feedback styles of different countries.

### S-B-I Model

The Situation-Behavior-Impact (S-B-I) Model focuses feedback based on:

**Situation** - Define the when and where by anchoring in time and place.

**Behavior** -  Describe the observable behavior and how it was applied.

**Impact** - Describe how the other person's action affected you or others experiences and thinking.

For a more in-depth look at how to apply this model see [The Situation-Behavior-Impact-Feedback Framework](https://medium.com/pm101/the-situation-behavior-impact-feedback-framework-e20ce52c9357), an external blog post that has a bit more detail and some examples.

### Live Learning Session on Delivering Feedback

{{< youtube "KSp4jIN2W5E" >}}

*Originally hosted on 2020-06-08.*

- [Slide Deck](https://docs.google.com/presentation/d/1Wz8hr98CTiaytz1yIxG-D7H1P1eCm7ejnUl8O9YANEU/edit)
- [Meeting Agenda](https://docs.google.com/document/d/1wpS1kfRitFuBXihU-Z0fRkzEbtN1mx5z6bpJlqb1N1Y/edit)
- [Mentimeter Results](https://docs.google.com/spreadsheets/d/1gpxH80LNbXRUQdb9fFxlFDB-1QuGeO4D0XmaNNly1Fw/edit)

## Receiving Feedback

Receiving all types of feedback can be difficult. Our brains want to protect us from any potential dangers, and receiving feedback can be perceived as a physical threat. We have outlined some guidelines and tips to help with this:

1. Assume positive intent
   - This is likely uncomfortable for the feedback giver as well
1. Be an active listener
   - This is hard because our brains want us to run away
   - Slow down and really take the time to listen to what the other person is saying so you can reflect on it
1. Be respectful
   - Give them your full attention
1. Ask questions
   - It's okay to take time to reflect on it and then come back with questions at a later time
1. Show appreciation
   - Say thank you and mean it
1. Reflect on the feedback
   - Take time to reflect on what you have heard and then think about the action
   - Pitfall: Over-engineering or overdoing the response
1. Make a decision
   - What are the most impactful actions you can take - prioritize
   - Who has what responsibility in follow up (i.e. giver/receiver)? Both.

### Live Learning Session on Receiving Feedback

{{< youtube "ZdUMoI1jMvI" >}}

*Originally hosted on 2020-02-25*

- [Slide Deck](https://docs.google.com/presentation/d/1yziTxwnAHD6vA1deSPf4DCwGLNYRijAmHiYcdoAxOmo/edit?usp=sharing)
- [Meeting Agenda](https://docs.google.com/document/d/1k5ja-8qJRMnguVOUOOsMUAQ2PEbXiuDBsbpstJPkSEo/edit?usp=sharing).

## Recognition

While not always immediately thought of as a form of feedback, recognition is one of the most essential forms of providing feedback in the workplace.

### How To Recognize Team Members

It's important to be precise about both team member's accomplishment and the impact of their accomplishment.

Example:

**General Feedback:**

*"Thank you for helping troubleshoot sessions on XYZ tickets so we could resolve them inside the SLA."*

**Precise Feedback That Includes impact:**

*"Thank you for helping troubleshoot sessions on XYZ tickets so we could resolve them inside the SLA. This helps keep customers happy with our solutions and shows our team how to resolve similar issues faster in the future."*

### When and Where to Give Recognition

**When:**

1. Team member is **excelling with respect to CREDIT**
1. Team member has **gone through a significant challenge** and remained transparent in explaining those challenges
1. Team member completes a **high impact Epic / Issue either quickly** or that they **worked on over multiple releases**.
1. Team member has **recently undergone a reorganization**.
1. Any **impactful Security / Quality achievement**
1. **Engagement with a Community Contributor**

**Where:**

1. Post a message in the #thanks channel for team member recognition
1. Share an update of the team member(s) recognition during the next team meeting
1. Highlight the recognition of the team members during a group conversation with the broader organization
1. Showcase the recognition during an e-group meeting to executives
1. Consider a [discretionary bonus per team member](/handbook/total-rewards/incentives/) as a form of superior recognition
1. Managers can also recognize team members during 1-1 meetings
1. Quarterly [Skip Level](/handbook/leadership/skip-levels/) Meetings.

*Managers should consider their team member's preference for how to receive recognition when choosing what forum seems the most appropriate.*

### Beware Of Saying "Thank You" Too Much

Take a moment to identify situations in which you or your team are saying "Thank You" to the same person or team **too often**. Recognition is essential, but if it becomes very frequent, it can start to be perceived as less sincere. **If the same team member or team is going above and beyond their job responsibility on a regular basis, the best way to say thank you is to recognize this pattern of overachievement.**

## Additional Resources

- [Your Employees Want the Negative Feedback you hate to Give](https://hbr.org/2014/01/your-employees-want-the-negative-feedback-you-hate-to-give)
- [Principles of Charity](https://en.wikipedia.org/wiki/Principle_of_charity)
- [Difficult Conversations: How to Discuss What Matters Most](https://www.goodreads.com/book/show/774088.Difficult_Conversations)
- [The Culture Map](https://www.amazon.com/Culture-Map-Breaking-Invisible-Boundaries/dp/1610392507)
- On 2018-02-15, we recorded a training on [Peer to Peer Feedback](https://www.youtube.com/watch?v=yzjAeu7RpU8&feature=emb_logo)
- [Hofstede Country Comparison Tool](https://www.theculturefactor.com/country-comparison-tool)
- [Kim Malone Scott speaking about Radical Candor - The Surprising Secret to being a good Boss](https://www.youtube.com/embed/4yODalLQ2lM)
- [Radical Candor and giving constructive feedback](https://www.youtube.com/embed/0YaXSbLqork)
- [Giving and Receiving Feedback](https://www.linkedin.com/learning/giving-and-receiving-feedback-18926015) - a 28 minute LinkedIn Learning course by Dr. Gemma Lee Roberts
- [Coaching Feedback Model](https://www.coachingcultureatwork.com/coaching-feedback-model/)
- COIN & COILED feedback models - [World of Work Project Article](https://worldofwork.io/2019/07/the-coin-coiled-feedback-models/), 3 minute LinkedIn Learning [video](https://www.linkedin.com/learning/coaching-virtually/use-the-coin-model-to-give-feedback-virtually?u=2255073) on COIN.
- CEDAR Feedback model - introduction and overview from [join.com](https://join.com/recruitment-hr-blog/feedback-models#6thecedarfeedbackmodel:~:text=6.%20The%20CEDAR,way%20of%20working), and a more comprehensive article and sample conversation at [World of Work Project](https://worldofwork.io/2019/07/the-cedar-feedback-model/)

## Modeling a Culture of Feedback Manager Competency

In an all-remote organization, people managers model a culture of feedback that promotes ongoing feedback that happens throughout the year. Feedback should not wait until performance evaluations, it should happen throughout the year - anytime and in real-time. People managers can develop their team members through positive and constructive forms of feedback.

**Skills and behavior of the modeling a culture of feedback manager competency:**

- Solicits and is open to feedback
- Promotes a culture of ongoing feedback that occurs any time of year and is done in real-time
- Creates a welcoming environment for feedback and enables team members to value open discussions and debates where they continually learn from one another
- Turns challenges into learning opportunities
- Champions a team environment where feedback occurs all the time and is not done once or twice a year during performance review cycles
