---
title: Individual Growth Plan (IGP) Guide
description: "Step by Step resource for team members filling out the GitLab Individual Growth Plan (IGP) "
---

This guide is for team members who are looking for guidance on how to complete their IGP. The guide will go through each section of the IGP including resources, inspiration, and suggestions for how to best use the IGP in Workday to plan and take action towards your career goals.

## Your Role with the IGP

As the Directly Responsible Individual (DRI) of your career, it's your responsibility to make decisions that best serve your growth. Consider this course as guidance, not prescription. At its core, the Individual Growth Plan (or IGP) is a tool to reflect, set, and action on goals.

Once your IGP is complete, it's important to think about how you'll practice continuous learning.
The best way to do this is to block calendar time for learning. This blocked time might start with your work on the IGP and evolve to taking a course, earning a certification, working on a stretch assignment, reading a book, or engaging in a mentor relationship. Socialize the time you're spending learning to your team - especially if you're a manager. We all play a role in modeling continuous learning at GitLab and encouraging others to prioritize their growth.

## Section 1: Discover your Inspiration

Reflection helps guide our career decisions. Section 1 of the IGP is focused on reflection, asking these 5 questions:

1. What parts of your role are most engaging?
1. What work brings the greatest sense of excitement and belonging?
1. Which areas of work feel draining?
1. How do you like to learn?
1. In 2-3 years, what role would you like to be in and why?

Be flexible with yourself in this section. Some choose to make this an elaborate reflection and lean on resources like the [Myers Briggs assessment](https://www.16personalities.com/free-personality-test), [Strengths Finder assessment](https://www.gallup.com/cliftonstrengths/en/home.aspx), or [learning style definition](https://edugage.com/what-is-my-learning-style/). Others treat it like a quick check-in.

**Get Inspired: Listen to a group of GitLab team members share what gives them energy, and what drains them, at work. Do you notice any of the same trends in your own reflection?**

**What energizes you?**

{{< youtube "vkFVwW-sovA" >}}

**What drains your energy?**

{{< youtube "ST2IA-4iX-E" >}}

**Tip: Having trouble answering these questions? Try using a journal to record your energy throughout the day for 1 week, then look back at what drained or energized you.**

## Section 2: Narrow your Focus

Knowing your growth direction helps you set goals and find the right resources. This is the goal of Section 2 of the IGP - to clarify your role trajectory by focusing on the following 3 questions:

1. Do you want to stay on your current team or try something new?
1. Would you like to manage a team or department?
1. Would you like to stay as an individual contributor and develop a specific area of expertise?

Think big in this section. Do you want to become a manager? Are you growing as an IC leader? Maybe you're ready for a career transition to a new team. Remember that at GitLab, career growth is non-linear - we grow in all directions.

![infographic showing examples of non-linear careers at GitLab](../non-linear.png)

## Section 3: Set your Intention

Done exploring for now? It's time to populate section 3 of the IGP. Setting your eyes on the future, section 3 prompts you to think about your medium-term goals. Think about what you want your next career step to be (from section 2) and how you will know you are successful by answering the following 2 questions:

1. What accomplishments would you like to achieve to help you reach your career objectives?
1. How will you know that you have been successful?

A few examples of how to answer those questions are below:

| Example | Accomplishments | Measuring Success |
| ----- | ------------ | ------------ |
| Lateral Career Move | I want to learn more about product management and what types of skills are needed to pursue product management as a career. | I will know I have been successful if I can clearly articulate whether I am interested in a career in product management in 6 months. |
| Aspiring Manager | I would like to become a people manager as part of my journey to leading a functional area. | I will know I have been successful if I am managing a team of 3 team members. |
| IC Growth | I would like to become a technical expert in data integrations. | I will know I have been successful if I am able to lead a data integration project for a key customer account. |

## Set Development Goals

Now that you set your intention, it's time to set specific development goals to help you reach your career objectives. Team members should focus on setting 1-3 development goals per review period to help them reach their overall career goals.

When setting your development goals, try to make your goals specific.  Think about and include details such as:

1. What resources or support will you need?
1. How will this support your career goals?
1. What actionable steps will you take to reach your goal?
1. How will you engage your network?
1. What challenges do you anticipate?

Think creatively about your development goals, focusing on the [70-20-10 rule for development]({{< ref "career-development#70-20-10-rule-for-development" >}}).

<div style="width: 100%;"><div style="position: relative; padding-bottom: 75.93%; padding-top: 0; height: 0;"><iframe frameborder="0" width="300" height="250" style="position: absolute; top: 0; left: 0; width: 100%; height: 100%;" src="https://view.genial.ly/62fd2aa9021efd0018b7c8eb" type="text/html" allowscriptaccess="always" allowfullscreen="true" scrolling="yes" allownetworking="all"></iframe> </div> </div>

If you need ideas or help finding development opportunities, [access this repository]({{< ref "career-development#directory" >}}) of resources, programs, and learning platforms. Explore the directory of handbook links to guide you. Bookmark learning programs that are most relevant to the direction you'd like to grow.

**Tip: If you can't find resources internally, refer to the Growth and Development Benefit to cover university programs, coding classes, external certifications, coaching programs, and more.**

## Track, Reflect, and Iterate

The IGP is a dynamic tool to help support your growth and development. Workday will send a reminder for you to review and re-launch your IGP 6 months after your manager provides input. You can also set calendar reminders where appropriate so you don't forget to revisit your IGP. [Update your development goals](https://docs.google.com/document/d/1qEqTHx_G1uIPQi8rIIbrHjJ6S0NYhKDoHeBOLXsjkNw/edit#heading=h.wje1pky1vhig) directly in Workday as you make progress against each one. Below are suggestions regarding how and when you might reference, reflect, and iterate on your goals and IGP:

1. Select a format to track your progress. Consider [these examples]({{< ref "career-development#tracking-your-progress" >}}).
1. Have at least one quarterly [career conversation]({{< ref "career-development#having-career-conversations" >}}) with your manager during a 1:1.
1. Review your IGP before completing the [Engagement Survey](/handbook/people-group/engagement#cultureamp-engagement-survey-overview) to incorporate in your feedback on career growth.
1. Review before engaging in the [360 feedback program]({{< ref "360-feedback" >}}). Ask for feedback on your specific development areas.
1. Include your lessons learned and growth opportunities in your [Talent Assessments](/handbook/people-group/talent-assessment).

Below is a sample timeline that you may want to follow when it comes to tracking, reflecting and iterating on your IGP, aligning with each half of the fiscal year.

| Months | Activity | Resource |
| ----- | ------------ | ------------ |
| February | IGP Review/Iteration | [Workday User Guide - How to: Launch an Individual Growth Plan](https://docs.google.com/document/d/1qEqTHx_G1uIPQi8rIIbrHjJ6S0NYhKDoHeBOLXsjkNw/edit#heading=h.4zqq3z25qo1i) |
| March - July | Update your development goals as you make progress | [Workday User Guide - How to: Update Your Development Goals](https://docs.google.com/document/d/1qEqTHx_G1uIPQi8rIIbrHjJ6S0NYhKDoHeBOLXsjkNw/edit#heading=h.wje1pky1vhig) |
| August | IGP Review/Iteration | [Workday User Guide - How to: Launch an Individual Growth Plan](https://docs.google.com/document/d/1qEqTHx_G1uIPQi8rIIbrHjJ6S0NYhKDoHeBOLXsjkNw/edit#heading=h.4zqq3z25qo1i) |
| September - January | Update your development goals as you make progress | [Workday User Guide - How to: Update Your Development Goals](https://docs.google.com/document/d/1qEqTHx_G1uIPQi8rIIbrHjJ6S0NYhKDoHeBOLXsjkNw/edit#heading=h.wje1pky1vhig) |

## Additional Resources

1. LinkedIn Learning Course: Building a Career Plan (course no longer available)
1. Watch this interview with a GitLab team member who's used the IGP to plan a career transition at GitLab:

{{< youtube "0ih0lMoKxN0" >}}

1. Listen to team members speak about non-linear careers at GitLab:

{{< youtube "ttQv6tCaDD0" >}}

1. An [Engineering specific IGP Template](https://docs.google.com/spreadsheets/d/1hYkaQrPYhnp8V_8woCrig4cqIiL0G7eEzlwBS-7wGPk/edit). This templates combines multiple resources such as the [Engineering Career Framework](/handbook/engineering/careers/matrix/), [Career Conversation Meeting Template](https://docs.google.com/document/d/1ugfwvhOcX6xPuxsn_oqZi7HV8364nQ5VnGO42IDlZkU/edit), and [Job Framework](https://docs.google.com/spreadsheets/d/1FX4NBwF099uMBm7mGBtf1orIJZuHEjtiEa3jSbg9jJs/edit#gid=0)
