---
title: Growth and Development Fund - Managers Guide
description: A guide for Managers on the Growth and Development Fund
---

## Introduction

GitLab's Growth & Development (G&D) Fund is an investment into continuously expanding skills and capabilities of GitLab team members. As a people leader at GitLab, encouraging use of the Growth and Development Fund is a fantastic way to help develop your team members so that they can achieve their career goals at GitLab. This guide provides information on how and why managers should encourage the use of this opportunity, guidance on appropriate usage, and some tips on utilization.

### "Fund" vs "Benefit"

After considering how G&D works at GitLab, talent teams challenged the word "benefit". Since team members apply for this reimbursement, and go through an approval process it's less a "benefit" that's automatically granted and more in line with a "fund" where team members request access. Maintainers will begin updating this small language tweak everywhere. Updated language will be "Growth & Development Fund".

### Eligibility

There are certain criteria that team members must meet in order to be eligible to use the Growth and Development Fund. These are as follows:

- Must be a full-time employee, and have been at GitLab for at least 3 months. (Part-time employees may be eligible for a reduced allownace)
- Team members must not be on "leave" status.
- Team members should in good standing with GitLab in terms of performance and behaviours.
- Team members should not be on a Performance Improvement Plan, or any type of remedial coaching in regards to underperformance.

### The Role of Managers in Growth and Development Applications

All Growth and Development applications need manager approval, so applications from team members should not come as a surprise to you when they are created, but should come about as a result of ongoing [Career Development](/handbook/people-group/learning-and-development/career-development/#what-is-career-development)  conversations with your team. If you don't already have regular career development conversations planned in with your team members (either as part of a regular 1:1 or a separately scheduled meeting), we recommend scheduling these in so that you can better understand your team members' career goals. Take a look at the [Support your team with Career Conversations](https://levelup.gitlab.com/access/saml/login/internal-team-members?returnTo=https://levelup.gitlab.com/learn/course/support-your-team-with-career-conversations) course in Level Up for best practice on how to handle these conversations effectively.

As a result of these career conversations, you may identify an opportunity that could be suitable for a Growth and Development Fund application, that aligns with the team member's career goals. As a manager, you should try to look out for such opportunities to encourage this usage, it can make team members feel that they are valued and that you show an understanding and appreciation of their career goals, and want to play an active role in helping them achieve them.

Individual OKRs and business goals should not be tied to GD opportunities, unless the individual team member thinks it's appropriate.

Growth and Development applications should generally be self-directed by your team members, but if each of your team members has G&D budget remaining, there are instances in which a manager can recommend a training for their whole team to make use of. Take a look at the [Bulk Applications](/handbook/people-group/learning-and-development/growth-and-development/#bulk-applications) section for more info

We see use of the Growth and Development fund as a great means of supporting [High Performing Teams](/handbook/company/high-performing-teams/#high-performing-teams-indicators) at GitLab

### Expected Outcomes

As a manager you should take into consideration what the benefit of the proposed opportunity will be for the team member AND for the work they do at GitLab. Our most important value at GitLab is Results for Customers - and this should be considered in everything we do. We encourage you to use your best judgement when talking to team members about G&D opportunities, taking into consideration the relevance of the opportunity and the value it potentially represents both to the team member's career, but also how it may produce results further down the line.

### Time Investment

Some G&D opportunities may come with a considerable time investment (conferences, academic study, etc.). There is shared responsibility across both the manager and the team member to understand the time commitments for the opportunity and be confident that it won't negatively impact the delivery of day-to-day required work.

If there is some concern that the time commitment required for a G&D application could compromise a team member's ability to deliver in their role, we would recommend either delaying the start date to a more suitable time, or looking for alternative options that may have a lighter workload or one that is more spread out.

## Understanding Approvals

When a manager approves a G&D request, they are communicating that the growth experience is in line with the skills development for the team member (requestor) and this experience helps them in their contributions to overall team performance. Managers are approving the time and financial investment. If requests do not align with role/team performance and GitLab's focus on results for customers. Managers should be able to speak to the WHAT and HOW behind the request. This should drive ongoing performance and application conversations. In addition, these growth experiences should inform inputs into the Talent Assessment.

**Approval Requirements:**

1. Manager Approval: $0-$1000
1. Manager AND VP Approval: $1000.01 - $5000
1. Manager AND e-group Approval for any spend beyond $5000
    1. Sales: $5000+ approval by VP

### Managers should know what they are approving

As a manager you are ultimately responsible for the performance and behaviours of your team members. Therefore, it's important that you understand the opportunities you are approving for your team members, and that you have discussed them during a career development conversation.

You should feel in all instances that you are able to explain the reasoning and benefits behind your team members G&D fund applications.

### Approving travel for live, in person experiences

Our intent at GitLab is to pay for everything a team member needs when travelling to a conference, but there are a couple of things to be mindful of when approving these requests.

- The G&D Fund should be used to pay for conference registration, tickets, etc.
- The costs for travelling to and from a conference, including hotel stays and meals, comes from the Travel & Expenses budget.

These two costs should still be detailed in the Growth and Development request issue. They just need to be expensed separately. The travel costs won't be subtracted from the team members' personal G&D budget.

There may be budgetary concerns if a team member is applying for a conference that would incur significant travel and accommodation costs. When approving a team members' G&D request, managers should feel confident that they can justify the total cost.

If you are unsure whether the cost of travel for one of your team members G&D applications is justifiable, please speak to your manager / VP **before** approving the request. VP approval is required on all applications over $1000 involving travel, so in most cases they will be made aware as a matter of course.

If you have any questions, please reach out to the [Learning & Development](https://gitlab.enterprise.slack.com/archives/CMRAWQ97W) team for support.

### You are approving time away / team member out of production

If you are approving an opportunity that requires the participant to be away from work during their normal hours, make sure you have a plan for coverage. You should have a direct conversation with the team member on how much time should be allocated for the experience and on what frequency.

### Note on Reimbursement

Growth & Development requests are a reimbursed expense and follow a reimbursement workflow. Approved experiences will be reimbursed upon completion. This means requestors carry the financial responsibility associated with the growth experience through completion.

As an option, requests over $1000 USD can take advantage of the split disbursement option designed to help team members carry the financial lift of costly experiences. The split disbursement option allows for 50% of the costs to be reimbursed immediately after payment and the remaining 50% is reimbursed upon completion.

*Here's how this workflow works*: 1). After all necessary approvals, the requesting team member pays for approved G&D experience. 2). If costs for this G&D experience exceed $1000USD, the team member can submit the proof of payment (via Navan), and the approved GitLab issue to receive a reimbursement of 50% of the total costs. 3). Upon completion, the team member will submit the proof of completion (certificate, completion email, etc.) along with that same approved issue to receive the remaining 50% of total costs.

## Types of opportunities

Before encouraging team members to utilize the G&D Fund, it's important to be aware of the types of opportunities that are eligible. Review the main [Types of Growth and Development Reimbursement](/handbook/people-group/learning-and-development/growth-and-development/#types-of-growth-and-development-reimbursements) for more information on this.

## Company-directed Learning vs Growth & Development funded learning experiences

It's important to differentiate between mandatory, company-directed learning initiatives and optional opportunities funded by G&D. While both are essential for professional development, the G&D Fund specifically supports elective learning experiences that align with the team member's personal growth/development goals. This does not mean that team-based learning applications will be rejected in all instances, please see the FAQs below for more detail.

## FAQs

### I would like to utilize the Growth and Development Fund for some team training, is that allowed?

The G&D Fund is primarily intended for individual use for career growth and this accounts for the vast majority of applications. However, if a manager feels strongly they could benefit from a team-based training opportunity, their team members are supportive of that, and each team member has the remaining G&D allowance required for the opportunity, this may be suitable for G&D use. The Learning & Development review these applications on a case by case basis, so please reach out in [#learninganddevelopment](https://gitlab.enterprise.slack.com/archives/CMRAWQ97W) to discuss the suitability of your team training opportunity.

If the budget isn't available to put team members through a paid learning opportunity, we recommend engaging the Learning and Development Team using our [Team Workshops](/handbook/people-group/learning-and-development/team-workshops/) program, where we can assist in creating a customized learning path using our existing resources and expertise.

Note: G&D budgets cannot be pooled - e.g. if one team member has spent their full allowance for the year and you want to put them through a team training that costs $2000 per participant, they can't draw on the unused allowance from other team members to fund the training.

### Can I utilize the Growth and Development Fund to help manage underperformance?

No. The G&D Fund shouldn't be used as a means to help underperformance, only team members who are meeting performance expectations in their current role are eligible. Team members on a Performance Improvement Plan (PIP) or any type of remedial, as outlined in the [Underperformance](/handbook/leadership/underperformance/) page are not eligible for the G&D Fund.

### Can I recommend G&D opportunities to help solve ongoing business issues within my work scope?

No. The G&D Fund is to empower individual team members to work on their career growth, it should not be used to solve ongoing business issues. If you feel an ongoing business problem cannot be solved without some sort of formal training, this should come from the department budget, and we would recommend speaking to your manager about this.

In some countries, the Growth and Development Benefit may be considered as taxable income and can be (partially) exempted from personal income taxes or subject to employer withholding taxes. Check the tax table for any tax implications in your country.

Please contact Payroll for any tax-related questions in your country.

#### I'm unsure if my team member's application is appropriate for the G&D Fund, what should I do?

If you are unsure as to the suitability of an application one of your team members has made, feel free to reach out the Learning & Development Team. Due to the sheer range of topics and types of Growth and Development opportunities, we are happy to review on a case by case basis where necessary.

As a general rule of thumb, opportunities to improve skills that are rarely needed in your business area should be kept to applications for $1000 or less. There may be exceptions to his, but you as a manager should feel that you are able to justify this through evidence of team members' past performance and future career goals.

#### My team member wants to go to a conference, but the travel isn't covered by the G&D Fund, why?

If the Growth & Development conference request has been approved, then the accompanied travel expenses are also approved, but they must be filed/reimbursed separately because they come from two different budgets.

The Growth and Development Fund can be used to cover the cost of conference tickets and admission, but the costs for travel, accommodation, and meals, should come from your departments Travel & Expenses budget. These costs have been accounted for in the budget for each department. Team members should still include the approximate travel and hotel costs in their Growth and Development issue, so that your department's VP can review and approve the costs, with the understanding that it is coming from their T&E budget. The T&E costs are not subtracted from a team members G&D budget of 10,000 USD.
