---
title: "Handbook-First Approach to Interactive Learning"
description: "All elearning courses tied to the Field Certification Program will utilize the Handbook as the Single Source of Truth (SSOT)"
---

All elearning courses at GitLab will utilize the Handbook as the Single Source of Truth (SSOT).

![gitlab-learning-content-diagram](gitlab-learning-content-diagram.png)

All our available learning material can be found on [Level Up](https://levelup.gitlab.com/learn/dashboard).

## Examples

1. Teams like Field Enablement use a handbook-first approach to learning in their [Field Certification Program](/handbook/sales/training/field-certification/), built with Articulate 360 Storyline Suite. Learners refer to the Handbook directly within elearning courses.
1. L&D hosts [Mini and Extended Challenges](/handbook/people-group/learning-and-development#gitlab-mini-and-extended-challenges) to engage team members in bite sized learning about a specific topic. Participants in the challenge collaborate on issues and are driven to the handbook to review learning content.

## Self-Paced Learning Outline

Below is an outlined example of how the field enablement team created a handbook first learning course using Articulate 360.

1. **Introduction** Explain learner objectives and how to navigate the course content
1. **Video** Embedded in the handbook and linked from the LXP
1. **iFrames** Display content directly from the GitLab handbook. Before each iframe, a short description sets the expectation of the learner, time needed to read the handbook section, and a direct link to the handbook to open in a new tab
1. **Intellectual property** Linked directly to the course
1. **Interactive Learning** Quick learning checks to review previous material

## Creating new learning material

### Best Practices

The Instructional Designer on the Learning & Development Team maintains a [Content Creation Best Practices Guide](https://docs.google.com/document/d/1YZnPU5qCO6VhXttqTt97A69jsQyUsO0oPCNJe_Adv4o/edit?usp=sharing) to provide team members with a guide when creating learning content.

### Course Development Workflow

Instructional designers use the [ADDIE instructional systems design (ISD) framework](https://www.instructionaldesign.org/models/addie/) to design and develop courses. The workflow of course development will be as follows:

1. Create learning objectives
1. Design storyboard and get SME buy in
1. Outline course Handbook page
1. Develop elearning
1. Conduct a course Alpha
1. Incorporate feedback
1. Conduct a course Beta (as needed)
1. Publish course in LXP
1. Announce course launch
1. Enroll learners (as needed)

### Documenting learning content in the handbook

Our goal is that each course will have an associated Handbook page including learning objectives, static learning content, quizzes, and applicable links.

Consider the following when documenting course content in the handbook:

1. Outline clear learning objectives
1. Make content discoverable. For example, leadership content should not live in the Learning and Development handbook, but instead in the [Leadership handbook]({{< ref "leadership" >}})
1. Embed relevant YouTube videos in the handbook
1. Link to knowledge assessments
1. Cross reference any additional handbook content with links

### Using iFrames

This [training video](https://youtu.be/wlLKZz3vSAk) provides an example of how iframes can be used to display sections of the handbook in a Rise 360 course. The same can be done in Level Up.

{{< youtube "wlLKZz3vSAk" >}}

In the team Articulate - Rise 360 license, there is a block template for iframes. You can access this template in the `block templates` section and add your iframe code directly.

![iframe-embed-template](../iframe-block.png)

#### iframe tag examples

Consider copying and pasting the iframe tag below to apply the strategies outlined in the training. GitLab team members can access [this Google doc resource](https://docs.google.com/document/d/1HvikZayptzqT8kFFB_EPdiXBl04iYsnRzwFKGKgLVxI/edit) for ease of access to iframe tags that can be copied and edited when building courses using Articulate360 tools.

1. `<iframe src="link-to-your-page" title="title for iframe metadata" scrolling="yes" height="500" width="800"></iframe>`

## Interactivity in E-learning

Interactivity such as games, drag-and-drop, matching, and other interactive components in a published elearning course will not be accessible via the Handbook; however, all information conveyed to learners through the elearning course will have an associated Handbook page as needed. This will make sure that despite the interactivity of the elearning course, learners will have access to all topics covered in a course via the Handbook.

## Handbook First Video

The following best practices should be followed when using video to create handbook first learning material.

1. Upload recorded video to the GitLab Unfiltered channel
1. Embed videos into the handbook on the appropriate content page
1. Ensure that embedded videos have a sub-header on the page. This will be an essential piece when linking to the handbook using iframes. Here is an [example of this layout](/handbook/company/culture/all-remote/mental-health/#do-not-celebrate-working-long-hours).
1. Build iframes within a lesson to display video by linking to these sub headers

Other best practices for recording new learning video include:

1. Turn on [Zoom closed captionining and live transcription](https://support.zoom.us/hc/en-us/articles/207279736-Closed-captioning-and-live-transcription)
1. Whenever possible, upload public videos to YouTube and use the YouTube link to share video on EdCast. This allows users to enable YouTube `closed caption` feature
1. Upload `.vtt` files with video content added to Rise courses using Articulate360 to include closed captions within the course.
1. The L&D team collaborates with Marketing Ops to use the tool Smartling to hard code closed captions to video that is not uploaded to YouTube. Video files should be shared with the Marketing Ops team who can support collaboration with Smartling. Expect anywhere between 1 day to 1 week turnaround on the video transcription based on the video length.

### Creating a Learning Video in Zoom

When creating learning content, the Learning & Development team may work with other teams on creating videos.

Guidelines for recording a video for a course:

1. **Tool:** The recording will be done in Zoom.
   - Open your zoom app and click `new meeting`
   - Once the zoom meeting starts, make sure your video is turned on and you are unmuted.
   - Once you are ready, click the `Record` button, then click `Record on this Computer` - This will make the file save to your computer and then you can drag and drop into the designated Google Drive folder
   - If you are sharing slides during your talk you can use the   `share screen` button as your normally would if sharing your screen in a meeting. Select the one browser that has your slides when selecting which screen to share - do not share your full Desktop as slack or other notifications could pop up in the Full Desktop mode (we don't want to see any other applications or tabs you have open). Also, please ensure your slides are in `Present` mode and are taking up your full screen .
   - Once you are done recording, you can either hit `Pause` or `Stop` recording or just end the meeting. (Note: We can snip pieces of the video so if you start recording and then not start talking for 30+ seconds, we can snip that from the recording (same for any blank time at the end).
   - The file will take a moment to download.
   - Once it has downloaded, please either send it to the L&D team member that is working on the course or upload it to the appropriate folder for recordings for the course you are assisting with.
1. **Appearance:** We want you to be your authentic self that you're comfortable with anyone on the internet seeing. The video will be public on YouTube unfiltered.
1. **Slides:** Slides can be used during your presentation if you wish. Please use the provided slides template for the course.
1. **Background:** You can use either a GitLab branded virtual background, no virtual background if you are comfortable with the area behind your workspace being on the internet, or use the blurred feature on zoom to blur your background.
1. **Completed Recording:** Once the recording is completed, please add it to the appropriate Google Drive Folder or send it to the L&D team member that you have been working with. L&D will add GitLab L&D branded content to the beginning and end (intros/outtros) of the video.

### Private Video

The following best practices should be followed when building learning content that includes private or internal only video.

1. Professional services shares recordings of live learning sessions directly with customers involved in each specific training via a Zoom link and recording password. These videos are not published on YouTube or to the handbook. Future iterations will include using EdCast to store and share these recordings using private Groups.

## Toolkit

Use the following resources when building handbook first learning. Review the [tech stack](/handbook/business-technology/tech-stack-applications/) to find the current application owner at GitLab.

1. Articulate360
1. [ScribehHow](https://scribehow.com/)
1. [Biteable](https://biteable.com)
1. [Powtoon](https://www.powtoon.com)
1. [Iorad](https://www.iorad.com/)

## Examples of what is not considered handbook first

Avoiding these examples can help ensure that the content you're producing follows a handbook first approach.

| Example | Suggested handbook first improvement |
| ----- | ----- |
| Introducing new content within a course or Pathway | Add new content to an existing handbook page, or open a new page to document |
| Directly uploading a public video to the LXP | Upload the video first to GitLab Unfiltered, emebed on the correct handbook page, and either display in an Articulate course via iframe in Level Up |

## Challenges

- iframes can break if the page or subsection of the linked handbook is updated
- Updates to courses that are saved as SCORM files must be updated in the course creation tool and then reuploaded to the EdCast platform
- When iframes are not used, the user needs to navigate to text and video content in the handbook on a new internet tab
- New handbook/docs pages may need to be created in cases where videos should be included in a learning path
