---
title: Mentoring at GitLab
---

Mentorship is an opportunity to learn from personal experience, background, and perspective. Mentorship builds trust, provides a safe space to make mistakes, and encourages growth for both the mentor and mentee. Reach out in the [#mentoring Slack channel](https://app.slack.com/client/T02592416/C01QKNDJ76J) with questions or feedback.

***The Power of Mentoring***

{{< youtube "0W3d-PJ4-FM" >}}

## How to get started

Team members have multiple options to participate in mentorship at GitLab.

1. **Identify and self-select a mentor** from your professional network or the [list of available mentors below](#find-a-mentor).
1. **Make yourself available as a mentor** by following [these steps](#become-a-mentor).
1. **Participate in an [organized mentorship program](#organized-mentorship-programs)** where mentors and mentees are paired based on an application process.

### What team members are Saying

1. `Although not directly, but my mentor has indirectly helped me with my OKRs. My mentor has given me more confidence and knows-how in approaching my OKR goals.`
1. `With advice from my mentor, I was able to adjust the way I was reporting on my OKRs & projects to better communicate my progress. I also was coached on how to prepare myself for feedback & criticisms on my projects and how to better receive those comments - not taking them personally, and striving to be a part of the solution to fixing problems versus thinking I am the problem.`
1. `I have learnt to navigate GitLab code and improve my debugging skills, which directly feeds into delivering exceptional experience to my efficiency, customers results and skills development.`
1. `My mentor has been a force in my life. She is incredible - from helping me navigate new manager styles to how to prospect to how to deal with my mental health better - she's so so good. I hit the jackpot! I am in such a better place to actually work hard with her on my team, so the impact is indirectly directly related to my ability to sell.`

### Results

In FY23 Q1, 17% of mentees in current organized mentorship programs completed a survey and reported the effects of the mentorship on business and personal results.

<iframe src="https://docs.google.com/presentation/d/e/2PACX-1vSQo5yL0DOCgaAQWwXaIYHfb20pGIxlkzkxBB_xgU-rEsNkNa4U1NxevaCIQRZrgExrSQecEng50Kmy/embed?start=false&loop=false&delayms=3000" frameborder="0" width="960" height="569" allowfullscreen="true" mozallowfullscreen="true" webkitallowfullscreen="true"></iframe>

## Benefits and Expectations

### Benefits for the mentee

1. Be encouraged to prioritize, and be held accountable for, your [career development]({{< ref "career-development" >}})
1. Learn new skills related to your current role, your future career goals, or an area that you're passionate about
1. Set and reach clearly outlined [goals](/handbook/company/okrs).

### Benefits for the mentor

1. Serve as a [leader in the organization]({{< ref "leadership" >}}) by enabling growth for other team members
1. Practice leadership, [effective communication]({{< ref "communication" >}}), and [coaching]({{< ref "coaching" >}}) skills
1. Establish yourself as an expert in a field or speciality
1. [Build trust]({{< ref "building-trust" >}}) with team members

### Expectations

| Expectation | Description |
| ----- | --------------- |
| **Mentees lead conversations** | Mentorship is led by the mentee, similar to how [1:1's at GitLab]({{< ref "1-1" >}}) are driven by direct reports. |
| **Maintain Boundaries** | Maintain clear and appropriate boundaries. Be clear on your responsibilities and those of their manager. |
| **Set Goals** | Mentees should create goals, put them in writing, and frequently revisit goals to measure progress. |
| **Build Trust** | Colleague first, expert second. Spend time [getting to know one another](/handbook/values/#diversity-inclusion). [Be open, honest, and fully authentic](/handbook/values/#transparency). |
| **Set Expectations** | Be realistic and uphold your commitment. Share access to resources and people, but make it clear you do not wield your influence over others.|
| **Listen** | Establish [trust]({{< ref "building-trust" >}}) and openness in communication. Give your full, undivided attention. Hear concerns before offering advice and guidance.|
| **Acknowledge Independence** | Recognize mentee goals and autonomy. Your role as a mentor is to guide; it's up to the mentee to decide what to implement in their own career. |
| **Respect Diverse Experiences** | Recognise that underrepresented groups might face additional barriers to advancement. Educate yourself and ask for advice and support via the [appropriate DIB channels](/handbook/company/culture/inclusion/erg-guide/#how-to-join-current-tmrgs-and-their-slack-channels). |
| **Practice Self-Awareness** | Identify your strengths, weaknesses, and [biases](/handbook/values/#unconscious-bias). Be aware of and respect other's experiences, ideas, and goals. |
| **Advocate** | Mentor others on being effective managers or colleagues to those who might have different experiences to them. Teach your mentee how to become a mentor themselves – by example and by encouragement.|
| **Express Gratitude** | Share openly about your experience. Express gratitude for the skills or experiences developed over time. |
| **Maintain a Growth Mindset** | Practice a [growth mindset](/handbook/values/#growth-mindset). Both parties can learn and grow from mentorship |
| **Iterate** | [Iterate](/handbook/values/#iteration) on goals throughout the mentorship. Focus on quick wins that the mentee can reach, then keep growing. |
| **Confidentiality** | Respect the trust built between mentor and mentee. Challenges and conversations shared in mentorship sessions should be kept confidential unless the mentor and mentee are okay with them being shared. |

*Adapted from the [NCWIT Mentoring-in-a-Box Mentoring Basics - A Mentor's Guide to Success](https://ncwit.org/resource/imentor/), section What Are the "Dos" of Mentoring and [People Grove resources](https://support.peoplegrove.com/hc/en-us/articles/360001265792-Structure-Goals-and-Agendas)*

## Find a mentor

The following team members are available as mentors. Schedule a [coffee chat](/handbook/company/culture/all-remote/informal-communication/#coffee-chats) to get the conversation started!

The `Expertise` column comes from the team member .yaml entry and might not include all subjects they can help you with.

{{< mentors >}}

## Become a mentor

1. Indicate your mentorship availability on the GitLab team page by setting the `mentor` status to `true`. This will appear on the team page with a line that reads `Available as a mentor`. [Example MR](https://gitlab.com/gitlab-com/www-gitlab-com/-/merge_requests/75890)

## Organized mentorship programs

Learn more about organized mentorship programs for team members:

1. [Company-Wide](company-program)
1. [Minorities in Tech](/handbook/company/culture/inclusion/erg-minorities-in-tech/mentoring/)
1. [Women at GitLab](/handbook/company/culture/inclusion/tmrg-gitlab-women/mentorship-program/)
1. [Aspiring Managers](/handbook/engineering/development/dev/training/ic-to-manager/#aspiring-manager-mentorship-pilot-program)
1. [Finance Team](/handbook/finance/) is running a [mentorship program](/handbook/finance/growth-and-development/mentorship).

## Resources

Resources below are designed to guide mentor/mentee relationships in both synchronous and asynchronous formats. Adopt what fits and leave what doesn't.

### Mentor and Mentee training

Enjoy the following [Google Slides presentation](https://docs.google.com/presentation/d/1QPx9ZGa051Jhwwfb78cKW1LD0uVTUdKxRdElBk4Ku9I/edit?usp=sharing) on finding a mentor, setting clear expectations, and achieving goals through mentorship.

<iframe src="https://docs.google.com/presentation/d/e/2PACX-1vS3cZJcCIv_s44OfN9QLjje2wRqS7EwnrK3HCS_ZeT-ZGwk58hPq17L-c_DvCdvu0jxjR3r6yY8xY79/embed?start=false&loop=false&delayms=3000" frameborder="0" width="960" height="569" allowfullscreen="true" mozallowfullscreen="true" webkitallowfullscreen="true"></iframe>

### Mentee: What to do before your mentorship begins

1. Set up a coffee chat with your mentor. Take time to get to know them and [build trust](/handbook/leadership/building-trust/). Discuss communication styles and preferences.
1. Set a specific goal for your mentorship. It's OK if you don't reach 100% of your goal during the mentorship.
1. Join the [#mentoring](https://app.slack.com/client/T02592416/C01QKNDJ76J/thread/C5P8T9VQX-1587584276.009700) Slack channel

### Mentee: Set your goal and purpose

In their book [Burnout: the secret to unlocking the stress cycle](https://www.burnoutbook.net/), authors Emily and Amelia Nagoski explain the difference between goals and purpose:

| Idea | Definition |
| ---- | --------------- |
| Goal | the `what` - outcome driven |
| Purpose | the `why` - value driven |

Mentees should set a foundational goal and purpose for their mentorship. **Mentee goals should drive the relationship.**. Mentors might also set a goal around their own growth objectives as a mentor. Both mentors and mentees bring their own original purpose to mentorship.

### What is your goal?

| Criteria | Description |
| -------- | ----------- |
| Time-bound | When will the goal be complete? |
| Certain | Is achievement of the goal within your control? |
| Specific | What is the desired outcome? |
| Positive | What positive impact will the outcome create? |
| Measurable | How will success be measured? |
| Personal | Why does achieving the goal matter? Tie goal to purpose. |

Using the matrix below, fill in each empty space based on the descriptions above to draft your goal:

| Time-bound | Certain | Specific | Positive | Measurable | Personal |
| ---------- | ------- | -------- | -------- | ---------- | -------- |
| | | | | | |

*This structure is adapted from [Burnout: the secret to unlocking the stress cycle](https://www.burnoutbook.net/) and the [SMART goal framework](https://support.peoplegrove.com/hc/en-us/articles/360001265792-Structure-Goals-and-Agendas). Learn more about goal setting by taking the [Setting Team and Employee Goals using SMART Methodology LinkedIn Learning course](https://www.linkedin.com/learning/setting-team-and-employee-goals-using-smart-methodology/how-to-use-smart-goals-2?u=2255073)*

#### Setting tool-specific goals

Goals that are specific to learning a tool, like increasing confidence with GitLab, might be challenging to fit in the SMART model. Consider asking yourself these two questions to help clarify your goal.

1. What will you do to improve your understanding of the GitLab product?
1. How will you show that you have improved your understanding of the GitLab product / what do you expect to be able to do?

Then, try breaking down your goal into clear actions as shown in the examples below:

> Example 1: Improve my understanding of GitLab product by X date
>
> 1. Move all personal projects to GitLab
> 1. Configure CI/CD tools to automate 1 manual task
> 1. Track career development in a personal project
>
> Example 2: Learn about Ruby by X date
>
> 1. Take X course
> 1. Resolve 3 ruby bugs in the product
> 1. Create 1 blog post with learnings

### What is your purpose?

Purpose is value-driven and based on your values. Determine what values drive you to be part of a mentorship and complete the following statement:

**I'm a `mentor/mentee` because I care about `value`. `Value` drives me to be a `mentor/mentee` because `your why`.**

### Communicate your goal and purpose

Discussions about goals and purpose should be part of your first mentorship meeting. Progress and iterations on goals should be revisited often.

## Mentee: Set a Meeting Schedule

Set clear expectations with your mentor/mentee about when, how often, and for how long you will formally meet. Below is a suggested format for this meeting cadence:

1. Establish a timeframe: 3-6 month is suggested
1. Set a meeting cadence every other week for 30-45 minutes or agree to spend 30-45 minutes every other week communicating asynchronously

### Sample sync meeting agendas

Mentorship agendas are important for resources documentation and future planning. The mentee should be the DRI for each session and use the agenda to set meeting goals and ask questions. Use and customize the following meeting agenda templates as a baseline for each session. Please make a copy of these templates and save to your own Google Drive.

1. [Initial Meeting Agenda Template](https://docs.google.com/document/d/1p1jVyE6S2qvCiNwjdwhREj4ge1AGneb0pFxfC3T2rPY/edit?usp=sharing)
1. [Regular Meeting Agenda Template](https://docs.google.com/document/d/1ufU9Hjcuf2-psASdXS_B7zX64C-5eBuvOR-P7pbSULM/edit?usp=sharing)
1. [Final Meeting Agenda Template](https://docs.google.com/document/d/1IVwilfvUN-XE6FE1kjKLLmou4YUQYDD8ba57kM7dyGY/edit?usp=sharing)

*Sample agendas below are inspired by resources from [Arizona State University](https://wms.arizona.edu/sites/default/files/Sample%20Meeting%20Agendas%20and%20Emails%20for%20Mentors.pdf) and [People Grove](https://support.peoplegrove.com/hc/en-us/articles/360001265792-Structure-Goals-and-Agendas).*

### Sample async meeting formats

GitLab issues can be used to collaborate async in a mentorship. Use this [issue template](https://gitlab.com/gitlab-com/people-group/learning-development/mentorship/-/blob/main/.gitlab/issue_templates/async-mentorship.md) to get started.

### Other tools for async mentorship

1. [Template for using Google Docs](https://docs.google.com/document/d/1isANsPewF44w9cLP6JHZJEX4n4cyXHjqpfVvhqQKnOk/edit?usp=sharing)
1. Slack voice memos
1. Slack recording
1. Loom recording

## Track your progress

Use [this issue template](https://gitlab.com/gitlab-com/people-group/learning-development/mentorship/-/blob/main/.gitlab/issue_templates/progress.md) to track progress on goals set for both mentor and mentee.

## Ending your mentorship

Mentorships end or change over time. Review these guidelines for how to end your mentorship with grace and some suggested actions to take as your mentorship ends.

1. It's OK for a mentorship to end if the mentor and mentor and mentee feel they've accomplished a goal or if the pair isn't a good fit. Consider having a coffee chat with your mentor/mentee to discuss what was accomplished or what didn't work. Thank each other for dedicating time for the mentorship.
1. Mentorship doesn't have to end, either! Establish a meeting cadence to stay connected with your mentor. You might meet 1x per month for a coffee chat, connect async via Slack, or continue with your 2x monthly sessions.
1. Share your mentorship results with your manager or your direct reports. Take time in your 1:1s to share why and how the mentorship helped you reach your goals, either professionally or personally. This is also a great time to connect your mentorship with the accomplishment of your OKRs, if it helped you achieve results.
1. Add your mentorship to your resume or to your LinkedIn profile. For mentors, this might look like a separate entry to demonstrate leadership. For mentees, you might mention the mentorship in relation to the goals you achieved.
1. Write a blog or LinkedIn post with a shout out to your mentor/mentee, highlighting what you learned and what surprised you.

## Additional Resources

These resources are meant to provide both mentors and mentees with additional personal and professional development. Consider reviewing these resources asynchronously and discuss/debrief them during a session with your mentor/mentee.

***Why the Power of Mentoring can Change the World***

{{< youtube "u4kTlK5mUHc" >}}

1. The [Engineering department](/handbook/engineering/) outlines [strategies for mentors and mentees](/handbook/engineering/careers/mentoring/) with suggestions on how to host meetings and set and evaluate goals.
1. The [Support team](/handbook/support) has outlined expectations and examples on [Mentorship in Support Engineering](/handbook/support/engineering/mentorship).
1. [Career growth resources at GitLab]({{< ref "career-development" >}})
1. [Harvard Business Review: What efficient mentorship looks like](https://hbr.org/2020/08/what-efficient-mentorship-looks-like)
1. [Harvard Business Review: What great mentorship looks like in a hybrid workplace](https://hbr.org/2021/05/what-great-mentorship-looks-like-in-a-hybrid-workplace)
1. [Harvard Business Review: The best mentorship help both people grow](https://hbr.org/2022/01/the-best-mentorships-help-both-people-grow)

## FAQs for New Mentors and Mentees

Is this your first mentorship at GitLab? Maybe it's your first time as a mentor. Check out the FAQ section below as a guide to find resources you need to make your mentorship a success.

| Question | Answer |
| ----- | ----- |
| **Where do I find resources about being a great mentor or mentee?** | On this page! The [expectations table](#expectations) is the best place to start. |
| **Are there meeting templates I can use?** | Yes! We have meeting templates for the initial session, ongoing sessions, and final mentorship sessions [here](#sample-sync-meeting-agendas). Mentors should encourage their mentees to start these and populate before each session. |
| **How do I connect with and learn from others in GitLab's mentorship programs?** | Each organized mentorship program has a Slack channel. The program organizers will post resources and discussion prompts there throughout the length of the program. Use these channels to ask questions and gain experience from other mentors and mentees. |
| **How do I get feedback from my mentor or mentee?** | Asking for feedback at the end of the program is a great time to connect and reflect on your relationship. You might also request feedback from your mentor or mentee during our [360 review cycle](/handbook/people-group/360-feedback/). |
| **Who drives the mentorship meetings?** | Mentees will drive the meetings. Mentees should come prepared to each session with questions or topics to discuss related to their mentorship goal. |
| **Is there a mentorship confidentialy agreement?** | While there is no formal agreement, `confidentiality` is one of the key expectations of mentors and mentees at GitLab. You can review this and other expectations [in the table above](#expectations)  |

## How to organize an all-remote mentorship program

Consider the following practices and lessons learned by the GitLab team when organizing your own all-remote mentorship program. [Open a Merge Request](/handbook/handbook-usage) to contribute your own learning to list!

1. Share call for applications across multiple channels and do direct outreach to great mentors for the best engagement. Lean on People Business Partners for suggestions of team members who would make great mentors and mentees.
1. In applications, ask for role, location, and mentorship focus area, along with ideal goals. Use multiple choice questions to easily sort and pair responses.
1. Give at least 2 weeks for folks to apply as mentors and mentees. Keep applications open past the deadline for rolling applications with a note that late applicants might not be paired. Rolling applications might help fill in the gaps with hard to pair mentors/mentees
1. Collaborate with Team Member Relations and People Business Partners to ensure that participatns are not on performance improvement plans and that their work performance qualifies them to participate (as program applications outline)
1. Consider using automation, if available, to pair. At GitLab we haven't used automation yet, but we are exploring it for future iterations.
1. If pairing manually, set aside at least 1 week to work on making pairs based on application responses. Consider recruiting a committee to delegate to.
1. Use Slack to send a message to mentors and mentees once paired. Put all relevant information for starting the program into one message and consider using both text and a short video to share this information.
1. Use a dedicated #mentorship Slack channel to communicate to participants over the length of the program.
1. Send 1-2 resources via Slack throughout the program to keep participants engaged and learning.
1. Use Polly or another survey tool to do a 1 month check in with mentees. This helps identify pairs that have not yet met or foks that might have left the company.
1. Give participants at least 3 weeks to complete the end of program survey.
