---
title: "Self-Paced External Trainings"
description: "Details of third-party training providers utilised by various GitLab departments"
---

Teams around GitLab utilize other training providers for accessing role specific training courses and learning materials. This handbook page lists the different providers used, including details on access and licensing.

## O'Reilly Learning

The O'Reilly Learning library, contains thousands of books, videos and live learning courses to assist team members' with professional development and staying up-to-date with changing technology trends. Additionally, code sandboxes are included within the O'Reilly platform that team members's can utilize to practice new skills or hone existing ones.

### How to get an O'Reilly license

The Customer Success and Development departments each have a number of licenses available for team-members. If you would like access to O'Reilly, please check Okta for the O'Reilly App.

#### Customer Success

- If the O'Reilly App isn't listed on Okta, please open an Access Request using instructions on this [handbook page](/handbook/it/end-user-services/onboarding-access-requests/access-requests/).
- If you are unable to log in from the Okta O'Reilly App, please contact [#it_help](https://gitlab.slack.com/archives/CK4EQH50E) with the AR number you created using the link above.

#### Development

- If the O'Reilly App isn't listed on Okta, please contact [Tim Zallmann](https://gitlab.com/timzallmann) or [John Hope](https://gitlab.com/johnhope) via Slack or Email to be added to the corresponding Google Group.

#### Other

If you aren't in Customer Success or Development but would still like access to an O'Reilly licenses, you can utilize the [Growth and Development benefit](/handbook/people-group/learning-and-development/growth-and-development/) to purchase a license (Manager approval required).

### Accessing O'Reilly content

Once you have an active license, we have a content integration set up in [GitLab Learn](https://gitlab.edcast.com/), so you can find and filter O'Reilly content using the search function, alongside all our other self-paces learning materials.

You can also access via the [O'Reilly platform](https://www.oreilly.com/online-learning/) directly.

## Linux Foundation Courses

GitLab has access to the Linux Foundation [Course Catalog](https://training.linuxfoundation.org/full-catalog/) and certification programs. We have a 60 seat subscription that will be granted to team members who required related course offerings to achieve their career development goals at GitLab. Each license includes 2 free exams. After the exams are used, team members can use their Growth and Development benefit to purchase additional exams at a 25% off discount.

License allocation will follow this approximate breakdown by department. If your department is not listed below and your career development goals required a course offered by the Linux Foundation, please reach out to the Learning and Development team to check on license availability.

*please note that this breakdown is an ideal allocation based on usage and total team members but does not necessarily represent the current license allocation. As license are moved to different team members throughout the year, we'll use both this breakdown and actual need to best allocate licenses.*

| Department | % Licenses Allocated |
| ----- | ----- |
| Development | 45% |
| Support | 30% |
| Quality, Infra, Security | 10% |
| Other as needed | 10% |
| Incubation | 5% |

### Sign Up

Open an [access request](https://gitlab.com/gitlab-com/team-member-epics/access-requests/-/issues/new?issuable_template=Individual_Bulk_Access_Request) and **indicate what career development goal you plan to use Linux Foundation to achieve.** Please assign to your manager for approval, and then assign to `@jallen16` for allocation and to obtain a unique redemption code.

### License Audit

Due to demand and the limited number of licenses available, we want to ensure that the available licenses are utilized as well as they can be.

The L&D team will conduct a voluntary audit at the end of Q1 & Q3 each fiscal year for any users who would like to give up their licenses, in case they have not used it or found it as useful as they had hoped. In times of demand for licenses, we may revoke those that haven't been used in 6+ months. We will always give advanced notice of any licenses being revoked, with the option to keep the license if desired.

### Learning Portal Access

After your access request as been approved, team members should follow these steps for activating their license:

- Go to: <https://trainingportal.linuxfoundation.org/redeem>
- Log in if you already have an LF-ID, or click `Create an Account`
- For new accounts, check your email and validate your email address. Please use your `@gitlab.com` email address-
- When back at the LF page, enter your assigned redemption code (case-sensitive) as the `Registration Code`. You will receive this code after your access request has been approved.
- Accept the terms and conditions and click `Redeem`
- You should then land in the learner dashboard where you can start scrolling through courses and exams. Click any title to begin.
- For support, please log a ticket at <https://trainingsupport.linuxfoundation.org/>

### FAQs

**How many exams can I take?**

Every license and unique registration code include 2 free exams. Depending on license rotation between team members, you may get a license without any exams. This is more likely to occur in Q3 and Q4 as the year comes to an end. Additional exams can be purchased using your Growth and Development benefit for a 25% off discount.

**I'm not sure if I did something wrong but how do I actually access the courses? I signed up with my GitLab email address, used the redemption code - But when I go to view the catalog all the courses still show the full amount and the certification code only works for the exam itself and not the course.**

Please send an email to `mcampbell@linuxfoundation.org` with your name and email address, cc'd `jallen@gitlab.com` for the email. This should not be the case but Linux can have a look at their ID and make sure their access was triggered properly.

**Can I get both a company O'Reilly and Linux Foundation License?**

Due to limited licenses, we ask that team members use one license at a time from either O'Reilly or Linux Foundation. If team members are interested in both, the L&D team can work with them to develop a plan to rotate licenses over a series of quarters to ensure team members have time to access courses in both platforms.

### Processing Notes for the L&D Team

#### First Time License Allocation Steps

1. Review the submitted AR. Ensure the request is linked to/mentions a career development goal has manager approval. Close the AR if confirmed.
1. If there is not mention of a career development goal, paste the following text as a comment on the issue and tag the issue creator:

> For a GitLab Linux Foundation licenses, your Access Request must mention [which career goal you'll work towards using your license]({{< ref "#sign-up" >}}). Please add this information to the AR and tag me for review upon completion.

1. Update the [license usage sheet](https://docs.google.com/spreadsheets/d/1gHwWy7TKAXem24NVCUmq94sICp_yCocDaf_onUZ3BPg/edit#gid=0) with team member's `first name`, `last name`, `email`, `department`, and `link to their Access Request`.
1. Communicate the following template to each new user. Include the unique access code associated with their name from the licenage usage sheet.

> Your access to the Linux Foundation has been approved! Please follow these [instructions](#learning-portal-access) to set up your account using your GitLab email address. Your unique and case sensitive access code is `XXXX`. You only need this code for your initial login. Let me know if you have any questions.

#### License Audit + Reallocation Steps

1. Communicate with users who have had a license for 6+ months. Start with an opt-in audit and remove licenses from inactive users.
1. Email the vendor with a list of users to be revoked from the platform. Confirm how many certifications remain on each license.
1. Add users who have been revoked from the platform to the [revoked access tab](https://docs.google.com/spreadsheets/d/1gHwWy7TKAXem24NVCUmq94sICp_yCocDaf_onUZ3BPg/edit#gid=137096765). Fill in as much information about the user platform behavior as you have available.
1. The vendor will return an email with new signup codes. Update the [license usage sheet](https://docs.google.com/spreadsheets/d/1gHwWy7TKAXem24NVCUmq94sICp_yCocDaf_onUZ3BPg/edit#gid=0) with these codes and certification counts.
1. Restart the `first time license allocation steps`.

## GCP Learning

As a GCP Partner, GitLab has *unlimited* seats to Google Cloud's [Skills Boost Platform for Partners](https://partner.cloudskillsboost.google/catalog). This portal includes a wide array of learning materials related to Google Cloud's offerings, ranging from introductory to advanced.

This is a completely self-paced learning platform with a variety of learning formats, including video content and hands-on labs style engagement.

### Sign Up

Any current GitLab team member can gain access to the learning platform by filling out [this form](https://inthecloud.withgoogle.com/partner-training/request-training-resources.html). Required information includes your first and last name, your GitLab email address, a phone number, and your location. While it asks you to identify areas of interest, this is optional, and you are not limited to just the area of interest you've indicated.

Once you've submitted the form, you should receive a welcome email from partner-training@google.com within 1-3 business days with instructions for how to access the learning platform. If you don't receive an email try to sign-in to platform via Google. Once you gain access, all the learning content is available to you, and you can engage as much or as little as suits your individual learning goals and level of interest.

### Certifications

Some learning paths are meant to give you knowledge and experience to pass a certification. To get the voucher code for passing a Google Cloud Certification please reach out to the #learninganddevelopment slack channel.

## LinkedIn Learning

From January 2021 - January 2024, GitLab had a 1000 license agreement with LinkedIn Learning. Due to the licenses being under-utilized, we decided to end this agreement so that we can explore other more cost-effective and impactful solutions for off the shelf content and self-paced trainings. However, for those team members who would like to continue to use a LinkedIn Learning license to access their training content, they can purchase one using the [Growth and Development Fund.](/handbook/people-group/learning-and-development/growth-and-development/).

Also, there are a number of LinkedIn Learning courses that are free for anyone to access, even if they do not have a paid license. You can review the full list of courses in the [Unlocked LinkedIn Learning course list.](https://docs.google.com/spreadsheets/d/1vafTEKxtm0TSF3maK1xdLPIA7OkYVPsQZH9CtC8tVmw/edit#gid=0)
