---
title: "GitLab Offboarding"
description: "Offboarding Procedures for GitLab Team Members and Stakeholders"
---
<!-- markdownlint-disable MD051 -->
## Offboarding Overview

The offboarding process is facilitated by the People Connect team who collaborates throughout the process with various other stakeholders such as Team Member Relations, IT Operations and Payroll.

If you have any questions around the offboarding process, please be sure to review the [Offboarding FAQs](/handbook/people-group/offboarding/faq) handbook page.

**Note:** Departing team members will receive a comprehensive email prior to their final date of employment with information such as the impact on benefits coverage, final pay, arranging for a laptop wipe and stock administration.

### Offboarding Support

For system access questions and [laptop wipes](/handbook/it/end-user-services/gitlab-laptop-offboarding/) related to offboarding, send an email to `itops@gitlab.com`.

For payroll questions or outstanding expense claims, please reach out to either `uspayroll@gitlab.com` or `nonuspayroll@gitlab.com`.

For any other offboarding questions from active team members please reach out to People Connect via [HelpLab](https://helplab.gitlab.systems/esc?id=emp_taxonomy_topic&topic_id=897eb385478c069067429ee0026d432c) or send an email to `people-connect@gitlab.com` if your access has already been terminated.

**Note:** If a termination date changes, please reach out to People Connect via HelpLab. The team will update Workday.  The notice is used as supporting documentation of the change and is saved in the team members Workday record. If the team member is employed via a PEO, they will also be notified by People Connect.

## Voluntary Terminations

### Prior to Resignation

1. **Team Member:** Please reach out to your Direct Manager prior to submitting your resignation particularly to discuss the handover process and the [communication plan](#communicating-departures) regarding your departure.
1. **Team Member:** Review the documented [notice period]({{< ref "contracts-probation-periods#probation-periods-of-team-members-employed-through-a-peo-or-an-entity" >}}) for your location if applicable and factor in the notice period when submitting your resignation through Workday.
1. **Team Member:** Compile your Letter of Resignation for uploading into Workday.  If you are employed through a PEO or Third-Party Employer, send a copy of your resignation letter to the PEO contact as well.

### Resignation

1. **Team Member:** Following the guidelines in the 'How to Submit a Resignation' [Job Aid](https://docs.google.com/document/d/1AVHHBKd6dtyn0DOl4_UydbdEhectLpH5aMh17r9Sg_4/edit) submit your resignation directly in Workday accessible through Okta.
1. **Team Member:** If you are employed via a PEO or Third-Party Employer forward a copy of your Letter of Resignation directly to them.
1. **Team Member:** After your resignation is submitted in Workday, your manager will receive a request to complete your offboarding in Workday. Once your termination is complete, you can anticipate receiving your offboarding packet with information regarding your final pay, continued benefit offerings, and additional offboarding information such as returning your devices. You can also expect a request to complete an exit survey along with an invitation to take part in an optional exit interview within 48 hours.
1. **Team Member:** You should review the [Offboarding FAQ](/handbook/people-group/offboarding/faq) handbook page to address any questions you may have. If you have a question that is not on that page, please reach out to the People Connect Team using [HelpLab](https://helplab.gitlab.systems/esc?id=emp_taxonomy_topic&topic_id=897eb385478c069067429ee0026d432c). **Note: You will not see your offboarding issue prior to your departure as this is an issue used to deprovision access and is created once you are done working.**

#### ***Country Specific Requirements for Resignation***

##### France

In addition to submitting their resignation directly in Workday (following the guidelines in the 'How to Submit a Resignation' [e-Learning](https://drive.google.com/file/d/1CWEfVPFLRLtcFQh81mYAuXtYKvf3hKW0/view?usp=sharing) or [Job Aid](https://docs.google.com/document/d/1AVHHBKd6dtyn0DOl4_UydbdEhectLpH5aMh17r9Sg_4/edit)) and complying with any contractual requirements, Team Members resigning in France should also email a copy of their resignation letter to legal-employment@gitlab.com.

##### Singapore

Team Members located in Singapore who are resigning and are **not** Singapore citizens need to complete a Letter of Undertaking [document](https://docs.google.com/document/d/1l4Iq6atvXzq6Gt_DdiWfv3DwvshTOoEYZv8baMq_HKo/edit?usp=sharing) and send it to payroll via [HelpLab](https://helplab.gitlab.systems/esc?id=emp_taxonomy_topic&topic_id=0d510c99478c069067429ee0026d4356) in order to process this with the local provider/partner. Please download or make a copy of the document in order to complete.

### Termination

1. **Manager:** If your team member completes a resignation in Workday, you will receive a prompt in your Workday inbox to terminate the team member by following the steps documented in the following [job aid](https://docs.google.com/document/d/1Fr1G1i1kssfADgDf3D6LbZHR8RZmWKZYDNV8AfduZ1c/edit) If a resignation was not submitted, you should initiate the termination by going to the departing team member's Workday Profile and selecting `Actions` followed by `Job Change` and finally `Terminate Employee`).
   - **Note**: Submitting the termination in Workday does not immediately terminate access. The offboarding issue, which is opened on the team members last day worked, initiates the deprovisioning process for terminated team members.
1. **Manager:** You will be prompted to indicate whether the termination is regrettable or non-regrettable:
    - Regrettable: The team members departure has a significant negative impact on the company, its customers, its projects or the team - the team member was a good and consistent performer both in terms of results and behaviours specifically upholding the GitLab values.
    - Non-Regrettable i.e. The team members departure has a minimal impact on the company, its customers, its projects or the team - the team member has not been meeting expectations due to conduct, culture or values misalignment or performance concerns.
1. **Manager:** Once the details about the team members departure have been finalized schedule time with the team member to plan the [departure announcement](#communicating-departures). Please reach out to your PBP if you need additional guidance.
1. **People Business Partner:** You will receive a prompt in your Workday inbox to review the termination details submitted by the Manager and to close the position in Workday. If you are aligned with the details including the final date of employment click `Approve`.  In the instance that you feel further discussion is required a sync with the Manager and/or Team Member should be arranged and the termination can be sent back for further review.
1. **People Connect:** Once the transaction has been fully approved the team will receive a notification of the termination within the Workday Inbox.

### Offboarding

1. **People Connect:** On the Last Day of Work as indicated in the Workday Termination Report at the [pre-determined time]({{< ref "offboarding_standards#notice-of-offboarding" >}}) the offboarding issue will be [created](/handbook/people-group/engineering/offboarding#scheduled-offboarding-issue-creation) - this will signal to all system owners that team member access can be revoked.  In the instance that the automation does not trigger the offboarding can be [initiated manually](https://internal.gitlab.com/handbook/people-group/people-operations/engineering/employment-automation/pops-commands/offboarding/) once this has happened all other back-end offboarding processes facilitated by People Connect can get underway.
1. **Deprovisioners (Systems):** You will be tagged in the departing team members offboarding issue and required to indicate that the team members access has been revoked kindly note that access to SOX Systems must be attended to with urgency and all other tasks within the offboarding issue must be closed out within five days.

## Involuntary Terminations

**Note:** Involuntary terminations are **only** facilitated by Team Member Relations (TMR) who will initiate the process in Workday.
Involuntary offboarding of any team member is never easy. We've created guidelines and information to make this process as humane as we can. Beyond the points outlined below, make sure to refer to our guidelines on [underperformance]({{< ref "underperformance" >}}), as well as the [offboarding issue](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/blob/main/.gitlab/issue_templates/offboarding.md).

### Involuntary Process

The manager and the team member should have walked through the guidelines on [underperformance]({{< ref "underperformance" >}}) before reaching this point.

1. **Manager**: Reach out to the their TMR specialist for assistance.
    - TMR will ask about what the performance issues have been, how they have been attempted to be addressed, and review all manager/team member documentation.
    - Once the review has been completed and the decision has been made to offboard the team member, the manager should review the best timing for the involuntary offboarding call and termination date. We recommend to avoid scheduling a involuntary offboarding call while a team member is scheduled for any sensitive customer meetings or is on-call, per guidance below under Last working day.
    - TMR will enter and approve the offboarding in Workday. Once entered, the releavant offboarding stakeholders will receive an alert via Workday reports or a Workday notification.
    - TMR will work with IT in a seperate Slack channel.
1. **TMR**: TMR will create a private Slack channel that will include the PBP, Manager, and Leader of the organization to review the offboarding and agreed upon offboarding date.
1. **TMR**: If applicable, TMR will prepare the severance agreement in preparation for the call between the TMR specialist, Manager, and team member. Additional guidelines for the preparation of this agreement can be found below in the [Separation and Release of Claims Agreements](#separation-agreement) section. To determine whether or not a severance agreement is applicable, please refer to the `Severance Elgibility` guidelines accessible by PBPs, and Team Member Relations Specialist.
1. **Manager**: Once the date and time is confirmed, the manager will schedule time with the team member and send the TMR specialist a *private and separate calendar invite* with the Zoom details for the meeting with the team member to share the news of the offboarding.
1. **Payroll**: If the team member is employed by a PEO/entity with statutory leave requirements, review if any time off needs to be paid on the last paycheck by looking in Workday in the `Time Off` section.
1. **Payroll**: If the team member has a contract with a co-employer, the payroll lead will forward an email to the contact at the co-employer with the information surrounding the departing team members statutory leave etc.
1. **TMR/Manager**: Discuss best mode of communicating the bad news to the team member. This discussion can happen via a private chat-channel, but it is best to be done via video.
1. **TMR/Manager**: Decide who will handle which part of the conversation, and if desired, practice it.
    - If needed the TMR will provide the manager with a script for the offboarding meeting.
1. **TMR/Manager**: If the team member who is being terminated is a people manager, a *communication plan for the team* regarding the departure should be in place before the offboarding proceeds. The communication plan should include: identification of an interim leader, (ideally) a scheduled meeting with the interim leader for the direct reports, a scheduled team call to announce the current manager's departure and the interim leadership, and finally an announcement in the `#team-member-updates` Slack channel to share with the wider team.
   - Important:
      - Informing the team and answering questions should be the top priority.
      - No announcement should be made in the `#team-member-updates` Slack channel until the team call has been completed.
      - In most cases, a team call can occur the same day of the offboarding. If necessary, the offboarding can be announced in the `#team-member-updates` Slack channel the following day.
1. **TMR/Manager**: Decide what offboarding actions need to be taken *before* the call (e.g. revoke admin permissions), or *during* the call (e.g. revoke Slack and Gmail access), and which ones can wait until later. You can reference the [offboarding issue template](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/blob/main/.gitlab/issue_templates/offboarding.md) for the full list of actions. This conversation should take place in the private Slack channel with PBP, Manager and Leader.
1. **TMR**: If the team member is a risk to the production environment, the TMR should privately reach out to the `Infrastructure Managers` to determine who will be available to assist with the offboarding. Once an infrastructure team member has been identified, they should be added to the private calendar invite sent to People Connect, Security, and Payroll to hold the time for the team member offboarding. Once the offboarding conversation starts the TMR will privately Slack the infrastructure contact the name of the team member to start the offboarding process.

### Facilitating the Call

1. **Manager**: Deliver the bad news up-front, do not beat around the bush and prolong the inevitable pain for everyone involved. The Manager will make it clear that the decision is final, but will also explain what led to this decision and will point to the process that was followed to reach this decision. A sample leading sentence can be *"Thanks for joining the call, [team member name]. Unfortunately, the reason I wanted to speak with you is because we have decided that we have to let you go and end your employment / contract with GitLab because of xyz."*
1. **Manager**: Hand the call over to the TMR to continue.
1. **TMR**: The TMR will also make it clear that the decision is final, but also will genuinely listen to the team member's side of the story since there may be useful lessons in what they say for the rest of the team e.g. regarding hiring and vetting practices.
1. **TMR**: Make sure to communicate the [practical points](#offboarding-points) from the offboarding memo outlined below.
1. **TMR**: Once the conversation is complete, the TMR will stage the involuntary offboardingemail document along with the severance document in DocuSign for review and signatures.

#### Critical Points During Offboarding Call {#offboarding-points}

##### All Team Members

1. **Final Pay:** "Your final check (or invoice period) is for the pay period of X and includes X days of pay".
1. **Company Property:** "Please return all property as explained in the handbook, also please delete GitLab's email connection from your phone".
1. **Business Expenses:** "Please create your final expense report to Navan Expense (for employees), OR, please file any outstanding expenses with your final invoice (for contractors), so these can be reimbursed to you in a timely manner".
1. **Confidentiality and Non-Disclosure:** "We know you are a professional, please keep in mind the agreement you signed when you were hired".
1. **Personal Particulars:** If you would like GitLab to share your personal email with the rest of the company, please send an email to People Ops or a farewell message that can be forwarded on your behalf.

##### US Team Members

1. **COBRA:** "Your benefits will cease on last day of the month you are eligible for Consolidated Omnibus Budget Reconciliation Act ("COBRA"), the carrier (Lumity) has been notified and the carrier will send out the paperwork to your home address on file".
1. **PPACA:** "You may also be eligible under the Patient Protection and Affordable Care Act ("PPACA") for subsidized health care options via the marketplace.
If you are interested it is important that you sign up with the market place well before the 15th of the month to have coverage for the following month".
1. **HIPAA:** " Under the Health Insurance Portability and Accountability Act of 1996 (HIPAA), if you need a certificate of credible coverage please download it from your current carrier's online portal or request it from People Ops".
1. **Unemployment Insurance:** "It is up to your state's labor agency (in CA: EDD) to decide if you are eligible for unemployment insurance".
1. **Keep GitLab Informed:** "If you move I want to be sure your W-2 gets to you at the end of the year.
You may also contact X at GitLab (provide phone number and email address) with any other questions that you may have" (consider inviting them to contact you at anytime for any reason).

### Initiating an Involuntary Termination in Workday

1. **TMR:** Terminate the team member in the system by following the steps documented in the following [job aid](https://docs.google.com/document/d/1Fr1G1i1kssfADgDf3D6LbZHR8RZmWKZYDNV8AfduZ1c/edit) alternatively you can do so from within the team members Workday Profile by selecting `Actions` followed by `Job Change` and finally `Terminate Employee`.
1. **TMR:** You will be prompted to indicate whether the termination is regrettable or non-regrettable and whether the team member would be eligible for re-hire in future or not i.e. with review unless specifically relating to [conduct](https://ir.gitlab.com/static-files/7d8c7eb3-cb17-4d68-a607-1b7a1fa1c95d) or [job abandonment]({{< ref "people-policies#job-abandonment" >}}) in which case they would not be eligible.
1. **People Business Partner:** You will receive a prompt in your Workday Inbox to review the termination particlars submitted by the Manager if you are satisfied with the details enclosed and aligned with the Manager on the final date of employment click `Approve`.  In the instance that you feel further discussion is required a sync with the Manager and TMR in question should be arranged and the particulars can be sent back for further review.
1. **People Connect:** Once the transaction has been fully approved the team will receive a TODO of the termination within your Workday Inbox.

### Last Working Day

After the involuntary offboarding call has taken place and the last working day has been determined, team members will have no access to GitLab systems and may not be required to do any work on GitLab's behalf.

If they are on "Garden Leave" they will still be active on payroll through the termination date. When determining the timing of the involuntary offboarding call and termination date it is important to consider any effect this might have on ongoing tasks and responsibilities of the team member.

As a manager, in collaboration with the Team Member Relations Specialist (TMR) and/or the People Business Partner (PBP), we recommend to avoid scheduling the involuntary offboarding call while a team member is scheduled for any sensitive customer meetings or is [on-call](/handbook/engineering/on-call/). If this is unavoidable, the manager is responsible for ensuring a transition/remediation plan.

[People Engineering automations](https://gitlab.com/gitlab-com/people-group/peopleops-eng/employment-automation) will generate the offboarding issue at the end of the team member's last working day, as per notification from the Team Member Relations Specialist (TMR) and the People Business Partner (PBP). Once the `Last Working Day` or Garden leave expires the team member will be officially offboarded from GitLab.  Prior to the offboarding issue and the overall process for the term listed below.

#### Last Working Day for US Team Members

1. **TMR**: TMR will have a legal/CPO review of the planned offboarding.
1. **TMR**: TMR will inform payroll, compensation and benefits, security and the stock administration of the date the team member will have access suspended and the official offboarding date prior to the opening of the offboarding issue.
1. **TMR**: TMR will work with People Connect to ensure the offboarding issue has the correct dates and that all stakeholders in Payroll, Compensation and Benefits (Total Rewards), Security and Stock Administration have been communicated to and understand the offboarding details.

### Sample Offboarding Memo

If appropriate (to be determined by conversation with the manager, the Group Executive, and People Ops), use the following [offboarding memo](https://docs.google.com/document/d/11Uk8p4VJrLnDD5IAtbTwswPUUEnmeEOazS1kJMhOu70/edit?usp=sharing), which is provided here as an openly viewable Google Doc, but of course needs to be personalized and tailored to each individual's situation.
As written, it is applicable to US-based employees only.

### Separation and Release of Claims Agreements {#separation-agreement}

Separation and Release of Claims Agreements ***do not*** apply for all offboardings. To review in which cases they do/do not apply, please reference the `Severance Eligibility` document accessible by People Connect Team and PBPs. In the case that a severance agreement is applicable, the steps below should be followed:

### Severance Process for US-based Team Members

1. **TMR**: The TMR Partner/Specialist assigned to the particular offboarding case at hand should select the appropriate severance template. Options include: Non-California over 40, California over 40, Non-California under 40, California under 40.
1. **TMR**: The TMR Partner/Specialist should make a copy of the template and save it in the `Copies of Individual Severance Agreements` folder.
1. **TMR**: The TMR Partner/Specialist should fill out the document.
1. **TMR**: The TMR Partner/Specialist will ping the stock team in the stock option section of the document.
1. **TMR**: The TMR Partner/Specialist will share with the PBP and Legal for final review/approval.
1. **TMR**: The TMR Partner/Specialist will stage the document in DocuSign for signatures. Please note that depending on the template used, team members have a limited amount of time to sign the Separation and Release of Claims Agreement.
    - When staging the document for signatures, please note:
        - Remember to send the document to the team member's *personal* email address
        - Select the `assign signature order` option in DocuSign to ensure the team member signs the document first
        - All US (Inc.) severance agreements should be signed by Pattie Egan, VP of People Operations. If Pattie is unavailable then Wendy Nice Barnes, CPO will be responsible for signing.
        - US (Federal LLC.) severance agreements need to be signed by an appropriate team member within the Federal Entity.
1. **TMR**: When the signed document is received, the TMR should upload it to the team member's Workday Profile in the documents tab.
1. **TMR**: As a final step, the TMR specialist will email the appropriate `uspayroll@gitlab` or `nonuspayroll@gitlab` and total rewards that the final severance agreement has been uploaded to the team members Workday Profile in the documents tab.

*Important Notes:*

- Separation pay is not paid until the ex-team member signs the document and the revocation period has passed.
- We treat team members equally and therefore do not take tenure into consideration when determining separation pay unless legally required. We know that other companies sometimes gives higher separation pay to longer tenure. We think that a short tenure can be harder to explain to a next employer and with a shorter tenure you might have less stock option upside, maybe you have not even reached your vesting cliff.
- Make sure you understand the rules for over 40.
- You must use language in your exit meeting that is in no way forceful of the ex-team member to sign the agreement. Use phrasing such as "if you choose to sign"; "you have a right to have legal council review this document before you sign", etc.

### Team Member Leave during an Investigation

For team members who will be placed on leave during an investigation please follow the process below:

1. **TMR**: Communicates with Legal, Aligned PBP regarding the decision to place a team member on leave and disable accounts during an investigation.
1. **TMR**: TMR will request IT and People Connect support for disabling a team members accounts.
1. **TMR**: TMR schedules a call with the teammember and manager to inform them of the decision to place the team member on leave while an investigation occurs.
1. **TMR**: TMR informs the manager and PBP when the conversation is completed and accounts are disabled. During this period managers will not have access to the team members accounts.
1. **TMR**: TMR notifies IT that an Out Of Office message needs to be set on the account and include the message that the team member is OOO and please reach out to their manager.
1. **TMR**: TMR send the team member to their personal email the "Team member Suspension letter" via DocuSign. The TMR will upload this document to the team members Workday Profile in documents tab.
1. **TMR**: TMR once the investigation is completed the TMR will inform the aligned PBP and manager of the final decision. If the team member is to be returned to work the TMR will reach out and schedule time to meet with the team member.
1. **TMR**: If the team member is returning to work the TMR will notify IT and People Connect that the team member will be returning from leave and the date that accounts should be enabled.

### Offboarding Compliance

The People Connect member in the relevant rotation will complete a weekly audit of all offboarding issues opened within that specific week and check that all People Connect tasks have been completed and that the label `peopleops::done` has been added.

All offboarding tasks by all Departments need to be completed within 5 days of the offboarding date. For systems that are more critical and time sensitive, these will be completed within the first 24 hours (example 1Password, Slack) by the relevant Departments. Information about application & system deprovisioners can be found on the [Tech Stack Applications handbook page](/handbook/business-technology/tech-stack-applications/).

To ensure a successful completion of the offboarding issue, it is important that all tasks are checked off, whether the system/tool is applicable to the offboarding team member or not. Checking the box indicates one of the following:

- I have revoked team member access to this particular system/tool
- I have checked and this team member was not given access to this particular the system/tool.

## GitLab Alumni Program

All voluntary exits are eligible to be added to the Slack channel `#gitlab-alumni`, unless otherwise noted. Involuntary exits are not eligible for the alumni channel, unless otherwise noted by Team Member Relations.
The offboarding details provided by the terminatino transaction in Workday is how eligibility is determined and later shared with IT.

The purpose of this channel is to network and socialize with team members.

Joining the channel is voluntary and subject to GitLab's [Code of Conduct](https://about.gitlab.com/community/contribute/code-of-conduct/).

GitLab, the company, monitors the channel and can remove people from it at their sole discretion.
The GitLab [Code of Business Conduct and Ethics](https://ir.gitlab.com/static-files/7d8c7eb3-cb17-4d68-a607-1b7a1fa1c95d) is enforced in the channel.

## Communicating Departures

Our goals in communicating offboardings are transparency, and to provide an opportunity for team members to say goodbye. We understand that different individuals are comfortable with different levels of communication and that each offboarding situation has different situations and nuances. For this reason and out of respect for individuals, we have a couple of key guiding principles for communicating offboarding:

1. We ask that all offboardings are announced in the `#team-member-updates` Slack channel for transparency and awareness. While we encourage all offboardings to be posted in #team-member-updates, we recognize there may be select situations that we should consider a different approach for. If a team member or their manager does not want to post in #team-member-updates, please discuss with your [People Business Partner](/handbook/people-group#people-business-partner-alignment-to-division) or [Team Member Relations](/handbook/people-group/team-member-relations).
1. Team members and managers have the discretion to determine who shares the news of the team member's offboarding (I.E. team member or manager). Regardless of who shares, it is required that team members review offboarding messaging with their managers prior to sharing.

Depending on the team members' role, timing of communication may vary (e.g. direct team, key stakeholders, etc.), and managers have discretion to determine who should be informed most immediately. The typical order followed for communicating departures is:

### 1. Inform Direct Team

The "direct team" is typically the team member's peers within their immediate team (I.E. reporting to the same manager and/or in the same functional group, etc.) and is typically a relatively small group of people.

In most cases, team members communicate their departures to their direct team, though messaging should be cross-checked with their manager for consistency.

### 2. Inform Key Stakeholders

Key stakeholder communication can be done through 1:1 notifications, and/or by posting the update in team-specific channels for general awareness. Key stakeholders are individuals that departing team members work very closely with (typically in their day-to-day work) that will feel the impact of the team member's departure in their work. Managers of key stakeholders should also be looped into communication to ensure awareness.

It is essential that key stakeholders are looped in to offboardings to:

1. Communicate go forward plans
1. Ensure business continuity and transparency

Departures should be communicated with stakeholders as soon as possible, with a maximum timeframe of 2 business days after the team member's departure.

Where possible and appropriate, we also encourage managers to work with departing team members to align on transitions plans to transition as much of the departing team members' work as possible before their departure.

In most cases, managers communicate team member departures to key stakeholders.

### 3. Announce In #team-member-updates

As explained briefly in the [offboarding issue](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/blob/main/.gitlab/issue_templates/offboarding.md), GitLab is not always able to provide full context on why people are leaving when they do.

However as mentioned in the procedures, for [voluntary offboarding](/handbook/people-group/offboarding#voluntary-offboarding), the team member can work with their manager on messaging to share a company-wide message about their departure.

Once the news has been shared with the team member's team and other stakeholders, and messaging is agreed upon between the departing team members and their manager, the departure message should be shared in the `#team-member-updates` Slack channel.
Managers and team members can optionally leverage this template as a guide on how to communicate a team member's upcoming departure:

```text
I want to share that [team member's name] ([group] [role]) will be leaving GitLab, and [his/her/their] last day is (date of their last day). (Context to add about the team member's time at GitLab - examples: their favorite contribution to the handbook or they can use the update to express gratitude towards teams and individuals that have made their experience at GitLab positive.) I would like to take this opportunity to thank (team member's name) for their contributions and wish them all the best for the future. If you have questions about tasks or projects that need to be picked up, please let me know. If you have concerns, please bring them up with your manager. To keep in touch with (team member's name) he/she/they can be reached at (contact info - e.g. LinkedIn, email, etc.)
```

There will be situations in which team members prefer to share their offboarding message, and situations in which managers prefer to do so. Either is ok, **so long as team member and manager have reviewed the messaging together prior to posting**.

If someone is let go involuntarily, this generally cannot be shared since it affects the individual's privacy and job performance is intentionally kept [between an individual and their manager]({{< ref "confidentiality-levels#not-public" >}}).

If you are not close to an employee's offboarding, it may seem unnecessarily swift.
Please remember that these decisions are never made without following the above process to come to a positive resolution first - we need to protect the interests of the individual as well as the company, and offboarding is a last resort.
According to our values [negative feedback is 1-1 between you and your manager](/handbook/values/#negative-feedback-is-1-1) and we are limited in what we can share about private employee issues.
Please discuss any concerns you have about another employee's offboarding with your manager or your People Business Partner.

Given the expectations and responsibility that come with a VP and above position, when there is an involuntary offboarding for one of these positions, additional context for the personnel change can be provided to the organization.

### 4. Inform The Department

Managers should consider cross-posting the message in #team-member-updates to inform the wider Department of the departing team member.

## What Do We Share?

We strive to maintain personal information regarding all team members private, this includes information regarding a team members voluntary or involuntary departure from GitLab.
However, a manager with the consent and approval of the departing team member can share more details with the GitLab team regarding the decision to leave GitLab. If the departing team member gives their manager permission to share that information then the manager will share while making the departure announcement on the team call.

Regarding involuntary offboarding, certain information can also be shared with the GitLab team regarding the departure.

The departing team member may work with their manager to author a goodbye message for voluntary offboarding:

1. Work with your manager on the message that your manager will share in `#team-member-updates` on Slack.
1. Send it to your manager for approval. If, as a manager, you are in doubt about the message - please reach out to your manager or [aligned People Business Partner](/handbook/people-group/#people-business-partner-alignment-to-division) for additional review.
1. Managers are encouraged to use the suggested template (above link) and have the space to add more color wherever they see fit.

In some instances there will be no further clarification on why a team member has departed, if there are concerns you can address those with your manager.
Different levels of transparency will exist based on maintaining respectful treatment for all departures. Having team members leave may be a learning opportunity for some, but should not be a point of gossip for anyone. Managers will need to balance the opportunity for learning with the expectation of privacy and consult their People Business Partner should they have questions.

Transparency is one of our values. In the case of offboarding, we opt to share the feedback only with peers and direct reports as needed, since we balance transparency with our value of collaboration and [constructive guidance]({{< ref "guidance-on-feedback" >}}) shared 1-1.

## Turnover Data

GitLab's [turnover data](https://10az.online.tableau.com/#/site/gitlab/workbooks/2024177?:origin=card_share_link) is only viewable internally.

## Managing the Offboarding Tasks

### Offboarding Issue

To track all tool deprovisioning, please open an offboarding issue following the [offboarding standards]({{< ref "offboarding_standards" >}}).

### Returning Property to GitLab

As part of offboarding, any GitLab property valued above 1,000 USD needs to be returned to GitLab.

For laptops, please check and refer to the [Laptop Buyback Policy](/handbook/security/corporate/services/laptops/buyback/) which states that team members *may*, at GitLab's discretion, have the option to keep or buy back their existing laptops either when it gets refreshed for a new one, or when the team member is offboarding.  However, the option to purchase or keep a laptop at no cost may be voided where the team member is involved in cases of investigation, misconduct, termination for cause of any violation of [GitLab's Code of Business Conduct & Ethics](https://ir.gitlab.com/static-files/7d8c7eb3-cb17-4d68-a607-1b7a1fa1c95d), or other legal or security related inquiries.

To return your laptop to GitLab, please contact `itops@gitlab.com` immediately upon offboarding.

### Navan Expense

This section of the Accounting Department.

To remove someone from Navan Expense Log in to [Navan Expense](https://www.expensify.com/signin) and go to "Settings" in the left sidebar.
Select the right policy based upon the entity that employs the team member. Select "People" in the left menu.
Select the individual's name and click "Remove".
If the person has a Corporate Credit Card assigned to them, please notify Accounts Payable before un-assigning it.

### Retrospective for Managers

For involuntary offboardings it is optional to do a retrospective on the hiring, onboarding and coaching/communication of the departing team member. As a manager, you can use [this template](https://docs.google.com/document/d/1AWth5o_sagDTwQ92FJr7WDHPNezEg6-BgRY6Tafejgo/edit?usp=sharing) for a retrospective. Please share the filled out template with your manager as well as the [People Business Partner](/handbook/people-group#people-business-partner-alignment-to-division) for your group.

Within the Engineering division this is a **required process** because it causes hiring managers to reflect on what led to the ultimate decision of parting ways with the team member, and how that might be prevented during future hiring processes.

#### Evaluation Framework

1. How could this outcome have been avoided?
1. Were there early signs that were missed?
1. In retrospect, what questions should have been asked to bring awareness and ownership to performance issues e.g. *"How would you compare yourself relative to your peers"*? - people are surprisingly honest here.

## Unemployment Claims

### Unemployment Claims in the US

In the United States, Unemployment Insurance provides benefits to GitLab team members who have lost their jobs through no fault of their own. The purpose is to provide temporary financial assistance to employees who meet certain requirements.

Unemployment insurance is administered at a state level and in compliance with Federal Law. Each state establishes its own eligibility criteria and regulations surrounding Unemployment Insurance with respect to the amount allocated, duration and eligibility for Unemployment Insurance.

Eligibility criteria include meeting the state specified requirements in terms of both earnings and time worked during the base period. In some instances the state may require additional supporting information particularly more extensive wage related details surrounding a claim.

Unemployment Insurance is funded through employer contributions and most states will have State Unemployment Taxes that apply however many employers typically pay the State Unemployment Taxes too.

### Reporting a False Unemployment Claim

If you are a full-time team member and you are contacted by your state's Unemployment Commission to discuss your request for Unemployment Benefits, you may be a victim of Unemployment Claim Fraud.

Before giving out any information to the caller, please confirm that you are speaking with an agency employee. If you confirm with your state's Unemployment Commission that there is a fraudulent claim, please report it via [HelpLab](https://helplab.gitlab.systems/esc?id=emp_taxonomy_topic&topic_id=57e1ad3997804e50a326158de053af3d) to the People Connect team.

Additionally here is a link to the [U.S Department of Labor Contact Particulars](https://www.dol.gov/agencies/eta/unemployment-insurance-payment-accuracy/UIFraudReporting) to report Unemployment Insurance Fraud.
