---
title: Organizational Change Management
---

## Introduction

GitLab is growing fast and we have been ranked as one of the [fastest-growing private software companies](https://about.gitlab.com/blog/2018/08/16/gitlab-ranked-44-on-inc-5000-list/). Headcount has nearly doubled in the last year and we have plans to [continue to grow](/handbook/company/strategy/). As we scale, there will be more and more changes to how we operate as an organization. New technology will be introduced to make us more efficient, new processes will be introduced to improve transparency, functional groups will be redesigned and adjusted to meet our growing headcount and strategic objectives, job families will change, and policies in the handbook will be altered that have a big impact on how we operate.

As we evolve, there is a need to implement organizational change management (OCM) processes and methodologies to ensure impacted team members are enabled with the knowledge, leadership, coaching, and training they need to adapt successfully. This handbook page will walk through a step-by-step approach to OCM within GitLab. People leaders and individual contributors can use this page when structuring an organizational change management process and campaign.

## What is Organizational Change Management (OCM)

[Change Management has traditionally referred](/handbook/engineering/infrastructure/change-management/#context-and-objectives) to the processes, procedures, tools, and techniques applied in IT environments to carefully manage changes in an operational environment. In our context, OCM refers to the actions in which a company or business alters a major component of its organization, such as its culture, technology, people, process, or policies it uses to operate. OCM is the method of leveraging change to bring about a successful resolution, and it typically includes a systematic methodology to support a transformational journey.

## When to use OCM at GitLab

At GitLab, there are many use cases for applying an OCM process. Consider it a methodology to apply when rolling out major initiatives that impact our people and ways of working. The methodology does not have to apply to every new initiative but it should be considered.

Examples of when to use OCM include:

- Adoption of a new technology that all team members will use (i.e. Integrating the Learning Management System, etc.)
- Implementing a new succession planning process (i.e. Performance/Potential Matrix)
- Rolling out a 360 review process for all team members to use
- Updating our total rewards policies (i.e. updating our [compensation calculator](/handbook/total-rewards/compensation/compensation-calculator/calculator/), iterating on benefits plans, etc.)
- Changing a hot button policy (i.e. discretionary bonus criteria requiring additional requirements, changes to compensation plans)
- Implementing a new system or tool for all team members that some may see as contentious (i.e. Endpoint Management software,etc.)
- Enabling team members to effectively use new tools to improve their job at the time of release (i.e. Culture AMP, Learning Management System, etc.)
- Significant team restructures
- Other examples

There are varying levels of the OCM process that can be implemented to facilitate the change. The above is a small example of the type of organization-wide initiatives that we can consider applying the OCM methodology. Keep in mind that some transformations require less OCM, while major changes require a heavy focus on OCM. Consider if they change will impact the whole organization. If it will, the DRI can review the OCM methodology to ensure the change lands successfully.

Not every change project at GitLab requires the full OCM methodology to be applied. Consider applying OCM when there are major people, processes, technology, and policy changes that impact our team member's ways of working.

**Examples of when not to apply the OCM methodology:**

- Announcing a new GitLab feature
- Communicating executive-level updates that come directly from leadership
- Implementing an iterative change that has a track record of iteration and team member input
- Updating and communicating changes to the Handbook
- Providing awareness and generating excitement for a company-wide initiative (i.e. Family and Friends Day, etc.)
- Announcing and implementing a company-wide initiative (i.e. Direct messages in Slack, internal comms campaign, etc.)
- Training team members on new skills, business/technical acumen, etc
- Much more!

## Why is OCM important

Organizational change is necessary for GitLab to succeed and grow. OCM drives the successful adoption and usage of change within the business. It allows team members to understand and commit to the shift and work effectively during it. Without effective OCM, GitLab transitions can be rocky and expensive in terms of both time and resources. Ultimately, a lack of OCM can lead to important initiatives to not take off or fail after the introduction.

## GitLab OCM methodology

We are going to define an OCM process that aligns with our values, organizational structure, and ways of working. Consider applying aspects of the methodology to change initiatives. The methodology does not have to be applied formally but components of it can be considered and reviewed before rolling out change initiatives.

Key components of GitLab's OCM methodology:

1. Develop an agile change plan
1. Assess the impact
1. Analyze team member engagement
1. Communicate the change
1. Train for the change
1. Measure and adopt the change

### Step 1 - Develop an agile change plan

When rolling out an organization-wide change that will impact all team members, the first step is to develop an agile change plan. An agile change plan can be informal and the DRI for the change can do it asynchronously with others leading the change. You can draft the plan in a Google doc and use it as a starting point when planning for change. For OCM to work, it's essential to have all the components documented as a source of record and plan for the change.

When developing the agile change plan, there are a few important components to consider:

1. **Leadership Engagement:** Visible leadership is the key to success on any large scale transformations at GitLab. Team members will be looking to leaders for cues on how to interpret the change and what actions to take. Depending on the scale of the change, its success will depend on leaders effectively sponsoring and ensuring readiness within their functional groups.
    - Leadership will drive team member engagement and adoption of the change
1. **Leadership awareness and engagement plan:** As you start to develop an understanding of how to drive team member engagement with leaders, consider plotting out awareness activities you will do with leaders to get them bought in on the change. Communicate what you will do and why you need their support to drive adoption.
1. **Include all other components** of the GitLab OCM methodology to your change plan:
   - Impact assessment
   - Team member engagement analysis
   - Communication plan
   - Training plan
   - Measurement and adoption

### Step 2 - Assess the impact

Before rolling out the change, consider measuring the impact. Depending on the severity, it is important to understand the current state before communicating the future state. Document the impacts in your agile change plan. It's important to consider all of the potential impacts to mitigate disruptions to team member's day-to-day work. Some key questions to answer when assessing the impact of the change:

- What's the history behind this transformation?
- Has GitLab tried to do this before?
- Were previous changes successful? If not, why weren't they?
- Have similar changes been well received?
- What is the current process outlined in the Handbook?
- How will the new change impact team members' ways of working?
- Other impacts to consider

### Step 3 - Analyze team member engagement

With any major change, it is essential to identify which groups within the organization that will be impacted. In this step, we can determine who will be impacted and identify mitigation strategies to ensure minimal disruption to their day-to-day work.

After you have completed the impact assessment, you can determine which groups of people in the organization will be impacted the most by the change. For example, 360 reviews will require significant manager time and dedication. Managers are the most impacted by the reviews, especially if they have a high number of direct reports. When rolling out the 360 reviews, managers should be the target audience to cascade information down to their teams.

When rolling out a new initiative, consider who in the organization will be the most impacted.

This is also a good time to identify champions within the impacted groups that can help serve as positive change agents throughout the remainder of the OCM process. Champions can help "message test" the change before you send it out to the wider audience, and they can serve as advocates and subject matter experts for the change in their day-to-day work once the change is announced. Champions can include members of leadership, but they should also include team members from all varieties of organizational levels to ensure that you have access to feedback and perceived impact at all levels, allowing you to more effectively craft your communications.

### Step 4 - Communicating the change

Once you've understood the impacts and who will be most impacted, start developing a communication plan. Analyzing team member engagement and impacts can help guide and engage team members through the change program. Communications should be updated per feedback from all team members to ensure that everyone has an opportunity to contribute before a change is finalized. The timing of communications can also be different based on the impact analysis and who are the most impacted audience groups. And, depending on the impact of the change, you might want to consider giving managers talking points/guidance that they can use to discuss the changes 1:1 with their team to answer questions and/or address concerns.

Focus on delivering the right amount of detail to the right audience, through the right communications channel, and at the right time. We typically rely on Slack channels to send organization-wide communications. Leverage the channels that will provide the most impact to ensure leaders and team members can articulate with clarity and purpose of the change project.

The goal of this step is to build the credibility of the project and clearly articulate what it will deliver as well as the ideal end-state. It can also help generate a positive perception of the transformation.

**Key Activities:**

- Communication plan: identify what, when, and to whom
- Key messages outlined in an Issue or Google Doc
- Communication materials: Slack messages that direct team members to Issues for feedback and a historical record, handbook page links, templates, videos, AMA meeting, manager talking points, etc.

### Step 5 - Train for the change

Training for the change should include both traditional and informal methods to address the needs of varied audiences. Relevant content can be developed to support team members who will be most impacted and the specific project requirements. Training materials can include slide decks, handbook pages, explainer videos, job-aides, tutorials, etc. Training can also be delivered through [live learning](https://gitlab.zoom.us/j/6941107756?pwd=ZFJHT0lDSFhRYStZd2VKWEdNQ3hqQT09 Hide) and recordings that walk team members through the transformation.

Research shows that a blend of the types of training below is the most effective to achieve successful knowledge retention and skill internalization. Per the GitLab 70-20-10 training approach, the majority of the training will focus on where 70% of learning occurs - learning all the time resources, 20% occurs when learning from others, and 10% via traditional instruction. Consider holding a traditional/formal training event for the type of transformation that is taking place.

GitLab Learner Experience - 70-20-10 Training approach:

<figure class="video_container">
<iframe src="https://docs.google.com/presentation/d/e/2PACX-1vTivHwhC_9pzPirV2tZxi6TGhGHfFTVw7Xr0NieqPIxLi7UDvbG6AUAPAQYeueeRSsftVtPWHkLsQjO/embed?start=true&loop=false&delayms=3000" frameborder="0" width="960" height="569" allowfullscreen="true" mozallowfullscreen="true" webkitallowfullscreen="true"></iframe>
</figure>

### Step 6 - Measure and adopt the change

The ultimate purpose of the OCM process is to get team members to adopt the change and implement it in their day-to-day role. To ensure this, it is important to focus on user adoption and measure it regularly so we can adjust the communications and training approach. [Apply iteration](/handbook/engineering/workflow/iteration/) to the change by consistently looking for new ways to roll out programs more [efficiently](/handbook/engineering/workflow/iteration/).  If appropriate, consider opening an issue to allow for team members to provide feedback which will inform future iterations.

To drive the adoption and usage of new changes, it is essential to provide proper metrics and measurement tools. A successful adoption helps in mitigating the organizational challenges and realizing business benefits to ensure better ROI and a successful sustained transformation.

### Step 7 - Close the feedback loop

Part of successful OCM is creating a positive experience and sentiment for team members around large organizational changes – meaning, team members feel that their feedback was heard, and they understand the positive impact of the change. This means that communication should not stop abruptly once the change is made. Instead, it is crucial for you to "close the feedback loop" by clearly communicating the metrics from the steps above as well as providing insight into how the organization has benefited (and is expected to continue benefiting) from the change that has been made.

## A Manager's role in OCM

Within GitLab, every team member has a different role in assisting with change. Leaders, for example, have to be courageous by taking on risks. They can look at the big picture and articulate high-level changes to the organization, explain why it is occurring, and motivate team members to support the transition.

Managers can be more concentrated on making business transitions successful. They focus on implementing change by determining the discrete steps that need to happen and their sequence. It is the primary responsibility of a manager to know how to design, direct, and shape change processes while advocating for its support. By learning how to preempt and address the challenges associated with change, managers can ensure they are equipped with the skills and knowledge needed to manage it.

## Preparing for OCM at GitLab

To prepare for GitLab transformations/changes, first, define the goal of the organizational change, understand why it is critical, and garner support from team members. Then, use the OCM methodology laid out on the page to begin designing and delivering the OCM process. Ensure the methodology aligns with the goals. Note what challenges may arise and be flexible enough to adjust accordingly. Be sure to celebrate small victories along the way!

OCM doesn't stop once you've successfully executed the transition. Both throughout and following the OCM process, you need to continuously assess outcomes, measure data, train employees on new methodologies and business practices, and readjust goals as necessary to increase adoption.

Please contact the [Learning & Development team](/handbook/people-group/learning-and-development/) if you would like more of an understanding of OCM and how to apply the methodology to a change/transformation at GitLab!

## Additional Resources on Organizational Change Management

- Change Management Primer ([Slides](https://docs.google.com/presentation/d/1KrFKBHS0IC15cn7q2CYGakCRfcq-A5tmRCxg8ys_v-Y/edit#slide=id.g82ed3c344a_0_0)) ([Video](https://www.youtube.com/watch?v=Gz6OpHnOGlM&feature=youtu.be)) from our Field Enablement Team
- [Prosci change management resources](https://www.prosci.com/resources)
- [Harvard Business Review Change Management Resources](https://hbr.org/topic/change-management)
- [Five Levers of Change Management](https://www.prosci.com/resources/articles/five-levers-of-organizational-change-management) (article)
- [Keys to Prepare for Change](https://blog.prosci.com/keys-to-prepare-for-change)
- [Understanding Resistance to Change](https://blog.prosci.com/understanding-resistance-to-change)
