---
title: "Gender and Sexual Orientation Identity Definitions and FAQ"
description: "Gender and sexual identity definitions, frequently asked questions, and resources"
---

The content on this page is inspired by [other sites](#additional-resources) with glossaries and FAQs. It should be noted that many LGBTQ+ terms don't have complete alignment and can have different meanings and nuance in different communities. This is a glossary of terms with some broadly accepted definitions.

The reasons for creating a Gender and Sexual Orientation Identity page in the GitLab handbook:

1. Many organizations, including the [HRC](https://www.hrc.org/), have put careful thought and effort into how these delicate concepts can be explained with clarity, fairness, and respect. At GitLab we should leverage this work.
1. Adding it as readable content rather than directing to a new website means this information is searchable within the handbook for folks who are looking for answers as well as making sections directly linkable from elsewhere in the handbook, in issues, slack, etc.
1. GitLab has employees from around the globe, where the language used may be different. This gives all employees the opportunity to establish a common language framework to help create a healthy, supportive, and inclusive environment.

### Additional resources

- [GitLab Ally Resources]({{< ref "ally-resources" >}})
- [Diversity, Inclusion and Belonging at GitLab](/handbook/company/culture/inclusion/)
- [Human Rights Campaign website](https://www.hrc.org/)
  - [HRC Sexual Orientation and Gender Identity Definitions](https://www.hrc.org/resources/sexual-orientation-and-gender-identity-terminology-and-definitions)
  - [HRC Transgender FAQ](https://www.hrc.org/resources/transgender-and-non-binary-faq)
- [The Genderbread Person](https://www.itspronouncedmetrosexual.com/2018/10/the-genderbread-person-v4/)
- [A comprehensive list of LGBTQ+ term definitions](https://www.itspronouncedmetrosexual.com/2013/01/a-comprehensive-list-of-lgbtq-term-definitions/)
- [We Are Family Lesbian, Gay and Bisexual Glossary of Terms](https://www.wearefamilycharleston.org/lgbt-glossary-az)
- [UC Davis LGBTQIA Resource Center Glossary](https://lgbtqia.ucdavis.edu/educated/glossary)
- [Things not to say to a trans person](https://www.youtube.com/watch?v=pvBwWeG4Rpc)

## Definitions

### Gender identity

A person's internal perception of their own gender and the words they use to label themselves. A person may identify as a woman, or a man, a blend of the two (keep reading for more information on this), or neither. A person's gender identity may or may not be the same as their sex assigned at birth.

In our HRIS (Human Resource Information System) [Workday](/handbook/people-group/systems-architecture#Workday), we have two self-identification fields related to Gender, which we ask our team members to complete during the onboarding process, although it is completely optional. We have one **Gender** field with only two options. This field is a default field in the HRIS and is not inclusive due to the fact that it is primarily used for mandatory Governmental reports and data classification.

At GitLab, we have the additional **Other Gender Options** field, which currently has a number of options for our team members to choose if you would like to. If you would like an additional option added, please contact our DIB team at `diversityinclusion@gitlab.com`. We are transparent in our results in our anonymous [Identity Data](/handbook/company/culture/inclusion/identity-data/).

### Gender expression

A person's external display of their gender identity through clothing, grooming, behavior, etc. Gender expression commonly falls on a spectrum between feminine, androgynous, and masculine.

### Cisgender

Cisgender or cis, refers to a person whose gender identity and/or expression generally aligns with the typical expectations of their sex assigned at birth.

### Assigned Female/Male at Birth (AFAB, AMAB)

**Sex Assignment** is the determination of an infant's [sex](#whats-the-difference-between-sex-and-gender) at birth. All babies are assigned a sex at birth which is generally directly related to their anatomy.
However, there are a variety of situations in which an individual may be assigned a certain sex but develop differing physical characteristics as they age.

Being assigned female/male at birth sets an expectation of the associated socially accepted [gender expression](#gender-expression). As mentioned above, [cisgender](#cisgender) is when a person's gender and assigned sex are the same.

The terms AFAB/AMAB are often used by people to communicate about their gender identity without reinforcing the typical views on sex.

### Transgender

Transgender or "trans", is an umbrella term for people whose gender identity and/or expression generally differs from typical expectations of their sex assigned at birth. For example, along with trans men and trans women, people who identify genderqueer, non-binary, or genderfluid can be also identified as transgender. Transgender people may or may not choose to alter their bodies hormonally and/or surgically.

There are many people who choose to socially identify as transgender, or "trans" and it is a big part of who they are. Many people are transgender and choose to keep it hidden, as they want to be known as the gender they feel most comfortable with.

Some people may be visibly transgender. It is important that you do not address them by the gender and pronouns you *think* they are based on physical appearance. If you are not sure, use gender-neutral pronouns (they/them).

### Trans man

An identity that describes a man who was assigned a female gender at birth. The term female-to-male transgender, abbreviated as FTM or F2M, is also used by some transgender people.

### Trans woman

An identity that describes a woman who was assigned a male gender at birth. The term male-to-female transgender, abbreviated as MTF or M2F, is also used by some transgender people.

### Genderqueer

Genderqueer is an umbrella term to refer to gender identities that differ from the binary identities of male and female, including gender non-conforming and non-binary identities. People who identify as genderqueer may see themselves as a combination of both male and female, neither male nor female, different genders at different times or as no specific gender at all.

There can be an overlap between genderqueer, gender non-conforming, non-binary, and genderfluid, but they are not interchangeable terms. You should not use these terms to refer to someone unless they have self-identified with the term(s).

Genderqueer, gender non-conforming, non-binary, and genderfluid people may or may not identify as lesbian, gay, bisexual, transgender, or queer.

### Gender non-conforming (GNC)

Gender non-conforming is an umbrella term for gender identities and expressions that don't conform to typical gender expectations and falls outside of or in between the feminine and masculine binary.

### Non-binary

Non-binary refers to gender identities other than the traditional female and male "binary" identities.

### Genderfluid

Genderfluid is a gender identity where someone sees themselves as male, female, or non-binary at different times or under different circumstances. Some people like to express different sides of themselves depending on who they are with or where they are.

### Transition or transitioning

Gender transition is a process of changing to align more closely with one's gender identity. It is not a one-time event but involves many steps over time to change social, medical, and/or legal aspects of one's life such as name, appearance, and pronouns. Transitioning can involve talking to friends, family, and coworkers, changing legal and medical documents, and/or medical intervention such as taking hormones or undergoing surgeries. It's important to understand that not everyone who transitions chooses to change their body and some people may choose to change some parts of their body but not others in order to feel comfortable within themselves.

### Gender dysphoria

[Gender dysphoria](https://www.psychiatry.org/patients-families/gender-dysphoria) is a clinical diagnosis in the American Psychiatric Association's Diagnostic and Statistical Manual of Mental Disorders (DSM) that refers to undue pain and distress experienced when a person's gender assigned at birth is different from their gender identity.

### Sexual orientation

The enduring pattern of emotional, romantic, and/or sexual attraction (or lack of attraction) to other people. Sexual orientation is an inherent, unchanging attribute (i.e. not a preference or a choice.) People do change how they describe and/or understand their own sexual orientation.

### Some common terms to describe Sexual orientation include

#### Homosexual

Describes a person who is attracted to the same gender. In some regions, "homosexual" is [considered offensive](https://www.nytimes.com/2014/03/23/fashion/gays-lesbians-the-term-homosexual.html) due to its history as a clinical term used to marginalize LBGT people.

#### Asexual or ace

Not sexually attracted to anyone. Asexual folks can still have happy, healthy, romantic, and loving relationships with other people and can also be gay, bisexual, pansexual, etc.

#### Aromantic or aro

Not romantically attracted to anyone. As with asexual people, aromantic people can still be happy
and have healthy relationships with other people.

#### Heterosexual/straight

Attracted to the sex/gender opposite their own on the spectrum.

#### Demisexual

Doesn't experience sexual attraction to someone unless they have a deep, emotional connection with them.

#### Gay

Attraction primarily to members of the same sex/gender. This term has historically been used for men specifically, but is often a more widely used term for both men and women.

#### Lesbian

Describes a woman whose sexual orientation is primarily geared towards other women.

#### Bisexual

Attracted to more than one gender or gender identity. Although the prefix "bi" strictly means "two", it is inaccurate to say that all bisexual people are only attracted to two genders (i.e. male and female). More commonly, people who identify as bi are attracted to multiple gender identities, including
trans/non-binary identities.

#### Pansexual

Attracted to the person rather than their sex, gender, or gender identity. Pansexual people commonly describe their pattern of attraction as being interested in "[hearts, not parts](https://pairedlife.com/gender-sexuality/Bisexuality-vs-Pansexuality-What-is-the-Difference)."

#### Queer

Often used as a term for someone who is gay, but more recently has become popular as an umbrella term for someone who identifies as anything other than straight/cisgender.

Some people also choose the labels 'queer' or 'fluid' as a way of expressing themselves by their own personal feelings.

Make sure that you use queer as an *adjective* and not as a noun. Good examples:

- "Amy is a queer developer."
- "Amy is queer."

But something like "Amy is **a** queer" is offensive.

#### QUILTBAG

QUILTBAG is a comprehensive, newer term that stands for queer and questioning, unsure, intersex, lesbian, transgender and two-spirit, bisexual, asexual and aromantic, and gay and genderqueer. It is a easier way to say LGBTQ+ as well as being a bit more inclusive. It was first coined in October 2006 by Sadie Lee in *Diva Magazine*.

## Frequently Asked Questions

### What's the difference between sex and gender?

Sex and gender are often seen as the same thing but in reality, [sex and gender are distinct](https://www.medicalnewstoday.com/articles/232363.php).

Sex can refer to a person's anatomy and physiology, which can include phenotype, internal and external genitalia, gonads, hormone levels, chromosomes, epigenetics, etc... Maybe people believe sex is binary (either male or female) but in reality, sex is a non-binary construct where [1 in 1500 people are born intersex](https://isna.org/faq/frequency/).

Gender refers to the social norms, emotions, and behaviors that are associated with being female, male, androgynous, or others. Gender traits can vary greatly depending on the time period and cultural context. It's important to remember that gender is not an inherently natural thing, but rather a social construct that varies from society to society.

### What's the difference between being transgender and being gay?

Transgender is a gender identity while gay is a sexual orientation. They are two different concepts. Someone can be transgender while being straight, gay, bisexual, or another sexual orientation. Similarly, someone can be gay and be cis, trans, genderqueer, or another gender identity.

### What's the difference between being bisexual and pansexual?

Both [gay](#gay) and [straight](#heterosexualstraight) refer to sexual orientations in which a person is primarily attracted to only one gender. Bi- and pan- are sexual orientations in which a person is attracted to multiple genders. [Bisexual](#bisexual) tends to refer to attraction to multiple sexes, genders, and/or gender identities. [Pansexual](#pansexual) tends to refer to being attracted to a person, rather than their sex, gender, and/or gender identity.

This FAQ on [bisexual vs pansexual orientations](https://pairedlife.com/gender-sexuality/Bisexuality-vs-Pansexuality-What-is-the-Difference) goes into more details.

Bi- and pan- can be very similar so it is ultimately up to the individual as to which they identify as.

### What's the difference between cross-dressing and being transgender?

Cross-dressing is a specific form of gender expression that involves wearing clothing, accessories, etc. that is traditionally not associated with one's gender. Cross-dressing does not imply anything about a person's gender identity or sexual orientation.

Transgender is an umbrella term to refer to and capture all non-traditional gender identities and expressions. As such, people who cross-dress may also identify as transgender however, the distinction between being trans and cross-dressing should be noted. Cross-dressing is a temporary activity, while transgender is a state of permanence. It is best to use the term preferred by the individual.

### Is being transgender a mental disorder?

No, being transgender is not a mental illness.

Transgender people can experience a mental illness known as [gender dysphoria]({{< ref "orientation-identity#gender-dysphoria" >}}), however not all trans people have this experience, so being trans in and of itself is not a mental illness.

This [Vox article on transgender mental health](https://www.vox.com/identities/2016/5/13/17938120/transgender-people-mental-illness-health-care) says it well,

> "The AMA, APA, and other medical experts agree that letting someone transition, which can entail medical treatments like hormone therapy and gender-affirming surgeries, without social stigma is the main treatment for gender dysphoria. In this way, being trans isn't the medical condition; living as trans is in fact the treatment to the medical condition."

### Do all people who transition have surgery?

No, not all transgender people desire medical transition such as hormone therapy and surgeries. Additionally, some trans people do desire medical transition, but cannot afford it. [They are still trans none the less](https://www.vox.com/identities/2016/5/13/17938114/transgender-people-transitioning-surgery-medical).

As [HRC says well](https://www.hrc.org/resources/transgender-and-non-binary-faq),

> "Many transgender people cannot afford medical treatment nor can they access it. In light of these injustices, it is important that civil rights and protections are extended to all transgender people equally, regardless of their medical histories. It's also critical to continue advocating for full access to health care coverage for transgender people."

### How do I know which pronouns to use?

Simple, just ask :)

Asking for someone's pronouns is the same as asking for their name. In the same way that you wouldn't assume what someone's name is and start calling them by a name that wasn't theirs, you shouldn't assume someone's pronouns.

In English, there are [many common pronouns](https://uwm.edu/lgbtrc/support-resources/gender-pronouns/) such as the singular they/them and ze/hir/hirs. To learn more see this [Time article on pronouns](https://time.com/4327915/gender-neutral-pronouns/).

For more information on pronouns, check out [Pronoun Guidance and Information]({{< ref "pronouns" >}}).

### What if I accidentally use the wrong pronouns?

Quickly apologize, correct yourself and move on. Don't make a big deal out of it. It happens.

### Can someone be fired for being transgender, gay, etc.?

At GitLab, you will not get fired for any of the following reasons, no matter where you are:

Race, color, religion, national origin, sex (including pregnancy), age, disability, HIV status, sexual orientation, gender identity, marital status, past or present military service, or any other status protected by the laws or regulations in the locations where we operate.

Please review our [anti-discrimination guidelines]({{< ref "anti-harassment#discrimination" >}}) for more information on what is not tolerated at GitLab.
