---
title: "Paid Time Off at GitLab"
---

## Introduction

This policy relates to the types of leaves that GitLab offers and the guidelines associated with each leave type. Training on our PTO policy is included as part of a team member's onboarding, and is also available [here](https://levelup.gitlab.com/access/saml/login/internal-team-members?returnTo=https://levelup.gitlab.com/learn/course/pto-training-gitlab) for reference or if a refresher is needed.

## Paid Time Off

Time away from work can be extremely helpful for maintaining a [healthy work/life balance](/handbook/company/culture/all-remote/people/#worklife-harmony). GitLab encourages managers and [leadership]({{< ref "leadership" >}}) to set the example by taking time off when needed, and ensuring their reports do the same.

Taking time off is not a selfish behavior. Not only is time away from work aligned with GitLab's operating principle [Family and friends first, work second](/handbook/values/#family-and-friends-first-work-second), but it is vital to maintaining [mental health](/handbook/company/culture/all-remote/mental-health/). It is also a core part of the creative process.

It is important to take time off to recharge batteries and refresh your mind so you can come back to GitLab with renewed energy and be prepared to do your best work ever!

This page is written with a focus on vacation. The below recommendations on communicating your time off apply to time off for all reasons where possible and avoid concerns of health, safety, or job abandonment. GitLab offers a Flexible PTO Policy, but team members are not allowed to substitute PTO for sick time. If taking time off for medical needs or sick time, whether physical or mental, please follow our [Sick Time Policy](/handbook/people-group/paid-time-off/#sick-time---taking-and-reporting).

If you are taking Parental Leave, please see our [Parental Leave Policy](/handbook/total-rewards/benefits/general-and-entity-benefits/#parental-leave).

## A GitLab Team Member's Guide to Time Off

If you are taking Parental Leave, please see our [Parental Leave Policy](/handbook/total-rewards/benefits/general-and-entity-benefits/#parental-leave).

Paid time off is in addition to any [official public holidays](#holidays) that apply to the country where you live, and [Friends and Family days]({{< ref "family-and-friends-day" >}}). When accounting for time off in Workday, please use the label `Public Holiday` or `Friends and Family`. This helps us to ensure that all of our Team Members are meeting at least the [Statutory Vacation Requirements](#statutory-vacation-requirements).

As we all work remotely it can sometimes be difficult to know when and how to plan time off. Here is some advice and guidance on how this can be done in an easy and collaborative way. **Please note that for audit and compliance purposes, all team members are required to use Workday as the single source of truth to accurately track and communicate all time off.**

{{< note >}}
Entering time off in Workday is not necessary if working but working asynchronously. Instead, please follow the [communicating your async work days](/handbook/company/culture/all-remote/asynchronous/#communicating-your-async-work-days) section of the asynchronous handbook.
{{< /note >}}

1. As of 2022-05-01, we've created a Flexible PTO policy to better outline communication expectations for team members and managers. This means that:
    - Our move to a Flexible PTO policy means that as long as you have coordinated with your manager about your planned time off and made a coverage plan, you are free to take PTO. There continues to be no set limit per year on the amount of PTO a team member can take.
    - You are required to coordinate with your manager about your planned PTO at least twice as many days in advance as the total number of days that you plan to take off. For example, if you plan to take 3 days off, you are required to coordinate with your manager a minimum of 6 business days before. Please inform your manager of your PTO plans as soon as possible to allow for appropriate planning.
    - Once you have discussed with your manager, please coordinate with your team before taking time off, especially during popular or official holidays, so that we can ensure business continuity. We want to ensure we have adequate coverage and avoid situations where all/most of the team is taking time off at the same time. Some departments have specific windows during the quarter where the team's presence is critical to accomplishing key results. Check out your departments' handbook page for more information if applicable.
    - What we care about are your results, not how long you work, but we require managers to ensure that appropriate coverage is in place for their team. This requires managers to assess all PTO against team deliverables.
    - Note that your manager is required to ensure that your PTO does not impact business results disproportionately and as such may request that you modify your dates when necessary.
    - When asking for PTO plans to be adjusted, managers are required to specify the goal or result that may be impacted by planned PTO and share how time off may interfere with that result or goal. Managers will be given the guidance that any requested changes they ask a team member to make need to be shared within 48 hours of the team member originally sharing their PTO plans. If there isn't a compromise that can be reached, the team member and manager should escalate to the manager's manager.
    - At GitLab, team members are required to enter all days away (such as PTO, public holidays, Family & Friends Days, bereavement) in Workday. It creates an event, captures your out-of-office dates, and notifies your manager.
    - If your planned leave exceeds the 25 calendar days (including weekends and holidays), please make sure to reach out to your Manager, relevant [People Business Partner](/handbook/people-group/#people-business-partner-alignment-to-division), and the Absence Management Team at `leaves@gitlab.com` for a special request. You will need additional permission if you want to take more than 25 consecutive calendar days (including weekends and holidays) off. The 25 calendar day limit is per vacation, not per year. You can have multiple vacations per year that add up to more than 25 calendar days in total; there is no limit to this.
    - If you're gone for 72 hours without notification, this could be deemed as [Job Abandonment](/handbook/people-policies/#job-abandonment).
    - It can be helpful to take longer breaks to re-energize. If this is helpful to you, we strongly recommend taking at least two consecutive weeks of time off and at minimum 25 days total throughout the year.
1. We don't frown on people taking time off, but rather encourage people to take care of themselves and others by having some time away. If you notice that your co-worker is working long hours over a sustained period, you may want to let them know about the time off policy.
1. We encourage all team members to take time off for [holidays](#holidays) observed in their country.
1. For some countries, GitLab is required to pay out unused statutory vacation balances at the end of the team members employment. To prevent any discrepancies, make sure you select the correct category for your time off (e.g. vacation).
1. Not taking time off is viewed as a weakness and people shouldn't boast about it. It is viewed as a lack of humility about your role, not fostering collaboration in training others in your job, and not being able to document and explain your work. You are doing the company a disservice by being a single point of failure. The company must be able to go for long periods without you. We don't want to lose you permanently by you burning yourself out by not taking regular time off.
1. Working hours are flexible. We encourage you to read the [#whats-happening-at-gitlab](https://gitlab.slack.com/archives/general) Slack channel on your return to catch up on the announcements made while you were on your time off.
1. You don't need to worry about taking time off to go to the gym, take a nap, go grocery shopping, do household chores, help someone, take care of a loved one, etc. If you have urgent tasks, but something comes up or takes longer than expected, just ensure the rest of the team **knows** and someone can pick up the tasks (assuming you're able to communicate).
1. GitLab encourages team members to volunteer within their community to take care of others. Consider taking time in support of causes that matter to you and support your personal commitment to GitLab's values such as diversity, inclusion and belonging.
1. GitLab also encourages you to use your leave for jury duty, bereavement leave, or other needs. You are not expected to work during this time off, but we recommend following the guidance under [Communicating Your Time Off](#communicating-your-time-off) when these situations arise.
1. GitLab also encourages you to take time off to vote, volunteer at the polls or volunteer in your community.
1. It's important to take PTO while you have something you *want* to do – taking a mental health day, for example – rather than waiting until you *need* the time off.
   - When taking PTO for a mental health day, please select the Paid Time Off label in Workday.  If you'd like to add additional details, you can select Vacation from the drop down 'reason' menu, or add comments.
1. GitLab runs as usual during regional official days off (including public or statutory holidays): we still help clients during those days, unless they are official days off in both the Netherlands *and* the U.S. On those days, only vital functions (such as incident remediation, emergency on-call, and customer support during [GitLab Global Support Hours](https://about.gitlab.com/support/#hours-of-operation) and [US Federal Support Hours](https://about.gitlab.com/support/us-government-support/#hours-of-operation)) will be staffed. If you need to work during an official day off in your country, you should take a different day off in return.
1. Please also remember to turn on your out of office message and include the contact details of a co-worker in case anything urgent or critical comes into your inbox while you're away. If you have to respond to an incident while on-call outside of your regular working hours, you should feel free to take off some time the following day to recover and be well-rested. If you feel pressured to *not* take time off to rest, refer to this part of the handbook and explain that you had to handle an incident.
1. If during a PTO event, you realize that certain days will need to be changed from PTO to Sick Time, or another category, log into Workday and correct the entry. Events can only be changed within 30 days of the intial request.

### Holidays

1. We encourage all team members to take time off for public holidays observed in their country. No one is expected to attend calls on days they are not working or out of the office for an official public holiday. As a company that prides itself on a [family & friends first](/handbook/values/#family-and-friends-first-work-second) approach, it's a general guideline that if public schools or government offices in your area are closed for a particular national or regional holiday, that it's recognized for GitLab team members in that location to take that time off as a public holiday as well. For a general listing of public holidays by country, follow these steps:
    1. Go to the [timeanddate.com](https://www.timeanddate.com/date/)
    1. Select 'Holidays Worldwide' from the Calendar dropdown menu.
    1. Select your country of residence
    1. Change the dropdown from 'All holidays and national observances' to 'Public Holidays'

We recognize this list may not encompass all state or local public holidays, but please follow the guidance above--if public schools or government offices in your location are closed--then please enter your time off as a public holiday in Workday.  For any questions related to holidays or how to categorize time off please reach out to `leaves@gitlab.com`.

1. If you decide to work on a holiday and then take another day off in lieu of the actual holiday date, we ask that you choose Public Holiday as a PTO category, and in the section `What is this OOO for?` please clarify that this day is taken in lieu of the actual holiday date.

   ![picture-of-pto-ninja-OOO-request](/handbook/people-group/paid-time-off/pto_ninja_OOO.png)

1. Please note that Public Holidays will be listed in Workday with a Length of 0 days (0 hours).

### Communicating Your Time Off

Communicate broadly when you will be away so other people can manage time efficiently, projects don't slip through the cracks, and so that you don't get bothered while away.

1. Please use the following syntax which uses the [ISO 8601](https://en.wikipedia.org/wiki/ISO_8601) date notation in order to avoid confusion: `OOO from YYYY-MM-DD to YYYY-MM-DD, please contact XXX for assistance`.
    - Workday will automatically add this time to Time Off by Deel and as a busy event on your Google Calendar. Your manager will also receive a free event on their calendar.
    - When your time off starts, Time off by Deel will automatically update your Slack status to communicate your time off. This will prevent you from appearing in [reviewer roulette](https://docs.gitlab.com/ee/development/code_review.html#reviewer-roulette).
1. As outlined above, it's expected that you provide your manager and team members who may expect to work with you with as much advanced notice as possible about your planned time off. You should give other team members advanced notice that is at least twice as many days as the time that you plan to take off. For example, if you plan to take 3 days off, you should let other team members know **at least** 6 business days before.
1. Add an out of office automated response including the dates you plan to be away in your automated response.
1. Consider using [Google Calendar's "out of office" setting](https://support.google.com/calendar/answer/7638168?hl=en) (scroll down to "Show when you're out of office") to create an out of office event that will automatically decline new and existing meetings for you.
1. If you plan to be out of the office for more than 48 hours, update your GitLab.com status with your out of office dates by clicking on your profile picture and selecting "Edit Status." For Example: 'OOO Back on 2018-06-28.' Don't forget to change it back upon your return, and be aware that this information is publicly accessible.
    - In order to be skipped by reviewer roulette, you must have either a Slack status or a GitLab.com status indicating that you are out (the exact criteria can be found on the [reviewer roulette docs page](https://docs.gitlab.com/ee/development/code_review.html#reviewer-roulette)).
1. If your team or work group has a specific scheduling calendar, ensure to update it with your out of office plans.
1. Decline any meetings you will not be present for so the organizer can make appropriate arrangements.
    - Cancel, move, or find coverage for any meetings for which you are the organizer.
    - Optionally, if you partake in [Donut coffee chat pairings](/handbook/company/culture/all-remote/tips/#coffee-chats) you can temporarily "snooze" them by opening a direct message with Donut and typing `help` to indicate which weeks you won't be able to participate. Pairings will automatically resume when you're back.
1. If you are an interviewer, review your calendar to address any scheduled interviews. To ensure we provide a great candidate experience, if you find that you cannot attend an interview, you will be responsible for finding a replacement interviewer. You must communicate directly with your recruiter, as being out of the office does not always mean that you will be unavailable to interview.
1. If you're one of the people who typically handle availability emergencies (the on-call heroes), you **do** need to ensure that someone will be available to cover for you while you're out of office. You can check for this with your manager. Managers can import their team's calendars into their Google Calendar to get a quick view of their team members' availability.
1. Being part of a global remote team means you need to be highly organized and a considerate team player. Each team has busy times so it is always a good idea to check with them to ensure there is adequate coverage in place.
1. In case an emergency arises while you're away, please designate a backup individual and brief them on your key projects so they can assist in your absence.
1. Transition and reassign work that is already in progress to another member of your team whenever possible.
1. Please document your knowledge and share it with others. [Key-person-risk](https://dynamicbusiness.com/locked/managing-key-person-risk.html) can have a large impact. This is especially true for "subject matter experts" or SME, people with specialized knowledge of a project, tool, or subject.
    1. It can be very helpful for your PTO and team members if you document, share (weekly team call + async in Slack) and communicate your PTO already well in advance (2-3 weeks).
    1. One useful way of capturing work is to create & share a Google Doc which lists all your important projects / customer interactions + a short list of useful details per entry. This include tips for covering you best while on PTO. For example:
        1. "Name of covering team member" - also useful for your manager to quickly know who is covering which projects or customers for you.
        1. "Attendance in calls/zoom sessions required while on PTO" - Teammates can already start to plan and free up time in their calendar for specified dates/times.
        1. "High Priority Topics" - List of topics and/or links to issues which are most relevant while you are on PTO.
        1. "Comments by covering team member" - Very useful to asynchronously get updates quickly when you return from your PTO.
        1. Pro tip: Use color codes (e.g. green, red) and symbols (e.g. ✅, ❗️) to let others easily & quickly identify most important entries.
            - Please don't use colors only as people with [color blindness](https://www.mayoclinic.org/diseases-conditions/poor-color-vision/symptoms-causes/syc-20354988) may not be able to distinguish between them
    1. It may be useful to share your planned time off as an **FYI** on your team's Slack channel(s); especially if you lead a team. You can [schedule messages in Slack](https://slack.com/help/articles/1500012915082-Schedule-messages-to-send-later) to remind your team of items that are due or projects that are pending while you are off. Here are some examples of remimders that could be scheduled:
        - > Hey team, just a reminder that I'm out today.  Please take a look at my open tickets. Thanks!
        - > Hello team, I am out of the office for the next several days. Please double check the pending tasks on our team's Google Doc for any upcoming deadlines.
1. Please see the [On-Call](/handbook/engineering/on-call/) page for information on how to handle scheduled leave for someone from the On-Call team.
1. If you are a people manager, please complete the following:
    - Workday: set up a [delegate](https://docs.google.com/document/d/1BDME_47-mif1ZihO5Id-wejbjAU_-PLIr1dJ46z1F_c/edit) in Workday to be able to approve transactions on your behalf while you are away
    - Navan Expense: delegate expense approval to your back-up team member by following these steps:
        - Navan Expense
        - Settings
        - Your Account
        - Vacation Delegate - enter their email address and Payroll will grant the backup team member the necessary access
        - ***Note** - remove the vacation delegate after your PTO*

### Communicating Time Off for Emergency Situations

Emergencies, by definition, are unexpected. They can range from natural disasters, terrorist events, accidents, family deaths, hospitalization and any other unexpected situation. During these times we ask team members to use their best judgement as well as listen to and adhere to public safety officials when possible. If an unexpected emergency occurs please contact your manager via Slack or email as soon as possible if you will be unavailable or unable to work. This will allow your manager to confirm your safety and reassign any critical work during your absence. Please make sure you've added at least one emergency contact in Workday. We will only contact your emergency contact if we are unable to reach you via Slack, email or phone. We also recommend that if you are able, to use the `Public Emergency` OOO category in Workday.

### Returning from PTO

Returning from PTO of any length can feel overwhelming. Consider implementing these strategies when returning from time off in order to make the most of the rest and reflection you've achieved.

1. Remember that it's normal to take extra time to catch up after returning from paid time off. Taking time off doesn't mean that you need to work extra hours before or after your vacation. When taking extended time off, expect to have reduced capacity to take on new work the week of your return while you're catching up on the work that happened while you were away. Remember that [it's impossible to know everything](/handbook/values/#its-impossible-to-know-everything).

1. Honor a window of transition when returning from PTO and recognize that [rest and time off is productive](/handbook/company/culture/all-remote/mental-health/#rest-and-time-off-are-productive). Big, reflective moments may happen when you take a step back and reflect. Before catching up on all missed emails and Slack messages, consider first revisiting priority projects to take action on these reflections. In our [interview about managing burnout](/handbook/company/culture/all-remote/mental-health/#rest-and-time-off-are-productive), John Fitch described this approach as spending time working *on* your projects, rather than *in* your projects. This could look like blocking off a few days with no meetings to complete deep work on an OKR or hosting a collaborative session with your team to brainstorm.

1. When returning from paid time off, it can be helpful to schedule a [coffee chat](/handbook/company/culture/all-remote/informal-communication/#coffee-chats) or two on the day of your return to get caught up, share stories from your time off, and simply reconnect with your team members. It also provides a nice break from to-dos and unread emails. This type of conversation may occur organically in a colocated office but needs to be managed with intent in an all-remote company.

#### Adjust/Remove PTO from past events

The People Operations team is able to adjust active PTO events and past PTO events. If you need the team to adjust an event, please submit a HelpLab - Paid Time Off request with the details e.g. 'please remove two hours of PTO from October 31st'.

We encourage everyone to fully step away from work on their days off but understand that unforseen events can arise.

### Sick Time - Taking and Reporting

Sick time refers to the time away a team member needs to recover from short-term (non-chronic, or reoccurring) illness such as but not limited to COVID-19, menstrual pain, cold/flu, surgery, care for a close family member recovering from illness, or for preventative reasons like a doctor's appointment. Eligible family members includes but may not be limited to: parent(s), child(ren), spouse, domestic partner, grandparent(s), grandchild(ren), or sibling(s).

In keeping with our values of [CREDIT](/handbook/values/), we have crafted the following protocols around GitLab's global sick time policy available to all GitLab team members.  Team members may be eligible for their own country's [Sick Time Policies](/handbook/total-rewards/benefits/general-and-entity-benefits/#entity-benefits) and should review eligiblilty under these policies as they may offer more time away or have different reporting procedures.  We understand team members experience situations when they need continuous time away from work (5 days or more) to care for themselves or a family member, or situations when they just need a few days (less than 5), GitLab's Sick Time policy is applicable in both situations.

*Sick time does not get paid out in case of termination, nor does it reduce your final paycheck in case of a negative balance.

#### Sick Time Reporting Procedures - All Team Members

*Team members in France, Netherlands, and U.S, please read specific reporting procedures below.

All team members, regardless of the duration of sick time, are required to notify GitLab of their absence.  Team members must notify their Manager, first, and then enter the time away in Workday by selecting the label `Out Sick`.  If your sick time extends beyond 5 days, or less per your country's [statutory sick time reporting requirements](/handbook/total-rewards/benefits/general-and-entity-benefits/#entity-benefits), team members are required to notify the Absence Management Team (leaves@gitlab.com) first, and then enter the time away into Workday.

**Continuous Time Away (in excess of 5 days or more), or Non-Continuous if related to the same illness:**

Whenever allowed by law, GitLab's Sick Time Policy will supplement a team member's pay up to 100% of their regular salary for up to 25 working days of continuous absences, and run concurrently with any statutory Sick Leave policies team members are eligible for.  Eligibility is calculated on a rolling 12-month period, and only pertains to absences when team members need to be away from work for 5 or more continuous days or non-continuous if related to the same illness.

We understand some team members may need additional time away to care for a sick family member, but many countries do not offer statutory family care leave and/or pay when needing to care for a sick family member.  If a team member is not eligible for statutory family care leave or pay in their country, GitLab will provide an additional 25 working days of sick time to care for their family member. This means, a team member in a country that does not provide statutory family care leave and/or pay is eligible to receive 25 working days of sick leave for their own condition, plus an additional 25 working days of sick leave to care for an ill family member.  Eligibility is contingent on providing evidence, in accordance with local requirements, supporting the need for Sick Leave to care for their ill family member.  (see medical certificate/doctor's note below for more information)

**Non-Continuous Absences or absences less than 5 continuous days:**

If you or a loved one is ill, we want you to take care of yourself or your loved one(s). To facilitate this, you should take sick time when you need it, but you still need to report when you take sick time by notifying GitLab first and then entering the dates in Workday by selecting the label `Out Sick`.

- Once entered in Workday, your sick time will be automatically updated in Time Off by Deel.

If you end up more than 5 consecutive calendar days, or 5 non-continuous calendar days related to the same illness, please follow the instructions in the [Communicating Illness-Related Leave](#communicating-illness-related-leave) section.

#### Sick Time Procedures - USA

In the United States, team members may experience a qualifying condition under the Family Medical Leave Act (FMLA) after 3 days of continuous or non-continuous absences (if related to the same condition).  If you are missing more than 3 calendar days of work due to a serious medical condition or to care for a family member with a serious medical condition, your time away will be reviewed to determine if it qualifies as leave under the Family Medical Leave Act (FMLA) and/or any concurrent state sick leave statutes. Team Members are required to notify the Absence Management Team [leaves@gitlab.com] no later than the 5th consecutive/non-consecutive absence, so that the time away can be processed under the applicable leave laws, but may notify the Absence Management Team as of the 3 consecutive/non-consecutive day.

- Please be aware that certain states in the US require you to notify your employer of the need for a medical leave prior to your first day of leave whenever possible. To ensure timely reporting and prevent any delays in your pay, please follow the instructions listed in the [Family Medical Leave Act](/handbook/people-policies/leave-of-absence/us/) handbook section to report your time away.
- Sick Pay will be coordinated with [Short-Term Disability](/handbook/total-rewards/benefits/general-and-entity-benefits/inc-benefits-us/#group-long-term-and-short-term-disability-insurance), and/or the equivalent State pay benefits.

#### Sick Time Procedures - Netherlands

Employees of GitLab B.V. have further rights and responsibilities regarding sick time based on Dutch law, as written into their employment [contracts](https://internal.gitlab.com/handbook/people-group/people-operations/people-connect/employment_contracts/):

- Team members must notify their manager of any sick leave needed.
- Team members must then enter the sick time via Workday as aligned above.
- If the sick leave extends 8 days it should be reported to the Absence Management team via `leaves@gitlab.com` by the Manager and team member (if able).
- If team members are reporting multiple instances of sick leave in a 28 day timeframe, please reach out to the Absence Management team.
- Once the Absence Management team has been notified of the sick time they will inform HRSavvy.
- HRSavvy will be registering the sick time in their HR portal from the first day of absence (retrospectively).
- GitLab has engaged with an occupational health and safety centre, called Leuk Personeel, to assist employees of GitLab B.V. who may need support while being on long-term sick leave.
- If the team members is on long-term sick leave (8 days of more), the Absence Management team will instruct HRSavvy to register the team member at the occupational health and safety service, depending on the situation and agreement with the team member.

#### Sick Time Procedures - France

See the [France S.A.S. benefits page](/handbook/total-rewards/benefits/general-and-entity-benefits/france-sas/#sick-time).

#### Medical Certificate/Doctor's Note

Please be aware that certain countries require a medical certificate, doctor's note or similar type of documentation for your sick time. Please review your employment contract or your [country's](/handbook/total-rewards/benefits/general-and-entity-benefits/#entity-benefits) Sick Time policy to determine what documentation may be needed.

Eligibility for GitLab's Sick Time policy will require team members to provide evidence, in accordance with local requirements, supporting the need for Sick Leave.

Team Members should email the documentation to Absence Management team (leaves@gitlab.com).

## Communicating Illness-Related Leave

In the unfortunate event that a team member is dealing with a medical situation, they are under no obligation to reveal details to their manager directly. Instead, you can reach out to the Absence Management Team `leaves@gitlab.com`. The Absence Management Team will inform the People Business Partner and Manager on a need-to-know basis, but will only provide details related to leave dates; not illness. If the manager does become aware of the team members illness, the manager should under no circumstances reveal any illness-related leave to other team members to ensure we respect the privacy of the team member affected.

## Accommodations

If you believe you need reasonable accommodations to perform the essential functions of your job in accordance with applicable law(s), please email leaves@gitlab.com (Non-US Only).  [US team members](/handbook/people-policies/inc-usa/#reasonable-accommodation) please follow the steps outlined in the handbook.

If a team member starts the conversation with their manager, or People Business Partner, the manager or People Business Partner should either reach out to the Absence Management Team by emailing `leaves@gitlab.com`, or direct the team member to follow the steps outline in the handbook (links above).

The Absence Management Team will keep a log of all accommodation requests. What can (or must) be accommodated varies from location to location. GitLab will comply with the applicable laws in your specific location.

### Communicating with team members while they are leave of absence

For team members who are on paid or unpaid leave of absence like [parental leave](/handbook/total-rewards/benefits/general-and-entity-benefits/#parental-leave), [short or long-term disability](/handbook/total-rewards/benefits/general-and-entity-benefits/inc-benefits-us/#group-long-term-and-short-term-disability-insurance), or other approved leaves there is no expectation that work would be accomplished during this time. Team members should use their approved paid or unpaid leave as an opportunity to focus on their health and well being. For managers it is important that you do not reach out to team members and ask them to complete work while on an approved leave of absence. An occasional quick call for a simple question is acceptable but these should be infrequent and simple requests that can be answered during that conversation.

We do understand that during extended periods of time off team members may still want to feel connected. We encourage team members at their discretion to maintain a social connection with their peers and team members. This is completely up to the team member on leave on how or if they want to remain connected while on leave of absence.

For managers it is ok to reach out to a team member every 3-4 weeks to just to say hello. These conversations should remain social and avoid work related topics.

## Workday

All team members and Managers, including those employed under a PEO, are expected to log all time away requests into Workday (Vacation, Public Holiday, Friends & Family, Sick Time, etc.)

As of October 1, 2024, Workday and Workday Slack will be the primary point of entry for all time away needs.  This allows team members and managers to coordinate time off seamlessly.  The integration between Workday and Time Off by Deel will still be available, but all data will feed from Workday into Time Off by Deel; retaining Deel's functionality (reminds employees of their upcoming time off, assign roles and tasks for co-workers, Google Calendar synronization, and automatic OOO updates).

GitLab team member questions about Workday can be directed to the HelpLab portal.

### Workday to Time Off by Deel Synronization

#### Google Calendar Sync

Workday time away entries will flow into Time Off by Deel allowing you to sync time off requests with your Google Calendar.

A calendar invite will also be sent to your manager to help them keep track of their team's time away. This event will always be based on the calendar date and will not adjust for timezones. If you are a manager with team members in varying timezones, you may end up with calendar invites that do not accurately reflect the actual time away. As a manager, you can simply decline the calendar invite and manually create a correct entry on your own calendar without affecting the actual time off request.

More information regarding this sync can be found on the [Team PTO Calendar](/handbook/people-group/engineering/team-pto-calendar/) handbook page.

#### Automatic Status + Do Not Disturb Updates

Time Off by Deel can automatically set your OOO status in Slack and apply "Do Not Disturb" settings while you're away. You must add these permissions individually.

#### Roles and Task Handoffs

Time off by Deel provides an experience that allows you to set roles and tasks for co-workers while
you're away. Accepted roles then become a part of a Slack away message that appears as
co-workers try to tag you in discussions while you're OOO.

Before assigning a `#channel` to a role, please ask for permission to do so in that channel.
Especially in large channels and during popular vacation times, PTO's role reminders could create a lot of noise, so some teams may recommend against them until there is an option to allow turning off the PTO notifications.

#### Monthly reminder to consider taking PTO

We get it — life gets busy. So busy, in fact, that you may need a little nudge to consider taking time off to recharge. Time off by Deel allows you to subscribe (and unsubscribe) to a monthly prompt, sent on the first *working* day of each month, reminding you to pause and think about time away from work and prioritizing [mental health](/handbook/company/culture/all-remote/mental-health/).

The reminder will read as follows.

> Hi there! Have you thought about what days you may take off this month? 🌴⛰️ We want to make sure you stay healthy! If you feel like you can't reasonably take time off, feel welcome to add this note to your next 1:1 with your manager and discuss further. Learn more about paid time off at GitLab: `/handbook/people-group/paid-time-off/`

To subscribe or unsubscribe, follow the below instructions and [see an associated screenshot](/handbook/people-group/gitlab-slack-pto-reminder.png).

- Visit `Apps` in the menu bar within Slack and search for or select `Time Off by Deel`
- On the application's `Home` tab, select `Notifications` from the dropdown
- Beneath the dropdown, you'll see a line that says "Send me a monthly reminder about taking time off." Click the **Subscribe** button to trigger the notification, which will begin on the first *working* day (e.g. not a weekend or a public holiday) in the month following your subscription.
- To unsubscribe, revisit Workday within Slack Apps and click the button that says **Unsubscribe**.

##### Checking "Who's Out?"

Considering GitLab has a [flexible time off policy](#a-gitlab-team-members-guide-to-time-off), it is helpful to know who else on your team is out of office prior to requesting time. In order to see who is out of your team, follow the steps below:

- Go to the Time off by Deel application in Slack
- In the `Home` section, select `Who's Out?` from the dropdown list
- Click `new search` to view who is out by `#channel`, `@usergroup`, or `@username`

#### Requesting and documenting new Workday features

You can request a new Workday feature by using the aforementioned `/time-off-deel feedback` command in Slack. If you receive feedback from the Workday team, or a new feature is implemented, please document the discussion in [this GitLab issue](https://gitlab.com/gitlab-com/people-group/General/issues/285). You can also create an issue in the [People Group general project](https://gitlab.com/gitlab-com/people-group/General) and ping CEO Kevin Corliss `@pto-ninja` and CTO Doug Franklin `@doug17` for review.

### Instructions for Team Members to update past events

Team members can [correct or edit](https://docs.google.com/document/d/1c0Qp738HXEeIb_SxUeKZYlG3su086CO5Dxa618Rvffk/edit) past-dated time off entries up to 30 days in the past.  All other entries will need to be submitted to the People Connect team for review.  Not all requests will be approved as it is the team member's responsibility to assure all time away requests are accurate.

## Management's Role in Paid Time Off

Managers have a duty to manage their direct reports well-being and ensure that time off is being taken. Sometimes, when working remotely from home, it can be hard to find a good work-life balance. It is also easy to forget that your team is working across multiple time zones, so some may feel obligated to work longer to ensure there is overlap. It is important that you check-in with your reports through one-to-ones, and if you think someone needs some time off, let them know they can do this.

For audit and compliance purposes, managers are responsible for ensuring that their team members track and communicate all time off using Workday as the single source of truth. Whether a team member is taking one day off, or 25+ calendar days off, all team members must use Workday.

For audit and compliance purposes, managers have a responsibility to be aware of their direct reports' [statutory time off policies](#statutory-vacation-requirements), as applicable in countries in which GitLab is the employer. Some countries require employers to ensure team members are taking time off, so it is recommended that managers review their direct reports' OOO time frequently, using the reports described in the section below. Managers do not need to understand the ins and outs of the policies; just that team member in specific country receives certain amount of days/year. The specifics of these policies (accrual maximums, rollover, accrual rates, etc) will still be managed within the People Ops team. Please feel free to reach out to `leaves@gitlab.com` with any questions.

If you discover that multiple people in your team want to be off at the same time, see what the priorities are, review the impact to the business, and use your best judgement. Discuss this with your team so you can manage the time off together. It is also a good idea to remind your team to give everyone an early heads-up, if possible, about upcoming vacation plans. Reminders can be sent in Slack, shared on a team calendar, or noted during team meetings.

If as a manager you are notified that your direct report has been incapacitated or unable to submit an OOO request in Workday and needs to take time off, be it Sick Time or otherwise, please document this information, and relay it to the Absence Management Team via leaves@gitlab.com without disclosing private medical information in compliance with applicable privacy laws. The Absence Management Team will submit an OOO request on the team members behalf and mark the reason as `Per Manager Name`, and save the email thread in the team members profile in Workday. This documentation will be unshared and will not contain any personal medical information.

### Workday Manager Reporting

Reporting from Workday helps managers:

1. Be sure their direct reports are taking enough PTO
1. Review upcoming PTO of direct reports to make project management decisions and manage team member burnout

Managers will have access to Time Away dashboards and other reports within Workday.

#### How to use Workday data to support your team

Understanding the PTO that teams have taken, and plan to take, helps managers have conversations about burnout and burnout management with their direct reports. Below are common scenarios faced by managers than can be supported using Workday data.

#### Planning and decision making for future projects

1. Review time away data planned for the upcoming quarter
1. Use planned PTO to make decisions including
     - What does my team have capacity to achieve this quarter?
     - What weeks should I avoid scheduling key communication or planning?
     - What weeks are best to have synchronous team calls?
     - What weeks do I plan to take off, and how do those overlap with my team?
1. If your team does not have any planned PTO, consider sending a message or encouraging them in your next 1:1 to plan ahead to take PTO. Getting ahead of burnout is important and can be partially addressed with adequate rest.
1. Confirm that you're getting calendar invitations for your direct reports PTO.

### Supporting Team Members Taking Time Off

Taking time off should be a chance for a team members to step away from work and we need each other's help to make that easier.  PTO should not encourage people to cram work in before they leave or work extra hard upon their return in order to catch up.

1. Before a team member goes on leave, avoid the temptation to ask them to work on a few more things.
1. Tell fellow team members that you are expecting them not to check in while they are on PTO.
1. Minimize emails and mentions to team members who are on PTO, unless it's critical that they know something when they return.  Try to keep their inbox empty.
1. Welcome team members back to work and do not ask them work questions until they are ready.

### Recognizing Burnout

It is important for us to take a step back to recognize and acknowledge the feeling of being "[burned out](/handbook/company/culture/all-remote/mental-health/)".
We are not as effective or efficient when we work long hours, miss meals or forego nurturing our personal lives
for sustained periods of time. If you feel that you or someone on your team may be experiencing [burnout](https://www.mayoclinic.org/healthy-lifestyle/adult-health/in-depth/burnout/art-20046642), be sure to address it right away.

To get ahead of a problem, be sure to communicate with your manager if any of the following statements ever apply to you:

- "I am losing interest in social interaction." - This is especially dangerous in an all-remote setting.
- "I've lost the motivation to work." - Everyone has days when they don't want to work
but if you hear yourself saying this often, you're on the road to burnout.
- "I often feel tired." - Indicative of being overworked for prolonged periods of time.
- "I get agitated easily."
- "I've been hostile to my coworkers." - You see yourself "snap" at people for
no apparent reason.
- "I've been having headaches often." - A headache can manifest itself for multiple
reasons but if you catch yourself only having headaches on work days, it is time to
evaluate your situation.

These and similar symptoms might get missed or dismissed, as people who are on the path to burnout, or who are burnt out, are usually unable to spend the mental energy to recognize it in themselves. Having an external source objectively identify the situation can be helpful. A great tool for objectively recognizing burn out is [`burnoutindex.org`](https://web.archive.org/web/20240121220209/https://burnoutindex.yerbo.co/).

If someone is showing signs of burnout, they should take time off to focus on things that are relaxing and improve their overall health and welfare.

As a manager, it is your task to evaluate your team's state of mind.
Address possible burnout by discussing options with your team member to manage contributing stressors and evaluate the workload.
Some things to help with this:

- Try to follow each of your team members' work habits. If they start being less efficient,
or working more hours, they might be on the road to burnout.
- Try to keep track of when they had their last paid day off. If they hadn't had a personal day
in a long time, look closer at their behavior.
- Make sure you let your team members know they can talk to you about their challenges.
- When you recognize symptoms of burnout in others, help them to get out the "Burnout trap".

Don't just tell people to [take a break](https://medium.com/@zenpeacekeeper/take-a-break-f877907877bc),
but help them arrange things so they **can** take a break. Ask why they feel they can't take a break
(there are almost certainly real, concrete reasons) and then ask permission to get busy putting things in place
that will overcome those barriers. People might be trapped by their own fatigue, being too worn out to find the creative solutions needed to take a break.

Other [tips to avoid burnout](https://www.mayoclinic.org/healthy-lifestyle/adult-health/in-depth/burnout/art-20046642?pg=2) include:

- Make use of our [Employee Assistance Program](/handbook/total-rewards/benefits/general-and-entity-benefits/#employee-assistance-program) that can offer professional support during this time.
- Assess and pursue your interests, skills and passions.
- Take breaks during the day to eat healthy food and stretch your legs. The [Timeout app](https://dejal.com/timeout/) can help with that.
- Make time each day to increase blood and oxygen circulation which improves brain activity and functionality.
- Get plenty of restful sleep.
- Meditate to take your mind away from work. [Headspace](https://www.headspace.com/science) and [Calm](https://www.calm.com/meditate) are good tools for creating meditation habits.
- Don't start work as soon as you wake up. Take your time doing your morning routine.
- Set yourself as away when you are not working. Snooze your Slack notifications. It is fine to be not reachable during your off time.

Don't let burnout creep up on you. Working remotely can allow us to create bad habits, such as working straight through lunch to get something finished. Once in a while this feels good, perhaps to check that nagging task or big project off the list, but don't let this become a bad habit. Before long, you'll begin to feel the effects on your body and see it in your work.

Keep in mind that you are not alone! Chances are that you have a colleague who already
experienced burnout or has been on the road to burnout. Schedule coffee calls with
your team members or with anyone you'd like to talk to. Talk to your manager. If none of that
is an option for you, schedule a coffee call with [Marin](slack://user?team=T02592416&id=U025925R0).

Take care not to burn yourself out!

## Statutory Vacation Requirements

The following is a list of all statutory annual vacation entitlements by entity and country. Once the statutory amounts have been taken, team members can still make use of GitLab's Flexible time off policy.

### GitLab LTD (UK)

Team members are [entitled to at least 28 vacation days](https://www.gov.uk/holiday-entitlement-rights), this is broken down by 20 days standard annual leave plus 8 public holidays. These days will accrue from the start date at a rate of 1.67 days/month. It is important for UK team members to utilise time off for public holidays as the total amount of annual leave is accrued here inclusive of public holidays. Under normal circumstances, there is no carryover for unused vacation days. However, given the situation surrounding COVID-19 team members may be eligible to carry over unused vacation days if team members have a COVID-related reason that prevented them from being able to utilize vacation.  [UK government announcement](https://www.gov.uk/government/news/rules-on-carrying-over-annual-leave-to-be-relaxed-to-support-key-industries-during-covid-19).

### GitLab BV (Netherlands)

Team members are entitled to at least 20 statutory vacation days per calendar year. The days will accrue at 1.67 days/month from the team members start date. Any unused statutory vacation days will be carried into the next calendar year, but expire on July 1st. Should the team member leave GitLab within the calendar year, an entitlement to a pro rata portion of vacation days exists.

### GitLab BV (Finland)

Team members with less than 1 year of tenure are entitled to 2 days/month totaling 2 weeks per year.  Team members with 1 year or more of tenure are entitled to 2.5 day/month totaling 30 days per year.  Team members are allowed to carry over up to 24 workdays into the next calendar year, but expire 1 year from the accrual on April 1st.

### GitLab BV (Belgium)

Team members are entitled to at least 20 vacation days/year.  These days will be front-loaded at the beginning of each year. The days taken must be communicated to the Belgian payroll provider each month by People Ops. These days do not carry over into the next calendar year.

### GitLab IT BV (Contractors)

Contractors do not have statutory vacation requirements, but are eligible for our Flexible Time Off Policy.

### GitLab GmbH (Germany)

Team members are entitled to at least 20 vacation days. The days will accrue from the start date at a rate of 1.67 days/month. In general, team members must take their annual vacation days during the calendar year, otherwise it is forfeited. However, unused vacation days can be carried forward until the 31st of March of the next calendar year if the employee was unable to take the holiday due to operational or personal reasons.

### GitLab PTY (Australia & New Zealand)

Team members are entitled to a minimum of four weeks' annual holidays per year. Annual leave does not expire and can be carried over each year.

***New Zealand Only***:  GitLab may set expectations on how much annual leave team members may accumulate and may require team members to take entitled leave with 14 days notice.

### GitLab GK (Japan)

An employee who has been continuously employed for six months and whose attendance has been at least 80% of the total number of working days during that period, is entitled to a minimum of ten days' annual paid leave on the day after completing six months of employment. The entitlement increases by one day per year for the following two years and by two days per year thereafter, up to a maximum of 20 days per year. Unused annual paid leave expires after two years if not used. Companies are not required to purchase out unused annual paid leave when team members leave companies unless otherwise provided in the work rules or employment contracts.

### GitLab Inc. (USA)

The U.S. [Fair Labor Standards Act (FLSA)](https://www.dol.gov/general/topic/workhours/vacation_leave) does not require payment for time not worked, such as vacations, sick leave or federal or other holidays.

### GitLab Ireland

Team members are entitled to accrue 20 days per year at a rate of 1.67 days/month from the team member's start date. The holiday year will run from January 1st to December 31st of each year. Unused vacation days cannot ordinarily be carried forward into the following holiday year, however, if the team member is unable to take vacation due to long-term sick leave, then unused vacation days can be carried forward for up to 15 months from the end of the relevant holiday year.

### GitLab Korea Limited

- Team members with 0-1 year of service are entitled to 1 day/month or 12 days/year.
- Team members with 1-3 years of service are entitled to 1.25 days/month or 15 days/year.
- Team members with 3+ years of service are entitled to one additional day for every two years continuously worked up to 25 days/year.
- Accrual balances reset January 1st of every year.

### GitLab PTE Ltd. (Singapore)

- After 3 months of employment, accrual rates will be based on tenure. Team members are allowed to carry over unused vacation up to the statutory accrual limit based on tenure.
- 1 year of service:  7 days/year
- 2 years of service:  8 days/year
- 3 years of service:  9 days/year
- 4 years of service:  10 days/year
- 5 years of service:  11 days/year
- 6 years of service:  12 days/year
- 7 years of service:  13 days/year
- 8 years of service:  14 days/year

### GitLab S.A.S (France)

Team members are entitled to a minimum of 5 weeks of statutory vacation per year. The accrual period in France is June 1st - May 31st and accruals are prorated based on the number of months worked in the accrual period. Any unused statutory vacation days will be carried into the next accrual period, but expire one year after it's accrued.

#### Reduction of working time (RTT)

- Certain roles within GitLab may benefit from reduced working time (RTT), and the accrual period for RTT days is January 1st - December 31st each year.
- Team members cannot carry RTT days to the following year and we encourage all team members to use RTT accruals within the year.
Team members are encouraged to review additional information on [working time in France](https://internal.gitlab.com/handbook/finance/payroll/timekeeping/france/) and [RTT calculation](https://internal.gitlab.com/handbook/finance/payroll/timekeeping/france/#rtt-calculation (**accessible internally only*).

### GitLab Canada Corp (Canada)

GitLab's [PTO policy](paid-time-off) overrides over GitLab Canada Corp in the sense that the policies listed here are stating the statutory minimum that each GitLab Canada Corp team member must take to be compliant with relevant provincial laws. For more information, refer to the applicable employment standards legislation of the Province in which you reside.

- [Alberta Employment Standards](https://www.alberta.ca/employment-standards.aspx)
- [British Columbia Employment Standards](https://www2.gov.bc.ca/gov/content/employment-business/employment-standards-advice/employment-standards)
- [Manitoba Employment Standards](https://www.gov.mb.ca/labour/standards/doc,quick_guide,factsheet.html)
- [New Brunswick Employment Standards](https://laws.gnb.ca/en/showfulldoc/cs/E-7.2//20220106)
- [Newfoundland and Labrador Labor Standards](https://www.gov.nl.ca/ecc/labour/lsaissues/)
- [Northwest Territories Employment Standards](https://www.ece.gov.nt.ca/en/services/employment-standards)
- [Nova Scotia Labor Standards](https://novascotia.ca/lae/employmentrights/docs/LabourStandardsCodeGuide.pdf)
- [Nunavut Labor Standards](https://www.nu-nlsb.ca/)
- [Ontario Employment Standards](https://www.labour.gov.on.ca/english/es/)
- [Prince Edward Island Employment Standards](https://www.princeedwardisland.ca/en/information/workforce-advanced-learning-and-population/employment-standards-in-pei)
- [Quebec Labor Standards](https://www.cnesst.gouv.qc.ca/sites/default/files/documents/labour-standards-quebec.pdf)
- [Saskatchewan Employment Standards](https://www.saskatchewan.ca/business/employment-standards)
- [Yukon Employment Standards](https://yukon.ca/en/employment/employment-standards)
- In most provinces in Canada, team members are entitled to ***Vacation time*** after they have worked for 12 consecutive months.
- ***Vacation pay*** is calculated as a percentage of the gross wages an employee earns during a "year of employment". Vacation pay is earned the moment employment begins (except in Newfoundland and Labrador and British Columbia which starts accruing after 5 calendar days). "Gross wages" include: base salary, hourly wages (if applicable), and commission or other incentive-based pay. It does not include discretionary bonuses that are not related to hours, production or efficiency.
- Vacation pay in respect of any earned but unused vacation time must be paid out on termination.
- GitLab Canada Corp should ensure that all statutory mandatory minimum vacation time is taken within 12 months of it being earned.

| Policy Locations             | Statutory Minimum Vacation Time               | Statutory Minimum Vacation Pay             |
|------------------------------|-----------------------------------------------|--------------------------------------------|
| All of Canada (except SK, QC, ON)| 2 weeks after 1 year / 3 weeks after 5 years  | 4% for the first 5 years, 6% after 5 years |
| Quebec Only | Less than 1 year - 1 day per full month of uninterrupted service, not to exceed 2 weeks; 1 year to less than 3 years - 2 consecutive weeks; 3 years or more - 3 consecutive weeks | 4% for first 3 years; 6% after 3 years |
| Saskatchewan Only | 3 weeks after 1 year / 4 weeks after 10 years | 6% for the first 9 years, 8% after 9 years |
| Ontario Only | 2 weeks after 1 year / 3 weeks after 4 years  | 4% for the first 5 years, 6% after 5 years |
