---
title: "People Compliance Reporting"
description: "The People Compliance team manages and ensure that all mandated HR-related reporting are completed swiftly and submitted accurately."
---

## United States

### EEO-1

The [EEO-1 Component 1](https://www.eeocdata.org/eeo1) report is a mandatory annual data collection that requires all private sector employers with 100 or more employees, and federal contractors with 50 or more employees meeting certain criteria, to submit demographic workforce data, including data by race/ethnicity, sex and job categories. GitLab submits our EEO-1 reports annually within the required time frame.

### AAP

According to United States Federal regulation [41 CFR § 60-2.10](https://www.ecfr.gov/cgi-bin/text-idx?SID=e0353318617a8ade7d25fbafc465539c&mc=true&tpl=/ecfrbrowse/Title41/41cfr60-2_main_02.tpl), "an affirmative action program is a management tool designed to ensure equal employment opportunity. A central premise underlying affirmative action is that, absent discrimination, over time a contractor's workforce, generally, will reflect the gender, racial and ethnic profile of the labor pools from which the contractor recruits and selects. Affirmative action programs contain a diagnostic component which includes a number of quantitative analyses designed to evaluate the composition of the workforce of the contractor and compare it to the composition of the relevant labor pools. Affirmative action programs (AAP) also include action-oriented programs. If women and minorities are not being employed at a rate to be expected given their availability in the relevant labor pool, the contractor's affirmative action program includes specific practical steps designed to address this underutilization. Effective affirmative action programs also include internal auditing and reporting systems as a means of measuring the contractor's progress toward achieving the workforce that would be expected in the absence of discrimination."

The US Department of Labor's Office of Federal Contract Compliance Programs (OFCCP) enforces the Executive Order 11246, as amended; Section 503 of the Rehabilitation Act of 1973, as amended; and the affirmative action provisions (Section 4212) of the Vietnam Era Veterans' Readjustment Assistance Act, as amended. Taken together, these laws ban discrimination and require federal contractors and subcontractors to take affirmative action to ensure that all individuals have an equal opportunity for employment, without regard to race, color, religion, sex, national origin, disability or status as a Vietnam era or special disabled veteran.

Our AAP is developed using the same start month every year. The AAP report is kept on file internally and shared with the OFCCP in the case of an audit. Our first AAP was for our Fiscal Year 2022 (February 1, 2021 to January 31, 2022). Further information for team members is found on our [Affirmative Action Plan](/handbook/people-group/people-compliance/people-compliance-reporting/aap/) page.

### VETS-4212

The U.S. Department of Labor's Veterans' Employment and Training Service (VETS) and Office of Federal Contractor Compliance Programs (OFCCP) have supported affirmative actions to employ and advance in employment of covered veterans since 2008. As legislatively mandated under 38 U.S. Code Section 4212, codified at 41 CFR 61-300, contractors and subcontractors who enter into, or modify a contract or subcontract with the federal government, and whose contract meets the criteria set forth in the above legislation / regulations, are required to report annually on their affirmative action efforts in employing veterans. Data reported through form [VETS-4212](https://www.dol.gov/agencies/vets/programs/vets4212) is used by OFCCP in compliance evaluations.

The VETS deadline is September 30 every year, looking back at the previous full calendar year. Our VETS data set is combined with our EEO data set.

### Other State Reports

#### California Pay Data Report

As of 2021, due to Senate Bill 973, California employers are required to submit annual information on its employees' pay data by gender, race, and ethnicity to the state's Department of Fair Employment and Housing (DFEH). Specifically, the new law requires employers, (a) with 100 or more employees; and (b) that must file an annual Employer Information Report (EEO-1) under federal law, to submit an annual report to the DFEH that includes the number of employees (and the hours they worked):

- By race, ethnicity, and sex;
- In each of the Job Categories in the federal EEO-1 Report; and
- Whose annual earnings fall within each of the pay bands used by the United States Bureau of Labor Statistics in the Occupational Employment Statistics survey.

Employers must create a "snapshot" that counts all of the individuals in each job category by race, ethnicity and sex employed during a single pay period of the employer's choice between October 1 and December 31 of the reporting year. The CA Pay Data reports are usually due in late March / early April of the succeeding year. Our California Pay Data Reports were submitted within the deadline since the required was put in place.

#### Illinois SB 1480

**EEO-1 data filing requirements**

Illinois' SB 1480 requires employers to make their EEO-1 reports public beginning in early 2023. SB 1480 amends the Illinois Business Corporation Act to require public-facing reporting of employee demographic data to the Illinois Secretary of State. Applicable employers required to file an EEO-1 report must report information "substantially similar" to the employment data reported under Section D of the corporation's EEO-1 form.

**Amendments to the Illinois Equal Pay Act**

Illinois SB 1480 amends the Illinois Equal Pay Act of 2003 and requires private employers in the state with more than 100 Illinois-based employees to obtain an Equal Pay Registration Certificate from the state Department of Labor or certify in writing that it is exempt. Employers must also re-certify every two years. New businesses meeting the employee threshold must obtain an Equal Pay Registration Certificate within three years of commencing operations and recertify every two years.

To apply for an Equal Pay Registration Certificate employers must pay a $150 filing fee and provide the following to the Illinois Department of Labor:

- Equal Pay Compliance Statement: An Equal Pay Compliance Statement, signed by a corporate officer, legal counsel, or authorized agent of the business that certifies the organization is in compliance with state and federal equal pay laws, including but not limited to, Title VII of the Civil Rights Act of 1964, the Equal Pay Act of 1963, the Illinois Human Rights Act, the Equal Wage Act, and the Equal Pay Act of 2003.
- Employer Information Report EEO-1: If required to file an EEO-1 report with the EEOC, a copy of the business's most recently filed EEO-1 report for each county in which the business has a facility or employees.
- List of employees: Separated by gender and race/ethnicity categories as reported in the business's most recently filed EEO-1 report and the total wages as defined by Section 2 of the Illinois Wage Payment and Collection Act paid to each employee during the past calendar year. The Illinois Department of Labor may also audit a business's compliance by requesting the following information in the major job categories in the EEO-1 report: Number of male employees; Number of female employees; Average annualized salaries paid to male and female employees; Information on performance payments, benefits, or other elements of compensation; The average length of service for male and female employees in each major job category; Other information identified by the business or by the Illinois Department of Labor as needed to determine compliance with the above-specified requirements.

## Australia

### Workplace Gender Equality Act (WGWA) Report

The [Workplace Gender Equality Act 2012](https://www.wgea.gov.au/what-we-do/reporting) requires non-public sector employers with 100 or more employees (for 6 months or more of a reporting period) to submit a report to the Workplace Gender Equality Agency.

Each year, the WGEA Portal opens on 1 April for reporting. Organisations then have two months to submit their reports, with reports due on 31 May. Reports cover the preceding 12-month reporting period. The reporting period is the same each year, from 1 April (the previous year) to 31 March (the current year). As of May 2024 has not yet reached the threshold. GitLab continues to track our headcount in Australia, and in the event that we fall under the headcount requirement, we will ensure to submit our WGEA report by the deadline.

## Ireland

### Gender Pay Gap Report

Under the [Gender Pay Gap Information Act 2021](https://www.irishstatutebook.ie/eli/2021/act/20/enacted/en/print.html), certain employers are required to report not only whether there is a gender pay gap in their organisation, but why there is one, and what they intend to do about it. Employers must choose a "snapshot date" in June, which will establish the data set for its December report, and which will then be used for year-on-year comparison purposes into the future.

Employers are required to publish the information annually on their website and ensure that the information is accessible to their employees and also the general public. From 2024, this report will be required for employers with a minimum of 150 employees, and from 2025, this report will be required for employers with a minimum of 50 employees. GitLab Ireland Ltd will continue to monitor our team member head count to ensure that we comply with this reporting requirement should we reach this or above the threshold.
