---
title: "Affirmative Action Plan Information"
description: "GitLab is committed to our OFCCP compliance in relation to our Affirmative Action Plan."
---

GitLab Inc (including GitLab Federal) is categorized as a U.S. federal contractor, and as such, is subject to annual and ongoing Affirmative Action requirements.

## Why are we an Affirmative Action employer?

A US employer is subject to US Federal affirmative action regulations if it has 50 or more employees and a Federal contract or subcontract of $50,000 or more.

## What is involved as an Affirmative Action employer?

GitLab is committed to providing a fair, equitable, and non-discriminatory work environment in which all qualified applicants and employees have an equal opportunity to be employed and to advance in their careers. This pertains to all employment actions, including, but not limited to: hiring, promotion, termination, and the accurate recordkeeping of related data and actions.

GitLab Inc is required to make deliberate efforts to recruit and retain women, minorities (see below), protected veterans, and individuals with disabilities to and within our workforce. This includes making reasonable accommodations for individuals with disabilities and for religious practice/observance. Minorities are defined for all US hires as those identifying as the following ethnicities:

- Asian
- Black/African American
- Hawaiian/Pacific Islander
- Hispanic/Latino
- Indigenous Peoples/Alaska Native
- Two or more races

GitLab Inc must create and maintain a written Affirmative Action plan (AAP), developed and maintained on an annual basis, which documents our efforts and goals.

GitLab Inc must communicate this context and information to any team member who may as part of their role interview, hire, or promote US-based candidates or team members, even if they themselves are not based in the US.

## What is an Affirmative Action Plan (AAP)?

An Affirmative Action plan contains both narrative and statistical components, related to any employment action related to a US-based applicant or team member only. Our Affirmative Action plan establishes goals for minority and female placements by job type, as well as a hiring benchmark for protected veterans and a utilization goal for individuals with disabilities.

Our compliance is measured by **our efforts** to meet each of these goals rather than whether we actually achieve the goals. Note that our AAP does not include quotas and it is unlawful for us to grant preferential treatment based on gender, race, protected veteran, or disability status. Our responsibility is to remove barriers to employment that members of these four groups have historically faced and, in all instances, to select the most qualified individual for the position being filled. The AAP serves as a management tool designed to help us remove those barriers and ensure equal opportunity.

## What are our Affirmative Action Plan compliance goals for the US workforce?

To understand our goals, we must look at **utilization analysis**, which is defined as a tool used in Affirmative Action plans to compare:

- The demographics of current employees
- The demographics of the available workforce

The goal is to ensure equal access and opportunity for all workers. Placement goals serve as targets or objectives reasonably attainable by applying good faith efforts to our Affirmative Action plan. This number is not a quota. In all employment decisions, selections must be made in a nondiscriminatory manner.

GitLab is striving to enhance employment opportunities for women and minorities throughout our organization. Our annual goals are shared with relevant leaders and team members during our annual Affirmative Action plan training. These goals are quatified and related to their relevant job groups.

## What are job groups?

All GitLab job codes are categorized in Workday from the 10 [EEO Job Categories](https://www.eeoc.gov/sites/default/files/migrated_files/employers/eeo1/jobclassguide.pdf). These categorizations are only used for required US reporting and classification purposes.

The 6 main categories that are applicable to GitLab are:

1. Executive/Senior Level Officials and Managers
1. First/Mid Level Officials and Managers
1. Professionals
1. Technicians
1. Sales Workers
1. Administrative Support Workers

The remaining four job groups are not applicable to GitLab: Craft Workers; Operatives; Laborers and Helpers; Service Workers.

In addition to the 6 main EEO job group categories, GitLab sub-categorizes certain larger categories to ensure a better understanding of distribution, utilization, hiring and promotion according to similar roles and levels. Workday only contains the main categorization. Here are GitLab's sub-categories and their definitions:

### 1A. Executive/Senior Level Officials and Managers

Individuals who plan, direct and formulate policies, set strategy and provide overall direction to enterprises/organizations for the development and delivery of products and services, within parameters approved by a board of directors or other governing body. They reside in the highest levels of organizations (within two reporting levels of the CEO in larger organizations). The 1.1 job group equates to the 1A sub-category, and it includes only Level 15, 14 e-group members, and Level 12 VPs.

### 1B. Mid Level Officials and Managers

1B and 1C must include all managers, regardless if they are Professional or a Sales Worker, their management of direct report(s) is the defining characteristic for being in the category. This large group includes any level above the first level of managers (1C) and below the VP level (1A). This will include any Job Levels 9 Senior Manager, Level 10 Director, and Level 11 Senior Director with direct reports.

### 1C. First Level Officials and Managers

The first level of Management at GitLab, usually Job Level 7, 8, or 9 with a title starting with Manager, Associate Manager, or Lead with direct reports.

### 2A. Non-Technical Professionals

Occupations requiring either bachelor or graduate degrees or experience of such kind and amount as to provide a comparable background. These positions are ones which have more independent decision-making capacity, and require minimal supervision.

Non-technical individual contributor roles with Job Levels 5, 6, and 7 whose role does not deal primarily with creating, updating, and maintaining our GitLab product (all software, networking, & related systems). This would include the majority of the roles in Finance, and Legal, some Product and those that do not fall into 2E (Customer Support Professionals) or 2G (Sales, HR, and Marketing Professionals).

### 2B. Senior Non-Technical Professionals

Non-technical individual contributor roles with Job Levels 7, 8, 9, or 10 with Lead, Senior, Staff, Principal or Senior Principal in their title, that do not fall into 2F (Senior Customer Support Professionals) or 2H (Senior Sales, HR, and Marketing Professionals).

### 2C. Technical Professionals

Technical roles with Job Levels 5, 6, and 7. For our internal sub-categorization purposes, a technical role is one that deals primarily with creating, updating, and maintaining our product GitLab (all software, networking, & related systems). This would include the majority of the roles in the Engineering and Product. Marketing roles could be defined as Technical if their primary purpose is to work on the GitLab product itself.

### 2D. Senior Technical Professionals

Technical roles with Job Levels 7, 8, and 9 with Senior, Staff or Principal in their title.

### 2E. Customer Support Professionals

Technical and non-technical roles with Job Levels 4 to 6 with Customer Success or Customer Support-related roles.

### 2F. Senior Customer Support Professionals

Technical and non-technical roles with Job Levels 7, 8, and 9 with Senior, Staff or Principal in their title, with Customer Success or Customer Support-related roles.

### 2G. Sales, People, and Marketing Professionals

Non-technical roles with Job Levels 5 to 7 in the Sales, Marketing, or People Group Divisions.

### 2H. Senior Sales, People, and Marketing Professionals

Non-technical roles with Job Levels 7, 8, and 9 with (but not limited to) Senior, Staff or Principal in their title, in the Sales, Marketing, or People Group Divisions.

### 2I. Infrastructure and Development Professionals

Technical roles with Job Levels 4 to 6, within the Development and Infrastructure Departments in the Engineering Division.

### 2J. Senior Infrastructure and Development Professionals

Technical roles with Job Levels 7, 8, and 9 with Senior, Staff or Principal in their title, within the Development and Infrastructure Departments in the Engineering Division.

### 3A. Technicians

Occupations requiring applied scientific skills which can be obtained through post-high school education of varying lengths, as offered in many technical institutes and junior colleges, certification programs, or through equivalent on-the-job training. This category contains all level 4 technical interns and is named 3A internally, as the level 4 non-technical interns fall into the 5A. Administrative Support Workers category.

### 4A. Sales Professionals

Occupations engaging wholly or primarily in direct selling. **At least 50%+ of work time must be involved in sales to be classified in this category**. The 4A sub-category contains individual contributor roles with 50% or more of sales work time, at Job Levels 5, 6, and 7.

### 4B. Sales Account Management

Roles with 50% or more of sales work time, but more focused on account management, usually higher Job Levels 7 and 8.

### 5A. Administrative Support Workers

Administrative support positions have more clearly defined processes or procedures to follow to complete their job duties, that have more supervisor oversight, and are often non-exempt (but not always). The Admin Support Workers category at GitLab has the 5A - Admin Support Workers internal categorization label, and it includes all who fall into the category. They are levels 4, 5, or 6 across non-technical job families.

## What are our responsibilities?

We all share responsibility for maintaining compliance with equal opportunity and affirmative action laws. The People Compliance team has a responsibility for ensuring systems and procedures are in place to effectively implement our Affirmative Action plan.

Managers, leaders, and recruiting team members have responsibilities under our Affirmative Action plan. These include:

- Ensuring that all interviews and job offers adhere to company policy.
- Administering compensation in accordance with company policy.
- Providing necessary training to employees to enhance personal growth and promotion opportunities.
- Promoting and/or transferring employees in a non-discriminatory manner, awarding each available job to the most qualified candidate.
- Seeking and sharing information on accommodations that have been or could be made for persons with disabilities.
- Protecting applicants and employees from harassment, threats, coercion, intimidation, interference, or discrimination for filing a complaint, assisting in an investigation, or exercising their rights under equal opportunity and affirmative action regulations.
- Ensuring that company-sponsored events are inclusive.

Please note that managers, leaders, and recruiting team members have no metric-based action required regarding our specific AAP compliance goals. As a global company, GitLab strives to work on our global, company-wide hiring and diversity goals, and the US-specific data and success of AAP goals is tracked annually per US law.

If you have questions regarding our affirmative action efforts, the People Compliance Partner is available to assist you and may be reached at `people-connect@gitlab.com`.
