---
title: People Group Program Management
description: "This page provides an overview of Program Management positions within the People Group today, a list of key competencies, and links to templates and resources for reference."
---

## Overview

Program Managers keep our division aligned on what success looks like, how to measure it, and what steps are required to achieve our goals. Through effective management of programs and projects, this group keeps us on track, organized, and driving towards our most impactful business results. By staying closely connected, this function supports our ability to remain agile, iterative, and connected through cross-functional and team-specific projects.

We have various Program Management roles across GitLab. Within the People Group, Program Managers report directly to the team they support to ensure they are as close as possible to their core areas of responsibility, team, and focus.

The goals of this page are to:

- Generate more awareness around Program Manager roles in the People Group
- Create consistent Program Management practices within the People Group
- Drive further cross-departmental connection, alignment, and awareness
- Facilitate internal networking for learning and connection amongst individuals in these roles
- Provide a space for knowledge-sharing and learning

## Key Competencies

Regardless of the team, our Program Management key competencies are consistent to ensure the function at its core remains aligned. While the job families remain the [SSOT](/teamops/shared-reality/#single-source-of-truth-ssot) for roles across GitLab, a few key competencies and behaviors to expect from all Program Managers within the People Group are:

| Key Competency | Behavior |
| ------ | ------ |
| Subject matter expertise | Guides and oversees programs and projects within their functional area of expertise. |
| Effective communication | Provides regular project status updates to stakeholders through effective communication; maps team projects and the status of various projects for stakeholder visibility. |
| Growth mindset | Ensure we remain iterative and continue to grow and improve (e.g. facilitate retrospectives, and optimize where possible). |
| Change management | Supports change management when needed and can quickly facilitate or pivot changes in schedule or timeline. |
| Stakeholder management | Keeps project teams and stakeholders aligned and accountable for executing deliverables. |
| Strategic planning | Ensures work aligns with the division's and organization's overall goals. |
| Program management methodologies | Research, discovery, and documentation of current state processes and workflow. Creates and maintains the project plan in collaboration with team members and helps identify, mitigate, and escalate risks and issues. |

*Note: Company-wide competencies can be referenced [here](/handbook/competencies/) and company-wide job frameworks can be referenced [here](https://docs.google.com/spreadsheets/d/1FX4NBwF099uMBm7mGBtf1orIJZuHEjtiEa3jSbg9jJs/edit#gid=819074618). The competencies outlined above are intended to complement these existing artifacts, not replace them.*

## Roles

We have Program Management roles on several teams across the People Group.

While the core competencies remain across all of the roles, we have separate job families across functions to ensure that the niche experience or focus required to be successful in specific areas of our division is captured.

Role overviews, responsibilities, requirements, and performance indicators can be reviewed on the team-specific job family pages below.

- [People Operations Program Manager](/job-families/people-group/people-operations-program-manager/)
  - Key Ongoing Programs: Quarterly intake and program management of HR systems, tools, and technologies (i.e. Workday)
- [Global Workforce Strategy Program Manager](/job-families/people-group/global-workforce-strategy/#senior-global-workforce-strategy-program-manager)
  - Key Ongoing Programs: Own employment solution model across every country and PEO relationships
- [People Compliance Program Manager](/job-families/people-group/people-compliance/)
  - Key Ongoing Programs: Cross-functional programs that mitigate risk and drive success, People policy and labor-law related program iterations and implementations (US and EMEA)
- [Learning & Development Program Manager](/job-families/people-group/learning-development/)
  - Key Ongoing Programs: Growth & Development Fund, Elevate (Leadership Development experience), Mentorship Programs, etc.
- [Talent Acquisition Enablement Program Manager](/job-families/people-group/talent-acquisition-enablement-ops/)
  - Key Ongoing Programs: Talent Acquisition metrics and reporting, Interviewer training
  - Job Architecture: [Job Architecture for Talent Brand & Enablement Program Management job families](https://docs.google.com/spreadsheets/d/1kQPdeUEhIMoN0RtzcGlwf8jWCG2UzgDfKxBZmFhlMT4/edit#gid=1508763785)
- [Talent Brand Program Manager](/job-families/people-group/talent-brand-and-talent-acquisition-enablement/#talent-brand)
  - Key Ongoing Programs: Talent Attraction content, Careers platform management, Talent Brand Events
  - Job Architecture: [Job Architecture for Talent Brand & Enablement Program Management job families](https://docs.google.com/spreadsheets/d/1kQPdeUEhIMoN0RtzcGlwf8jWCG2UzgDfKxBZmFhlMT4/edit#gid=1508763785)
- [People Communications & Engagement Program Manager](/job-families/people-group/people-communications-engagement/)
  - Key Ongoing Programs: Onboarding, Engagement Survey, Values and DZ Awards
- [Benefits Program Manager](/job-families/people-group/total-rewards/#senior-benefits-program-manager)
  - Key Ongoing Programs: Benefits Renewals and Open Enrollments for Entities, PEO to Entity enablement; Benefits Communication Strategy and Execution
- [Compensation Program Manager](/job-families/people-group/total-rewards/#compensation-program-manager)
  - Key Ongoing Programs: ACR, Job Architecture and Comp Calculator maintenance, CLDC meetings; Bonus program management in partnership with Finance; equity program management in partnership with Stock Admin
- [People Business Partner Program Manager](/job-families/people-group/program-manager-people-business-partner/)
  - Key Ongoing Programs: Org design capability review, Realignments, Quarterly org health metrics, Division-specific programs that drive success

### Determining Drive

As our Program Management function in the People Group continues to expand, we anticipate that we will encounter situations where we have multiple Program Managers involved in the same programs or projects. When these situations arise, the Program Manager aligned to the team that is the project or program DRI will be the primary Program Manager and responsible for managing end-to-end program management. Other Program Managers should approach the program as a partner from the lens of the group they are aligned with, collaborating closely with the DRI Program Manager.

## Resources

An overview of People Group program management and touchpoints in place to stay connected.

- [Repository](https://drive.google.com/drive/folders/1cUD80mIIMRCNDkhPfDnDkB84tw4-KmId?role=writer) for Program Management planning resources and best practices
- Slack channel for Program Management Individual Contributors `#ppl_program_managers`
- Monthly meeting for Program Managers
