---
title: Promotions and Transfers
description: "Information and protocols related to GitLab promotions and transfers."
---

Developing talent internally is a key component of our success at GitLab, and our promotion and transfer process is built to support that development in alignment with our [values](/handbook/values/). Team members have two main avenues to pursue career advancement at GitLab: 1) Via our cyclical [promotion calibration process]({{< ref "promotions-transfers#calibration" >}}), and 2) by applying and interviewing for open positions.

We encourage team members to take control of their own career advancement, and are empowered to own their development.  Team members are encouraged to utilize the  [Individual Growth Plan]({{< ref "career-development#individual-growth-plan" >}}) as a tool to articulate and align with their manager on the skills they want to develop as they think about growing into a different or larger role.
This page captures information about transfers, promotions, realignments and career mobility.

## Definitions

### Internal Mobility

Internal mobility is the process by which team members move into open positions at GitLab. When a position is open and posted on the career site via Greenhouse, and then filled by a current GitLab team member, it is classified as 'internal mobility'. Similar to filling a role with an external candidate, internal team member candidates will also follow the same Greenhouse hiring steps and experience a full interview process to enable an informed hiring decision. All open positions should be posted to allow for equal opportunity for consideration.

The type of action resulting from receiving an offer for an open role following the Greenhouse hiring process will depend on the changes in level and job scope:

- If a team member applies for and accepts a position at the same grade, it will most likely be considered a [lateral transfer](#transfer-compensation-guidelines). In most cases, a lateral transfer will not result in a compensation increase, unless there is a significant difference in the compensation structure between the new and prior job families. When a team member moves to a new role, a review of the job level, family, and scope will determine if this is indeed a lateral move.
- If a team member applies for and accepts a position at a higher grade, it will most likely be considered a "promotion" and will result in a change in compensation and/or promotional stock grant. Some job families differ in their job grading and when a team member moves to a new job family, a review of the level and job scope will determine if this is indeed a promotion.
- If a team member applies for and accepts a position at a lower grade, it will most likely be considered a "demotion" and may or may not result in a change in compensation. Some job families differ in their job grading and when a team member moves to a new job family, a review of the level and job scope will determine if this is indeed a demotion.

Upon applying for a new role, it's recommended that team members understand the impact of the change based on their current job grade and family.

Note: If a team member wishes to move from an Individual Contributor to a Management position, the position must be posted and follow the normal hiring process steps to ensure all interested candidates have the chance to apply. This provides an equitable and transparent process for everyone.  

Internal mobility opportunities are dependent on [employee eligibility](/handbook/hiring/talent-acquisition-framework/internal-hiring-process/#team-member-responsibilities) and available open headcount.  

- Timelines
  - Based on an open requisition and [internal hiring process](/handbook/hiring/talent-acquisition-framework/internal-hiring-process/) via Greenhouse.
  - All positions must be open for a minimum of 5 calendar days.
  - At least 2 interviews must be completed before moving to an offer for a candidate internal or external.  
  - If there is a change in compensation, the start date should fall on the start of a pay period aligned with the team member's country. If the team is in a commissions role, the start date should always align with the first of the month.

**Job Detail Changes Due to Business Requirements or Reorganizations**

At times, the business may need to change job attributes such as the direct manager or department. These changes may be a result of consolidating teams, creating new departments, or moving team members to report to a new manager. These types of changes are specified as job attribute changes and don't meet the definition of internal mobility, and can be initiated by the current manager via Workday.  

#### Engineering Internal Mobility

For Engineering, please see [Engineering Mobility Principles](/handbook/engineering/careers/#mobility-principles) for additional guidelines and justification.

### Promotions

**In-Cycle Promotions:**  An in-cycle promotion is any individual that is within the same job family, and has a similar but increased job scope. A promotion is not necessarily defined with a new grade due to differences in job families. We would typically expect a team member to have been in position for at least twelve months prior to being promoted to the next level position within the same job family. This process does not require interview(s), does not create backfill headcount and occurs semi-annually through the calibrated promotion process or monthly for level 5 team members in the Sales Development job family. All in-cycle promotions are processed in **Workday and not in Greenhouse.**  

**Internal Mobility Promotions:**  Internal Mobility promotions occur when a team member applies for an open position and accepts a role at a higher grade/job responsibilities when compared to their current role.  

- In order for promotions through internal mobility to occur, approval from the skip-level leader is required.
- Additionally, the aligned People Business Partner should be consulted for alignment and visibility.

## Promotion Philosophy

Our promotion philosophy comprises core pillars surrounding the approach and process alignment to our values.

### Pillars

- Promotions are based on performance, not on growth potential. If being considered for an in-line promotion, Team members should already be executing at the next level [job frameworks level]({{< ref "structure#job-frameworks" >}}) prior to promotion. Team members would typically be eligible for promotion to the next level in the same job family after twelve months in their current position.
- Career growth should be a partnership between team member and manager. As a manager, it is important to create space to regularly discuss your team members' development and career aspirations, and identify opportunities to support them in their advancement and growth.
- When reviewing a proposed promotion, we consider: 1) readiness of the individual, and 2) business justification/opportunity.
- All in-line promotions at GitLab require a [promotion document](#promotion-document). We believe in [transparency](/handbook/values/#transparency) within the promotion process.
- We encourage team members to live our [efficiency value](/handbook/values/#efficiency), be a [manager of one](/handbook/values/#managers-of-one), and take ownership of their promotion document in partnership with their manager.
- We calibrate planned promotions on a twice per year basis to ensure an equitable review, and through this process track metrics that help us understand if our promotions are occurring at a healthy and fair rate.

### Values Alignment

Our promotion philosophy is also aligned with our [values](/handbook/values/):

- **Collaboration**: Cross-functional lens for feedback and calibration
- **Results**: Business justification, scope, and team member results are demonstrated and documented to support promotions
- **Efficiency**: Consistency and scalability in our promotion processes by twice per year planning and calibration. The planning and calibration timing considers existing programs and cycles for the business and aims to embed promotions into cadences where they best align for efficiency.
- **Diversity, Inclusion, and Belonging**: Fairness and equity reflected through a consistent approach and documentation to promotions at all levels in the organization and supported by our [job frameworks](/handbook/company/structure/) and Total Rewards [URG]({{< ref "review-cycle-inputs#underrepresented-group-audit" >}}) audit
- **Iteration**: Process is improved each cycle. In FY24, we moved to a twice per year. We continue to look at ways we can iterate on our process for efficiency and scalability.
- **Transparency**: Clarity and efficacy of promotion metrics, budget, and guidelines, in addition to transparency in promotion justification through internally public promotion documents.

### Processing a Promotion

Most promotions are processed through our twice per year Promotion Calibrations, with exceptions going through Greenhouse or Workday depending on whether or not the individual interviews and accepts a position filling an approved headcount. More info on these 3 methods for processing a promotion below.

## Twice per Year Promotion Calibration Process & Timeline

At GitLab, we promote on a twice per year basis. There are three core stages to the promotion process: Planning, Calibration, and Processing.

The Sales Development organization reviews In-Cycle Promotions on a monthly basis, due to the specific [promotion criteria](/handbook/marketing/sales-development/#sales-development-fy24-career-path) for each level within the job family structure. Planning, calibration and processing steps are aligned to the details below.

| Stage | Purpose |
| ---------- | ----- |
| [Planning]({{< ref "promotions-transfers#planning" >}}) | Managers and leaders to review their respective teams to determine promotion readiness, business need, and timeline for the upcoming quarters and project promotions. |
| [Calibration]({{< ref "promotions-transfers#calibration" >}}) | The calibration exercise is an opportunity for leaders (sync or async) to review projected promotions on a twice per year basis. This is an opportunity to create visibility and ensure consistency in who we are promoting and why. |
| [Processing]({{< ref "promotions-transfers#process-for-managers-requesting-a-promotion" >}}) | The final stage once promotions are defined, is to determine where to process the promotion to finalize (this will take place via Workday or Greenhouse). |

### Sales Development Process

Sales Development promotions will be reviewed on a monthly basis.

- Planning & Calibration: by the third week of each month
- Processing: promotions must be added to HRIS by the 5th day of each effective month
- Effective date for promotions: 20XX-11-01, 20XX-12-01, 20XX-01-01

### Twice Annual Process

Below is the timeline for FY26:
*Please note that the Calibration timeline for Senior Director+ promotions will differ slightly from the timelines indicated above, as Senior Director+ promotions are calibrated twice per year at the [E-group offsite]({{< ref "offsite#schedule" >}}).*

### FY26-Q1 (Feb 1)

*Status:* In Progress

- Planning: 2024-11-01 to 2024-12-01
- Calibrations: 2024-12-02 to 2025-01-03
- Workday input by Director+: 2025-01-09 to 2025-01-17
- PBP + E-Group Leader approvals: 2025-01-20 to 2025-01-21
- Workday Approvals: 2025-01-22 to 2025-01-24
- Team member individual communication: 2025-01-27 to 2025-01-31 (after fully approved in Workday)
- Effective date for promotions: 2025-02-01
- After communicating 1:1 with individuals on or after 2025-02-01, updates can be posted publicly in #team-member-updates. **Managers should not communicate until Total Rewards communicates that the promotions are fully approved.**

### FY26-Q4 (Nov 1)

Status: Pending  

- Planning:
- Calibrations & Workday input by Director+:
- PBP & E-Group leader approvals:
- Workday Approvals: 2
- Communication:
- Effective date for promotions: 2025-11-01
- After communicating 1:1 with individuals **on or after 2025-11-01**, updates can be posted publicly in #team-member-updates. Managers should *not* communicate until Total Rewards communicates that the promotions are approved.

### FY27-Q2 (May 1)

Status: Pending  

- Planning:
- Calibrations & Workday input by Director+:
- PBP & E-Group leader approvals:
- Workday Approvals: 2
- Communication:
- Effective date for promotions: 2026-05-01
- After communicating 1:1 with individuals **on or after 2026-05-01**, updates can be posted publicly in #team-member-updates. Managers should *not* communicate until Total Rewards communicates that the promotions are approved.

### FY27-Q4 (Nov 1)

Status: Pending  

- Planning:
- Calibrations & Workday input by Director+:
- PBP & E-Group leader approvals:
- Workday Approvals: 2
- Communication:
- Effective date for promotions: 2026-11-01
- After communicating 1:1 with individuals **on or after 2026-11-01**, updates can be posted publicly in #team-member-updates. Managers should *not* communicate until Total Rewards communicates that the promotions are approved.

## Planning

FY26 Q1 Promotion **Planning** will be completed via spreadsheets to maintain confidentiality and enable collaboration across department leaders where appropriate. Prior to the Planning phase in the timeline above, People Business Partners will make sure the spreadsheets are up to date before going into the Calibration phase.

Once the Calibration phase by Division is complete, Directors and above will have the ability to enter promotion compensation recommendations into the [Workday planning grid](https://docs.google.com/document/d/1KwpFnZC5MFpCwS9ElqkSh0f1bdZ3l0Gp-B4lDdJwIg0/edit?usp=sharing). For specific Division calibration meeting timelines, please reach out to your People Business Partner.

### Promotion Document

The [promotion document](https://docs.google.com/document/d/1oXH9HzdO8gjqdeosstQRC1Mqt_5lCaN1U2kaF9Av-Ec/edit?usp=sharing) is required for all in-line promotions. **Promotion documents should not exceed three pages total.**

As the audience are other GitLab team members, the text should be written in third person using the team member's name and appropriate pronouns (he/she/they) to highlight the work and skills as evidence of the team member's suitability for the role. A [style guide](/handbook/people-group/promotion-document-style-guide/) is available to assist in crafting a compelling document. You can utilize a bullet format to ensure that you are capturing the relevant sections per [business result](/handbook.gitlab.com/handbook/people-group/promotions-transfers/#business-results) or a short paragraph.

In-line promotion documents should demonstrate values alignment, business need for the role, and team member readiness through delivery of impactful business results. The core sections in our promotion document are: Promotion Summary, Business Results/Impact, Values Alignment and Business Justification.

#### Promotion Summary

This section is a high-level summary (3-5 sentences) of achievements that demonstrate how the team member has the capability to perform at the next level.

#### Business Results

As our most important [value](/handbook/values/#hierarchy), results are at the core of everything we do.

Please list the 3 most impactful results (accomplishments, initiatives, or projects) that demonstrate the team member's performance at the next level aligned with our values and expectations in the [job framework](https://docs.google.com/spreadsheets/d/1A46wqVK0ZdhmN7HT7G3QrBbExJw6vZJrSCFIiFd9T7U/edit?gid=0#gid=0).

**Project impact on GitLab / Business Result**

**Project/accomplishment impact**

- Example: The creation of the Org Design Playbook outlines a repeatable process for any organizational change across the company. It creates a collaborative, team member oriented, communication centric, and results driven format that leaders and People Business Partners can leverage to execute and lead through change. This directly ties to building a high performance culture as a key resource for change management, execution, and stakeholder alignment.

**Business result**

- Example: Since the implementation of the Org Design Playbook we also implemented a scoring system that allows us to measure the success of the changes we execute. We have seen an increase in the overall average score since the playbook’s creation.

**Business relevance** refers to *why* the project/accomplishment is important to the company (I.E. related to an OKR? a key investment theme? etc.).

- Example: One of our FY25 Yearlies is related to driving a high performance culture. A key aspect of high performance culture is our ability to manage through change in an efficient and results-oriented way. Organizational design shifts and realignments can have an adverse impact on team member’s velocity in delivering results if we are not aligned on an efficient, thorough, and team member oriented approach to execution.

**Team member’s direct contribution**

- Example: Tanuki was the DRI for the global cross functional team, and established all change management communication for the project.

**How the team member exhibited CREDIT values in their work on this accomplishment.**

- Example: Tanuki demonstrated the Iteration value while delivering this result. They drove a subset of feature teams to commit on delivery timelines to enable GTM motions for the product launch while giving other teams flexibility to deliver iteratively.

We ask that the structure above be followed for business results consistently to ensure that we:

1. **Highlight impact**: Directly connect our accomplishments to business goals and ties impact and role in projects to next level performance expectations.
2. **Cross-functionally understandable**: The story-telling structure facilitates more cross-functional understanding of what the team member did, why it matters, and the impact it drove for the business.
3. **Add objectivity**: Adds objectivity through focus on the contribution, impact, and relevance, in a consistent format, decreasing opportunity for unconscious bias.

#### Business Justification

GitLab considers both individual readiness and business need when we think about promotions. Managers are responsible for completing the business justification section of the promotion document to include what justifies the need for the team members skills and work to be completed at the higher level. Possible business justifications typically include: more complex projects, additional scope of work required as the team scales, and/or additional responsibility due to XYZ business reason.

#### Values Alignment

Values are at the core of everything we do at GitLab. It is essential to tie team member achievements and initiatives back to the values they support. Every Value should be referenced in the promotion document *at least once* with an example of how the promotion candidate contribution to the business result align to the Value. Please provide a 1-2 sentence example for Values that were not referenced in the Business Results section which highlight further how the team member has exhibited CREDIT.

- Please review our guidance on [DIB behaviours](/handbook/values/#diversity-inclusion--belonging-competency) aligned to each job level which provides examples of how to demonstrate our [Diversity Inclusion & Belonging Value](/handbook/values/#diversity-inclusion)

#### Additional Tips

When creating promotion documents, remember:

- Promotions are based on performance, not growth potential.
- Promotion documents should not exceed 3 pages total.
- Please reference the [job frameworks]({{< ref "structure#job-frameworks" >}}) in the handbook for guidance pertaining to expectations at the various levels at GitLab. The job levels should help guide data chosen to be included in the promotion document, in addition to discussion during calibration sessions.
- Please be sure that the promotion document has "comment" access enabled to 'GitLab' to ensure the review and approval process is not delayed. Please delete the instructions associated with each section of the promotion document below before submitting the promotions.
- If you find yourself struggling to articulate your accomplishments, your manager can help support you and provide feedback. You can also consider reaching out to stakeholders for feedback, or meeting with a trusted colleague or mentor to brainstorm.
- It should not include Talent Assessment ratings, such as "Exceeding Performance", as these must remain confidential and only discussed in confidential settings such as [Promotion Calibration]({{< ref "promotions-transfers#calibration" >}}), talent assessment calibrations, and within reporting structures.

## Calibration

Each quarter, Department/Division Leadership and the aligned People Business Partner plan a calibration session to review projected promotions. The goal of these calibration sessions is to set a fair and consistent standard in the Department for promotions, to allow peer reviews, and provide an opportunity to ask questions. These sessions can be async or sync.

During calibration sessions, leaders should be prepared to discuss:

1. Core themes of the promotion document: Values alignment, business justification, business results.
1. Development areas: The promotion document outlines strengths, but we also want to highlight how we will support a team member's opportunity to develop at the next level.
1. Cross-functional feedback: As our business goals and initiatives become increasingly cross-functional, managers should have a picture of how their team member collaborates effectively within their immediate teams, and with their core cross-functional partners and stakeholders.
1. Performance against with the current and (some) next level expectations aligned with the [job framework]({{< ref "structure#job-frameworks" >}}).
1. [Competencies](/handbook/people-group/competencies/#list): Where available and applicable.
1. Most recent talent assessment (and any relevant changes since).

Calibration should be aligned to the following levels of leaders and people managers:

| Promotion Level | Level Calibrated |
| ---------- | ----- |
| Under Director level ([Job Grade]({{< ref "compensation-calculator#gitlab-job-grades" >}}) 5-9) | Calibrated at the Department level |
| Director level ([Job Grade]({{< ref "compensation-calculator#gitlab-job-grades" >}}) 10) | Calibrated at the Division level |
| Senior Director+ level ([Job Grade]({{< ref "compensation-calculator#gitlab-job-grades" >}}) 11-15) | Calibrated at the E-Group level |

Note that calibration structure may vary by division and department depending on size/scope/etc.

### Promotions to Senior Director+

Philosophically, all promotions at GitLab are approached in the same way, follow the same high level process (Planning, Calibration, Processing), and use the same promotion document template.

Promotions to Senior Director+ level ([job grade 11]({{< ref "compensation-calculator#gitlab-job-grades" >}}) and above) have the following differences:

1. **Planning**: Senior Director+ promotions need to be added to E-group's promotion project sheet at least two quarters ahead of the desired promotion quarter for visibility. For example, if I want to promote an individual effective in Q1 (February), then I need to have this team member added to E-group's projection sheet within Q3 (latest October). Please work with your aligned People Business Partner, who will ensure the promotion projection is added.
1. **Level Scoping**: We want to ensure rigor and consistency in our organization design principles and expectations for senior leadership roles. For Senior Director+ promotions, we utilize a scoping tool to evaluate the role (not the team member) for business need and alignment to the Job Frameworks.
1. **Cross Functional Feedback**: We require at least 3 examples of cross functional feedback when reviewing Senior Director+ promotions. This feedback will not be made public and will only be reviewed by the calibration committee, PBP, direct manager and team member.

- All three of the business results highlighted in the promotion document should have feedback provided from at least one cross functional team member.
- Feedback providers should have direct experience working with the team member on one or more of the business results highlighted in their promotion document as a project team member, DRI, or stakeholder.
- Feedback provider is not in the same reporting line as the manager (I.E. not team member’s manager, skip level, etc.)
- Feedback providers must be cross-functional. When determining the most appropriate team members to provide feedback, the core focus should be on who worked most closely with the promotion candidate on the business results highlighted in the promotion document.
- Feedback providers should be at or above the target promotion level. Feedback providers can be individual contributors or people managers at or above the target promotion level. The reason we require feedback providers to be at or above the target promotion level is to ensure they are able to speak to business results and collaboration in the context of next level expectations as team members who are already operating at the next level.
- Feedback will be captured in [this template](https://docs.google.com/document/d/12WRYWICcxwvyVP4L052v9ciSNIhUlRUKGkr1AKq89zY/edit?usp=sharing), separate from the Promotion Document and will be reviewed as part of the calibration discussion. Feedback will be summarized, and it is not required to provide specific names of the feedback providers.

**Feedback question guidance**:

1. Please provide feedback on X delivery of Y business results, and collaboration with you and/or your team.
1. Specifically highlight performance against the Job Frameworks, CREDIT Values and HPT Pillars

1. **Calibration**: All Senior Director level promotions are calibrated at the Divisional VP+ leadership level, as opposed to at the Department level. Vice President level promotions are calibrated at E-group. The calibration timeline will align to the timing of the [E-group offsite]({{< ref "offsite#schedule" >}}) or extended monthly meeting, and will thus differ from the Calibration timeline of the rest of the organization. All promotion documents, feedback summaries and scoping tools need to be completed and shared with the E-group for visibility and preparation at least *2 weeks before the off-site date*.

The only exception to this process is when there is an open budgeted and publicly advertised vacancy for a Director or above level role that an internal team member interviews for and is offered. If external candidates have been considered and interviewed, and the internal candidate earns the role through a standard hiring process (screening, full interview process) then the recruiter may make an offer to the candidate as soon as the offer is approved. There should be no difference in the timing or process of making and accepting an offer for open roles between internal and external candidates.

### Promotion Metrics

GitLab tracks the following promotion metrics in [Tableau](https://10az.online.tableau.com/#/site/gitlab/workbooks/2292010/views)

#### Internal Mobility

GitLab tracks Internal Mobility rate. Market data indicates a 15% rolling promotion rate as the guideline for what we should see on average across the company for promotions. This is a guideline, not a cap.

#### Average % Compensation Change

GitLab targets an average of [5-10% compensation change]({{< ref "promotions-transfers#recommending-a-compensation-increase" >}}) in general for promotions. This metric is in place to ensure we are consistent and equitable across the company when allocating promotion compensation raises to team members, in addition to ensuring competitive and meaningful promotion increases across the board.

### Budget Impact (see below)

FP&A tracks budget impact by Department/Division twice per year.

### Promotion Budget

Promotion budget is held at the division leader level and is scaled down to the director and above level for planning in Workday.

Please review the [Compensation Program Budget]({{< ref "compensation-review-cycle#compensation-program-budget" >}}) to understand how the promotion budget is allocated and the process to review potential tradeoffs if divisions/departments are over/under budget for any given quarter.

## Promotions Processed Outside of the Twice Per Year Promotion Calibration Process

Certain types of promotions can be handled outside of the Twice Per Year Promotion Calibration process:

1. Application to a new, approved headcount in Greenhouse:
    - Internal candidates go through an interview process as defined further in the Greenhouse Promotions/Transfers section.
1. Promotions stemming from individuals in [interim/acting roles]({{< ref "promotions-transfers#interim-and-acting-roles" >}}).
1. Exceptions that are outside of the twice per year process and not aligned with any of the types listed above.

### How to Process an Exception: Submitting an out-of-cycle Promotion request in Workday

For exceptional situations where a promotion is not handled through the twice per year promotion calibration process or via an open requisition in Greenhouse, managers can work with their People Business Partner to submit promotions through Workday. Managers should reach out to their PBP via email and  include a promotion document, justification for the exception,  and next level manager approval for any compensation increase recommendations above 10%. Once the People Business Partner approves an exception, the promotion can be processed and the People Business Partner can submit the promotion in Workday.  See the [Workday Guide](https://docs.google.com/document/d/1hpPikG0STncYKamaY8XlfMTwYdoszP-0Xogvpp5hyZ4/edit) for help with submitting the changes.

#### Exception Approvals

| Promotion Level | Approvals Required |
| ---------- | ----- |
| Under Director level ([Job Grade]({{< ref "compensation-calculator#gitlab-job-grades" >}}) 5-9) | 1) Direct Manager, 2) Department Head, 3) People Business Partner, 4) Total Rewards, 5) FP&A |
| Director+ level ([Job Grade]({{< ref "compensation-calculator#gitlab-job-grades" >}}) 10-15) | 1) Direct Manager, 2) Department Head, 3) People Business Partner, 4) Total Rewards, 5) FP&A, 6) **E-Group Leader** |

Approvals for the Director+ level off-cycle promotion exceptions require E-Group approval, and off-cycle promotions for levels under Director require approval through Department head.

Regardless of the promotion level, it is critical that leaders work with their People Business Partner, Total Rewards, and FP&A [as outlined]({{< ref "compensation-review-cycle#compensation-program-budget" >}}) to identify tradeoffs we can review to fund the promotion.

### FY25 CTO Organization Promotion Guidance

**Required Documentation**

In the CTO Organization, we will follow the company process for promotions and use the standard Promotion Document. We will require business justification to be filled out for every role, regardless of seniority. There is specific guidance that we'd like our managers to focus on when considering promotions in this fiscal year. Please see below. Please note, effective for the FY25 Q3 promotions, peer feedback is not required for promotion consideration. We may re-evaluate this component in the future.

#### CTO Timeline for FY25-Q3

- 2024-06-10 to 2024-06-21: Direct managers of promotion nominees complete the Promotion Document after discussing the individual's readiness with peers, stakeholders, and fellow team members. Completed documents are shared with Kristina Bullock and Jess Durbin by 2024-06-21 (End of Business Pacific time).
  - Please note: direct managers can start working on promotion documents prior to 2024-06-10. This is the start of the company-wide planning period.
- 2024-06-24 to 2024-07-10: Department level calibrations (facilitated by PBP) followed by a CTO Leaders Calibration.
- 2024-07-16 to 2024-08-01: Approved promotions are entered into Workday, Comp review is completed and final approvals are obtained.
- 2024-08-01: Promotions effective in Workday.

#### Context Setting for Managers

As a leader, if your team member's promotion is approved, you will need to reset expectations with the individual and will likely need to make changes to accommodate the growth in seniority of the team. Before you write up the rationale, thinking through what these changes will entail will help you prepare the best business justification. A positive result not only changes the expectations of the individual but also of the manager, current and future, for how work should get done.

#### Guiding Questions for FY25 Promotions

*Please refer to the [GitLab Job Frameworks](https://docs.google.com/spreadsheets/d/1A46wqVK0ZdhmN7HT7G3QrBbExJw6vZJrSCFIiFd9T7U/edit?gid=0#gid=0), [Engineering IC Career Matrix](/handbook/engineering/careers/matrix/) and the [Engineering Leadership Job Families](/job-families/engineering/development/management/) to view the team member's current responsibilities, and future expectations after the promotion.*

1. How will this team member's role change if the promotion is approved? What work will they stop doing in order to make room for their increased responsibilities? It is expected that this be included in the business justification and that these decisions are a benefit to the team, stage and company, depending on the level of the promotion.

    1. **Example:** Tanuki is ready to be a senior engineer. This is displayed by the fact that she streamlined her own work by developing an evaluative framework for adding telemetry and quality metrics that will identify regressions before they are put into production. This has improved the quality of her work, and now as a senior engineer she will lead the rest of the team to ensure they are setting the appropriate quality bar for all the team's feature before they are pushed to production. As a senior engineer she will continue to work across the team to incorporate this new evaluative framework in how the team will work. She has the opportunity to expand this across multiple teams but that will be part of her development plan for continued growth.

2. How will the team member work differently if the promotion is approved?

   1. **Example:** Tanuki currently receives their work items from the Quad, but in the new role Tanuki will be expected to work x-functionally to identify potential work that should be prioritized and incorporated into the planned milestones. Tanuki will be able to present the challenges and rationale for the work to be appropriately prioritized and will be able to execute quickly for GitLab to realize the benefit of this new work.

3. Have you considered how the team might function differently with this team member in a higher level role?

    1. **Additional Detail:** All promotions increase cost and expectations of a given team and/or project. How will you and the person ensure the return on this increased investment of the company in this person/team/project. Elaborating on the commitment and changes that will occur with a positive outcome will benefit the decision makers to have confidence that this promotion will produced improved outcomes for all parties.

4. Do I need this many "X" level (i.e. Senior Engineer)  team members in my current team state? Is there enough work at that level to be done?

### Security Promotion Process

Giving and receiving feedback is a critical part of building high performing teams. Feedback from team members on key business results achieved is an important data point to consider when assessing team member promotion readiness. In an effort to continue to foster a feedback culture within the Security division and ensure we are calibrating collaboration effectiveness through business results, starting in FY25 Q3 we embedded a formal feedback touchpoint into our promotion process for the division. **Please note that the feedback does not determine whether the team member is ready for promotion in isolation, but is rather a data point to consider throughout the promotion planning and calibration process.**

The steps below outline the process promotion candidates should follow to request feedback as part of our bi-annual promotion process, key due dates, and helpful resources for both promotion candidates and feedback providers to review.

1. Team members aligns with manager on promotion readiness and candidacy
    - Ahead of requesting feedback, team members should have a conversation on promotion readiness with their manager. If there is alignment on readiness for the upcoming promotion cycle between both manager and team member, the team member qualifies as a "promotion candidate". Managers should ensure that the CISO direct in their leadership chain is also aware and supportive of the promotion candidacy before kicking off the process. This also creates space for early feedback.
    - **Due date: 2024-10-31**
2. Team member completes their [promotion document](/handbook/people-group/promotions-transfers/#promotion-document)
    - The promotion document completion should be team member driven with manager support, review, and feedback. Ahead of requesting feedback, the promotion document should be complete, as it will serve as the baseline to provide feedback. Team members should ensure their manager has reviewed their promotion document and is aligned with the content ahead of requesting feedback.
    - **Due date: 2024-11-08**
3. Team member makes a copy of feedback form template
    - This [Google Form](https://docs.google.com/forms/d/1h-_ZOQS8Hug168P76qgdO5Coj2rfPceLHZ6xjjLPWjQ/edit) provides a template for promotion feedback collection across the Security division to ensure consistency in the format and questions to facilitate more consistent and equitable [calibration process](/handbook/people-group/promotions-transfers/#calibration). This process focuses specifically on feedback related to the business results section of the promotion document to ensure feedback is consistently tied back to key deliverables that demonstrate next level performance.
    - *Each promotion candidate should make a copy of this form to use to collect feedback from their respective feedback providers.*
4. Team member identifies stakeholders for feedback request
    - Team members should ideally select 3-4 distinct team members to provide feedback across the three business results highlighted in their [promotion documents](/handbook/people-group/promotions-transfers/#promotion-document), but are required to select *at least* 2 distinct team members to provide feedback. All three of the business results highlighted in the promotion document should have feedback provided from at least one feedback provider. Team members should review their proposed feedback providers with their manager before sending out the feedback form to ensure alignment.
    - Requirements for feedback providers are:
        - Feedback providers should have direct experience working with the team member on one or more of the [business results](/handbook/people-group/promotions-transfers/#business-results) highlighted in their [promotion document](/handbook/people-group/promotions-transfers/#promotion-document) as a project team member, DRI, or stakeholder.
        - Feedback provider is not in the same reporting line as the manager (I.E. not team member's manager, skip level, etc.)
        - Feedback providers can be cross-functional or within the division, with a mix of both being the preference and recommendation. The core focus when thinking through who the most appropriate team members to provide feedback are is to reflect on who worked most closely with the promotion candidate on the business results highlighted in the promotion document.
        - Feedback providers should be at or above the target promotion level (I.E. if a Security Engineer is targeting a Senior Security Engineer promotion, the feedback provider's level should be Senior Security Engineer or higher). Feedback providers can be individual contributors or people managers at or above the target promotion level. The reason we require feedback providers to be at or above the target promotion level is to ensure they are able to speak to business results and collaboration in the context of next level expectations as team members who are already operating at the next level.
    - You can reference our [job grades](/handbook/total-rewards/compensation/compensation-calculator/#job-grades) for a refresh on the people management and individual contributor corresponding job levels, [GitLab Job Frameworks](https://docs.google.com/spreadsheets/d/1A46wqVK0ZdhmN7HT7G3QrBbExJw6vZJrSCFIiFd9T7U/edit?gid=0#gid=0) for an overview of key differences by level company-wide, and our [job families](/job-families/security/) as a resource for Security-specific differences in expectations by level.
    - If you need assistance meeting these requirements for selecting feedback providers, please discuss with your manager for support.
    - **Due date: 2024-11-14**
5. Team member sends out feedback form copy to feedback providers
    - This references the form promotion candidates made a copy of in Step 3.
    - Team members can leverage this as a structure to include in the feedback request if helpful: *Hi [team member name], I am currently under consideration for a promotion to [next level job title]. I would really appreciate your feedback on our work together, specifically on results and our collaboration related to [name business result]. Please complete this feedback form by [insert due date]. You can read more about the feedback process [link this handbook section].*
    - For promotion candidates requesting feedback and for team members providing feedback, we recommend that you review our [Guidance on Feedback](/handbook/people-group/guidance-on-feedback/) ahead of the process kicking off. The [S-B-I model](/handbook/people-group/guidance-on-feedback/#s-b-i-model) can be a helpful framework in ensuring feedback is structured in a clear and digestible way.
    **Feedback will be ongoing from 2024-11-15 through 2024-11-29. If team members are prepared to send out the feedback form to stakeholders prior to 2024-11-11 they may do so. All feedback needs to be obtained by 2024-11-29.**
6. Team member and manager analyze feedback
    - Team member shares the feedback obtained with their manager and they discuss and analyze themes and trends
    - Team member and manager compile themes to share with CISO direct. Leverage [this template](https://docs.google.com/document/d/11w4fI2iJj0-GRgtQxRGgRMiUyt60Z1Xv1w19UkC2ubE/edit) for theme compilation and analysis to ensure consistency. Analysis should focus on key themes and feedback provided in the Google Form.
    - CISO direct has the opportunity to review, provide feedback, and ask any clarifying questions to ensure they are able to represent the feedback in the CISO directs [calibration session](/handbook/people-group/promotions-transfers/#calibration).
    - **Due date: 2024-12-06**
7. CISO direct adds feedback summary to calibration spreadsheet
    - CISO direct is responsible for adding the promotion feedback analysis compiled in Step 6 to the CISO directs promotion calibration spreadsheet to ensure visibility ahead of the calibration session. The spreadsheet is titled `Security Promotion Projections` for reference.
    - Add the complete [feedback analysis](https://docs.google.com/document/d/11w4fI2iJj0-GRgtQxRGgRMiUyt60Z1Xv1w19UkC2ubE/edit) for each promotion candidate to column J and ensure that the CISO, CISO directs, and the Security [People Business Partner](/handbook/people-group/people-business-partners/#people-business-partner-alignments) have access.
    - **Due date: 2024-12-11**
8. Calibration session occurs
    - Calibration is scheduled for the week of 2024-12-16 where CISO directs calibrate promotion candidates across the division.
    - CISO direct is responsible for following up with the promotion candidate's manager to provide feedback and key takeaways from the calibration session.
9. Managers communicate promotion status
    - Promotions are effective 2025-02-01 and the communication window is 2025-01-27 to 2025-01-31 aligned with the [company-wide timeline](/handbook/people-group/promotions-transfers/#fy26-q1-feb-1)
    - Managers will communicate successful or unsuccessful promotion with team members directly. For unsuccessful promotions, clear feedback should be provided to the team member.

#### Feedback Confidentiality

A goal through this process is to continue to facilitate opportunity to provide more regular and ongoing feedback and flex the feedback muscle as a division. We encourage team members to own the feedback that they provide to strengthen relationships, invest in each other's growth and development, and provide the opportunity for team members receiving the feedback to ask clarifying questions if needed.

The feedback form asks for feedback provider's information, so promotion candidates and their managers will have visibility into specifics of the feedback provided. At the CISO directs calibration session we will review themes in [this structure](https://docs.google.com/document/d/11w4fI2iJj0-GRgtQxRGgRMiUyt60Z1Xv1w19UkC2ubE/edit).

Feedback provided **will not** be shared outside of the promotion candidates' leadership chain, CISO directs group, and aligned [People Business Partner](/handbook/people-group/people-business-partners/#people-business-partner-alignments).

#### Resources

An overview of key resources highlighted above for the Security promotion feedback process. These are either resources that will be used during the process, or resources we recommend team members and feedback providers review ahead of kicking off the process.

- [GitLab Job Frameworks](https://docs.google.com/spreadsheets/d/1A46wqVK0ZdhmN7HT7G3QrBbExJw6vZJrSCFIiFd9T7U/edit?gid=0#gid=0)
- [Security job families](/job-families/security/)
- [Guidance on Feedback](/handbook/people-group/guidance-on-feedback/)
- [GitLab job grades](/handbook/total-rewards/compensation/compensation-calculator/#job-grades)
- [Business results](/handbook/people-group/promotions-transfers/#business-results)
- [Promotion document](https://docs.google.com/document/d/1nDkYGK2yhe8pD-lnMGmEF-Cf0IlGgVOznjXMq9FxGiQ/edit#heading=h.5ahg1o4v53q7)
- [Feedback Provider Google Form](https://docs.google.com/forms/d/1h-_ZOQS8Hug168P76qgdO5Coj2rfPceLHZ6xjjLPWjQ/edit)
- [Feedback analysis template](https://docs.google.com/document/d/11w4fI2iJj0-GRgtQxRGgRMiUyt60Z1Xv1w19UkC2ubE/edit)
<br></br>
<br></br>
<br></br>
<br></br>

## Hiring for VP+ Roles

In order to ensure a consistent level of review for both internal promotions and new leadership roles, any net new VP and above "To be Hired" roles will be reviewed and approved by e-group. Senior leaders should partner with their People Business Partner to create a justification document for their proposed role. The [justification document](https://docs.google.com/document/d/1feA04oVpXYa1QWAnQA0OB1zC_KuaDNDq97gtmEJMUIk/edit#heading=h.o7rctrz9uxl7) allows for e-group to better understand the business need for the role and how it will align within the organization.

This review is part of our organizational design discussions that occur during the e-group offsite.

Proposed roles can be reviewed as soon as the organization has visibility to the business need. However, if the need for a new VP+ role comes up outside of those organizational design discussions, it can be reviewed during the weekly e-group meeting to continue to ensure that we are agile and competitive in our hiring practices.

The [justification document](https://docs.google.com/document/d/1feA04oVpXYa1QWAnQA0OB1zC_KuaDNDq97gtmEJMUIk/edit#heading=h.o7rctrz9uxl7) needs to be used when:

1. We decide to backfill an existing role at a higher level (VP+)
1. We open a net new headcount for a VP+ role (that is was not accounted for in the current fiscal year headcount plan)

## Process for Managers: Requesting a Promotion

1. Determine whether the promotion change should be processed through the [twice per year promotion cycle]({{< ref "promotions-transfers#twice-per-year-promotion-calibration-process--timeline" >}}) or through [Greenhouse]({{< ref "promotions-transfers#promotions-processed-outside-of-the-bi-annual-promotion-calibration-process" >}})
1. If proceeding with the [twice per year promotion cycle]({{< ref "promotions-transfers#twice-per-year-promotion-calibration-process--timeline" >}}), work with your People Business Partner and Leadership to recommend the promotion ahead of the [planning process]({{< ref "promotions-transfers#planning" >}}) so the team member included in planning and calibrations. Ensure the [Promotion or Compensation Change Document](promotions-transfers#promotion-document) has been created at this time.
   - If the team member you are recommending a promotion for is director or above, please refer to the [promotions to director and above]({{< ref "promotions-transfers#promotions-to-director-and-above" >}}).
1. If the promotion/compensation change should be processed through Greenhouse, please follow the steps outlined in the [Greenhouse Promotions/Transfers Process section]({{< ref "promotions-transfers#greenhouse-promotions-transfer-process" >}}).
1. If the promotion is considered an exception, please follow the steps outlined in the [How to Process an Exception: Submitting an out-of-cycle Promotion request in Workday]({{< ref "promotions-transfers#how-to-process-an-exception-submitting-an-out-of-cycle-promotion-request-in-workday" >}}).

**Things to consider before you start the process:**

- There will be situations when a team member is ready to move to the next level through a promotion, however, due to the nature of the business, that particular role or next level may not be available. For example, the team member is ready for a Manager or Director role, however, the business does not have the need, budget or scope for an additional manager/director at that time. The position may or may not become available in the future.
- If the vacancy is being advertised via the [jobs page](https://about.gitlab.com/jobs/all-jobs/) the individual must submit an application for the role. Similarly, if there is no vacancy posting, one must be created and shared on the `#new-vacancies` Slack channel so that everyone has the opportunity to apply and be considered.

## Recommending a Compensation Increase

At GitLab, we ensure that promotions are impactful from the compensation perspective, stay within range of the compensation calculator, and are equitable to peers in the same role. Managers propose a recommended increase in cash compensation for their direct report using the compensation calculator.  If you have any questions feel free to reach out to your People Business Partner or the Total Rewards Team.

### Promotion Compensation Guidelines

- When a team member is promoted from one level to the next in the same job family, it is typical to be brought between the minimum and median of the compensation range.
- The Total Rewards Team typically recommends a 5%-10% increase as part of the promotion to cash compensation. Additional equity is fixed based on [equity for promotions](/handbook/total-rewards/stock-options/#promotions).
  - Benchmarking data relays that typically [4-8% of your population will be promoted](https://www.shrm.org/content/dam/en/shrm/research/benchmarking/Human%20Capital%20Report-TOTAL.pdf) annually with an average of a [4.1% increase to base salary](https://worldatwork.org/media/CDN/dist/CDN2/documents/pdf/resources/sbs/SBS2022-23_TopLevelData.pdf).
- Any promotions with the following conditions will require additional justification to the Total Rewards team and executive approver. Please add the business justification as a comment in the promotion worksheet.
    1. An increase of more than 10%
    1. The promotion exceeds the range in the compensation calculator.

### Transfer Compensation Guidelines

When reviewing compensation for a transfer in Greenhouse, the Total Rewards team will ensure internal equity among like roles ahead of approving the offer details using the following general guidelines:

1. **Lateral Transfer (different or same job family, same grade)**: Typically we expect a team member to receive no increase for a lateral transfer.  This includes team members receiving a change in territory, segment, or specialty with no change in grade or job level.
1. **Promotional Transfer (different or same job family, higher grade)**: Typically we expect team members to receive a 5-10% increase (aligned to the promotional expected increase).
1. **Other Transfer types**: There are other transfers that can be reviewed on a case by case basis. For example, if someone is transferring to a lower grade in a different or same job family, compensation may be adjusted down to ensure alignment to market rates for the role. Please tag the Total Rewards team in Greenhouse to conduct a review.

## Workday Out-of-Cycle Promotion Approval Process

This section describes the approval chain after the People Business Partner submits a promotion request in Workday.

1. The changes will route for approval to the manager, next level manager, and e-Group leader.
1. If the request is approved, the People Connect Team will stage the [Job Change Letter]({{< ref "promotions-transfers#job-change-letter" >}}) in DocuSign.
1. DocuSign will prompt the manager to discuss the promotion with the team member. The Manager will communicate the change to the team member in their `1-1 meeting by sharing the job change letter on the call`. The Manager and the team member will process/sign the letter. Following the signatures, the manager will announce the promotion on the slack `#team-member-updates` channel. In the announcement the manager will describe how the individual met the promotion criteria and offer congratulations.
1. For change of departments and managers, People Connect Team members will create a Career Mobility Issue.

### For People Connect Team: Processing Promotions, Internal Transfers & Compensation Changes

1. If the request is approved through Workday, the People Connect Team will create the [Job Change Letter]({{< ref "promotions-transfers#job-change-letter" >}}), whereas if the request is through Greenhouse the `People Connect Team will be notified via the People Connect team email` inbox that the [Job Change Letter](/handbook/hiring/talent-acquisition-framework/ces-contract-processes/#job-change-letter) has been created by the CES team and signed.

#### Job Change Letter

1. For [GitLab entities](/handbook/people-group/employment-solutions/#gitlab-entities) and [Independent Contractors](/handbook/people-group/employment-solutions/#team-members-hired-as-contractors-via-our-gitlab-it-bv-entity) a job change letter may be required, as per the steps mentioned below. If the team member is employed by a PEO, notify the applicable [PEO](/handbook/people-group/employment-solutions/#peo-professional-employer-organization-employer-of-record-and-not-a-gitlab-entity) either by email or for remote.com via their dashboard. See the People Connect 1password vault for contact details.
1. Review the [Signature requirements per country](https://docs.google.com/spreadsheets/d/1soc-j0Z_UUqHX8X04zJUzBrDv0I1SNCjkbO8-OTZQ24/edit?usp=sharing) and process the job change letter accordingly. Please note not all entities and country locations require Job Change Letters (for example team members in the US will not receive a Job Change Letter).
1. Make a copy of the applicable Job Change Letter template and enter all applicable information based on the Workday request and add the applicable [Signatory](/handbook/hiring/talent-acquisition-framework/ces-contract-processes/#entity-contract-signatories) or [Company Signature Stamp](https://docs.google.com/document/d/1RWkI7zuFIUkW_sh1TmYii6e8zNOmz9USUoEr1wBIBpQ/edit?usp=sharing). The effective date is as follows:
    - For sales personnel with a variable change, the effective date is always the 1st of the month regardless of their entity.
    - If the team member is making a lateral move where there is no change in compensation, then the start date can be any Monday.
    - For US team members, the effective date should be either the 1st or the 16th. If the [payroll cut off date](/handbook/finance/payroll/#payroll-cut-off-date) has passed for the current pay period, the effective date should be made for the start of the next pay period. The GitLab Inc and Federal Payroll calendar should be referenced when determining the effective date.
    - For example, if the change is being processed on June 22, since this date is before the payroll cut off date of June 23, the effective date should be June 16.
    - If the change instead is being processed on June 25, the effective date should be July 1 since this is after the payroll cut off date.
    - For Canada team members, the effective should be the start of the pay period closest to, but not after the [payroll cut off date](/handbook/finance/payroll/#payroll-cut-off-date) depending on when the change is processed. The GitLab Canada Corp Payroll calendar should be referenced when determining the effective date.
    - For example, if the change is being processed on June 15, since the payroll cut off date of June 6 has passed, this would go to the next pay period with a cut off date of June 20. The corresponding start of the pay period for the June 20 cut off date is June 21 so June 21 should be the effective date.
    - For all other changes, the effective date should be the first of the current month if processed on or before the 8th of the month and the first of the next month if processed after the 8th of the month.
    - For example, if a GitLab Ltd team member has a change being processed on June 7, this would be effective June 1.
    - If the change was instead being processed on June 15, this would be effective July 1.
1. If the team member is employed in France please share the Job Change Letter with the Legal Employment team so they can confirm the classification in the letter.
1. If only the company stamp is required the letter should get emailed to the team member's manager to communicate the change
1. If e-signatures are required stage the letter in DocuSign and add the following team members to sign via their GitLab email addresses:
    - Add radio button (Delete the additional one) for the Manager to communicate the change to the team member by sharing the job change letter during the 1:1 Zoom call and then again add one radio button to (Delete the additional one) announce on the `#team-member-updates` Slack channel.
    - Add signature field for the team member
    - Add sign date field for the team member
    - **Note:** Make sure that **a)** "Set signing order" option has been selected while preparing the doc, and **b)** Select radio button instead of checkboxes as only radio button allows you to select the required field/mandatory field option. This prohibits the Manager to process the letter without checking the tasks on the letters.
1. Save the signed letter to the respective team members [Documents Tab](https://docs.google.com/document/d/1ao_d_JxvqvZdqxlt4mBoHe1GcAhYT7B6YQoBgDxPdRE/edit) within their Workday Profile.
1. If the [here mentioned criteria](/handbook/people-group/promotions-transfers/#career-mobility-issue) for a Career Mobility Issue is met the People Connect Specialists will receive an alert from Workday and ensure that an [issue is opened](/handbook/people-group/promotions-transfers/#career-mobility-issue-creation-process) for the transitioning team member.

## Interim and Acting Roles

### Interim

As part of the career development structure within the Engineering division, interim and acting role opportunities occasionally arise. For more information on how interim and acting roles fit into Engineering career development, please reference the [Engineering career development handbook page](/handbook/engineering/careers/). For information on the interim and acting processes, please continue reading below.

#### Beginning Interim Period

As highlighted in the Definition section, all interim roles (regardless of the number of applicants) should go through the Greenhouse application and interview process. The interview process steps will be determined by the hiring manager and next level leader. This will contain several steps of the standard [GitLab hiring process](/handbook/hiring/). The process for team members interested in applying for an interim role is as follows:

1. *Team Member*: Apply for the interim position in Greenhouse.

*Once a team member successfully completes the interview process and is selected for the interim period, the following steps should be taken to ensure the team member is set up for success in their interim role.*

1. *CES*: Issue a [Job Change Letter](/handbook/hiring/talent-acquisition-framework/ces-contract-processes/#job-change-letter) to finalize the beginning of the interim period. The Letter should include: interim job title, start date, and end date (if known). Job Change letters are important as this is the process by which Total Rewards is notified of change from Greenhouse.
1. *People Connect*: Update the team member's job and business titles in Workday to reflect that they have started an interim role e.g. `Senior Manager, Engineering (Interim)`. This update serves as the SSOT for tracking interim start and end dates, in addition to providing transparency pertaining to who is currently executing in an interim role. Job code and job grade will remain the same, as interim periods have no impact on compensation i.e. do not update any other fields when initiating the [Change Job Process](https://docs.google.com/document/d/1hpPikG0STncYKamaY8XlfMTwYdoszP-0Xogvpp5hyZ4/edit).
1. *Current Manager*: In the instance that there are direct reports that need to be moved to an Interim Manager this change needs to be initiated by the Current Manager or where necessary the People Business Partner for the respective group in Workday by following the [Change Manager Process](https://docs.google.com/document/d/1JEobACNSMeHU4pU5DaaF7aqmv9wmSDoXx7veZ6_SM_I/edit).  The philosophy here is that if a team member has successfully gone through the interview process and has demonstrated they are ready/able for an interim period in a manager role, they have the required level of EQ and discretion to have direct reports in Workday. It is, of course, expected that should the interim period not end in promotion, the team member continue to treat confidential information confidentially.

#### Ending Interim Period

When the interim period comes to a close, one of two outcomes can occur:

- The team member successfully completes the interim period aligned with [the success criteria](/handbook/engineering/careers/#interim-manager) and moves into the interim role permanently.
  - As a general guideline, the interim period should last no *less* than 30 days, and no *more* than 4 months .
  - The People Business Partner should submit the promotion request through Workday using the [Change Job](https://docs.google.com/document/d/1hpPikG0STncYKamaY8XlfMTwYdoszP-0Xogvpp5hyZ4/edit) job aid including the promotion document to make the change official. In Workday, the reason for the change should be `Promotion - Promotion`. The accomplishments leading up to the interim and during the interim can be used for the promotion document. The manager is responsible for creating the promotion document and [recommending a compensation increase]({{< ref "promotions-transfers#recommending-a-compensation-increase" >}}). *Note: Promotion documents are only required if the team member's move results in a promotion. For lateral moves, we do not require promotion documents.*
- The team member does not complete the interim period successfully or decides that the manager track is not something they want to pursue, and moves back to their role prior to the interim period.
  - A feedback session between the team member and hiring manager should take place, so it is clear to the team member why the interim period was not successful.
  - The People Business Partner at the request of the Manager should submit a [Workday Change Job Process and Approval Flow](https://docs.google.com/document/d/1hpPikG0STncYKamaY8XlfMTwYdoszP-0Xogvpp5hyZ4/edit) in Workday to revert the team member's job title once the interim period comes to an end.
  - Not successfully completing the interim period *does not* mean the team member can not move into a similar role in the future

Regardless of the outcome, when the interim period ends, the manager should review the [Criteria For Eligibility]({{< ref "compensation#criteria-for-eligibility" >}}) for the [Interim Bonus]({{< ref "compensation#calculation-of-interim-bonus" >}}) and [submit an interim bonus request]({{< ref "compensation#submitting" >}}) for the team member. Please ensure that the full bonus calculation is laid out in a comment of the bonus submission.

#### Updating Interim Movements in Workday

If you receive a [Job Change letter](/handbook/people-group/contracts-probation-periods/#job-change-letter) to an interim role, process the change by:

1. Saving the letter to `Documents` > `Contracts & Changes` Document Category in Workday
1. Review for compensation change
1. Access Level
    - Interim roles - Access changed (if required)
1. Update Job title (if required)
1. Update Manager (if required)

Note: There are no changes that are made in Workday for acting roles. To track acting positions, managers should complete this [form](https://forms.gle/KdB4TBtfuHxgGLzE8).

### Acting

A person "acting" in the role is someone who occupies a role temporarily and will move back to their original role. "Acting" in a role may be to experiment with the role to determine if it fits an individual's career development path goals, or may be filling in for a vacant role while we hire someone to fill the role permanently. While interim is only applicable to the Engineering division, acting is used across GitLab.

*Interviews are not required for Acting roles as they generally do not end in promotion, nor are direct reports in Workday generally moved to Acting managers.* The process for selecting someone for an acting position is:

- Upcoming Acting roles will be discussed during staff meetings.
- Leadership can gather interest from their team members for the upcoming acting roles.
- The hiring manager will determine the most suitable team member for the acting role.
- *Please make sure that the department head is in the loop and supportive of the acting period and candidate selected before moving forward.*

*When the acting period ends, the manager should review the [Criteria For Eligibility]({{< ref "compensation#criteria-for-eligibility" >}}) for the [Interim Bonus]({{< ref "compensation#calculation-of-interim-bonus" >}}) and [submit an interim bonus request]({{< ref "compensation#submitting" >}}) for the team member.*

### Acting Roles and Internal Mobility

In the event that a team member is working in an acting capacity in a role that then becomes an officially open position, the team member in the informal acting capacity may be considered for the open role along with other candidates. If the team member demonstrates interest in making the acting position permanent, the following process should be followed:

1. Team member expresses interest to their manager in pursuing the position on a permanent basis.
1. Team member reaches out to the Hiring Manager to receive feedback on their performance in the role thus far in the acting capacity.
1. Team member is welcome to apply for the position in Greenhouse aligned with our standard hiring practices.
  **Note:** If the Hiring Manager and acting team member mutually agree to move forward with consideration for the role, the position is at the same or lower [job grade](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades) as their current role, the position is within the same division, and the position is not a people management position, a formal interview process may not be required. If the Hiring Manager prefers to not include an interview process, they must connect with their aligned People Business Partner (PBP) to ensure they are supportive. This interview exception possibility exists due to the unique experience team members in acting positions have to demonstrate their ability to be successful in the position over time.
1. After the team member officially moves into the open role, a backfill position will be created.

## Demotions

Demotions are not always considered a step backwards.  It may be an opportunity for a team member to acquire new skills or to move to a role that more closely aligns with their area of interest. To demote one of your direct reports, a manager should follow the following steps:

- If the demotion is due to performance, the manager should discuss any performance issues or possible demotions with Team Member Relations.
- Demotions should also include a review of [compensation]({{< ref "compensation" >}}) and [equity](/handbook/total-rewards/stock-options/#equity-incentive-plans) in the google doc. Managers should consult with Total Rewards team on these topics; and of course always adhere to the Global Compensation Calculator.
- Once agreement is reached on the demotion and changes (if any) in Team will act as the point of escalation to have any demotion reviewed and approved by the Compensation Group once the relevant google doc is complete.
- Once approved, the manager informs the individual and should request the necessary changes by submitting a [request via HelpLab](https://helplab.gitlab.systems/esc?id=emp_taxonomy_topic&topic_id=c15e3b45478c069067429ee0026d43e1). A [Job Change Letter](https://docs.google.com/document/d/12AscsmP3qnTqCC9h6cx1UpIVrnZUfoN6AvfMjf8guyg/editm) will then be created.
- The People Connect team should then follow the process listed under the [For People Connect Team: Processing Promotions & Compensation Changes]({{< ref "promotions-transfers#for-people-connect-team-processing-promotions--compensation-changes" >}}).
- Communication should be on a need-to-know basis only and should not be made public out of respect for the individual.
- The manager will initiate any necessary access requests or access change requests.

## Job Title Specialty Changes

Job title specialties are used to indicate a stage, group and/or a specific focus area of the team member within their responsibilities. These specialties are not part of the job title, but are used to feed into reporting around stage, group and/or focus area investments. It is also a resource for the People Group and leaders to leverage to review organizational health metrics and ratios.

**If any changes are required to a team members Job Title Speciality, the manager should create a [HelpLab](https://helplab.gitlab.systems/esc?id=emp_taxonomy_topic&topic_id=6de369b997804e50a326158de053af7b) case for the People Connect team with the new job title specialty information along with the effective date of the change. If a new Job Title Specialty that does not already exist needs to be created, please open an [issue](https://gitlab.com/gitlab-com/people-group/people-tools-technology/general/-/issues/new#) to get it created in Workday using the `Workday: Job Title Specialty Request` template. It is an important manager responsibility to ensure this field remains accurate in Workday.**

### Job Title Specialty Guidance For Managers

Different departments at GitLab manage job title specialties in different ways. Below, we have outlined guidance for certain departments to document how they think through job title specialties to ensure a consistent approach.

To easily access a report for what current job title specialties are for your team, you can follow these steps:

- Log into Workday
- Type "My Team Job Title Specialties" in the search bar
- Click "OK" for your organization

#### For Development, Infrastructure, and Quality departments

- Who should have a specialty:
  - ICs: Job grade 11 and below should have Stage and/or primary group (if applicable)
  - People Mgrs: Managers, Senior Engineering Managers, and Group Product Managers managing ICs should have Stage and/or primary group (if applicable)
- When requesting a job title specialty update, please follow the following formatting:
  - Review Product/Categories and make sure the group names you use match these. If they don't, please connect with your Product Manager to confirm and work with them to update if needed.
  - Add both stage and group in the job title specialty field
    - Example:  Add "Govern: Authentication" instead of "Authentication"
    - **Important: Please ensure that you leave a space after the colon (:) between stage and group.**. For example, `Create: Source Code` is *correct* formatting, and `Create:Source Code` is *incorrect* formatting. This helps ensure that when pulling reports we have accurate counts for investment alignment.
  - Review each person and make sure it only lists one group.
    - Note: In situations where there are two groups, pick the primary group.
  - Ensure all specialty information is in the `Job Title Specialty` field as opposed to the `Job Title Specialty (Multi-Select)` field.

#### For Customer Support department

- Who should have a specialty:
  - ICs: Job Grade 9 and below to indicate the focus of the role being Global, Federal or Readiness (if applicable)
  - People Managers: Managers and Senior Managers to indicate the primary focus of their role (if applicable).

Note: For Support it's not tied to stage, group but rather the focus of the role that is not captured in the Job title.

- When requesting a job title specialty update, please make sure to use any of the below focus areas when reaching out to People Connect:
  - Global
  - Federal
  - Readiness

## Manager Self-Service in Workday: Job Information Change

Job information changes are used to update any information on the team member's profile in Workday that is not compensation related.   The current manager submits all job information change requests (including requests to change team member's manager). These changes are required through Workday to have an approval trail for compliance reasons.

### For Current Manager: Processing Manager Changes

[This job aid](https://docs.google.com/document/d/1JEobACNSMeHU4pU5DaaF7aqmv9wmSDoXx7veZ6_SM_I/edit?usp=sharing) will help provide people managers with instructions on how to move team members to another manager within Workday. If the manager you need to move your direct report to is not available, it likely means they do not have a “supervisory organization” created.  Even if their management level shows “Manager” a supervisory organization is needed in Workday for a team member to have a direct report. Supervisory organizations should have a name unique to the team they are managing (e.g. Commercial Sales - EMEA, Content Marketing (John Smith), Backend Engineering - Ruby). Please reach out to the People Connect team via [HelpLab](https://helplab.gitlab.systems/esc?id=emp_taxonomy_topic&topic_id=14aff309478c069067429ee0026d4372) with the name of the team member who needs the supervisory organization set up, the unique name, and the effective date of the supervisory organization. We can gladly help set it up in Workday.

Note for Sales Managers: If team members are not moved under the correct sales manager in Workday, credits will not be rolled-up to the correct manager for sales commissions. See additional promotion and transfer considerations for commissionable roles [here]({{< ref "promotions-transfers#promotions-and-transfers-of-employees-in-commissionable-roles" >}}).

### For People Connect: Processing Manager changes

1. The People Connect Specialist logs into Workday via Okta to approve the transfer in Workday > click on Inbox in top right corner
1. Review the business process titled 'Transfer' and reason 'Manager to Another Manager' > click: approve

**Process for EBA to update senior leadership:**

1. Create a case in [HelpLab](https://helplab.gitlab.systems/esc?id=emp_taxonomy_topic&topic_id=c15e3b45478c069067429ee0026d43e1) for the People Connect team requesting the changes to be made in Workday and provide an effective date.
1. The People Connect Team will process the changes in Workday.
1. Once complete, the team will follow-up with the EBA to let them know all changes have been made.
1. The EBA will then need to make the changes on the Team Page.

### For People Connect: Processing Job Information Change Requests

1. Audit all job change requests and ensure the changes are captured in the Payroll tracker.
1. In case of `Job Title Specialty` change requests, managers will reach out to the People Connect Team [HelpLab](https://helplab.gitlab.systems/esc?id=emp_taxonomy_topic&topic_id=14aff309478c069067429ee0026d4372) to have a team members `Speciality` updated in Workday.
    - The People Connect Team member should check whether the title already exists in Workday. If not, check whether the `Job Speciality` has been added to the respective departments Handbook page (example: [https://handbook.gitlab.com/handbook/engineering/development/enablement/data_stores/search/](/handbook/engineering/development/enablement/data_stores/search/)) or if the People Connect Team members are tagged in a respective issue to have it added. If unclear, reach out to the [respective People Business Partner](/handbook/people-group/people-business-partners/#people-business-partner-alignments)

## Department Transfers

If you are interested in applying for an open role, please do so  through [Greenhouse](https://boards.greenhouse.io/gitlab) or the internal job board, link found on the `#new-vacancies` Slack channel.

Please understand the following eligibility guidelines that need to be met to be able to proceed with your application:

- Guidelines for performance eligibility:
  - Team members who are assessed at a Performing or Exceeding Performance level during Talent Assessment are eligible to be considered for another role
  - Team members whose Performance is assessed as Developing or are actively undergoing written performance management, may not be eligible. These situations require manager and/or PBP approval to proceed.
  - Team members that have not had a Talent Assessment require manager and/or PBP approval to proceed
  - Time in role eligibility will be 6 months in current role. Exceptions to this:
  - Business Impact  (revenue-dependencies, interim role to perm)
  - Business driven transfers (example of realignments)
  - SDR/BDR 12 months in role

**Please note that internal applicants are required to speak with their current manager or People Business Partner prior to application submission. An official application is signaled by a team member applying to the open role or reaching out to the talent acquisition team. Informal conversations about the role do not require a team member to inform their manager. If you have concerns about communicating your interest in an internal role to your manager, please reach out to your People Business Partner.**

For more information please visit our [Internal Hiring Process](/handbook/hiring/talent-acquisition-framework/internal-hiring-process/) handbook page.

### For Internal Applicants

#### Different Job Family

- If you are interested in transferring, simply submit an application for the new position. If you are not sure the new role is a good fit, schedule time with the hiring manager to learn more about the role and the skills needed. If after that conversation you are interested in pursuing the internal opportunity, it is recommended that you inform your current manager of your intent to apply for the role. While you do not need their permission to apply, we encourage you to be transparent with them. Most will appreciate that transparency since it's generally better than learning about your move from someone reaching out to them as a reference check. You can also use this as an opportunity to discuss the feedback that would be given to the potential new manager regarding your performance from your current and/or past managers.
- Transfers must go through the application process for the new position by applying on the [jobs page](https://gitlab.greenhouse.io/internal_job_board). The team member may go through the entire interview process outlined on the vacancy description. Common exceptions to the standard interview process are behavioral or "values alignment" stages. The Recruiter will document the reason behind alterations to the standard interview plan in the team member's Greenhouse profile.  If you have any questions about the role or the process, please reach out to your Department or Division's [People Business Partner](/handbook/people-group#people-business-partner-alignment-to-division) and/or please visit our [Internal Hiring Process](/handbook/hiring/talent-acquisition-framework/internal-hiring-process/) handbook page. In all cases, the applicable People Business Partner should be informed via email, before a transfer is confirmed.
- In the case of transfers, it is expected and required that the gaining manager will check with internal references at GitLab limited to the previous and current managers; please do not conduct internal reference checks with peers or direct reports. For questions or exceptions, please engage your recruiter and people business partner.
- It is recommended (but not required) that the applicant, current manager, or gaining manager create a private Slack channel to help coordinate the transfer. Invite anyone who will be involved such as the relevant managers, directors, people business partners, finance business partners, and recruiters.
- If the current manager needs to backfill the role in Engineering they should follow [this process](/handbook/engineering/#rd-new-headcount-ghpid-request-backfill--transfer-process). For other divisions they should work with their department leader, recruiter, and the Finance Business Partner to confirm that a backfill is available. When the transfer is confirmed, the current manager should work with recruiter and Finance Partner to obtain a [GHP ID](/handbook/finance/financial-planning-and-analysis/#headcount-and-the-talent-acquisition-single-source-of-truth) for the backfill and open the role in Greenhouse.
- Before the offer is made the recruiter will confirm with the team member and the gaining manager that they have indeed reached out to the current manager. They will discuss the new opportunity and that an offer will be made to the team member.
- Talent Acquisition team will ensure that, if applicable, the position has been posted for at least three business days before an offer is made.
- [Compensation]({{< ref "compensation" >}}) and [equity](/handbook/total-rewards/stock-options/#equity-incentive-plans) may be reviewed during the hiring process to reflect the new level and position.
- If after interviews, the manager and the GitLab team member want to proceed with the transfer, internal references should be checked. While a manager cannot block a transfer, there is often good feedback that can help inform the decision. It is advised that the GitLab team member talk to their manager to explain their preference for the new team and to understand the feedback that will be given to the new manager. It should also be noted, that performance requirements are not always equal across roles, so if a GitLab team member struggles in one role, those weakness may not be as pronounced in the new role, and vice versa.
- The Recruiter and Hiring Manager will review the offer details with the internal candidate and a [Job Change Letter]({{< ref "promotions-transfers#job-change-letter" >}}) will be sent out by the Total Rewards team following the hiring process
- If the team member is transferred, the new manager will announce in the `#team-member-updates` Slack Channel and begin any additional onboarding or offboarding necessary. Before the new manager makes the transfer announcement they must confirm with the team members current manager that the current team has been informed about the team members new position and transfer.
- Team members changing functional roles should complete onboarding for the new function. For example, a Backend Engineer who transferring to become or work on Frontend work should do Frontend Engineer onboarding.

#### Same Job Family, Different Department or Specialty

If the team member is staying in the current Job Family, but changing their Specialty or Department (ex: moving from Plan to Secure or moving from Development to Infrastructure), the above steps will be followed. The recruitment procedure might be shortened if the requirements for the role are the same. At a minimum we ask that the hiring manager interview the team member.

If selected for the role, a [Job Change Letter]({{< ref "promotions-transfers#job-change-letter" >}}) will be sent by the People Connect Team outlining the changes to department and specialty for the People Connect team to process in Workday. If the current manager needs to backfill the role, they should reach out to the Finance Partner.

### Internal Department Transfers

If you are interested in another position within your department and the manager is also your manager you must do the following:

- Present your proposition to your manager with a Google doc.
- If the vacancy is advertised on the [jobs page](https://about.gitlab.com/jobs/all-jobs/), to be considered, you must submit an application. If there is no vacancy posting, one must be created and shared in the `#new-vacancies` channel so that everyone has the opportunity to apply and be considered.
- The manager will assess the function requirements; each level should be defined in the vacancy description.
- If approved, your manager will need to obtain approval from their manager, through the relevant chain of command.
- [Compensation]({{< ref "compensation" >}}) and [equity](/handbook/total-rewards/stock-options/#equity-incentive-plans) will be reevaluated to ensure it adheres to the compensation calculator. Do not send the proposal until this part is included.
- If the team member is transferred, the manager will announce in the `#team-member-updates` Slack channel and begin any additional onboarding or offboarding necessary.

## Internal Transfer Start Date

If a GitLab team member is chosen for a new role, the managers should agree on a reasonable and speedy transfer plan. Up to 4 weeks is usually a reasonable period, but good judgment should be used on completing the transfer in a way that is in the best interest of the company, impacted people, and projects.

The agreed upon transfer date should be reflected in the offer letter in Greenhouse to ensure transfer date alignment between current manager, new manager, and transferring team member. This is essential to ensure that both teams are able to plan and be set up for success. It is important to note that it is typically the former team of the team member that shuffles to ensure workload of the departing team member is covered while a backfill is hired. This is to ensure a smooth and speedy transfer and a positive team member experience. When aligning on a start date, please also consider [payroll alignment](/handbook/hiring/talent-acquisition-framework/ces-contract-processes/#job-change-letter) when selecting a start date.

Delaying transfers should be avoided to ensure a good team member experience for the transferring individual, however, if due to extenuating circumstances a transfer date needs to be pushed out, both managers need to agree on a new transfer date to communicate to the team member.

## Department Transfers Manager Initiated

All transfers should eventually be initiated by team members.

- During the application process, we highly encourage the hiring manager to be transparent with the team member's current manager. Doing so will allow the current manager the maximum amount of time to plan for the transfer and speed up the overall process.
- The hiring manager should post the open role in the `#new-vacancies` Slack channel to attract all potentially interested candidates.
- It is highly discouraged to reach out to a potential candidate directly without talking to their manager first. The hiring manager should share their intention of reaching out to the current manager's team member to ensure transparency and awareness.

### When promotion is a consideration - Within Same Job Family

If a team member sees a vacancy posted that is the next level up within their [job family](/handbook/hiring/job-families/#job-families) (for example an Intermediate Frontend Engineer sees a vacancy for an Senior Frontend Engineer), the team member should have a conversation with their manager about exploring that opportunity.

It is the manager's responsibility to be honest with the team member about their performance as it relates to their promotion readiness. If the manager agrees that the team member is ready, then they will follow the cyclical promotion calibration process. If they do not think the team member is ready for the promotion, they should walk through their career development document, as well as work on a promotion plan with the team member. The manager should be clear that the team member is not ready for the promotion at this time and what they need to work on. If the team member would still like to submit an application for the role after the conversation with their manager, they can apply and go through the same interview process as external candidates. The recruiter will confirm with the manager that the promotion readiness conversation has taken place before the internal interview process starts.

### For Internal Applicants - Different Job Family

If the role is in a completely different job family (within their own division or in a completely different division, for example, if a Product Designer is interested in a Product Manager role), the team member must submit an application via the posting on GitLab's [internal job board](https://gitlab.greenhouse.io/internal_job_board) on Greenhouse.

After the team member applies, the recruiter will reach out to the team member to connect regarding compensation for the role. In some cases, the compensation may be lower than the current one. Once the team member understands and agrees with the compensation for the new role, they can continue the process.
Internal and external candidates will follow the same process with the exception of the full screening call (which will instead be a short conversation to discuss compensation, as mentioned above). However, if the internal applicant will be staying in the same division and the executive level interview is a part of the process, the executive may choose to skip their interview. All interview feedback and notes will be captured in the internal team member's Greenhouse profile, which will be automatically hidden from the team member. After interviews are completed, internal "reference checks" will be completed with the applicant's current manager by the new hiring manager.
It is recommended that team members inform their manager of their desire to move internally and their career aspirations. Your manager should not hear about your new opportunity from the new hiring manager; it should come from the team member prior to the new hiring manager checking in for references with the current manager.

If you are unsure of the role, set up a coffee chat with the hiring manager to introduce yourself. Express your interest in the role and your desire to learn more about the vacancy requirements and skills needed. If after that conversation you do not feel that you are qualified or comfortable making the move, ask the hiring manager to provide guidance on what you can do to develop yourself so you will be ready for the next opportunity. It may also be possible to set up an [internship for learning]({{< ref "internship-for-learning" >}}) with the hiring manager.

### Announcing Internal Promotions/Transfers

While the [Career Mobility Issue](/handbook/people-group/promotions-transfers/#career-mobility-issue) aims to kick off the logistics of switching roles, the guidelines below are meant to guide the communication of internal promotions and transitions to ensure consistency and alignment from all parties involved.

1. Prior to any company-wide announcement, the team member should be given the opportunity to share the news with their immediate team members.
1. Promotions typically also include equity grants. If the equity grant amount is not listed on the Job Change Letter, managers can navigate to Workday to find the amount to communicate to the team member following these steps:
    - Navigate to Workday
    - Go to promoted team member's profile
    - Click `Job` on the left panel
    - Click `Worker History` from the tabs at the top.
    - Click the Business Process with `Stock Grant` in the title and effective date of the promotion.
    - This will open a new page to view the event. Scroll down to the `Stock Grant Details` table to see the proposed amount.

**Please Note**: Equity grants require board approval. When communicating, managers should highlight that this equity amount is the proposed amount, but will not be [officially approved](/handbook/total-rewards/stock-options/#grant-levels) until the next [board meeting](/handbook/board-meetings/#board-meeting-schedule).

1. The `new manager` should post the announcement in the `#team-member-updates` Slack channel. This should ideally happen (timezone permitting) on the **same day that the candidate signs their** [Job Change Letter]({{< ref "promotions-transfers#job-change-letter" >}}).
1. For cases where announcing on the same day the Job Change Letter is signed is not possible, the announcement should be no more than 24 hours after the candidate has signed.
1. Following this initial announcement, the `current manager` can proceed with making this announcement in other relevant team-specific channels.

NOTE: Although the Total Rewards and People Connect Team may have visibility into promotions or transfers due to the administration of updating information as part of their roles, they should not communicate with the team member about their promotion/transfer until an announcement has been made._

### For People Success & Talent Acquisition Team

Vacancies will be posted internally using the Greenhouse internal job board for at least 3 business days. If a role is not posted internally there must be a business case documented in the Workday documents of the team member who received the new role. See [Department Transfers]({{< ref "promotions-transfers#department-transfers" >}}) for additional details.

More details can be found in the [Job Change Letter]({{< ref "promotions-transfers#job-change-letter" >}}) section.

## Career Mobility Issue

A [Career Mobility Issue](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/blob/main/.gitlab/issue_templates/career_mobility.md) is created when the one of the following criteria is met:

- Migration from Manager to Individual Contributor (defined as a decrease in management level from Mgr+ to IC within Workday)
- Migration of Team (for purposes of Career Mobility issues, team changes are defined as a change in both manager & cost center)

Individual contributors moving into a Management level may or may not need their access to be reviewed, please check-in with your current and new manager to confirm this step. If access should be updated follow the AR process documented [here](/handbook/it/end-user-services/onboarding-access-requests/access-requests/).

Or, if the team member already has access to the systems and tools needed, the manager can open 'Becoming a GitLab Manager' and 'Interview Training' issues that are housed within the [Training Project](https://gitlab.com/gitlab-com/people-group/Training/-/issues/?sort=created_date&state=opened&first_page_size=100) in GitLab.

- To open the 'Becoming a GitLab Manager' and 'Interview Training' issues visit the Training project in GitLab -> Issues -> New Issue.
- Under 'Description' select the specified project template and then select Create Issue at the bottom.

When a career mobility may not be needed (but can be requested):

- Team/Speciality change but no access request needed

Any other role changes where a Manager feels their team member's role may require a career mobility issue, please reach out to the People Connect team via HelpLab.

## Career Mobility Issue Creation Process

The [People Connect Specialist](/job-families/people-group/people-connect) in the respective rotation will open a Career Mobility issue when an alert is received from Workday (for qualifying team members based on the criteria) and will be assigned to the migration for support.

The People Connect Leads will pull a monthly report to check that any qualifying team members did get their Career Mobility issue is opened.

The [Career Mobility Issue](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/blob/main/.gitlab/issue_templates/career_mobility.md) will then be created by the People Connect Team member assigned by using the [automated Slack command]({{< ref "employment-issues#career-mobility-issues" >}}) three days prior to the effective date to allow for the managers to start preparing for the team member's transition.

Important things to ensure:

1. Add a due date of two weeks from the migration effective date.
1. Check to see that the previous Manager and new Manager is listed correctly in the issue.
1. Complete all applicable tasks under the People Connect list.

## Important Tasks once Career Mobility has been finalized

Actions by both the current and new managers are required to set the team member up for success:

- Creating the correct Access Requests for systems needed and for systems no longer needed.
- Create any training issue that may be required.
- Reminding the team member to update their title on the team page, on their GitLab profile, in Zoom, in Slack and on professional networks like LinkedIn. If relevant, remind them to order new business cards as well.
- If we are in the middle of Annual Compensation Review, it is encouraged that the current manager and new manager arrange a successful handover of the feedback, whether sync or async.
- All migration tasks by the applicable team members need to be completed within 2 weeks of the migration start date.

## Career Mobility Retrospective

The team member going through this transition and assigned to their Career Mobility issue have a set of tasks to complete. An important one is to create a retrospective thread within their Career Mobility issue, so that they and their respective previous and current managers can discuss any questions, comments, and proposals. Retrospectives are used in many ways at GitLab, such as which are used after GitLab product [releases](/handbook/communication/#release-retrospectives-and-kickoffs) and describing the Product [retrospective workflow](/handbook/engineering/workflow/#retrospective). For the Career Mobility issue, simply comment in the issue, starting a thread titled **Retro thread** or **Retrospective**. Please feel free to ping your assigned People Connect Team member in your issue if you have any questions.

## Promotions and Transfers of Employees in Commissionable Roles

This section describes the steps required for promoting or transferring employees with a [Sales Commission Plan](https://internal.gitlab.com/handbook/sales/sales-commission/#fy23-sales-commission-policies). When a promotion or transfer occurs, it is important for Sales Managers to follow specific steps to ensure a smooth employee experience during the transition. The Sales Operations, Sales Finance, and the Commissions team need to be informed so the necessary systems can be updated and the team member can receive a new compensation plan.

**Note** These steps are in addition to all other steps required for promotions and transfers in partnership with the People team.

### For the Current Sales Managers

1. Determine the right path for the promotion and/or transfer. Our [promotion process]({{< ref "promotions-transfers" >}}) can be found in the handbook. For transfers, please confirm if there is an open role with your Sales recruiting team. Ensure necessary stakeholders and processes are followed in advance of processing a promotion and/or transfer.
1. Open a [Territory Change Request issue](https://gitlab.com/gitlab-com/sales-team/field-operations/sales-operations/issues/new?issuable_template=Territory_Change_Request) to inform Sales Operations of the change so they can update Salesforce and the Territory Mapping SSOT.

### For Sales Recruiting

1. Open a [Utilizing Backfill Headcount issue](https://gitlab.com/gitlab-headcount/sales-headcount/-/blob/master/.gitlab/issue_templates/utilizing_backfill_headcount.md) to inform Sales Finance of the promotion/transfer so they can update Adaptive.
1. Tag the appropriate members of the Sales Finance and Sales Commissions team as indicated in the 'Approval' section of the issue template.

### For Sales Finance

1. Update the team member's profile in Adaptive to account for the promotion/transfer.
1. Partner with leadership and the People team on whether we need to open a requisition to backfill the empty role from which the team member was promoted/transferred.

### For Sales Commissions

1. Every month, identify new hires, promotions, and transfers in Workday.
1. Create a monthly issue to notify the Sales Strategy and Analytics team of headcount changes. The Sales Strategy and Analytics team assigns quotas[^1] to sales employees within 4 weeks of the employee's hire/promotion/transfer date.
1. The quotas are submitted to the Commissions team to then add to the Xactly system where all commissions are managed and monitored.
1. Issue new compensation plan to the **New** Sales Manager for approval and release to team member.

[^1]: During fiscal year planning, Sales Strategy and Analytics work closely with Sales Management to assign values (full quota) to all the different Sales Territories. When a new sales employee joins, their ASM assigns them a territory (at which point there is a pre-determined value), and Sales Commissions applies a [ramp schedule](https://internal.gitlab.com/handbook/sales/sales-commission/#month-1-ramp-schedule) based on the employee's start date and role to arrive at their carried quota.

## For Team Members: Transitioning To A New Manager

There are several situations at GitLab that could lead to team members changing managers, including promotions, lateral transfers, company restructuring, manager resignation, etc. The process of building a new relationship with a new manager can be uncertain at times, but there are resources to help this transition process go smoothly:

- [Transitioning 1-1s]({{< ref "1-1#transitioning-1-1s" >}}) is a very important part of manager transitions. This helps ensure the new manager is up to speed on important discussions, deliverables, etc. so this information does not get lost in the transition.
- The [Career Mobility Handover template](https://docs.google.com/document/d/1iRbmS518CDjmhZEjvkaibqR1g0angWE83sWvtlH-elE/edit#heading=h.5ahg1o4v53q7) helps to ensure accomplishments, strengths, development areas, etc. are all captured with evidence moving forward. This makes sure career development progress continues and is not lost with manager changes.
- Sharing your most recent 360 feedback review and most recent performance review with your new manager can also be a great way to align on your strengths and improvement areas and discuss how they can partner with you in developing both.

## For Managers : Moving a Team Member to your team

When a new team member moves to your team, in addition to the items above in "Transitioning To A New Manager", there are some additional things to consider for the new manager.

- Do an initial `confidential handover` for any confidential topics between the previous and new manager (separate from the 1-1-1 with the previous manager, new manager, and team manager).
- Do this `confidential handover` periodically (perhaps 2 weeks, 4 weeks and 6 weeks after transition). This will allow not only initial questions and considerations to come up, but also new ones as they arise.
- Include in this handover the information you need for talent assessment planning that was confidential and not discussed in the 1-1-1.
- If your new direct report is potentially up for promotion in the next 6 months, be sure to transition the information that supports from the previous manager and be the DRI to drive this forward, including both information discussed in the 1-1-1 and any confidential information discussed in the `confidential handover`.

## Footnotes
