---
title: "Pronoun Guidance and Information"
description: "Resources for understanding and discussing pronouns and their usage at GitLab."
---

## What are pronouns?

At GitLab, [Diversity, Inclusion, & Belonging](/handbook/values/#diversity-inclusion) are written into our values.
Part of creating an inclusive workplace centers on
[the language that we use](/handbook/values/#inclusive-language--pronouns) when we communicate with each other.

This includes the usage of [pronouns](https://en.wikipedia.org/wiki/Pronoun), which are "a word or a group of words that
one may substitute for a noun or noun phrase."

## Importance

It's important that we understand pronouns and their function, because they go beyond simple substitution of nouns in
modern culture. Pronouns are a topic of much discussion lately, and they're an important part of our everyday lives.
Pronouns come in many shapes and sizes, so here are some examples:

> **I** didn't know **they** painted **their** kitchen pink this weekend!
>
> Have **you** ever seen a double rainbow? **It** is positively life-changing.
>
> Someone left **their** costume on the stage.

The reason why pronouns have become a highly-discussed topic is because they are also a core part of our identities, and
they enable us to express our gender identities more accurately. In order to promote a more inclusive environment, GitLab
is committed to recognizing and using the pronouns that our team members identify for themselves.

## Types of pronouns

Due to the nature of language, there are many pronouns that one could choose from. Perhaps the most common of these are
**she/her**, **they/them**, and **he/him**.

The way people display pronouns vary, but most people choose to display their
[personal pronouns](https://www.grammarly.com/blog/parts-of-speech/personal-pronouns/) in the format shown above. Occasionally, one might
also include the corresponding possessive pronoun, such as **they/them/theirs**, as a matter of personal preference or
to provide additional clarity.

### Singular they

The use of "they" as a singular pronoun is often cited as grammatically incorrect, and some argue that it should only be
used as a plural pronoun. While the plural "they" did arise before singular "they," the [singular they](https://en.wikipedia.org/wiki/Singular_they) has been in use since the 14th century.

Historically, the singular "they" was used in place of a singular pronoun where the gender of the subject is not known,
as in this example from [Wikipedia](https://en.wikipedia.org/wiki/Singular_they):

> Somebody left their umbrella in the office. Could you please let them know where they can get it?

More recently, "they" has seen an increase in usage as a singular pronoun for known individuals who do not identify as
a man or woman. Simply use "they" as you normally would in a sentence when referring to someone who uses **they/them**
pronouns, and you're all set! If you ever get stuck, Grammarly has a great write-up on
[singular they](https://www.grammarly.com/blog/parts-of-speech/use-the-singular-they/).

### Multiple pronouns

You might see multiple sets of pronouns listed for one person, such as:

> **she/her** or **they/them**

Or even simply:

> **she/they**

This usually signals that the individual is fine if you use either set of pronouns for them. Generally, pronouns are
listed in order of preference, so it's best to use the first one in the list if you're unsure.

### Neopronouns

While many individuals choose between **she/her**, **they/them**, and **he/him**, some folks don't identify with these.
As a result, one might choose pronouns that let them more accurately reflect their gender identity, such as **ze/hir**.
There are many neopronouns in use, which makes it difficult to list all of them in one place. If you're interested in neopronouns, you can read more
about them [in this NY Times article](https://www.nytimes.com/2021/04/08/style/neopronouns-nonbinary-explainer.html)
(requires subscription) and [on Pronouns.org Neopronouns guide](https://pronouns.org/neopronouns). Pronouns.org also
contains many additional pronoun-related guides.

## General etiquette

As with someone's name, you should respect the pronouns that someone shares with you when referring to them. If someone
uses **he/him** pronouns, it would be inappropriate to refer to him using other pronouns, unless specified. Just as it
would be disrespectful to intentionally misgender you, you should make the effort to correctly gender other people.

### Making mistakes

Mistakes happen! Every now and then, you might slip and use the incorrect pronoun for someone. This could happen for a
variety of reasons, so it's good to be aware of what to do if you accidentally use the wrong pronouns.

If you've accidentally used the wrong pronoun when referring to someone, simply correct yourself and move on. Since we
all make mistakes sometimes, it's usually not necessary to draw additional attention.

If you suspect that your mistake might have hurt someone's feelings, it's best to reach out to them one-on-one to check
in. A quick apology for using the wrong pronouns can go a long way! This is especially useful if you noticed your
mistake after the fact, perhaps after seeing someone's pronouns listed in Slack.

## Setting your pronouns in applications

### GitLab.com

You can set your GitLab.com pronouns on your [GitLab profile](https://docs.gitlab.com/ee/user/profile/#add-your-gender-pronouns).

### Google Mail (Gmail)

You can set your pronouns in your [email signature](/handbook/tools-and-tips/index.md#email-signature).

### Slack

You can set your Slack pronouns on your [Slack profile](https://slack.com/help/articles/204092246-Edit-your-profile).

### Zoom

You can set your Zoom pronouns through the [Zoom web portal](https://support.zoom.us/hc/en-us/articles/4402698027533-Adding-and-sharing-your-pronouns#h_01F89H5DCX04A6QG8Q3MS69Q4J).

## Additional resources

- [**Reference:** Pronouns.org](https://pronouns.org/)
- [**Article:** A Guide To Gender Identity Terms](https://www.npr.org/2021/06/02/996319297/gender-identity-pronouns-expression-guide-lgbtq)
- [**Article:** 'She/They' and Other Pronouns You Might See on Candidate Profiles](https://www.linkedin.com/business/talent/blog/talent-acquisition/pronouns-you-might-see-on-candidate-profiles)
- [**Book:** *Gender: A Graphic Guide*](https://www.introducingbooks.com/ib-title/gender-a-graphic-guide/)
- [**Book:** *What's Your Pronoun? Beyond He and She*](https://wwnorton.com/books/9781631496042)
- [**Book:** *A Quick & Easy Guide to They/Them Pronouns*](https://www.onipress.com/titles/project-one-f5w4d-233sh-3ybcx-9w275-dphaz-4h8ew-saabl-kdbm2-bed8a-szjan)
