---
title: "Relocation"
description: "GitLab's Policies & Processes in Relation to Team Member Relocations."
---

## Relocation / Address Change

This process is managed by the People Connect team as the DRI.  For any questions not addressed below, please submit a request via [HelpLab](/handbook/business-technology/enterprise-applications/guides/helplab-guide/#accessing-helplab).

Moving to a new location is an exciting adventure, and at GitLab, we want to encourage team members to utilize the flexibility that our relocation policy offers. However, there are multiple aspects to consider including eligibility, possible impact on compensation (including equity and benefit eligibility) and the impact on your role at GitLab.

**It's important to note that for both candidates about to join GitLab or existing team members all relocation requests will require business approval, which will consider the ability of the team member to drive results in the new location and the impact of a relocation on the departmental budget. Consult your [FP&A Partner](/handbook/finance/financial-planning-and-analysis/sales-finance/#finance-business-partner-alignment) as soon as possible to ensure the compensation change is accounted for in the department budget.**

A relocation that results in no change in compensation can be approved by the team member's direct manager.  Relocations resulting in an increase in compensation must be approved by the team member's direct manager, and location factor changes that are >.2 will require direct manager, VP as well as an e-group Member approval.

### Importance of Communicating Location

All Team Members are required to request an approval to relocate prior to moving. The consequences of not communicating to the appropriate group could result in [underperformance]({{< ref "underperformance" >}}) management action or loss of employment, depending on the circumstances.

Generally, team members may live or work outside their permanent residence for an aggregate amount of 183 days (6 months) per year.  However, the amount does depend on the particular country (or state) and what it considers to be a "resident" for tax purposes, as well as what it considers the tax year.  If you are not sure about the aggregate amount allowed by the country or state where you are visiting, you should check with your personal tax advisor. If you believe you or a team member you manage is at risk of exceeding (or has already exceeded) the aggregate amount of 183 days (6 months) (or less in certain countries), you must contact the People Connect Team **immediately**.

Having team members for 6 months or more working outside of their contractual location poses potential tax liability for both GitLab and the team member. For this reason, it is important to communicate transparently and promptly with the People Team.

Additionally, certain roles require team members to be present in the location for which they were hired to support business activities.  Sales, for example, may require travel to customers and be available for customers within a specific time.  Team members must seek manager approval to work outside of their home location regardless of the length of time at that location. Managers can deny a relocation request or ask for a team member to change their request due to the impact on business results. If a team member fails to communicate and seek approval to work outside of their hired location could also result in underperformance management action or loss of employment, depending on the circumstances. Long-term relocations must follow the application and approval process outlined below (/handbook/people-group/relocation/#how-to-apply-for-a-long-term-relocation).

### Short-Term Stay Definition

If you are not changing your permanent location (where you maintain permanent residency), but instead are traveling to different locations over a period of time, you are responsible for maintaining your health insurance, visas, and any other item directly relating to your travel.

Since any short-term stay is your decision and not required by GitLab as part of your role, you will not be eligible to use the [Business Accident Travel Policy]({{< ref "general-and-entity-benefits#business-travel-accident-policy" >}}) or submit any expenses related to your travel. If you are hired in a role requiring a time zone alignment, you must still be able to fulfill that requirement.

If your short-term stay is for less than 6 months in a new location, there should be no need to update your address in Workday.

If you plan on staying in a location for more than 6 months in a single calendar year, or are in that location for an aggregate of more than 6 months in a single calendar year, that becomes your residence and you must complete the long-term relocation process described below. In most countries, tax residency is determined by the place where a GitLab Team Member keeps its vital interests over the span of a calendar year. This is the place where you are registered, where your significant other (SO) and/or dependents live, the place where you work, where you live, where you keep your subscriptions etc.

** Please note that in some jurisdictions, even short term stays can add up to more than 183 days per year and can subject you to payroll tax in the new location.  Always make sure to check with your tax advisor before traveling to any location where you will be performing work for an extended period of time, whether it is more than or less than 183 days.

#### Considerations for Short-Term Travel

GitLab is an all-remote company that allows it's team members to work from most places globally, however, some places are subject to trade control restrictions. For this reason, team members cannot take company-owned devices to or otherwise work from US-embargoed countries or regions under any circumstances. The U.S. embargoed country list includes but not limited to Cuba, Iran, North Korea, Syria, Russia, Belarus, and the Crimea, Donetsk, and Luhansk regions of Ukraine.

GitLab provides this information, which is subject to change without notice, to facilitate GitLab users’ compliance with applicable trade control law. Additional information can be found on the [Trade Compliance](/handbook/legal/trade-compliance/) page in the handbook.

Some countries may not be on the US-embargoed list but still require prior GitLab notice and/or approval before traveling to or working from these locations. If you have any questions do not hesitate to contact the People Team via [HelpLab](https://helplab.gitlab.systems/esc?id=emp_taxonomy_topic&topic_id=57e1ad3997804e50a326158de053af3d).

### Long-Term Relocation

#### Long-Term Relocation Definition

A long-term relocation means that you will establish yourself in a new location. If you are spending more than six months in one calendar year in one location as part of an extensive period of travel and/or will have your mail delivered to an address in a different address, please follow the steps below to request a long-term relocation.

It is at the company's discretion to determine whether it can approve the relocation:

- Some job positions require GitLab team members to be located in particular countries, locations, regions, or time zones.  For example, a salesperson hired to serve a specific region may need to stay in that region, or an engineer hired to respond to customer requests in a specific region/country.
- GitLab only allows relocations to countries in which we already have a formed entity that carries no hiring restrictions. Review our [Country hiring guidelines]({{< ref "employment-solutions#country-hiring-guidelines" >}}) to see if the country is eligible for a relocation.
- GitLab cannot accept relocation requests to a location where there might be the possibility of the formation of a new entity until it is formally established, open for hiring, and the business objectives are fully understood.
- You can only work in countries where you can establish eligibility to work in the country without visa sponsorship provided by GitLab.
- Relocations can also result in an adjustment to compensation, including equity eligibility, based on the location and the location factor. Depending on the location factor and the benefits offered in the particular country, the adjustment will result in an increase or a decrease to the compensation package. The Company retains discretion to determine whether it can support the relocation due to the required adjustment.

At the onset, this practice may seem harsh when moving to a lower-paid location. One might argue that people should be paid the same regardless of where they live.  However, if you look at it from another angle and compare this practice to what most companies do, it should make more sense. For example, if you work for a company with physical locations and they require you to work out of an office or close to an office, you'd have to live in that area.  If you wanted to move to a location where they did not have a physical site, you would have no alternative but to resign and seek new employment in your new location. You would find that companies in the area pay at a locally competitive rate.

Now, let's say the company did have a site in your new location and they offered the flexibility to transfer. If they did not have a similar position open, you would have to either apply for a different open position in the same company or resign and apply externally (back to the realization that other companies will pay at a locally competitive rate). If you were lucky enough that they did have a similar role in the new location, a transfer would come with a pay rate based on the local market to ensure equity across all incumbents (people in the job) by location.

Adjusting [pay according to the local market in all cases]({{< ref "compensation" >}}) is fair to everyone. We can't remain consistent if we make exceptions to the policy and allow someone to earn more than locally competitive rates for the same work others in that region are performing (or will be hired to do). Being fair to all team members is not negotiable. It is a value we stand behind and take very seriously.

#### Considerations and Eligibility

**GitLab retains discretion at all times whether it can accommodate you to continue your role in the new location based on the requirements of your role and the potential impact on the business.  In some instances a move will not align to your proposed location, (e.g. a recruiter hired in EMEA to support EMEA would not be approved to move to the US), and in other instances the company may not be able to support a relocation in the proposed location. Second, in almost all situations the compensation, including equity eligibility, can change. During the relocation process, you will learn how your compensation may be impacted and be able to make an informed decision.  Any increases in compensation will need to go through an [approval process](/handbook/people-group/relocation/#approvals-phase).  This allows the business to validate budget availability early in the process. If you have a unique situation, please submit a [Relocation Evaluation](https://helplab.gitlab.systems/esc?id=sc_cat_item&sys_id=45f7278647533d1067429ee0026d432d) request via HelpLab to the People Connect team.**

1. If you are considering applying for a long-term relocation to a new country, the first consideration is to ensure that GitLab has an [entity]({{< ref "employment-solutions#gitlab-entities-and-branches" >}}) in the country to which you would like to move.  We currently only support relocations to GitLab Entities that are open for hiring and do not have hiring restrictions or headcount caps.  This is in alignment with our [Country hiring guidelines]({{< ref "employment-solutions#country-hiring-guidelines" >}}).
1. Consider any changes to [benefits]({{< ref "general-and-entity-benefits" >}}) as benefits can vary by country.
1. You must have the appropriate right to work documentation/visa requirements in the country that you are considering relocating to.

- Please note, at this moment GitLab only sponsors [relocations to the Netherlands]({{< ref "visas#right-to-immigrate-to-the-netherlands" >}}) and doesn't cover relocation costs for the team member's family members also looking to relocate.

1. You must have satisfied the required one year tenure to be eligible for relocation.

#### Eligibility to Work

If you are interested in a long-term relocation (defined above), you need to confirm that you would be eligible to work in that location. [Except for the Netherlands]({{< ref "visas#right-to-immigrate-to-the-netherlands" >}}), GitLab does not provide any form of sponsorship or immigration aid for team members who choose to move to new countries. For more information, please refer to our [Visa page]({{< ref "visas" >}}). GitLab cannot assist or facilitate a process to help you become eligible to work in a location if you do not already have that eligibility. You are of course free to apply and gain that eligibility if there are steps you can take that do not involve GitLab.  Once you are certain that you are eligible to work in your requested location country, you will need to provide proof of eligibility by [uploading the proof in the Documents tab of your Workday profile](https://docs.google.com/document/d/19B0lsMu7dMhof1ghPuBxHP23DuDqi2qpWF8pCWyEUN4/edit). If you move before establishing eligibility to work, but then cannot establish eligibility to work in the new location within the first six months of residency, it may affect your ability to continue your role with GitLab.

## How To Apply for a Long-Term Relocation

### Team Member

1. Review the [Country hiring guidelines]({{< ref "employment-solutions#country-hiring-guidelines" >}}) to see if we can support your relocation.
  *If you are moving to a different country, please start this process no later than **3 months** prior to your ideal relocation date.  If your relocation is within the same country, please start the process no later than 30 days before your ideal relocation date.*
1. If you are moving to a different country, upload eligibility documentation to Workday -  Per the [Eligibility to Work]({{< ref "relocation#eligibility-to-work" >}}) section above.
1. Complete the [Relocation Request Form](https://helplab.gitlab.systems/esc?id=sc_cat_item&sys_id=3537489247173d1067429ee0026d43b7) via [HelpLab](/handbook/business-technology/enterprise-applications/guides/helplab-guide/#accessing-helplab) to submit the initial request to start the process.  Upon completion, the form is sent automatically to People Connect who will review the details of your move and will work with the proper leaders and approvers to determine if the relocation can be approved (based on any budgetary and job duty impacts).  Your manager will review if your role can be performed adequately in the new location without negatively impacting stakeholders or customers.  Some positions require GitLab team members to be located in particular countries, locations, regions, or time zones and will not be eligible for relocation.  People Connect will work with your manager on the final decision.  Your manager will communicate the decision and the impact on your compensation so that you can make an informed final decision as to your move.  Your assigned People Business Partner will also be informed of your request to relocate.
1. Start preparing and avoid a delay in your pay or change to your relocation effective date by ensuring you have all required work documentation prior to your relocation. The onus is on the team member to research these requirements in advance as GitLab doesn't provide immigration support, except for the [Netherlands]({{< ref "visas#right-to-immigrate-to-the-netherlands" >}}). Please take into account processing times for visa and other required appointments in the relocating country needed in order to receive a tax number, bank account, etc.

Note: Assuming your relocation is approved, any applicable changes in compensation will not be effective until your move date (or the date you start working in the new location), which will be listed as the effective date on your new contract. **We will not be able to process retroactive dated relocations. Please only use future dates when applying for your relocation.**

### Approvals Phase

Below are the steps to approve a long term relocation. See compensation calculator to determine location factor.

#### Relocation Within Same Country and Same Location Factor

No approval is needed.  Team Members can [update their address](https://docs.google.com/document/d/1NiNKWd-H9FTnYkmsWWi79-DGDSUCiWMfwFaGQPRnj14/edit) in the Contact tab in their Workday profile. A People Connect Team member will [approve the address in Workday](https://internal.gitlab.com/handbook/people-group/people-operations/people-connect/people_connect_team/#home-contact-changes---workday-inbox) and reach out if there are any additional steps necessary to complete the relocation process.
If the country and the location factor don't change, no change in compensation is allowed as part of the relocation action.

#### Relocations To New Country or Different Location Factor

1. Complete the [Relocation Request Form](https://helplab.gitlab.systems/esc?id=sc_cat_item&sys_id=3537489247173d1067429ee0026d43b7) to submit the initial request to start the process. Upon completion, the form is sent automatically to People Connect.
1. Once the relocation request form has been received by People Connect, they should review the form playing close attention to the following information:

   - [Location Eligibility](https://comp-calculator.gitlab.net/hiring_status/index) Check the [Compensation calculator, country hiring status](https://comp-calculator.gitlab.net/hiring_status/index) to confirm that the country is currently an entity country open to further hiring.  These are the only countries where team members can relocate.
   - [Work Eligibility](#eligibility-to-work)
   - The relocation date is future dated and allows enough time for the process to be finalized.
   - Relocations from one country to a new country: once you have determined an appropriate month for your relocation we will request that the relocation effective date reflects either the 1st or 16th of the month to help avoid any complications with local taxes or absence accrual policies.
   - For sales personnel with a variable change, the effective date should always be the 1st of the month.
   - Reason for relocation is provided
   - Team member has confirmed whether or not they require employer sponsored visa for relocation
   - The team member has satisfied the required one year tenure to be eligible for relocation

1. The People Connect Team will determine the impact on compensation based on the relocation utilizing the following practices:

   - If the relocation request within the same country does not result in a change in compensation, no further approvals are required and The People Connect team will [inform the manager of the relocation](https://docs.google.com/document/d/1Zq_sxT3ASsnLeTNFJV3-HE5aG3ebv_JXMzhW1zXcEQI/edit)
   - If the country and/or the location factor changes, the compensation will be adjusted based on the location factor change.  For example, if a team member currently resides in a location with a location factor of .70 and the move results in the team member landing in a location with a location factor of .75, the compensation recommendation will be to increase the salary to position the team member's salary to an equal position in the new range (compa-ratio).  If the team member currently resides in a location with a location factor of .80 and the move results in landing in a location with a location factor of .70, the compensation recommendation will be to decrease the salary to position the team member's salary in an equal position in the new range. If the compensation range of the team member's role isn't available in our [compensation calculators](https://docs.google.com/spreadsheets/d/1lfWhPWOdQOpbORMiOawcQYpI4QWW8lpKetnWkneEkjE/edit?usp=sharing), the People Connect Team member reaches out to Total Rewards to discuss the new compensation.
   - If the relocation meets all requirements for a compensation change, the People Connect Team will [determine relocation salary](https://docs.google.com/spreadsheets/d/1lfWhPWOdQOpbORMiOawcQYpI4QWW8lpKetnWkneEkjE/edit#gid=341502022) using the same compa ratio as the previous location (if applicable) and [rounding best practice]({{< ref "compensation-calculator#rounding-best-practice" >}}) method. Ensure that the new salary is within the comp range per the [Compensation Calculator](https://gitlab.okta.com/home/bookmark/0oa87j8ow7KXpsUy1357/2557)

1. The People Connect team will then [obtain approvals](https://docs.google.com/document/d/1kn97Y-B7iTULhhdJ8yDnFHXgB7yw1iQtbhQqJFRDPSM/edit#heading=h.46wc4xqdjyi7) for the relocation request and add the applicable [PBP of the division](/handbook/people-group#people-business-partner-alignment-to-division) in copy. Considerations in addition to budget availability include business criticality of the role, ability to perform the role from the proposed new location, and demonstrated performance by the team member. Any increase in location factor equal to or greater than .20 will require [VP approval](https://docs.google.com/document/d/1kn97Y-B7iTULhhdJ8yDnFHXgB7yw1iQtbhQqJFRDPSM/edit#heading=h.46wc4xqdjyi7) and following that [E-Group member approval](https://docs.google.com/document/d/1kn97Y-B7iTULhhdJ8yDnFHXgB7yw1iQtbhQqJFRDPSM/edit#heading=h.1m16plpt2yam) BEFORE [manager approval](https://docs.google.com/document/d/1kn97Y-B7iTULhhdJ8yDnFHXgB7yw1iQtbhQqJFRDPSM/edit#heading=h.638wcz4rf9gd) due to the possible significant impact on compensation with a copy to the Division Director and VP to add context and transparency for E-Group member consideration.
1. The People Connect Team member will update the [Relocation Tracker](https://docs.google.com/spreadsheets/d/1Z45eOZ2rCRIKgGae3eOKQ8lhIbAPikSs5gLz3V8Kh9U/edit?ts=5e7a2c42#gid=972787144) with the details of the relocation

### Once Approved

1. The People Connect Team member will inform the Manager once the relocation has been fully approved.
1. The manager will convey to the team member that their relocation has been approved and relay their new compensation.  The manager will then determine if the team member still wishes to relocate based on the changes to compensation.  The manager will convey the team member's final decision to the People Connect team.
1. The People Connect Team member will ensure that all approval documents including original request from the team member and any approval email threads are saved in the team member's [Workday `Contracts & Changes` folder](https://docs.google.com/document/d/1ao_d_JxvqvZdqxlt4mBoHe1GcAhYT7B6YQoBgDxPdRE/edit). This approval will include the converted salary where applicable for the authorized signatory on the contract / job change letter to audit against before signing.

### Contract Phase

The contract phase is unique based upon the team member's relocation. The different options are as follows:

1. [Relocation within the Same Country](#relocation-within-the-same-country)
1. [Relocating to a new country](#relocation-to-a-new-country)

#### Relocation within the Same Country

##### Tasks for People Connect

1. If relocating between Quebec and Non-Quebec review applicable tasks [here](#canada)
1. A Relocation letter is only needed if there is a compensation change:
    - Make a copy of the [Relocation letter](https://docs.google.com/document/d/18V9Qqlaetft8XMXLMPgbTFtZAGgoa7uiuN01-W38c6k/edit) and save it to the [working documents folder](https://drive.google.com/drive/folders/0B4eFM43gu7VPNUlKZEFtNGtSRk0?resourcekey=0-_qX_2OXbs71yJa3HZy0TAQ&usp=sharing).
    - Enter all applicable information based on the relocation request approval email and the team member's Workday profile
1. Once the Relocation letter has been created, ping the People Connect Team for auditing.
1. Stage the letter in DocuSign and send for signature to the [applicable signatory](/handbook/hiring/talent-acquisition-framework/ces-contract-processes/#entity-contract-signatories) and the team member
1. Upload the signed document to the team member's `Contracts & Changes` folder in Workday.
1. Update the [Relocation Tracker](https://docs.google.com/spreadsheets/d/1Z45eOZ2rCRIKgGae3eOKQ8lhIbAPikSs5gLz3V8Kh9U/edit?ts=5e7a2c42#gid=972787144) with the details of this relocation.
1. The People Connect Team member makes any necessary updates to the team member's Workday profile by following these Job Aids:

   - [How to: Change Job](https://docs.google.com/document/d/1hpPikG0STncYKamaY8XlfMTwYdoszP-0Xogvpp5hyZ4/edit) and
   - For relocations to another state within the US: Set a reminder to [update the benefit group](https://docs.google.com/document/d/1MuRjPnvK9PZI2kk58jHnMgC3iUQCzp7xdjsfQpJT37k/edit) on the effective date of the relocation

1. Once the People Connect Team member has updated Workday, they will then reach out to another People Connect team member to audit the updated entry
1. Once the team member updates their address in Workday, the People Connect Team member [approves the address change](https://internal.gitlab.com/handbook/people-group/people-operations/people-connect/people_connect_team/#home-contact-changes---workday-inbox)

##### Tasks for the Team Member

1. [Update your address](https://docs.google.com/document/d/1NiNKWd-H9FTnYkmsWWi79-DGDSUCiWMfwFaGQPRnj14/edit) in the Contact tab in your Workday profile. Your [address will then get approved](https://internal.gitlab.com/handbook/people-group/people-operations/people-connect/people_connect_team/#home-contact-changes---workday-inbox) by the People Connect Team member team.

#### Relocation to a New Country

##### Tasks for People Connect

1. Create a new [contract](https://internal.gitlab.com/handbook/people-group/people-operations/people-connect/employment_contracts/) for the team member confirming new compensation (if applicable) and effective date.
    - If a team member is relocating to France, you should follow [similar steps to CES](/handbook/hiring/talent-acquisition-framework/ces-contract-processes/#creating-a-french-offer), when creating a French offer, by requesting support from the [Legal,Employment Team](legal-employment@gitlab.com) to determine which contract template should be used and to have the relocating team member classified under the applicable CBA in France. One of the Legal, Employment Team members will respond with the following information:
        - The Template that you should use (A,B or C); and
        - The classification wording that should be added to the template (including information on where the wording should be placed on both the English & French sides)
    - No stock options are given through relocation, so that line can be removed
    - [Probation Period](contracts-probation-periods/#probation-period): If a team member has continued service with GitLab (tenure with GitLab has been uninterrupted) and they have already passed the probationary period of their original location or contract, they do not need to go through the probation period of their new location or contract.
    - A list of all signatories can be found [here](/handbook/hiring/talent-acquisition-framework/ces-contract-processes/#entity-contract-signatories).
1. If applicable:
    - A [Mutual Termination Agreement](https://docs.google.com/document/d/1MJCWQupiqfU7rUk99qowHuxd64OPIHKfD05gLlfs7K8/edit) is needed, if the team member is relocating from IT BV.
    - A [Side letter Relocation - Transfer from one entity to another](https://docs.google.com/document/d/1UesnGAH1y0MMgWU37RRX2DuSP14mDLff/edit) is needed if the team member is relocating from one entity to another.
    - Please note that a wet signature is necessary if the team member is relocating from GitLab GmbH (Germany).
    - Inform the current PEO of the relocation effective date. See People Connect 1password vault for contact details. A resignation email (within notice period) from the team member to their current PEO is also required, if the team member is relocating away from a location with [PEO Employment]({{< ref "employment-solutions#peo-professional-employer-organization-employer-of-record-and-not-a-gitlab-entity-or-branch" >}}).
1. Ping a People Connect Team member for auditing in the `#connect-ops-team` private slack channel.
1. Stage the contract in DocuSign and send for signature first to the GitLab signatory and subsequently to the team member.
      - In the event that the team member requests any changes to the contract, once approved and updated, send an email to the team member with the breakdown of the applicable changes once the contract has been sent for signature via DocuSign.
1. Upload the signed document to the team member's `Contracts & Changes` folder in Workday.
1. The People Connect Team member makes any necessary updates to the team member's Workday profile following the [Change Job Aid](https://docs.google.com/document/d/1hpPikG0STncYKamaY8XlfMTwYdoszP-0Xogvpp5hyZ4/edit). Additional steps:
    - Update the locality at point of relocation (don't wait for the address change)
    - Check if a future dated One-Time-Payment needs to get updated due to the currency change
1. Once the People Connect Team member has updated Workday, they will then reach out to another People Connect team member to have them audit the updated entry.
1. The People Connect Team member will update the [Relocation Tracker](https://docs.google.com/spreadsheets/d/1Z45eOZ2rCRIKgGae3eOKQ8lhIbAPikSs5gLz3V8Kh9U/edit#gid=972787144), that the relocation has been completed.
1. Create a [relocation issue](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/blob/main/.gitlab/issue_templates/onboarding_tasks/relocations.md) for the team member using the applicable country template in the [team member epics](https://gitlab.com/gitlab-com/team-member-epics/employment/-/issues) and assign to yourself and the relocating team member. Ensure all tasks are completed and follow up with the relocating team member if required.
    - Copy/paste any country specific [on-/offboarding tasks](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/tree/main/.gitlab/issue_templates) to this issue
    - Complete any [Pre-Onboarding taks](https://internal.gitlab.com/handbook/people-group/people-operations/people-connect/onboarding_process/#pre-onboarding) for the applicable country
    - Complete any [Country Specific Tasks](#country-specific-tasks)
1. If there is a sales commission change: Add the details to the [Final Sales OTE](https://docs.google.com/spreadsheets/d/1lyGxlNAdY4PLMKR31Zw46i7jpb8qfMovMJBUql8PfjE/edit#gid=1320059142) sheet

##### Tasks for Team Members - Relocation Approved

Once your relocation has been approved and the contract has been signed, a [relocation issue](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/blob/main/.gitlab/issue_templates/onboarding_tasks/relocations.md) will get opened and assigned to you by the People Connect Team. Please ensure you complete any tasks by the due date to ensure a smooth onboarding and to have everything ready for your first payroll in the new country.
If you are relocating away from a location with PEO Employment, you must give notice to the PEO directly within the notice period. Most [notice periods]({{< ref "contracts-probation-periods#probation-periods-of-team-members-employed-through-a-peo-or-an-entity" >}}) are usually 30 days, but you must review your own contract, as it will be specified there.

### Country Specific Tasks

#### The United States of America

##### Relocating **To** The United States

1. Run the [Add Employee integration](https://internal.gitlab.com/handbook/people-group/people-operations/people-connect/onboarding_process/#steps-to-run-the-lawlogix-integration-in-workday) from Workday to LawLogix in order to intiate the I-9 process for the team member moving at least 5 days before the relocation.
1. [Place team member in the appropriate benefit group](https://docs.google.com/document/d/1MuRjPnvK9PZI2kk58jHnMgC3iUQCzp7xdjsfQpJT37k/edit) in Workday on the effective date

##### Relocating **From** The United States

1. If a team member is leaving the US, you will need to manually terminate the team member in LawLogix. This will allow the I-9 to be purged at the correct time.

- Log in to LawLogix > search employee > Job Details tab > click: terminate

1. Set yourself a reminder to [update the Benefit Group](https://docs.google.com/document/d/1MuRjPnvK9PZI2kk58jHnMgC3iUQCzp7xdjsfQpJT37k/edit?usp=sharing) in Workday to `INELIGIBLE` within one week of the relocation effective date. This confirms the end of the team member's US benefits eligiblity and the Total Rewards Team terminates the team member in PlanSource.

#### The Netherlands

##### Relocating **To** The Netherlands

The steps our People Connect Team member team uses to support relocations to the Netherlands in addition to above [relocation process](#how-to-apply-for-a-long-term-relocation):

1. The People Connect Team member stages the relocation contract via Docusign for the team member and GitLab signatory to sign and adds hr@savvy-group.eu to 'Receive a copy' once signed.
1. The People Connect Team member will then reach out to our Payroll vendor in the Netherlands by emailing hr@savvy-group.eu and introduce the relocating team member in cc to support them with their relocation.
1. The vendor will supply all the documentation needed to apply for relocation including information about: [30% Ruling Questionnaire](https://docs.google.com/document/d/1Ok6LS9T4P6tnPu2N6BDRDeveOYzd1ILpkbQRhl911w4/edit?ts=5caf1bca), [wage tax](https://drive.google.com/file/d/1q8N-idoYGFSCw2ajat9RscfQ004EL-PS/view) form and potentially an application for a BSN Number.
    - **During COVID a letter stating your requirement to relocate to the Netherlands at such time is required, the People Connect team member will provide the vendor with such, using the following [template](https://docs.google.com/document/d/1yE7DrHBLOj0blBJwaOIC8f2bLMFS10wYUZvg9BqjnF4/edit?ts=5e592e30)**
    - **A completed health declaration form, the vendor will provide this to you**.
1. Details on that process can be found under the BSN number section on the [visas page](/handbook/people-group/visas/#bsn-number) in the handbook.
    - **Once the approved Visa and 30% ruling is received by the team member, the team members should email this to PeopleOps for filing in Workday.**
1. Sometimes the BSN might not be ready for the first Payroll, if this happens team members can still be on the Dutch Payroll, it just means the highest rate of tax will apply for this period. Any overpaid tax can be claimed back via [a year end tax return](https://www.government.nl/topics/income-tax/filing-a-tax-return). When you receive your BSN please ensure to add to your Workday profile and email nonuspayroll@gitlab.com to let them know. Any Payroll queries should be directed to nonuspayroll@gitlab.com
1. If applicable due a temporary contract: Click on 'job change' actions to 'add contract'. Fill in start and end date, contract type and reason.

**Review [best practices](/handbook/people-group/contracts-probation-periods/#netherlands-renewal-process) for The Netherlands contracts**

#### India

##### Relocating **from** India

Our PEO in India can only process terminations on working days (typically Monday to Friday), please take this into account when deciding on the relocation effective date.

#### Germany

##### Relocating **to** Germany

1. Review current [onboarding tasks](https://gitlab.com/gitlab-com/people-group/people-operations/employment-templates/-/blob/main/.gitlab/issue_templates/onboarding_tasks/country_germany.md) for Germany and ensure necessary paperwork is filled out.

##### Relocating **from** Germany

- Relocation Contract and Mutual Termination Agreement Process for Germany

These are the steps our People Connect team uses to send contracts to team members relocating to, or moving from Germany. Please note all German documents require a wet signature.

Once the contract or Mutual Termination Agreement (MTA) has been created by the People Connect Team member, next steps are to stage the documents in DocuSign, while also sending the documents to the German counsel to have them physically sign and mail them.

1. Stage the documents for signature in DocuSign. This document will be sent to the Signatory first and then to the team member.

   - Once signed, save the file into the team members Workday profile.

1. Email an unsigned pdf of the document to both the German counsel as well as the team member.

   - Open the saved unsigned contract, remove GitLab signatory from the below fields:
     1. **Summary Key of Terms** - Delete the GitLab Signatory's name and leave the field
        blank.
     1. **Scroll down to the end of the contract** - replace Signatory's name with "GitLab Signatory". Save
        the contract as a PDF format.
   - In the body of the email, you will need to explain the below steps for the process.
      - **To (recipients)**-  Thomas.Leister@osborneclarke.com & julia.bauer@osborneclarke.com & Team member's GitLab email address
      - **Subject line**  : Please Send Physical Contract for "Name of the team member"
      - **Attachment** : attach the unsigned PDF contract
        1. The German counsel will need to print two copies of the document. They will need to sign both of the copies, and then mail them to the team member. Please include the address and phone number of the team member in the email.
        1. Once the team member receives the documents in the mail, they will keep one copy and then will need to sign and send the other copy to our German Counsel. The address for our German Counsel is listed in the PeopleOps 1password vault. Please include this address in the email.
   - The postage fees can be submitted for reimbursement. Please also include that information in the email.
   - It is also best practice to recommend in the email that the German counsel confirm that they have mailed the document.

1. Once the German Legal Counsel receives the documents to put them in our archive, they will also send a scanned copy of the signed documents to the People Connect team. This document will need to be saved in the team member's Workday profile.

#### Canada

##### Relocating between Quebec and Non-Quebec

1. The People Connect Team member creates the applicable [Employment Agreement](https://internal.gitlab.com/handbook/people-group/people-operations/people-connect/employment_contracts/#employment-agreements) due to the contractual differences of the provinces.
1. The People Connect Team member adds the following details to the contract:
    - Start Date: *add effective date of relocation*
    - Add this line underneath the start date at the top: "Continuous Service Date: *add original hire date*"
    - Add this sentence to the section above 1. Position: "Your continuity of service for all employment purposes begins on the *add original hire date: YYYY-MM-DD*"

#### South Korea, France or Singapore

##### Relocating **to** South Korea, France or Singapore

1. The People Connect Lead shares the relocation contract with gitlabHRSS@globalupside.com. Global Upside then sends an Egnyte (payroll platform) login invitation email to the relocating team member. If they are relocating to France an invite to Mihi will also be sent.
1. [France requires contracts to be individually drafted by the Legal team.](/handbook/hiring/talent-acquisition-framework/ces-contract-processes/#process-for-gitlab-team-members-in-singapore-south-korea-or-france)

1. If a team member relocating to France is an expatriate who has not been a French tax resident for the 5 calendar years before the calendar year during which they relocate, and they wish to assess their eligibility for the impatriate tax regime, they must let People Connect know three months in advance that they will be undertaking the assessment. The People Connect team can reach out to legal-employment@gitlab.com for support with appropriate contract language once the relocating team member confirms their eligibility. *Note that eligibility is a complex tax matter and the relocating team member should check with their personal tax advisor.*

##### Relocating **from** France

1. The relocating team member needs to resign from GitLab France S.A.S. with a notice date effective one day before the start date of their new contract. Please email the resignation letter to legal-employment@gitlab.com and also [upload the resignation letter to your Workday profile](https://docs.google.com/document/d/19B0lsMu7dMhof1ghPuBxHP23DuDqi2qpWF8pCWyEUN4/edit?tab=t.0). This is required to process your exit in France while you are simultaneously onboarded in the new country.
1. Once the resignation letter has been emailed to legal-employment@gitlab.com and uploaded to Workday, the People Connect team member will share [this letter](https://docs.google.com/document/d/1wgbt9vK4w-aQEgjDzdOs94t9XOZuiJmPWj6BvlSl7rY/edit?usp=sharing) with the team member relocating away from France for e-signature via DocuSign as soon as possible (and at least within 7 days) in order to waive the balance of the notice period and address any additional matters. Once signed, the People Connect team member will uplaod the letter to the team member's 'Contracts & Changes' Workday folder.

## Reporting for Relocations

Access to the 'GitLab Team Member Relocations' Workday report can be requested via [this issue](https://gitlab.com/gitlab-com/people-group/people-tools-technology/general/issues/new?issuable_template=intake) and automatically sent on a regular basis.

This report will include the following information:

- Team Member Name
- Manager
- Relocation Date
- Starting Location
- Ending Location

### Steps for a Canceled Relocation Request

In the event that the team member decides not to proceed with the relocation. Not all of these steps will be needed, depending on how far into the relocation process has taken place.

1. Delete the respective contracts from Google Drive and Workday, if signed
1. Notify stakeholder of the change.  Possible stakeholders:
      - PEO
      - Payroll
      - HRSavvy
1. Workday - Update fields that were changed for the relocation.
1. Update [relocation tracker](https://docs.google.com/spreadsheets/d/1Z45eOZ2rCRIKgGae3eOKQ8lhIbAPikSs5gLz3V8Kh9U/edit#gid=972787144)
