---
title: Talent Assessment
description: "Overview of three critical pieces of GitLab's talent development program: performance, growth potential, and key talent."
---
<!-- markdownlint-disable MD051 -->
## Purpose

The purpose of the Talent Assessment Program is to identify and retain team members who drive the success of our organization. This is a top priority and strategic process for people managers at GitLab. Our Talent Assessment Program (which is a critical piece of our overall [Talent Development Program](/handbook/people-group/talent-development-program/) serves as a mechanism to help mitigate a couple of our biggest concerns: [lack of performance management](https://internal.gitlab.com/handbook/leadership/mitigating-concerns/#underperformance) and [losing key people](https://internal.gitlab.com/handbook/leadership/mitigating-concerns/#key-people-leave).

Additional key benefits of the Assessment Program include:

- Help facilitate career development conversations (and ensure they're occurring regularly)
- Ensure transparency and ongoing feedback between team members and their managers
- Discuss promotion readiness and plan promotions
- Succession planning
- Increase awareness of top talent across departments (during calibration sessions)

## Overview

We use Workday to complete our Talent Assessment. You can review an overview of Workday Talent [here](https://docs.google.com/presentation/d/1CYNNtYWvbDyDu_WndCQ47uvTbZYhNKt5PJLnrwZ_3ek/edit?usp=sharing). Please reach out to your [People Business Partner](/handbook/people-group#people-business-partner-alignment-to-division) if you have any questions.
You can also review the following [guide](https://docs.google.com/document/d/1bdGDq85nY3uLRFLrmKV5RDyQpGkPmnvGAI1pN_RRNto/edit) which mirrors what is included in the Workday Talent Assessment template to prepare you prior to the tool being launched.

There are many talent assessment options, and we have opted to use a Performance/Growth Potential Matrix (commonly known as "9-Box" in the US) and annually review Key Talent.

GitLab's Performance/Growth Potential Matrix is a type of talent assessment that forms part of our [Talent Development Program](/handbook/people-group/talent-development-program/).

The FY5 talent assessment should consider performance from the period FY25Q1 - FY25Q4

In addition to assessing Performance/Growth Potential, we annually review Key Talent aligned with the criteria outlined below on this page. The combination of Performance/Growth Potential and Key Talent assessments allow us to identify team members who drive the organization's success and use our engagement tools to retain them.

For team members with a tenure up to three months to the launch of the Talent Assessment Program will be designated as "Too New to Rate". Also in some cases a "Too New to Rate" designation might be applicable for newly promoted or transferred team members. More about that designation can be found below.

## The Performance/Growth Potential Matrix

| Performance ↑ <br> Growth Potential →  | **Developing Growth Potential** | **Growing Growth Potential** | **Exceeding Growth Potential** |
|-----------------|---------------|---------------|----------------|
| **Exceeding** | **Box 5** Team member is consistently surpassing performance expectations in their current role but needs to continue to grow in current role, or has not exhibited the willingness or ability to grow in the current role.| **Box 2** Team member is consistently surpassing performance expectations in their current role, makes valuable contributions and consistently demonstrates competencies required. They have shown willingness and/or ability to further grow in their role and they may be ready to take on additional responsibilities in the next 12 months. | **Box 1** Team member is developing faster than the demands of their current position and/or division. Team member has been given additional assignments and has demonstrated high-level commitment/achieved significant results. Team member is ready to broaden their skill set and take on significantly greater scope and responsibility. |
| **Performing** | **Box 7** Team member is currently meeting expectations of their role, and/or team member is not willing or able to absorb greater scope, impact or complexity. | **Box 4** Team member is currently meeting expectations and has shown willingness or ability to further grow; may not be ready to absorb greater scope, impact or complexity in the next 12 months. | **Box 3** Team member is contributing as expected and is meeting performance expectations. They have shown willingness and/or ability to further grow in their role and they may be ready to take on additional responsibilities in the near future. |
| **Developing** | **Box 9** Team member is not meeting performance expectations and there is still more to learn in the current position, **or**, team member has not been in the position long enough (promotion, new to the role, or new hire) to adequately demonstrate the pillars of growth potential for a sustained period of time. | **Box 8** Team member has not been in the position long enough to adequately demonstrate their capacity (promotion, new to the role, or new hire), or may have lost pace with changes in the organization. The team member has shown the willingness and/or ability to grow in the role aligned with the pillars of growth or has had opportunity to consistently demonstrate performance and growth potential. | **Box 6** The team member is not meeting the requirements of their current role, but has demonstrated willingness and ability to extend beyond scope once ramped, and/or is showing the willingness and ability to grow further with additional guidance or direction. The team member could be more successful in the current role with more direction/time to ramp, or in another role or department that more appropriately suits their skill set.|

This matrix is an individual assessment tool that evaluates both a team members current contribution to the organization and their potential level of contribution.
It is commonly used in succession planning as a method of evaluation an organization's talent pool, identifying potential leaders, and identifying any gaps or risks.
It is regularly considered a catalyst for robust dialogue (through a calibration process) and is considered more accurate than one person's opinion.
The performance/growth potential matrix can be a diagnostic tool for career development.

The matrix serves as a tool to help managers assess, develop, and coach their team members - ultimately resulting in an ability to more effectively and efficiently lead teams.

### What is "Performance"?

Performance includes both results and behaviors, and is broken into three areas: Developing, Performing, and Exceeding.

### Developing

**Please note that `Developing` should not be automatically associated with underperformance. As highlighted below, `Developing` can also be used for new hires or newly promoted team members that are still ramping up in their new roles. Your manager will provide example and detail to ensure the rationale behind the `Developing` rating is communicated.**

Based on the Job Family responsibilities, [values](/handbook/people-group/competencies/#values-competencies) and [remote working competencies](/handbook/people-group/competencies/#remote-work-competencies), team members in this category are not meeting all of the expectations. There is still more to learn and improve on in the current position to achieve the desired results. This may be due to the following:

- The team member has not been in the position/at GitLab long enough to adequately demonstrate performance.
- The team member has been recently promoted and needs time to ramp up performance in the new role.
- The team member may have lost pace with changes in the organization.
- The team member is not committed to the job responsibilities and/or GitLab.
- The team member finds it difficult to perform work in a way that is aligned with our values and/or competencies.
- The team member's performance is aligned to our values and competencies, however, they lack results for Job Family responsibilities.
- Team member was part of a recent [transfer](/handbook/people-group/promotions-transfers/#department-transfers) and is still learning how to be successful on their new team.

Examples:

- The team member needs a lot of guidance from the manager with the majority of tasks to understand requirements and deliverables expected.
- The team member has not been in the position long enough to adequately demonstrate their capacity. For example, the team member was recently promoted or has changed roles and needs more time to ramp up.
- The team member is missing important due dates which is affecting the team, GitLab and/or customers.
- The team member still needs to adapt remote working best practices. For example, the team member does not manage their own time or work to achieve results or may have difficulty with asynchronous communication.
- The team member lacks (a part of) the knowledge, skills and abilities which are required for the role, resulting in a low quality of work being delivered.
- There is a significant mis-alignment (i.e. the team member struggles to collaborate with others, the team member does not work iteratively and key metrics are impacted, etc.)

### Performing

Based on Job Family responsibilities, [values](/handbook/people-group/competencies/#values-competencies) and [remote working competencies](/handbook/people-group/competencies/#remote-work-competencies) team members in this category are "on track" and meeting all expectations. They can independently and competently perform all aspects of the Job Family responsibilities in a way that is aligned with our values and competencies. Their performance consistently meets the requirements, standards, or objectives of the job, and they can occasionally exceed expectations. They deliver results in a timely and accurate fashion. This performance may be expected as a result of:

- The team member is consistent and stable in their performance.
- The team member has the required knowledge, skills and abilities to perform in the role successfully and also applies values and competencies in their work.
- The team member has adapted to remote working and their knowledge, skills, and abilities align seamlessly to their role at GitLab.

Examples:

- Team member is a dependable member of the team. Their manager can trust them to achieve key metrics.
- Team member consistently works in accordance with our value and remote working competencies.
- While consistently meeting expectations, the team member does not regularly exceed expectations.
- Team member does not frequently express interest in additional projects, responsibilities, or work outside of their immediate scope.
- The team member is exemplifying our values in their work, but might have some competencies to improve on.

### Exceeding

Team members that are exceeding consistently surpass the demands of their current position. They demonstrate unique understanding of work beyond the assigned area of responsibility. They contribute to GitLab's success by adding significant value well beyond Job Family requirements, [values](/handbook/people-group/competencies/#values-competencies), and [remote working competencies](/handbook/people-group/competencies/#remote-work-competencies). This performance may be expected as a result of:

- Individual is developing more quickly than the demands of their current position.
- They rise to the challenge when given additional assignments and achieve significant results.
- A "go-to" team member for their peers for tough problems and day-to-day guidance.
- High commitment and engagement to GitLab combined with extensive knowledge, skills, and abilities to perform in the role.

Examples:

- Constantly seeks opportunities to improve both self and organization.
- The team members exemplify great ways of giving and receiving feedback - incorporating this directly in their work.
- The team members are ambassadors for the values, take full ownership of delivering projects, and very rarely miss due dates.

**Please note that an `Exceeding` assessment for the performance factor does not guarantee a promotion. While the performance factor is a consideration, there are several considerations that are reviewed when evaluating promotion readiness. Please work with your manager to align expectations.**

### Expected Distribution Performance/Growth Potential Company-Wide

Note that this is an expected distribution, not a forced distribution. The bell curve distribution aligns with what is most commonly used as a benchmark in the industry and serves as a baseline for us to review and calibrate against. There may be exceptions that are justified that can be discussed and reviewed during calibration. Where deviations from the expected distribution occur, managers should use this as a data point to further review and work with their leadership to ensure appropriate growth plans are in place, proper role fit exists, hiring plans are adjusted, that we are promoting at a fair and accurate rate.

**We expect roughly ~5% of team members to be assess as [TNTR (Too New To Rate)](/handbook/people-group/talent-assessment/#too-new-to-rate).**
Performance:

- **Developing**: 10%, not yet meeting all of the expectations
- **Performing**: 60-65%, "on track" and meeting expectations
- **Exceeding**: 25%, consistently surpasses the demands of their current role

Growth Potential:

- **Developing**: 10%
- **Growing**: 60-65%
- **Exceeding**: 25%

Remember that "Developing" for Performance and Growth Potential should not be automatically associated with underperformance, and that many newly promoted team members and new hires fall into this category.

### The Performance Factor

While the primary objective of the performance axis of the Performance/Growth Potential Matrix is to calibrate team member performance, this axis of the matrix also directly impacts the [Performance Factor](/handbook/total-rewards/compensation/compensation-review-cycle/#performance-factor), which is a determining factor in the annual compensation review. Please reference the [Total Rewards Performance Factor page](/handbook/total-rewards/compensation/compensation-review-cycle/#performance-factor) for more detail on compensation impact.

### Measuring Performance

How can managers determine whether their team members are Developing, Performing, or Exceeding? "The Performance Factor" is determined from several components outlined below. It is *optional* to use [The Performance Factor Worksheet](https://docs.google.com/spreadsheets/d/1HHe-Vb6y6F4HXsek3sObV4IVNAGaTvXGi_9fbatT0Uo/edit#gid=241716076) for weighing the different Performance Factors.

#### Job Family Responsibilities and Functional Competencies

Performance against Job Family responsibilities, requirements, performance indicators, and functional competencies (if applicable) should be weighted at 60%.

- Review Job Families: Look at the Responsibilities section and how your team member is performing against those responsibilities
  - Example: [Software Engineer in Test](/job-families/engineering/software-engineer-in-test#responsibilities)
- Review Performance indicators per Job Family: Look at the Performance indicators.
  - Example: [Software Engineer in Test](/job-families/engineering/software-engineer-in-test#performance-indicators)
- *(if applicable)* [Functional Competencies](/handbook/people-group/competencies/#functional-competencies)

For management roles, please also review and consider the [levels](/handbook/company/structure/#levels) outlined in the Organizational Structure.

#### GitLab Competencies

Performance against these competencies should be weighted at 40%.

- [Values Competencies](/handbook/people-group/competencies/#values-competencies)
- [Remote Working Competencies](/handbook/people-group/competencies/#remote-work-competencies)
- [Job Frameworks](/handbook/company/structure/#job-frameworks)
- *(If applicable)* [Manager and Leadership Competencies](/handbook/people-group/competencies/#manager-and-leadership-competencies)

When completing the talent assessment form, team members and managers should reflect on the applicable competencies and job frameworks when filling out the achievements, strengths, and opportunities section.  Given GitLab's [CREDIT values](/handbook/values/#credit) should be lived, with each day representing a new opportunity to refamiliarize oneself with said values and strive to implement them in every professional interaction, there is an opportunity for team members and managers to rate how a team member demonstrates each of the CREDIT values.  The following rating scale is used for each value:

- **Rarely Demonstrated**: team member demonstrates some of the sub-values associated with this value on an occasional basis.
- **Sometime Demonstrated**: team member demonstrates most of the sub-values associated with this value on a regular basis.
- **Consistently Demonstrated**: team member demonstrates a large majority of the sub-values associated with the value in most interactions.

Use the comment box at the end of the CREDIT values section to provide examples to support the ratings selected.

## What is "Growth Potential"? {#what-is-growth}

While performance is focused on the past and present, growth potential is focused on the future. Because of the nature of the future-focus associated with growth potential, it is more difficult to measure than performance, and inherently more qualitative than quantitative. A key element in determining growth potential is the manager and leadership observation and experience working with team members. Managers can gauge team member growth potential against the expectations in their current role or their growth potential to take on different roles across GitLab.

Growth potential refers to the ability and desire of a team member to successfully assume increasingly more broad or complex responsibilities and learn new skills, as compared to peers and the roles' responsibilities outlined in their respective Job Family. This could include the growth potential to move up to the next level in their job family, and/or a lateral move.

The Growth Potential assessment helps managers determine the best growth trajectory for their team members. The growth potential assessment will be used as input to leverage our engagement tools, offer lateral and upwards career opportunities, and do succession planning.

Growth Potential *can change* over time as team members develop new interests, as new opportunities for growth arise, and as team members continue to broaden their knowledge, skills, and abilities.

### Measuring Growth Potential

There are four primary pillars to consider when measuring growth potential:

| "Growth Potential" Pillar | Definition |
| --------------- | ----------------- |
| Adaptability | Demonstrating a willingness and ability to learn new skills and apply them to be successful under new, tough, or difficult conditions. Ability to navigate uncertainty and be flexible with change. |
| Expandability | Expandability outside their areas (laterally or vertically), with the willingness and ability to take on a role of greater complexity, impact, and scope. |
| Consistency | Demonstrating effective problem-solving capabilities, the consistent delivery of results over time in changing circumstances, and dependability in the commitments you make. |
| Self-Awareness | The depth to which an individual recognizes skills, strengths, weaknesses, blind spots, and is able to reflect and act to improve and invest in their own development. Judgment in decision-making is also a key element of self-awareness. Judgment can be seen through our level of self-awareness in several ways, including communication, collaboration, and results. Judgment can be defined as "The ability to make considered decisions or come to well thought-out conclusions", and to do this effectively, we need to have a heightened sense of self-awareness in terms of how our communication will come across and how decisions and conclusions drawn will impact others and their willingness to collaborate. |

Under each pillar there are a few questions that managers should consider when assessing team member growth potential. Please note that the answer to all of these questions does not have to be `yes` to determine a team member is "exceeding" growth potential, the questions are here to help guide managers through the thought and evaluation process.

#### Adaptability

1. Does the team member adapt to change well? (i.e. realignments, management changes, company changes, etc.)
1. Does the team member seek to learn new skills to further succeed in their role?
1. Has the team member demonstrated ability to learn new things effectively under pressure?

#### Expandability

1. Does the team member demonstrate interest in other areas outside of the immediate scope of their role?
1. Does the team member invest time in learning new skills that will help them grow (laterally or vertically)?
1. Has the team member volunteered for any "stretch" projects or initiatives?
1. Does the team member coach, mentor, and/or influence others?

#### Consistency

1. Does the team member consistently deliver results?
1. Does the team member follow through on their commitments?
1. Is the team member dependable?
1. If scope or timeline change, does the team member communicate the change and provide updates to stakeholders?

#### Self-Awareness

1. Does the team member respond to feedback aligned with our [Receiving Feedback Guidelines](/handbook/people-group/guidance-on-feedback/#receiving-feedback)?
1. Does the team member acknowledge their strengths and areas of improvement?
1. Does the team member work towards closing gaps for their improvement areas?
1. Does the team member demonstrate sound judgment in their decision-making?

### Growth Potential Output

After assessing team member growth potential based on the four pillars outlined above, managers can determine whether team member growth potential is currently developing, growing, or exceeding.

#### Developing

"Developing" growth potential generally refers to a team member who is not working at full growth potential against the roles and responsibilities outlined in their Job Family. There could be a variety of reasons for this, including:

- They are new to their role and did not have the time to demonstrate willingness and/or ability aligned with the pillars of growth potential
- Lack of motivation to take on new projects
- Motivated to do what is needed in current job, not in what is required in a higher level
- Not expressing interest or demonstrating desire to continuously learn new skills

Please note that "developing" growth potential *does not* equate to "developing" performance, but correlates with the pillars of growth potential outlined in the "measuring growth potential" section below.

Examples:

- A team member is recently promoted or is new to the company, and hasn't had sufficient time to demonstrate the pillars of growth potential for a sustained period of time (and at the new level, if recently promoted)
- A team member has actively expressed that they do not have an interest in learning new skills or take on new projects. In a day-to-day they show self-awareness but they have not shown great adaptability, expandability and consistency to further expand on their role and responsibilities.

#### Growing

"Growing" growth potential generally refers to a team member who is growing in their current role and demonstrating interest in advancing (up or laterally) and they exhibit knowledge, skills, and abilities that indicate this. Team members with "growing" growth potential generally:

- Show interest in areas outside of their immediate scope occasionally
- Are comfortable in their current role
- Are a stable counterpart for other team members (especially for peers and more junior team members)
- Learn and apply new skills when the job calls for it; apply lessons learned to enhance success

Example:

- A team member has demonstrated adaptability and expandability but has not been consistent in their results or self-awareness. This holds the team member back from growing to a higher level or taking on more complex responsibilities in their current role.

#### Exceeding

"Exceeding" growth potential generally indicates that a team member will be ready for promotion within the next year (or when an opportunity arises). "Exceeding" growth potential team members:

- Frequently seek involvement in stretch project/projects outside of their scope
- Invest in their development; seek feedback to improve and applies that feedback on the job
- Demonstrate ability to learn new skills
- Actively pursue increased opportunities to influence decisions and inspire others

Example:

- A team member has consistently and proactively looked for opportunities to fill gaps and take on stretch projects. When another team member left the team, you leaned on this team member to help keep projects moving forward until you found a suitable backfill. They regularly ask for feedback from peers and adapt their approach accordingly. This has given your team member skills beyond their current job requirements, and broader understanding of the business.

## Calibration

The portion of the Performance/Growth Potential matrix that often entails the most significant time commitment is the live calibration session of team members with leadership. The calibration session is very valuable to ensure consistency across the Job Family and level, raise any questions, and provide cross-departmental and/or cross-divisional feedback on team members to capture the assessment of different managers as opposed to the opinion of the direct manager exclusively.

- Ensure consistency and fairness in assessments
- Calibrate on approach and thought process behind assessments
- Provide cross-departmental and/or cross-divisional feedback
- Provide an additional checkpoint to check for [unconscious bias](/handbook/company/culture/inclusion/unconscious-bias/)

Calibration can be done asynchronously or synchronously, and should be done by level (i.e. Manager calibration for their directs, Director calibration for their directs, etc.) so as not to disclose Talent Assessment evaluations amongst peers.

### Too New to Rate

For newly onboarded team members, with a tenure up to 3 months, we have implemented a "Too New to Rate" (TNTR) assessment category. This designation will be applied to individuals with a start date within 3 months of the kick off of Talent Assessment as they have not yet had sufficient time to demonstrate their Performance/Growth Potential according to the defined pillars.

The introduction of a "Too New to Rate" category is a solution as feedback was raised that being rated "Developing" in many cases does not reflect the actual Performance/Growth Potential. Therefore a TNTR designation is to accurately reflect the time to get up and running of recently onboarded team members. This category acknowledges that new hires require a reasonable timeframe to familiarize themselves with the organization, their role, and the expectations before they can be accurately assessed using the Performance/Growth Potential Matrix.

While newly onboarded team members do not need to complete the Talent Assessment evaluation in Workday, it's still important for them to have a check-in conversation with their manager. We recommend that this conversation happens after the team member has completed 3 months with GitLab. We've created [this template](https://docs.google.com/document/d/1itxP_OOuNC2oRXYu3ep_ZQdutqcZUdUyXgzQomEpuKM/edit) for team members and managers to complete. The goal would be for the newly onboarded team member and their manager to come together to have a conversation reflecting on their first 3 months at GitLab, highlighting their strengths and opportunities, then aligning on any support needed for the team member moving forward.

Besides team members with a GitLab tenure up to 3 months (New hire TNTR), the "Too New to Rate" designation will also be available for team members that have just transferred or were promoted to a new role. Please see the [Promotions or Transfer During Assessment Cycle](/handbook/people-group/talent-assessment/#promotions-or-transfers-during-assessment-cycle) section for more details and guidance on how to evaluate and consider performance in these scenarios.

If any of the above cases arise it is recommended that you discuss with your People Business Partner to ensure the Too New to Rate designation is consistently applied.

### Calibration Session

The calibration session is one of the most important pieces of the Performance/Growth Potential Matrix process, as it provides time for managers, their peers, and their manager to calibrate. Below are a few communication guidelines to ensure efficiency and fairness during the calibration session discussion.

#### Best Practices

- Be conscious of time and consider setting a (reasonable) time limit per team member being discussed.
- Review program guidelines and avoid leniency bias.
- Refer to performance data that you may have taken on a team member throughout the past year - including  any stakeholder or cross-functional feedback, performance against metrics over time, key accomplishments, etc.; this will help avoid bias like recency bias or the halo effect. Please note that when reviewing feedback for the  talent assessment, it's important to take into account areas in which the team member has improved. Two quarters is a fairly significant amount of time and team members have (hopefully) taken action on improvement areas during this period, which should be reflected in the assessment. Managers and other participants in calibration discussions should be prepared with this information if asked how they determined a rating.
- Leaders should feel comfortable providing feedback on team members in other functions that they have direct experience working with.
- Focus on discussing artifacts that are relevant to the performance factor and refrain from discussing artifacts that are not relevant to performance being developing, performing or exceeding. Examples of artifacts which are not relevant: upcoming maternity/parental leave, personal information/home situation or things that were confidentially shared and do not relate to performance.
- Refer to the competencies, job family, job frameworks and values when deciding what is relevant.
- Utilize the SBI model for [feedback](/handbook/people-group/guidance-on-feedback/#s-b-i-model). Focus on facts and avoid blanket statements as opposed to (i.e. [team member] has poor communication), "[team member] struggled with collaboration during the roll-out of x project and could have improved communciation by ensuring they aligned with x stakeholders more regularly during the process. The impact of this was x."
- Calibration is not a stack ranking of team members. While some inter-person comparison may happen, it should only be to ensure that evaluations are being applied fairly across different raters.
- **Ask questions and provide feedback!** This may seem obvious, but it is an important aspect to help identify any potential bias

##### Who Do I Calibrate?

It is likely not necessary to discuss each team member in detail, particularly for larger groups. Calibration sessions typically focus on gaps, outliers and areas that might require additional management attention and/or alignment.

As a best practice, we should calibrate outliers. "Outliers" are typically considered to [Box 1 ("Exceeding Growth Potential" and "Exceeding Performance") and Box 9 ("Developing Growth Potential" and "Developing Performance")](/handbook/people-group/talent-assessment). [People Business Partners](/handbook/people-group#people-business-partner-alignment-to-division) and business leaders have discretion to expand this threshold as needed, but live calibration for team members in Box 1 and Box 9 should be the baseline across the board.

A few additional reasons to consider calibrating beyond Box 1 and Box 9 are:

- Team members close to promotion
- Team members who have changed assessments from the previous fiscal year (i.e. "Performing Performance" to "Exceeding Performance")
- Team members in Box 3 ("Exceeding Growth Potential" and "Performing Performance") to highlight potential development opportunities from peer groups
- Outliers based on Performance alone (i.e. everyone "Developing Performance" and everyone "Exceeding performance")
- Anyone hired in the last 3 months assessed as Performing or Exceeding for Performance aligned with eligibility guidance
- Anyone identified as Key Talent

#### Calibration Session Pre-Work

It is **absolutely essential** that managers complete the required pre-work to ensure that the live calibration session is as efficient and productive as possible. Pre-work includes:

- For calibration sessions you can leverage [this agenda template](https://docs.google.com/document/d/1zrlZSfdNXpSZ09uvDM71KxH42RWBJxa6U1QTCTw05iI/edit)
- Review the team member's own [Self-Evaluation](#team-member-self-evaluations)  if they have completed one, if they wished to complete one.
- Review the Job Family/Families that will be calibrated in detail
- Review our competencies
  - [Talent Assessment Training in LevelUp](https://levelup.gitlab.com/access/saml/login/internal-team-members?returnTo=https://levelup.gitlab.com/learn/course/talent-assessment)
  - [Job frameworks](/handbook/company/structure/#job-frameworks)
  - [High Performing Team Indicators](/https://internal.gitlab.com/handbook/company/high-performing-teams/?search=values#high-performing-teams-indicators)
  - [Values competencies](/handbook/people-group/competencies/#values-competencies)
  - [Remote work competencies](/handbook/people-group/competencies/#remote-work-competencies)
  - [Functional competencies](/handbook/people-group/competencies/#functional-competencies) *(if applicable)*
- Review our [Unconscious Bias](/handbook/company/culture/inclusion/unconscious-bias/) handbook page and consider watching our [Recognizing Bias Training](/handbook/company/culture/inclusion/unconscious-bias/#recognizing-bias-training) if you haven't already.
- Review the [Performance/Growth Potential Matrix Training Information](https://docs.google.com/presentation/d/151ys8xkOak9ifU9IPXQydZ44sb_BoMpMocWmjVonLHE/edit), which delves into definitions for each box.
- Determine the appropriate box for each of your team members
- Add notes for each of your team members to the agenda, at least 12 hours before the session
  - An example of notes could include:
    - 2-3 strengths/accomplishments (and supporting examples)
    - 2-3 improvement areas
    - Anything else noteworthy (i.e. recently promoted or transferred, etc.)
- Keep the [SBI Model](/handbook/people-group/guidance-on-feedback/#s-b-i-model) (Situation, Behavior, Impact) in mind when adding notes for strengths/accomplishments and improvement areas. Each point should include clear examples and blanket statements should be avoided.
- Review the notes of your peers for other team members and add feedback/questions/thoughts for discussion
- If you did not attend the people manager live training session, please access the training video.

#### Topics To Avoid

While we want to encourage open and transparent conversation during calibration session, there are certain topics that should be avoided to ensure we respect team member privacy.

- Sharing whether team members are currently undergoing [formal performance remediation](/handbook/leadership/underperformance/#options-for-remediation). It is okay to share that team members are receiving coaching, but specifics pertaining to Written coaching, PIPs, etc. should be avoided.
- Anything related to health (i.e. medical diagnoses, conditions, disabilities, etc.). It is okay to share that team members have a lot going on in their personal lives, but we should not go into detail. *Note that this applies for team member's friends/family as well.*

## Identifying Action

After the calibration sessions the performance and growth potential outcomes can be used as input for the following:

- [Career Development Conversations](/handbook/leadership/1-1/#career-development-discussion-at-the-1-1)
- Promotion planning
- Identifying [L&D opportunities](/handbook/people-group/learning-and-development)
- Succession Planning

## Q4 Formal Talent Assessment

### Timeline

Below is the high level timeline for the formal assessment beginning in Q4 FY25 (January). Different departments may have additional due dates built into the high level timeline, so please follow up with your [People Business Partner](/handbook/people-group#people-business-partner-alignment-to-division) if you have any questions.

- **2025-01-27:** Kick off Optional Self-Evaluation cycle for all Team Members
- **2025-02-06 (5:00pm PST):** Due date for all Self-Evaluations
- **2025-02-07:** Workday Calibration open and calibration discussions occur
- **2025-02-28:** 5:00pm PST Workday Calibration will be locked
- **2025-03-03**: Kick off Manager Evaluation cycle
- **2025-03-07:** Annual Compensation Review Kicks off for Managers
- **2025-03-15:** Due date for all Manager evaluations. 5:00pm PST Talent Assessment in Workday is locked.
- **2025-03-31 to 2025-04-02:** Total Rewards and final E-Group review and approval
- **2025-04-27 to 2025-04-30:** Managers can communicate Performance/Growth Potential assessment and Annual Compensation Review to team members
- **TBD:** Talent Assessments pending in Workday will be auto advanced to team members*
- **2025-05-01:** Annual Compensation Review effective date

*Team members who are on Leave of Absence (LOA) on TBD are excluded from the auto advancement of their talent assessment until they return to work.

Note: For full details on our Annual Compensation Review (ACR) timeline and cycle, pelase refer to our ACR [handbook page](/handbook/total-rewards/compensation/compensation-review-cycle/).

### Cadence

GitLab completes talent assessment *at least* once per year in Q4, with a recommended informal mid-year check-in. The formal assessment ideally takes place prior to the [annual compensation review](/handbook/total-rewards/compensation/compensation-review-cycle/#annual-compensation-review). Our e-group completes Performance/Growth Potential Matrix multiple times a year for their direct reports.

### Eligibility

Anyone hired on or before January 31st should receive a Performance and Growth Potential assessment, as they are eligible for Annual Compensation Review. However, if the team member being assessed has been with GitLab for a period of 3 months or less or recently transferred roles or was promoted, please see the [Too New To Rate description](/handbook/people-group/talent-assessment/#too-new-to-rate).

### Team Member Self-Evaluations

It is up to all team members' discretion if they wish to complete their Self-Evaluation in Workday. While they are volunatary, self evaluations are highly encouraged so the team member's perspective is captured and shared with their manager prior to the manager's evaluation and Calibration Sessions. Please review the most current [timeline](#timeline) to ensure a timely delivery.

### Matrix Assessment Timeline

The Performance/Growth Potential Matrix typically takes 4-6 weeks to complete from beginning to end. Steps are as follows:

1. Team members have the opportunity to complete a Performance Review Self-Evaluation if they so wish, and share it with their manager through Workday.
1. Managers complete a Manager evaluation and Performance/Growth Potential ratings for their respective team members
1. Live session takes place for calibration with managers up to E-Group level
1. Executive Review (leadership meets to review the matrix results, key talent, promotion requests, development and performance actions, review discrepancies, and measure against previous matrix results)
1. Talent Management and People Analytics performs an equality review.
1. Final approval of E-Group members and Total Rewards.
1. Annual Compensation review kicks off after Talent Assessment
1. Performance/Growth Potential and Annual Compensation Review updates are communicated to team members

### Final Assessments in Workday

Aligned with the [timeline](#timeline), managers can see final assessments for each of their team members in their respective Workday profiles.

## Promotions or Transfers During Assessment Cycle

The cut-off date to determine whether to assess team members as Too New to Rate based on recent promotion/transfer for the FY25 Talent Assessment cycle is based on their time in role prior to the start of the Talent Assessment cycle, **2025-01-27**. Guidelines are as follows:

1. **If a team member interviews and transfers or is promoted to a new role, with an effective date *within* 90 days of the start of the talent assessment cycle or throughout the talent assessment cycle (on or after 2024-10-01), guidance would be that they should be assessed as Too New to Rate.**
1. **If a team member interviews and transfers to a new role or was promoted to a new role more than 90 days before the start of the talent assessment cycle (on or before 2024-10-01) they would be assessed based on the new level/role.**

It is important to note that because being promoted recognizes high performance both in terms of increased scope/responsibility and monetarily through compensation increase therefore a **promotion "resets" the performance factor evaluation**.

While a recent promotion resets the performance factor evaluation, and a job transfer is internal mobility that may be a lateral job level, there are  soft skills and technical skills that are most likely transferable. When assessing team members who have transferred teams or changed roles throughout the year, managers should gather feedback from the previous manager on performance as well and take that into account when evaluating and documenting performance to reflect performance for the entire year. Managers should also provide the team member feedback on how they're doing in their current role to ensure they're set up for success, and aware of feedback moving forward in their current position.

## Best Practices for Communicating Performance/Growth Potential Factors

## Communication

In most companies the Performance/Growth Potential Matrix is used exclusively as a management tool and results are not typically shared with team members. In the spirit of our transparency value, we want to encourage feedback with team members. **Discussion topics that arise during calibration sessions (or at any other point during the assessment process) are confidential. Please do not share with anyone other than each individual team member.**

After calibration sessions are done and performance and growth potential factors are determined, it's time to communicate the final results with team members. **Communications can begin after you have been notified that final talent assessment factors have been approved by the E-group**. The conversation following the talent assessment process is the most important part; it is a great way to drive alignment with your team members and set them up for success moving forward.  Below are  some of the best practices for communications, but remember, if you are ever in doubt please reach out to your manager or [People Business Partner](/handbook/people-group#people-business-partner-alignment-to-division) for additional support.

1. **Communicate performance and growth potential factors face-to-face over Zoom**. As a manager, this is the opportunity for you to have a conversation with your team member about their performance and growth potential. Having the conversation over Zoom allows for you to have a dialogue with your team member (versus just sharing their performance and growth potential factor asynchronously) and allows you to pick up other information, like tone and non-verbal cues which can tell you more about how someone is feeling during this conversation. You may also choose to share the PDF of the review prior to the conversation so that your team member has time to process the information. If so, ideally share just 1-2 days prior to the conversation so you are able to address questions promptly.
1. **Prepare for the discussion ahead of time.** As a manager, you should prepare in advance of calibration discussions with your team members. Before communicating a team member's [performance and growth potential factors](/handbook/total-rewards/compensation/compensation-review-cycle/#performance-factor), it's beneficial to look back through your preparation document, notes, and anything relevant that was discussed as part of the calibration exercise. Be prepared with notes on the following:
    - Areas the team member is doing well
    - Areas that need improvement
    - Areas that you identified as either strengths and/or development areas that differed from the team member's self-assessment.
    - Provide specific examples for both strengths and improvement areas. The [SBI](/handbook/people-group/guidance-on-feedback/#s-b-i-model) (Situation - Behavior - Impact) model can be effective for delivering examples structured in a way that makes impact clear to team members.
    - Think about recommendations and/or focus areas for a team member's development OR if a team member has an active [Individual Growth Plan(IGP)](/handbook/people-group/learning-and-development/career-development/igp-guide/), consider how the feedback fits into their current IGP
1. **Schedule a separate call or repurpose your [1:1](/handbook/leadership/1-1/)) to discuss a team member's performance and growth potential factor**. The performance and growth potential factors should be communicated at the beginning of the meeting. This allows the team member time to ask questions, discuss their assessment, and most importantly, determine next steps. If your 1:1s are often filled with agenda items, the recommendation is to schedule another call to make sure you have ample time allocated.
1. **Protect the confidentiality of other team members** by avoiding saying things like "you were the only team member to be rated this performance factor."
1. **Avoid making future promises** like, "In the next review, I will rate you X performance/growth potential factor."

### Sample Script for Delivering a Talent Assessment

The script below is intended to help you structure your Performance and Growth Potential conversation. Personalizing this conversation to reflect your authentic tone will make this a more effective conversation with your team member.

"Thank you for taking some time today to discuss your Performance and Growth Potential. I wanted to discuss your achievements and strengths, improvement areas, future development, and the final result of the talent assessment."

"I assessed your performance factor as ****[Insert Performance factor]***:"

- ***Exceeding*** (consistently surpassing the demands of their current position)
- ***Performing*** ("on track" and meeting all expectations of current position)
- ***Developing*** (room to learn and grow, not currently meeting all expectations of current position)
- ***Too New To Rate*** (hired or transferred <90 days from the start of the Talent Assessment program)

"I assessed your performance as ***[Insert Performance Factor]*** because:"

- I assessed your performance against your job responsibilities as ***[Insert Performance Factor]***.
  - Your strengths in your job responsibilities are [Insert strengths with supporting examples]
  - Your opportunities in your job responsibilities are [Insert opportunities with supporting examples]
- I assessed your performance against values competencies as ***[Insert Performance Factor]***.
  - Your strengths in aligned competencies are [Insert strengths with supporting examples]
  - Your opportunities in aligned competencies are [Insert opportunities with supporting examples]

"I assessed your growth potential factor as ****[Insert Growth potential factor]***:"

- ***Exceeding*** (ready to take on more responsibilities within the next year (or when an opportunity arises))
- ***Growing*** (growing in current role, demonstrating interest in advancing (up or laterally) and they exhibit knowledge, skills, and abilities that indicate this.)
- ***Developing*** (not working at full growth potential against the roles and responsibilities)

"I assessed your growth potential as ***[Insert Growth Potential Factor]*** because:"

- I assessed your growth potential against the four pillars of growth potential as ***[Insert Growth Potential Factor]***.
  - You have shown X, Y, Z [Insert strengths with supporting examples]
  - Your opportunities to further grow in your role are X, Y, Z are [Insert opportunities with supporting examples]

If a team member was identified as **key talent**, please ensure to communicate to the team member during the talent assessment conversation.

I'd like to thank you for your hard work as, and I look forward to continuing to work together! Do you have any questions? ***[Allow team member to ask questions and respond]***
As a next step, let's schedule some time to talk more about what you want to do in the future and create a career development plan together OR let's talk about how this feedback should be incorporated into your Individual Growth Plan.

### Sample Next Steps

The most important part of the talent assessment discussion is to determine next steps in partnership with your team member. The team member should be the DRI for the next steps with support from you as their manager. Our [Career Development handbook page](/handbook/people-group/learning-and-development/career-development/) includes a lot of great information and resources on career development including [an Individual Growth Plan guide](/handbook/people-group/learning-and-development/career-development/igp-guide/) which should help provide structure and a plan for next steps.
If you have any questions or concerns about next steps, please contact your manager and/or your [People Business Partner](/handbook/people-group#people-business-partner-alignment-to-division).

## Information Guide

### Performance/Growth Potential Review General Information

- **Why does this matter to me?**

The Talent Assessment involves all team members and managers.

- Team Members are assessed according to [performance](#what-is-performance) and [growth potential](#what-is-growth). Team Members should be prepared to have a conversation with their manager about their performance and growth potential in **Q1** each year.
- Managers assess their team members' [performance](#what-is-performance) and [growth potential](#what-is-growth). Managers attend calibration meetings in which team members' ratings are discussed and evaluated to ensure consistency and minimize bias. Once the program closes, managers are responsible for communicating Performance/Growth Potential Factor to team members.

- **How does this impact the way I work at GitLab?**
  - [The Performance Assessment](#what-is-performance) is an evaluation of your performance against [job family responsibilities](#job-family-responsibilities-and-functional-competencies) and [GitLab competencies](#gitlab-competencies) and [Growth](#what-is-growth) is evaluated against the 4 pillars of Growth Potential. Both can help you determine strengths and improvement areas that you can apply in your day-to-day work/way you work.

- **How does this impact the teams I lead?**
  - As a manager, you assess your team members' [performance](#what-is-performance) and [growth potential](#what-is-growth). Managers attend calibration meetings in which team members' assessments are discussed and evaluated to ensure consistency and minimise bias. Once the program closes, managers are responsible for communicating Performance/Growth Potential Factor to team members.

- **Who can I reach out to in supporting me during Talent Assessments for my team?**
  - You can reach out to your manager or your [aligned People Business Partner](/handbook/people-group/#people-business-partner-alignment-to-division).

- **As a manager, when reviewing my team members, what is the difference between Developing and Underperformance?**
  - The "Developing" rating means that the team member is not (yet) meeting all of the responsibilities and competencies for the role. This can be for many reasons, including a recent start date. By contrast, [Underperformance](/handbook/leadership/underperformance/) involves *consistently* not meeting the goals and requirements of the job; GitLab follows specific processes to attempt to remediate.
  - While everyone within the Developing category isn't automatically Underperforming, a team member who is Underperforming would also be grouped into the Developing category, because Performing is not an accurate assessment.
  - Team members who are on a formal Underperformance remediation plan, such as a [Performance Improvement Plan](/handbook/leadership/underperformance/#performance-improvement-plan-pip), are not eligible for a compensation increase as a result of the [Annual Compensation Review](/handbook/total-rewards/compensation/compensation-review-cycle/).

- **Will my Growth Potential assessment impact my compensation?**
  - Yes in FY25 both Performance, Growth Potential, and Key Talent Assessment can impact your Total Rewards.

    If you have any questions, please reach out to your aligned [People Business Partner](/handbook/people-group/#people-business-partner-alignment-to-division).

- **Can my performance factor be changed?**
  - After the Talent Assessment closes, the performance factor cannot be changed. You should work with your manager to develop a plan to develop your performance for future assessments.

- **Does this mean I am automatically getting an X% increase in the upcoming Annual Compensation Review?**
The Performance/Growth Potential Factor is one of the factors considered in the [Annual Compensation review](/handbook/total-rewards/compensation/compensation-review-cycle/). The recommended increases displayed in the handbook are there to ensure company wide consistency. The factors taken into account for the Annual Compensation Review are:
  - Your hire date (new hires hired after October 31st are ineligible for compensation review)
  - Other compensation increases received over the last year
  - Timing of promotion and/or role changes
  - Your current placement within the compensation band
  - Location factor
  - Role benchmark updates
  - Company budget for compensation increases

- **When is the next opportunity for my performance to be reviewed?**
  - Talent Assessments are performed twice per year -- one mid-year (Q2) and one at the end of fiscal year (Q4).

- **What can I do to change my performance factor in the future?**
  - There are many things that you can do to change your performance factor in the future. Please work with your manager on a career development plan and discuss actions that can be taken to improve.

- **Can my Growth Potential rating be changed?**
  - After the Talent Assessment closes, your growth potential factor cannot be changed. Your manager assessed your growth potential factor and this would be an opportunity for you and your manager to align on your growth opportunities. This discussion can also be an input into your career development discussion.

- **What can I do to change my Growth Potential rating in the future?**
  - There are many things that a team member can do to change their growth potential factor in the future. Talk with your manager about how you might be able to develop a plan to increase your [expandability, adaptability, consistency and self-awareness](/handbook/people-group/talent-assessment/#measuring-growth). Do you currently possess all the skills needed for your current role? Have you identified what skills you would like to learn? Have you determined what your career goals are, and are you actively working towards those goals? Are there additional projects to take on, to stretch your current responsibilities and/or skills? These are some discussion questions that might help you and your manager align on a future plan for growth.

- **My team member is currently on a performance remediation plan; how should I handle this?**
  - You should continue to move forward with communicating their performance factor to them and use the meeting as an opportunity to reinforce the expectations of meeting the goals highlighted in the plan.

### Talent Assessment - Manager Scenarios

**My team member is on a leave (protected leave or PTO) during the Talent Assessment period. How should I handle communication of their assessment?**

If they will be returning from leave before the due date to communicate [Talent Assessment results](#timeline), please wait until their return from leave to communicate their assessment. If they are returning from leave after the due date to communicate Talent Assessment results, you may email them to offer to discuss their assessment. If they do not reply or prefer to wait until their return, please respect that choice.

**My team member was on protected leave for a large portion of the Talent Assessment period. How should I factor this in when assessing them?**

It's important to ensure you are assessing the team member's performance for their contributions while working during the assessment time period. There should be no adverse impact on their overall assessment due to being on leave for a portion of the period. During calibration, please remain vigilant to ensure no private details related to their time away are disclosed. Please reach out to your PBP to discuss the specific details related to your team member.

**My team member is on leave of absence during the Talent Assessment communication window. What happens to their Talent Assessment?**

Please do not action the To-Do task "Meet with your Employee" if your team member is on leave of absence (LOA). We will exclude team members on LOA from the auto advancement setting on TBD and you can communicate their talent assessment when they return to work.

**My team member was assessed as key talent last year, and is not for this assessment period. How should I handle communication with them?**

There is no guarantee that team members will retain their key talent assessment each assessment period. Make sure to explain the reasons why their key talent assessment has changed, including how we assess Key Talent and the [definition outlined in the Handbook](#key-talent).
Remember to end the conversation by discussing what your expectations are of key talent going forward. It's important not to make promises about future assessments, but to focus on what makes a team member critical to the business, and how you, their manager, will support them.

**My team member was exceeding performance last assessment, and is not for this period. How should I communicate this change?**

It's important to take a look at what may have changed since last year. Is your team member in a new role? On a new team? Did they take on bigger stretch assignments?
Any of these factors can influence a team member's performance. Be prepared with specific examples to share which support your performance assessment. The feedback conversation should also focus on what success looks like for the team member in the year to come and how you, as the manager, can support them with their goals.

**I have just adopted a new team, and the previous manager is no longer at GitLab. How can I assess the performance of my team fairly?**

You may be able to gather insights from your manager or cross functional stakeholders who have worked closely with the team member in the performance period. You may have access to the recent 360 feedback for each of your team members, as well as their talent assessment from last year to help inform your thinking. If you haven't already, it's important to ask the team member to share their own perspective on their accomplishments prior to you taking the role, so you are well prepared for the discussion of your assessment.

**My team member does not agree with their placement in performance and growth potential. How should I approach this?**

Remember that this conversation will be most effective if you are well prepared. If you haven't yet, take an opportunity before the performance and growth potential conversation to understand their own assessment of their results.
During the performance and growth potential conversation, provide the opportunity for a dialogue with your team member. Remain open and curious about their perspective. Engage in active listening, ensuring that you aren't planning your counterpoints while they are sharing. The expectation is not that the results will necessarily change but the insights they provide may shape how you both think about their growth and development path.
If you feel a conversation might be particularly challenging, you may reach out to the TMR team or your PBP to role play the discussion and ensure you are prepared.

**My team member is exceeding growth potential expectations, how should I be thinking about their ongoing development?**

Great! At GitLab team members have the opportunity to own their own development, and deserve a great manager (you) to facilitate it. Ask your team member to articulate where they would like to see their skills and career develop. You may have insights that help them refine those goals based on where you see the business going, as they will be most successful in gaining the experience they're looking for if there are opportunities to align those goals with business goals.
Using the [70-20-10 model for learning](/handbook/people-group/learning-and-development/growth-and-development/#70-20-10-rule-for-development), help your team member identify experiential and formal learning opportunities, and consider connections you can facilitate that will support their growth.
The [Career Development handbook page](/handbook/people-group/learning-and-development/growth-and-development/) has more ideas to help your team member craft a growth plan, including information on GitLab's [Growth and Development benefit](/handbook/people-group/learning-and-development/growth-and-development/).

**How should we be communicating Growth Potential to team members who we haven't communicated this to before?**

First, ensure the team member understands what we mean when we say we are assessing Growth Potential, including the [4 pillars](#what-is-growth) that you considered when making the assessment. Be prepared with specifics that led to your evaluation.
Remember, Growth Potential can change over time as team members are promoted, develop new interests, as new opportunities for growth arise, and as team members continue to broaden their knowledge, skills, and abilities. Avoid making promises, but if your team member sees themselves in a higher position, help them understand behaviors you expect to be able to assess them differently next time.

**I received unexpected feedback about my team member from a cross-functional stakeholder in my calibration session. What should I do?**

If you receive unexpected feedback during the calibration, ensure you really understand what happened, and what has been discussed with your team member so far. If someone has tried to help this team member in the past, how did it go? Can your peer provide specifics to help you understand the impact of the behaviors? Talk to your peer about the importance of using this feedback to help your team member grow, and make sure you have agreement on how you plan to deliver this message.
During the discussion with your team member, be prepared to gain their perspective on the situation first. Listen actively and consider their point of view. When delivering the message, consider the root cause, focus on impact and alignment with our values, and end with a discussion on future actions that would be more successful.
If and when appropriate, check in with your peer on how improvements are going. Be sure to stay close to the situation so you are in a position to deliver more timely feedback if the behavior is ongoing.

**How do I assess team members in acting or interim roles?**

For team members who have assumed an [Acting or an Interim role](/handbook/people-group/promotions-transfers/#interim-and-acting-roles), we will assess team members aligned with their *permanent positions* (i.e. not the Acting or Interim position).
As the Talent Assessment impacts compensation, and Acting/Interim periods are not permanent, in the instance that a team member does not end up moving into the Acting/Interim role permanently, we would not want to have their compensation impacted by a temporary position.

**My team member is performing at a high level in terms of results, but they struggle with behavioral alignment to one or more of our values. How do I take the "how" into account when I am assessing their performance and growth?**

Review the handbook content on how we [measure Performance](#measuring-performance) and how we [measure Growth Potential](#measuring-growth). When a high output/results-oriented team member is struggling with soft skills and/or behavior, this is oftentimes related to improvement areas in terms of alignment to our [values competencies](#gitlab-competencies), and/or our [Growth Potential pillars](#measuring-growth) (particularly, but not limited to, Self-Awareness). Considering our measurement guidelines for Performance and Growth Potential holistically, and be sure that your assessment takes all of our competencies, job family responsibilities, and pillars into account.

**My team member has the skills to perform, but there are [will-based performance issues](/handbook/leadership/underperformance/#will-based-performance) that are impacting their ability or the team's ability to succeed. How should I think about this in terms of assessing their performance?**

First, act early. Do not wait for a formal performance and growth potential assessment conversation to deliver feedback about your concerns. Be specific, and document your conversation. Loop in a TMR specialist for support as these conversations can be challenging.

Review the definition of "Developing" performance. Note that one criteria that applies to this category is a team member who is struggling to perform in a way that is aligned to our values and competencies. Think about the specific behaviors or impacts of their work or how they are working that have led you to assess that they are not fully engaged. Despite having the skills, if your team member is not contributing at the level they are expected to be, you should consider that a performance issue in the way you would a skill based performance issue. Keep in mind that not addressing these challenges may be affecting your other team members, especially those who may be picking up the slack. We encourage to review the handbook page on [Underperformance](/handbook/leadership/underperformance/#talent-assessment-and-managing-underperformance).

## Mid-Year Check In

Great managers share [feedback](/handbook/people-group/guidance-on-feedback/) with team members year-round in 1:1 meetings and ad-hoc. A dedicated Mid-Year check-in is a useful tool to support a  holistic discussion between team member and manager about how things are going as we approach the second half of the fiscal year. During the Mid-Year check in, we assess how things are going from both the team member and managers' points of view, and share feedback to help inform performance and development plans. Leaning into where things are going well, as well as uncovering blind spots or improvement areas early are the keys to delivering great results. A Mid-Year check in complements weekly, on-going feedback, so we recommend documenting your discussion in your 1:1 doc to support frequent updates on action items and development goals.

Goals of the Mid-Year check in are:

- To provide a dedicated space for questions/clarification about performance and growth opportunities at GitLab
- Team members share a cumulative self assessment of their performance against expectations and progress on development goals
- Managers respond, and provide their own cumulative update to the team member on how things are going. This should build on the regular performance feedback they should be delivering weekly in 1:1s and ensure no surprises at the end of the year review.

### Eligibility

To participate in the mid-year check in we recommend that team members have at least 3 months of tenure so accomplishments and improvement areas are able to be clearly outlined with examples.

### Process

Recommended process for our Mid Year check-in will be as follows:

1. *Team Member Led: Team member provides a self-assessment on their own performance in their [1:1 document](/handbook/leadership/1-1/)*

   A [Google docs template](https://docs.google.com/document/d/1KOmpCXAGTJdS7hMKsuOZZpo803ECUsCd1xnryj7z0B4/edit) is available to guide the self-assessment process. Team members are encouraged to author a document based on this template, share it with their manager and link it to the top of their 1:1 document. Team members should reflect on their achievements, strengths, and opportunity areas since the last formal Talent Assessment in Q4. It is the team member's responsibility to provide the self-assessment and bring it to the conversation with their manager to discuss and align on. Linking the document to the 1:1 agenda ensures the self-assessment is available to come back to throughout the rest of the year.

    The template contains an agenda for the Mid-Year check-in as follows:

    - **Achievements**

      List your 3 most significant achievements since the last formal [Talent Assessment](/handbook/people-group/talent-assessment), aligned with the job responsibilities and expectations of the role. This can include significant impact to the department or company, customer-impact, community-impacting, etc. Feedback can also be included in this section if applicable.

    - **Strengths & Opportunities in Role**

      In this area the goal is to determine 2-3 strengths and 2-3 opportunity areas in accordance with your role, job family, and [job framework](/handbook/company/structure/#job-frameworks). Include examples when necessary to provide clarity or context.  Ensure there are actionable takeaways.

    - **Support Needed**

      A place to outline any support needed from your manager for your ongoing success and development at GitLab.

    - **Manager Feedback**

      Managers will provide additional feedback or response to the self-assessment outlined above. Managers should be sure to reference the Achievements (3) and Roles & Responsibilities (Strengths and Opportunities) outlined by the team member above, and to any additional thoughts or feedback (2-3 points).

    - **Next Steps**

      A space for the team member and manager to document any relevant next steps stemming from this conversation. This could be a full [Individual Growth Plan](/handbook/people-group/learning-and-development/career-development/#individual-growth-plan) or a couple of key actions or development opportunities for the individual.

1. *Manager Feedback: Team members let their manager know when they have provided their self-assessment overview in their [1:1 document](/handbook/leadership/1-1/)*

   Team members should share their Mid-Year Check In document with their manager at least one week prior to the live discussion to ensure managers have time to review the content, and to add in their own feedback in the `Manager Feedback` section.

1. *Live Discussion*

   Team members and managers use a dedicated 1:1 to discuss the Mid Year check in.

1. *Align on actions/next steps*

   Team member and manager align on action items stemming from the conversation to best support team member development and alignment to their goals. You are encourage to leverage our [Career Development and Mobility](/handbook/people-group/learning-and-development/career-development/)) handbook page for ideas and inspiration.

### Timeline

Mid-Year Check In launch:

- TBD

Mid-Year Check In end:

- TBD

We have intentionally provided a longer timeline to ensure different business group priorities are accommodated.

## Succession Planning

Succession planning is an important step in our Talent Assessment process. Completing the [Performance/Growth Potential Assessment](/handbook/people-group/talent-assessment) gives leaders a fresh overview of the top performers and the highest growth team members in their respective organizations. Particularly for individuals in Senior Leadership roles and above (the [S-Group](/handbook/company/structure/#s-group) and depending on structure the [Director-Group](/handbook/company/structure/#director-group), a recommended next step following the Performance/Growth Potential assessment is to do succession planning.

Succession planning ensures we are identifying and developing future GitLab leaders to ensure business continuity in the event of an unforeseen change, and providing the current leadership team the opportunity to grow and scale. It may provide an opportunity to diversify our leadership team by developing our internal bench of talent. Note, potential alone does not determine who will be a successor. Strong succession candidates should demonstrate sustained exceeding performance and growth, aspire to have a role at the next level, and be ready for a much larger role in the near term.

Questions we should ask ourselves when thinking about succession planning (and the individual(s) identified) are:

1. What are our current and upcoming business goals?
1. Does the successor candidate have a track record of delivering strategic results, working in alignment with our values, and demonstrating high growth potential?
1. Does our successor candidate have skill gaps that must close before they are ready to deliver on the business goals identified?
1. *(if we do have skill gaps)* Can we develop our successors to close those gaps? If so, how? How long will this additional exposure and skill development take? Who else at GitLab should we engage to support their development?
1. If not, do we need to hire externally to ensure business continuity?
1. If we do not have anyone who could assume the role in an emergency situation, what is our plan to provide emergency coverage?

### Succession Planning Process

The succession planning process might vary slightly for different areas of the business depending on size and structure, but at a high level the process should flow as follows:

1. **Leaders go through the [Performance/Growth Potential Assessment](/handbook/people-group/talent-assessment/#the-performancepotential-matrix) process for all of their direct reports.** Ideally, this process includes [calibration](/handbook/people-group/talent-assessment/#calibration-session-guidelines) to generate a level of initial familiarity amongst leadership peers with the talent in the organization.
1. **Leaders identify and document their respective successors** (and emergency coverage plans if the identified successor could not currently cover in an emergency situation) leveraging [this template](https://docs.google.com/presentation/d/1w-ODnm-S_sV7TAEDqfU6kUpZqr7-cDIFwAlPZI10HzU/edit#slide=id.p).
1. **Succession plans are reviewed with peers** (i.e. all other executives, all other senior leaders in the function, etc.) and your [People Business Partner](/handbook/people-group#people-business-partner-alignment-to-division), ideally during a synchronous session to facilitate discussion and questions.
1. **Development plans are finalized** for successors and documented in the successor slide.
1. *(if applicable)* **Skills gaps impacting ability to achieve business goals are identified and actions are put in place** to ensure these gaps are closed/minimized (i.e. stretch assignments, increased visibility and exposure, or hiring)

### Succession Readiness Definitions

| Succession Readiness    | Description |
|-----------|---|
| Emergency (ER) | Someone who could take over this role if the current person were affected by a [lottery factor](/handbook/total-rewards/compensation/#competitive-rate) or had to take emergency leave. Has competency and experience to provide coverage on an interim basis (~6 months), but may not be suitable for the role long-term *Note: If there is no one who could assume the role today in an emergency situation, part of the succession coverage plan should include an overview of recommendation steps (i.e. engaging a consultancy, splitting up the team, etc.)* |
| Ready Now (RN) | Someone who has 90% of the competency & experience to take the role now |
| Ready in 1-2 years | With additional responsibility & exposure, could take the role soon. Likely has the competency and experience to provide coverage on an interim basis if there is an urgent business need |
| Ready in 2-3+ years | Longer term candidate who requires significant development. May also have the competency to provide coverage on an interim basis if there is an urgent business need. |

*Note that the `Emergency Coverage` slide in the [template above](https://docs.google.com/presentation/d/1w-ODnm-S_sV7TAEDqfU6kUpZqr7-cDIFwAlPZI10HzU/edit#slide=id.gf99d467451_1_8) should only be used to if the identified successor could not provide temporary coverage for the current leader in an emergency situation.*

## Resources

| Resource | Purpose |
| ------ | ------ |
| [Workday: Self Assessment & Manager Evaluation Template](https://docs.google.com/document/d/1bdGDq85nY3uLRFLrmKV5RDyQpGkPmnvGAI1pN_RRNto/edit?usp=sharing) | Team members and managers can leverage this template to begin thinking through and documenting the optional self-assessment and the manager evaluation for the Talent Assessment. Please note that this template is for team members who would like to get an early start ahead of Workday launching the Talent Assessment cycle, however, all assessments will need to be transferred over to Workday for formal documentation and calibration.  |
| [Workday Job Aid: How to Complete My Annual Self Evaluation](https://docs.google.com/document/d/1xLsiB6RljJUQGT9EWbNOMqCVL-Kb8dS1PivriVjgz5E/edit?usp=sharing) | Team member instructions for how to complete their annual Self-Evaluation task in Workday. |
| [Workday Job Aid: How to Complete the Manager  Evaluation and Assess Growth Potential](https://docs.google.com/document/d/11wq7xkWi0O6a_YXtkH8RSy7DX5Rvxx1j7muWkaFIym0/edit?usp=sharing) | Manager instructions for how to complete their Manager Evaluation task and Assess Growth Potential task in Workday. |
| [Workday Job Aid: How to Complete Talent Calibration](https://docs.google.com/document/d/1rcHLTE3cvmh_zglHO789uqaN25vYhvGSFRBbHMg8tJk/edit?usp=sharing) | Manager instructions for how to complete their Talent Calibration in Workday. |
| [Workday Job Aid: How to Facilitate Calibration - PBPs](https://docs.google.com/document/d/1NZWGjhwGnRDcP2ANnyg8PLsNY-tRSlH5V8sEoSCE1Dc/edit) | PBP instructions for how to facilitate calibration sessions in Workday.|
| [Workday Calibration Video Tutorial](https://drive.google.com/file/d/1WiX6qawWqscJGMYR3IaxiCUycWwrrl-U/view?usp=share_link) | Manager instructions for how to complete their Talent Calibration in Workday. |
| [Talent Assessment Calibration Agenda Doc](https://docs.google.com/document/d/1zrlZSfdNXpSZ09uvDM71KxH42RWBJxa6U1QTCTw05iI/edit#heading=h.q1ptlqi506at) | This template can be used by managers to ensure similar pre-work, structure, and context to generate alignment ahead of live calibration sessions. The agenda is also recommend to ensure rationale behind potential assessment changes during calibration are recorded. |
| [Values competencies](/handbook/people-group/competencies/#values-competencies) | Values competencies form an important part of the Performance Factor evaluation and are important to review prior to beginning the assessment period. |
|[High Performing Team Indicators](/https://internal.gitlab.com/handbook/company/high-performing-teams/?search=values#high-performing-teams-indicators) | We’ve broken down each characteristic of high performance to help you recognize and measure success.|
|[Remote work competencies](/handbook/people-group/competencies/#remote-work-competencies) | Remote work competencies form an important part of the Performance Factor evaluation and are important to review prior to beginning the assessment period. |
| [Functional competencies](/handbook/people-group/competencies/#functional-competencies) | Functional competencies (for groups that have them developed) can also influence the Performance Factor and should be reviewed prior to the assessment period. |
| [Unconscious Bias](/handbook/company/culture/inclusion/unconscious-bias/) handbook page and [Recognizing Bias Training](/handbook/company/culture/inclusion/unconscious-bias/#recognizing-bias-training) | It is important to me mindful of unconscious bias always, and especially during talent reviews and assessments. It is highly recommended that you review the handbook page and watch the training. |
| [Performance Factor](/handbook/total-rewards/compensation/compensation-review-cycle/#performance-factor) handbook page | This page is the SSOT to review the Performance Factor's impact on compensation. |

## Key Talent

### Key Talent Criteria

Key Talent makes up roughly ~10% of the population. Key Talent represents team members who have a significant impact on GitLab's present and future success. They deliver quality results that are instrumental in moving critical company initiatives forward and do so consistently in alignment with our values. These team members are often recognized as experts in their current role. Team members, at any level, can be considered Key Talent.

Team members identified as Key Talent typically have knowledge, skills, and experience that:

- Contribute to key areas of the product
- Substantially impact the company's ability to achieve significant milestones and results
- Have a substantial impact to a key process which drives business performance
- Have a significant impact to the operation of a critical functional area
- Demonstrate consistently strong performance
- Demonstrates growth potential; the ability and desire to assume increasingly more broad or complex responsibilities and learn new skills.

While not all of the criteria above need to be met for an individual to be designated Key Talent, it is required that Performance and Growth Potential are in a good place and that the team member meets at least one of the requirements above related to business impact.

### Key Talent, Performance, and Growth Potential

Team members identified as key talent must be assessed at minimum Performing and Growing (Box 4) in the [Talent Assessment process](/handbook/people-group/talent-assessment/#the-performancegrowth-potential-matrix).

The only exception is for newly promoted individuals that fall into "Developing" Performance and "Developing" Growth Potential due to time and experience in their new role. Although Performance and Growth Potential are a consideration in the Key Talent selection process, they are not the only criteria used to determine the designation and should not be used in isolation. It is important to look holistically at the Key Talent Criteria outlined above when determining who qualifies as Key Talent on your team.

"Too new to rate" team members can be considered key talent but this would be an exception. In order for a "too new to rate" team member to be identified as key talent they must have specialized skills that drive a significant impact to business results.

Below are a few examples to help managers think through Key Talent designations as they relate to Performance and Growth Potential:

1. A team member that has a performance assessment of "Exceeding" is not automatically indicated as Key Talent. Perhaps they are doing exceptionally well in their role, but the impact on the business would not be considered "critical" if they were to leave.
1. A team member that is new to the role due to recent promotion and still "Developing" could be identified as Key Talent if they work in an area of the business that is highly specialized and critical to the success of key results at the company.

*Note: Intentionally hoarding knowledge is in direct conflict with our [transparency value](/handbook/values/#transparency) and is viewed as a performance issue as we measure performance based on alignment with our values.*

### Key Talent and Single Points of Failure (SPOF)

Single Points of Failure (SPOF) refers to a single person whose absence would significantly impact the ability of an area of the company to function.

Team members that are identified as Key Talent can also be SPOF, as the definition of SPOF overlaps with a few of the Key Talent Criteria outlined above, however, a team member who is identified as SPOF is not also Key Talent by default.

A few key differences between Key Talent and SPOF include: team member's performance and growth potential, risk mitigation plans, and support/development strategies.

Four scenarios exist in the context of our Talent Assessment:

- Team member identified as Key Talent
- Team member identified as SPOF
- Team member identified as Key Talent and SPOF
- Team member identified as neither one

To review the SPOF definition in more detail along with a few examples, please review our [Organizational Design](https://internal.gitlab.com/handbook/people-group/people-business-partners/organizational-design/) handbook page.

## Process To Determine Key Talent

It is important to have a holistic view of all team members when determining who meets the key talent criteria, which is why we require a certain scope when calibrating key talent and making final recommendations in the organization. There are several factors that can help determine the level at which key talent should be assessed, including things like reporting lines and span of control. As a general rule, if a people manager meets the following requirements, key talent calibrations should start at their level:

- Senior Manager level or above
- 20+ direct and indirect reports

The process to determine Key Talent is as follows:

1. Direct managers make initial key talent recommendations in Workday. The direct manager should include the key talent recommendation along with the Performance and Growth Potential recommendation. The [key talent criteria](/handbook/people-group/talent-assessment/#key-talent-criteria) that is met should be noted in Workday.
1. During sub-department calibration sessions, Senior Managers+ should calibrate on the initial key talent recommendations and make adjustments as appropriate, keeping in mind both [key talent criteria](/handbook/people-group/talent-assessment/#key-talent-criteria), and number of individuals identified as key talent, as key talent makes up only ~10% of team members company-wide.
1. The Senior Manager (if applicable), Director, Senior Directors, VP, and People Business Partner (PBP) discuss and calibrate the Key Talent nominations at the department level calibration sessions.
1. A final proposal goes to the E-Group member who adds in their Key Talent and reviews for final approval on Division level.

## Organizational Value

A very small portion of our business (roughly ~10% of the population) is considered to be key talent. As such, a team members' value in the organization should not be determined based on whether or not they are identified as key talent.

While some team members are identified as key talent, this does not mean the rest of our team is not valued and important to our organization's success. Aligned with our [expected performance distribution](/handbook/people-group/talent-assessment/#expected-distribution-company-wide), approximately 60-65% of our team are core performers (or ["performing"](/handbook/people-group/talent-assessment/#performing). Core performers are responsible for keeping things consistently moving forward. This group comprises the largest population in companies across the board for a reason and is an essential part of any organization's success.

## Impact of Being Identified as Key Talent

We want to make sure we use engagement tools to retain Key Talent. A few of our primary engagement tools are: [Learning & Development](/handbook/people-group/learning-and-development), growth opportunities and compensation.

- **Learning & Development:** We want to support the growth of Key Talent and their competencies, skills, and knowledge by providing them with the tools they need and the opportunities to progress their own personal and professional development goals. As a people manager it's your priority to identify [L&D opportunities](/handbook/people-group/learning-and-development) for your team.
- **Growth Opportunities:** As a people manager, it's important to have career conversations and identify growth opportunities with your team members. For Key Talent, it's especially important to discuss their motivation and ambitions. Growth opportunities can be both horizontal and vertical. Examples of growth opportunities are: expanding the scope within a team member's current role, a lateral move to a new role, or a promotion to the next level.
- **Compensation:** At GitLab, compensation = cash + equity + benefits. We have a [market-based approach](/handbook/total-rewards/compensation/#market-based-approach) and differentiate pay based on performance. Our Annual Compensation Review Cycle and Annual Equity Refresh program allow us to differentiate compensation based on performance and for Key Talent.
- **Succession Planning:** As team members identified as Key Talent are critical to roles that have a high impact on the company's success, it is important that we identify successors to avoid any single points of failure within the organization.

**Note that being considered or designated as a key talent one year, does not mean or guarantee that a team member will be considered or designated as a key talent moving forward.**

## Key Talent Program

Supporting Key Talent at GitLab is a critical element of business scalability and organizational development and growth. Our Key Talent are often individuals that can be looked to for mentorship and guidance by others, but it is also important that we invest in the development of this group and ensure that key knowledge is shared. A couple of key ways we can support our Key Talent is through regular discussions and the development of [Individual Growth Plans (IGPs)](/handbook/people-group/learning-and-development/career-development/igp-guide/).

Below are suggestions for getting started, resources for managers, a [Key Talent Engagement Discussion template](https://docs.google.com/document/d/1ZMDkD8TE7mAcB1IUuHjNi5VeuXDbvsEsqKnGFXUqxsc/edit#heading=h.akod5o3a8i5q), and a recommended cadence.

### Key Talent Engagement Discussion

One way to set up a structure and regular cadence for touchpoints with our Key Talent population is through Key Talent Engagement Discussions. We recommended these discussion focus areas are: Overall Engagement, Growth/Challenge, and Support Needed. The main goals for check-ins with this group include:

1. Get a pulse on overall engagement
1. Uncover potential risks for business continuity and implement plans to mitigate
1. Identify areas of support needed
1. Identify opportunity for stretch projects and continued growth
1. Use this discussion as a starting point to partner with team members to get [Individual Growth Plans (IGPs)](/handbook/people-group/learning-and-development/career-development/igp-guide/) in place
1. Leverage this data to identify key themes and potential actions across our Key Talent pool with the goal of improving engagement (leaders can work with their aligned [People Business Partner](/handbook/people-group#people-business-partner-alignment-to-division) on this piece)

Managers can leverage [this template](https://docs.google.com/document/d/1ZMDkD8TE7mAcB1IUuHjNi5VeuXDbvsEsqKnGFXUqxsc/edit#heading=h.akod5o3a8i5q) to help facilitate consistency in Key Talent Engagement Discussions.

### Individual Growth Plans (IGPs)

Key Talent Engagement Discussions can be a great starting point to start thinking through Individual Growth Plans, which is the recommended next step. Some ideas for our Key Talent population to consider when thinking through [Individual Growth Plans (IGPs)](/handbook/people-group/learning-and-development/career-development/igp-guide/) include:

- Stretch project (Cross functional, and an opportunity to be DRI)
- Mentor (leader to help identify internal or external mentor)
- Coach or Coaching program (e.g. [Coaching Right Now](/handbook/leadership/coaching/#selecting-a-coach)
- Management development (if applicable)
- Cross-functional/leadership exposure plan
- Cross learning plan with other roles within their division

### Cadence

We recommend that managers perform Key Talent Engagement Discussions twice per year, roughly every 5-6 months. Discussion timing is at manager discretion, as we want to ensure these discussions are held at the most relevant and impactful time for each team member. Key Talent Engagement Discussions are more geared towards stay interview format, and should not replace ongoing informal check-ins, regular feedback, and growth discussions that happen more regularly in 1:1s.

A couple of options for Key Talent Engagement Discussions that managers can consider are:

1. **Before Mid-Year check-in**: Before our company-wide [Mid-Year check-ins](/handbook/people-group/talent-assessment/#mid-year-check-in). This cadence would be 1) Key Talent Engagement Discussions, 2) Mid year check-in discussion, 3) [Individual Growth Plans (IGPs)](/handbook/people-group/learning-and-development/career-development/igp-guide/) (*if applicable*). Touching base with Key Talent ahead of Mid-year check-ins can help provide an insightful baseline and level of insight before going into more performance-focused discussions.

In FY'24 Q2, we will begin *optional* Key Talent Engagement Discussions across the organization aligned with our upcoming mid-year check-in process. For divisions or departments that choose to opt in, the high level timeline would be as follows (exact dates TBD):

- May: Key Talent Engagement Discussions (optional)
- June: [Mid year check-ins](/handbook/people-group/talent-assessment/#mid-year-check-in) (required)
- July: IGP (Individual Growth Plan) development (optional)

1. **After our [Talent Assessment cycle](/handbook/people-group/talent-assessment/#q4-formal-talent-assessment)**: This cadence would be 1) Self-assessment, 2) Talent Assessment performance review discussion, 3) Key Talent Engagement Discussion, 4) [Individual Growth Plans (IGPs)](/handbook/people-group/learning-and-development/career-development/igp-guide/) (*if applicable*). We recommend that Key Talent Engagement Discussions occur *after* Talent Assessments as opposed to before to ensure we have the most recent group of key talent calibrated and confirmed before Key Talent Engagement Discussions occur.

As mentioned above, Key Talent Engagement Discussions can be done at any point during the year, it is not necessary that they are coupled with our Mid year check-in process.
