---
title: "Visas"
description: "Information on travel visas, visa letters, and immigration to the Netherlands. "
---

## Visa and Sponsorship Policy

GitLab does **not** offer any form of work or study sponsorship anywhere in the world, other than our specific, internal [Netherlands]({{< ref "visas#right-to-immigrate-to-the-netherlands" >}}) process and support for highly skilled candidates in *certain* countries, where a candidate is already based in that country. GitLab does **not** offer any form of support to transfer an existing work permit. During the [screening process](/handbook/hiring/interviewing/#what-to-expect-during-an-interview-with-a-recruiter), recruiters will ask applicants if they require any type of sponsorship or support.

For our purposes, visa sponsorship is defined as the requirement that a company or individual support a foreign national’s visa application. Sponsorship may be referred to by different terms depending on the country or visa, but any visa application or approval that is contingent on the company taking on certain obligations is considered synonymous with sponsorship.

### General Work Authorization Guidelines

- GitLab does not support any visa that requires sponsorship. Sponsorship includes anything that requires GitLab to become a registered employer or sponsor, petition the government directly, fill out an application on behalf of a team member, pay an employer fee, or otherwise places a significant compliance obligation or burden on GitLab.
- GitLab is willing to provide company information, including contact information, an offer of employment, and an employment verification letter to validate employment to assist with a visa application that is not tied to a particular employer. This would not be considered sponsorship.
- GitLab can generally accept dependent visas or other family-based work permits that are not tied to an employer. However, if the individual loses a work permit based on their dependent status (e.g., the spouse who is sponsored by their employer loses their sponsored job), then the individual is no longer authorized to work for GitLab.
- Please note that if a visa expires (even if it was a visa accepted by GitLab), the individual is not eligible to work immediately upon expiration. If a team member’s work authorization expires, please reach out to People Connect to determine if any possible alternative options exist.
- The following information is limited to countries with GitLab entities. Alternative visa options may exist in locations where GitLab uses PEOs. As the employer of record, we expect PEOs may have their own policies on what visas they accept and/or assist with.
- Additional information for People Group members related to work authorization is available [here](https://docs.google.com/document/d/1LnDx1NeDDufo-mGYv-eMYqqaLLkIS0___QgtTXp7otI/edit?usp=sharing).

### Visas and work permits GitLab may be able to accept

GitLab's acceptance of a visa depends on many factors. The following visas may make a candidate eligible to work at GitLab. The following list is not exhaustive.

- Australia Employer Nomination Scheme visa (subclass 186)
- France EU Blue Card
- Germany EU Blue Card
- India Employment Visa
- Ireland Critical Skills Employment Permit
- Japan Engineer Visa
- Netherlands Highly Skilled Migrant
- Netherlands Partner Visa
- Netherlands EU Blue Card
- South Korea F5 Permanent Resident Visa
- Singapore Personalised Employment Pass
- Spain EU Blue Card
- UK Global Talent Visa
- UK India Young Professionals Scheme Visa
- UK Ancestry Visa
- US TN Visa (GitLab is unable to submit Form I-129 on a team member's behalf)
- US Green Card
- US H-4 EAD
- US F-1 CPT/OPT student visa

### Visas and work permits GitLab does not sponsor

The following list is not exhaustive.

- Australia Temporary Skill Shortage Visa
- Australia Global Talent Employer Sponsored (GTES) Visa
- Canada CUSMA Visa
- Japan Highly Skilled Professional Visa
- South Korea H1 Working Holiday Visa
- South Korea D7 Dispatch Visa
- Singapore Employment Pass / S Pass / ONE Pass
- UK Skilled Worker Visa
- US H-1B
- US H-1B1

## Travel Visas

For assistance with any employment or relocation visa please reach out to the People Connect.

## Expensing

You can expense (for approved GitLab/company events):

- Cost of the VISA
- Cost of pictures for the VISA
- Cost of a lawyer to help you with the application
- Cost of postage
- Cost of applying for the [30% ruling](#30-ruling-in-the-netherlands)

You can *not* expense relocation costs or costs related to visas for work authorization.

Please note, that GitLab is only able to cover the costs of one VISA attempt. If your VISA request is rejected, team members are free to re-submit at their discretion and any additional costs will be need to be covered by the team member.
Please refer to the [Global Travel and Expense Policy Handbook Page](/handbook/finance/expenses/#visaspermitscovid-tests) for more information regarding the reimbursement.

### Arranging a visa for travel

In some cases when traveling to a conference or summit you might need to arrange a visa to enter that specific country.

Always **check the website of the Embassy of the Country you want to visit** located in your home country. They will have the most updated information on whether or not you need a visa and what is needed for your application. In some instances you can travel under a visa waiver program (e.g. [ESTA](https://esta.cbp.dhs.gov/esta/)) in other cases you might need to arrange a tourist or business visa. Read their website carefully and if you need an invitation letter for your application you can request one following [this process](https://internal.gitlab.com/handbook/people-group/people-operations/people-connect/frequently_requested#visa-invitation-letter). If you need any further help with acquiring the needed documents for your application, please create a case for the People Connect team via [HelpLab](https://helplab.gitlab.systems/esc?id=emp_taxonomy_topic&topic_id=57e1ad3997804e50a326158de053af3d) with the information required.

#### Tips & Tricks for visa arrangements {#visa-tips}

- **Make sure to start on time with your arrangements for a visa**. Wait times can vary and may take longer than excepted to acquire a US visa.
- Check if your passport is still valid long enough as per the country's requirements.
- Give priority to arranging your visa, it can take time to get an appointment to apply at the Embassy.
- Double check if you have all the needed documentation and information.
- Think of the answers you will give during your visa interview; it can influence your visa approval/denial.
- Once the dates for a conference or summit are set, start as soon as possible with your application. If you have needed a special visa in previous situations, just to give yourself enough time and room for errors if they arise.
- If required, you can request a Visa Invitation Letter following [this](https://internal.gitlab.com/handbook/people-group/people-operations/people-connect/frequently_requested/#visa-invitation-letter) process

##### Timeline guide for visa applications

*Please note that the below timeline is just a guide, and you should always check the guidance on the official website of the embassy for the country you are applying to before making your application or traveling to an interview.*

- **6 months beforehand**: make appointment at embassy, and start gathering all necessary paperwork, forms, certificates, pictures, etc.
  - Sometimes you might call the embassy, and be told that you do not need to schedule an interview so far ahead of your trip. Don't take their word for it, since that advice is typically made with the "typical, best case"  process in mind and for example in the case of the USA does not account for the possibility of a black hole "administrative processing" period. In other words, make sure you get an appointment as early as possible.
  - If the country where the embassy/consulate is located where you are going for your application is listed as anything other than "High Income" by the [World Bank's "Little Data Book"](https://openknowledge.worldbank.org/bitstream/handle/10986/23968/9781464808340.pdf?sequence=4&isAllowed=y) then it is likely that the embassy/consulate there has a [high tendency to say "no" to visa applications](https://www.alllaw.com/articles/nolo/us-immigration/harder-get-visa-from-certain-countries.html). We recommend to engage the services of a local lawyer who is familiar with the embassy process to help check that your paperwork is in order, and to practice interview questions. You're also welcome to ask for support when you are in a "High Income" country. People Ops can help you with this.
- **3 months beforehand** (or earlier if indicated by the embassy you are applying to): go to embassy for interview.
- **2 months beforehand**: if you have not received your visa by now, contact your local lawyer again to see if anything can be done to expedite the process.

## Dutch Work Permits

Some of our GitLab team-members in the Netherlands have a "werkvergunning" or work permit under the [highly skilled migrants](https://ind.nl/en/work/working_in_the_Netherlands/Pages/Highly-skilled-migrant.aspx) category of the Immigration and Naturalization Service (IND).

- GitLab is a recognized organization ("erkend referent") with the IND, and Savvy provides support with respect to applying for new visas / permits or extending existing ones.
- Work permits must be renewed at the end of each contract period, but at minimum once every 5 years.
- At the time of applying for permit renewal, the application must satisfy various criteria including an age-dependent [minimum salary requirement](https://ind.nl/en/Pages/required-amounts-income-requirement.aspx) (with a step at age 30, also see this [handy table](https://ind.nl/en/required-amounts-income-requirements#application-to-work-as-a-highly-skilled-migrant-and-for-the-european-blue-card)). This requirement should be taken into consideration when issuing a new contract, since the contract can be made valid for just a year or for an indefinite period; thus triggering more or less frequent re-applications for work permit extensions. Permit extensions cannot be applied for when the current permit is still valid for more than 6 months.

Here is a [generally but not authoritative helpful guide](https://www.expatica.com/nl/moving/relocation/leaving-the-netherlands-108416/) on considerations around permit extensions.

The IND (Dutch immigration services) in general take about 4 to 6 weeks' time to make a decision on the renewal application, but officially they have 90 days to decide.

1. Some important notes before you arrange travel / depart to the Netherlands:

- **A direct flight to the Netherlands is required, indirect travel may result in entry refusal**

### 30% Ruling in the Netherlands

The [30% reimbursement ruling](https://www.iamsterdam.com/en/live-work-study/living/official-procedures/30-tax-ruling) (better known as the 30% ruling) is a tax advantage for highly skilled migrants moving to the Netherlands. This benefit, granted for five years, allows them to receive 30% of their employment income tax free. As an example, when your employment income is EUR 60,000; the 30% ruling ensures a net pay of EUR 18,000. The remainder of EUR 42,000 is subject to Dutch taxes. In addition, when being entitled to the 30% ruling you can exclude your savings from Dutch income tax (which can be beneficial once you have exercised your stock options).

The 30% ruling is a mutual application filed by the employee and GitLab BV as the employer. During the onboarding procedure a [questionnaire](https://docs.google.com/document/d/1Ok6LS9T4P6tnPu2N6BDRDeveOYzd1ILpkbQRhl911w4/edit?ts=5caf1bca) is shared in order to gather the necessary information to file the application for the 30% ruling. People Ops shares the 30% ruling questionnaire and supporting documentation with  HRSavvy (the company that supports GitLab with visas and payroll in the Netherlands). HR Savvy will subsequently apply for the 30% ruling. There are some conditions to be satisfied to be granted the 30% ruling.

1. The employee has to be hired as an employee.
1. The employer and employee have to agree in writing that the 30% ruling is applicable (addendum to the employment agreement).
1. The employee has to transfer or to be recruited abroad by a Dutch employer. In two years before being hired by a Dutch employer, the employee must be living outside of the Netherlands for more than 16 months, at a minimal distance of 150 kilometers from the Dutch border.
1. The employee must have specific experience or expertise that is not or rarely available in the Netherlands.
1. The gross annual salary has to surpass a minimum (adjusted annually).

**The decision from the Dutch Tax Authorities can take up to four months.** Once your 30% ruling is granted, the application will be made retroactively in the payroll administration to your starting date. Read more from the Dutch tax authorities by clicking this [link](https://www.belastingdienst.nl/wps/wcm/connect/bldcontenten/belastingdienst/individuals/living_and_working/working_in_another_country_temporarily/you_are_coming_to_work_in_the_netherlands/30_facility_for_incoming_employees/).

Here is [an approximate net-salary calculator in The Netherlands](https://relocate.me/net-pay-calculators/) (choose The Netherlands button) to reckon additional salary payment with 30% ruling.

### Transferring the 30% Ruling from a Previous Employer

The 30% ruling is a tax advantage granted for five years, which means that you can carry this over to a new employer if your new role still fulfills the requirements of the 30% ruling. Note that you are only allowed to transfer the 30% ruling when there is a gap of maximum three months between your previous employment and your employment at GitLab BV. The 30% ruling questionnaire includes a section where you can state that you have already been entitled to the 30% ruling. Transferring the 30% ruling tends to be faster since your qualifications were already assessed at your previous employment.

### BSN Number

A [BSN number](https://www.iamsterdam.com/en/living/take-care-of-official-matters/registration/citizen-service-number) is like a citizen number. It is required so new team members can be added to the B.V. Netherlands payroll. It's also required for things like health insurance and opening a bank account.

There are two options to get a BSN number in the Netherlands:

1. Getting a BSN number at the municipality. This process will take at least 1-4 weeks. There are no costs involved with registering and receiving a BSN at the municipality.

1. Getting a BSN number at your local [Expat center](https://www.iamexpat.nl/expat-info/organisations/expat-centres).

It is possible to make an appointment within 2 weeks.

### Right to Immigrate to the Netherlands

If a team member wishes to immigrate and relocate to the Netherlands, they will need to first follow the [relocation process](/handbook/people-group/relocation/) and requirements and obtain approval to relocate.  Once approved, team members will also need to pass the formal visa application process to qualify. The requirements are:

1. When using the [compensation calculator]({{< ref "calculator" >}}) you must meet the Dutch salary requirement for [highly skilled migrants for 3 more years](https://ind.nl/en/Pages/required-amounts-income-requirement.aspx#Application_for_residence_permit_highly_skilled_migrant_and_European_Blue_Card)
    - Note, that the Dutch government has a higher requirement for team members aged 30 and above. The age related wage requirement does not increase when reaching 30 if you already have an approved migrant visa (with the same employer).
    - The following pay elements are not included in the salary criterion and can't be used to meet the mimimum salary requirement: Vacation allowance; the value of payment made in kind; Uncertain, non-regular pay elements (for example overtime allowances, variable boni and payments from funds).
    - *Note: This calculation should be based on what GitLab **would** pay the team member in the Netherlands in accordance with the compensation calculator, **not** based on the team member's current salary.*
1. You have been a team member at GitLab for one year.
1. You are not on a Performance Improvement Plan (PIP).

#### Special considerations for team members in unsafe environments

Tenure of less than 1 year at GitLab may be possibly waived as a requirement if:

- You are a member of an [underrepresented](/handbook/company/culture/inclusion/#definitions) group that is unsafe or in any way mistreated in your country.
- Violence in your country does not provide a safe environment.

If you meet these requirements, kindly read our [Relocation]({{< ref "relocation" >}}) handbook page, as well as our specific [Netherlands section]({{< ref "relocation#relocating-to-the-netherlands" >}}), to ensure that your request is evaluated and approved following our protocols. **Please reach out to the People Connect team via HelpLab if you have any questions.**

#### Transferring a partner visa to a highly skilled migrant visa

Someone already in the Netherlands on a partner visa can be transferred to their own highly skilled migrant visa in order to not be dependent anymore. The process can take up to three months and is subject to above [eligibility criteria]({{< ref "visas#right-to-immigrate-to-the-netherlands" >}}) and executive approval. Please reach out to the People Connect team via HelpLab to get this process started.

Tasks for People Connect:

1. The People Connect team member reviews if the [eligibility criteria]({{< ref "visas#right-to-immigrate-to-the-netherlands" >}}) are met and asks the manager to confirm that the team member is not on a Performance Improvement Plan (PIP)
1. The People Connect team member emails HR Savvy (see contact details in 1password) to confirm the total amount of fees for this process since they are subject to change
1. The People Connect team member emails the team member's Division's E-Group leader for their written approval and includes the total amount of fees in the email
1. Once approved the People Connect team member emails HR Savvy with the team member in cc to request the visa transfer
1. HR Savvy will supply all the documentation needed to the team member to apply for the visa transfer

#### Resources

Our `#netherlands` Slack channel is a good place to ask immigration-related questions.

Here is a [document written by a GitLab team member](https://docs.google.com/document/d/1t5-jMIrWBxOJSka42uzPIPUnTLtRObbcQ6qBvTpjYI4/edit?usp=sharing) (internal only) detailing their immigration experience to the Netherlands.

{{< youtube "w_CRpuPwO0o" >}}

Sid and Marin discuss the history of GitLab's right to immigrate to the Netherlands.

## Highly Skilled Candidates (Ireland and EU Blue Card processes)

### Critical Skills Employment Permit Ireland

GitLab may be able to offer employment agreements to highly skilled candidates seeking employment already in Ireland, who apply for, or already hold, a [Critical Skills Employment Permit](https://enterprise.gov.ie/en/What-We-Do/Workplace-and-Skills/Employment-Permits/Permit-Types/Critical-Skills-Employment-Permit/), where the relevant role falls into a category listed on the [Critical Skills Occupations List](https://enterprise.gov.ie/en/What-We-Do/Workplace-and-Skills/Employment-Permits/Employment-Permit-Eligibility/Highly-Skilled-Eligible-Occupations-List/) or a salary threshold is exceeded.

Please note: GitLab does not cover any costs for the application nor does it guarantee the issuance of the Critical Skills Employment Permit.  The employment agreement offered will include the condition that the candidate will hold the sufficient right to work and if a permit is required that they will be able to obtain the permit.  If the critical skills employment permit application is refused, the employment agreement would be rescinded. Permit holders may apply to the Irish Naturalisation and Immigration Service for permission to reside and work without the requirement for an employment permit upon completion of the Critical Skills Employment Permit's duration.

#### The eligibility criteria

Occupations with a minimum annual remuneration of €32,000 for a restricted number of strategically important occupations contained in the Critical Skills Occupations List a relevant degree qualification or higher is required.
All occupations with a minimum annual remuneration of over €64,000, other than those on the [Ineligible List of Occupations for Employment Permits](https://enterprise.gov.ie/en/What-We-Do/Workplace-and-Skills/Employment-Permits/Employment-Permit-Eligibility/Ineligible-Categories-of-Employment/) or which are contrary to the public interest. A non-EEA national who does not have a degree qualification or higher, must have the necessary level of experience.
The prospective employee concerned must have secured a 2-year job offer in respect of the eligible occupation from the prospective employer.

#### Further criteria include

The prospective employee concerned must possess the relevant qualifications, skills and experience that are required for the employment.
An employment permit will not be granted to companies unless 50% or more of the employees in the firm are EEA nationals at the time of application. However, this restriction may be waived in respect of start-up companies within 2 years of their establishment (that is, registered as an employer with Revenue) and which are supported by the enterprise development agencies, Enterprise Ireland, or IDA Ireland (this applies to client companies of Enterprise Ireland or IDA Ireland only).

The details of what is required are set out on the application form and include:

- A full description of the proposed employment,
- Starting date,
- Annual remuneration excluding bonuses, and
- Information in respect of the qualifications, skills or experience required for the employment.

#### Application process

An application for a Critical Skills Employment Permit can be made online on the [Employment Permits Online System (EPOS)](https://epos.enterprise.gov.ie/). There is a [User Guide (PDF document)](https://epos.djei.ie/EPOSOnlinePortal/UserGuide.pdf) available on the online system which guides the applicant through the process and details the documentary requirements for each employment permit type.

Before you start an application please see the [Critical Skills Employment Permit Checklist (PDF document)](https://enterprise.gov.ie/en/Publications/Publication-files/Critical-Skills-Employment-Permits-Checklist.pdf) which will assist the process.

There are up to three stages in the passage of an employment permit application:

Application received (awaiting processing): Once an application is submitted and the associated fees, if appropriate, are recorded the application is then placed in the relevant processing queue. Please note that applications are processed strictly in date order by Employer Type and applicants can keep track of the [current processing dates](https://enterprise.gov.ie/en/What-We-Do/Workplace-and-Skills/Employment-Permits/Current-Application-Processing-Dates/). They can also check the progress of their specific application online on the [Online Status Update Enquiry facility](https://enterprise.gov.ie/en/What-We-Do/Workplace-and-Skills/Employment-Permits/Current-Application-Processing-Dates/).

Processing stage: This stage is where the application is considered by a decision maker, an official with decision making authority. The processor may request additional information, if required, which should be returned within 28 days. The processor will then either grant an application or refuse it for specific reasons.

Review: Where an applicant wishes a refusal decision to be reviewed then they may do so within 28 days on the prescribed Submission of a Decision for Review Form. The review will be considered by a separate and more senior official. The confirmation of a refusal decision on review does not preclude the applicant from submitting a new application following all of the relevant procedures for the specific employment permit type.

#### Fee

The processing fee for a Critical Skills Employment Permit is €1,000 (which must be paid by the applicant, GitLab does not cover the costs of an application). If an application is unsuccessful, 90% of the fee will be refunded.

There is more information [here](https://enterprise.gov.ie/en/what-we-do/workplace-and-skills/employment-permits/permit-types/critical-skills-employment-permit/).

### EU Blue Card

GitLab may be able to offer employment agreements to selected highly skilled candidates seeking employment in an EU country where GitLab has an entity who apply for, or already hold, an EU Blue card for that country. GitLab may also be able to offer employment agreements to current team members looking to relocate to an EU country where GitLab has an entity who have been [approved for relocation]({{< ref "relocation#how-to-apply-for-a-long-term-relocation" >}}) to such country and are planning to apply for an EU Blue Card.

Please note: GitLab does not cover any costs for the application nor does it guarantee the issuance of the EU Blue card. The employment agreement offered includes the condition that the candidate will hold the sufficient right to work and if a Blue Card is required that they will be able to obtain the Blue Card. If the Blue Card is denied, the employment agreement would be rescinded. GitLab will only consider candidates and team member relocation requests for prospective Blue Card holders in countries where we are currently open for hiring. GitLab will not assist with Blue Card applications beyond providing an employment agreement and any company information needed for the application.

The EU Blue Card is a work and residence permit for highly skilled workers who are non-EU citizens and meet the country-specific salary threshold. Blue Cards are employer-specific but may be transferred by giving proper notice to the immigration authorities. Application requirements may vary by country. As you will need a local employment agreement to complete your Blue Card application, current team members will need to [apply for a Long-Term Relocation]({{< ref "relocation#how-to-apply-for-a-long-term-relocation" >}}) to the country from which you are seeking a Blue Card. It is strongly recommended that you wait for approval for your long-term relocation before beginning your EU Blue Card application.

If a candidate is interested in employment at GitLab in a country where they require a Blue Card for work authorization, GitLab may move forward with their candidacy under the following circumstances:

- The candidate understands that GitLab will not assist with their Blue Card application or any associated fees. GitLab can only provide company information and a signed employment agreement. GitLab will not adjust offered compensation in order to meet Blue Card salary minimum requirements.
- The candidate understands that their employment in that country is contingent upon them securing proper work authorization before they begin working for GitLab. If their authorization is denied or lapses during the term of employment, they will be required to immediately cease working and GitLab will not be able to assist with pursuing a new work permit or sponsorship.
- Their employment agreement includes wording stating that their employment in that country is contingent upon them securing proper work authorization and if such authorization is denied or lapses the offer is rescinded.
- The hiring manager understands all of the above and acknowledges the risk that this candidate may not end up being authorized to work for GitLab, or that their visa may expire during the term of their employment and they will be unable to continue working. In the event that a visa is denied or expires GitLab will not be able to make any exceptions to the visa and sponsorship policy for any team members or candidates.

More detailed links on the process:

- [Schengenvisainfo.com/EU-Blue-Card](https://www.schengenvisainfo.com/eu-blue-card/)
- [EU Immigration portal](https://immigration-portal.ec.europa.eu/eu-blue-card/essential-information_en)

### Other visas GitLab may be able to accept

GitLab’s acceptance of a visa depends on many factors. The following visas may make a candidate eligible to work at GitLab. The following list is not exhaustive.

#### Australia Employer Nomination Scheme visa (subclass 186)

This is an employer-sponsored permanent resident visa. GitLab cannot support a new application for this visa, but may be able to hire a candidate who (1) has been granted this visa while working at a former employer, and (2) worked at that employer for at least 2 years after the visa was granted. This visa is valid for 5 years and cannot be renewed, but the visa holder is able to apply for permanent residency or citizenship upon expiration. Candidates and hiring managers must be aware that if the subclass 186 visa expires without securing a new form of work authorization the team member will need to stop working immediately upon expiration and GitLab will not be able to assist with or sponsor new work authorization.

#### India Employment Visa

Grants work rights for the duration of an employment relationship and does not require employer sponsorship. GitLab can assist with providing a local employment agreement and a copy of the company registration for the application, but will not apply for the visa on a team member’s behalf. Valid for up to one year and may be extended for up to five years. When hiring candidates who hold a this visa, emphasize that GitLab will not be able to assist with sponsorship of a new pass once their visa expires. Hiring managers should also understand that a candidate will only be able to work for GitLab until their visa expires and GitLab will not be able to make exceptions to our sponsorship policy at that time.

#### Japan Engineer Visa

GitLab can provide company information for this visa application. The employee is responsible for their own application and all fees associated with the visa. May be valid for 1 year, 3 years, or 5 years depending on the visa approval, and may be extended/renewed. GitLab cannot assist team members with obtaining a Certificate of Eligibility (COE).

For People Connect internal processing:

When receiving these requests from team members via HelpLab, provide the following documents to the team member:

- [Company Registration Document](https://drive.google.com/drive/folders/1cLcoIGyb501Zod4OXIKuZjPIL8b7eo8e)
- Current Year Financials (which can be found in this [folder](https://drive.google.com/drive/folders/1cLcoIGyb501Zod4OXIKuZjPIL8b7eo8e)). If the current/previous years financials are not available, reach out to the Tax team to assist with providing this.
- Save a copy of this [template](https://docs.google.com/document/d/1Qv8IJz5V4GGvqguuZx20N_V-W2chlV3u_X8iYzl2REU/edit?tab=t.0) and complete all fields that are marked with {}. Once you have all the information completed, send the document to Simon Mundy for signature.

#### Netherlands Partner Visa

Sponsored by partner, no employer involvement required. This visa is valid for up to 5 years depending on the sponsoring partner’s citizenship or work permit status. When hiring candidates who hold a this visa, emphasize that GitLab will not be able to assist with sponsorship of a new pass once their visa expires. Hiring managers should also understand that a candidate will only be able to work for GitLab until their visa expires and GitLab will not be able to make exceptions to our sponsorship policy at that time.

#### Korea F5 Permanent Resident Visa

Long-term visa that does not require employer sponsorship. Typically valid indefinitely.

#### Singapore Personalised Employment Pass

This is a visa for high earners that does not require sponsorship. Valid for 3 years and cannot be renewed. When hiring candidates who hold a PEP, emphasize that GitLab will not be able to assist with sponsorship of a new pass once their PEP expires. Hiring managers should also understand that a candidate will only be able to work for GitLab until their PEP expires and GitLab will not be able to make exceptions to our sponsorship policy at that time.

#### UK Global Talent Visa

This visa is for people who are considered leaders in various fields and does not require employer sponsorship. GitLab can likely employ anyone who has been awarded this visa but is unable to provide support with visa applications or fees. This visa is valid for five years and may be renewed.

#### UK India Young Professionals Scheme Visa

Grants full work rights without employer obligations. Valid for up to 24 months. When hiring candidates who hold a this visa, emphasize that GitLab will not be able to assist with sponsorship of a new pass once their visa expires. Hiring managers should also understand that a candidate will only be able to work for GitLab until their visa expires and GitLab will not be able to make exceptions to our sponsorship policy at that time.

#### UK Ancestry Visa/British National (Overseas) Visa

Grants full work rights without employer obligations. Valid for up to 5 years. When hiring candidates who hold a this visa, emphasize that GitLab will not be able to assist with sponsorship of a new pass once their visa expires. Hiring managers should also understand that a candidate will only be able to work for GitLab until their visa expires and GitLab will not be able to make exceptions to our sponsorship policy at that time.

#### USA TN Visa (USMCA)

This visa is available to Canadian or Mexican nationals in eligible roles. TN Visas are tied to a specific employer but do not place compliance obligations on the employer and so are not typically considered “sponsored.” GitLab will not submit the Form I-129 application on a candidate or employee’s behalf–they will need to submit their visa application at a Port of Entry instead. GitLab will only assist with providing company information and an employment contract or letter of employment. A candidate working at another company on a TN Visa will need to wait for their visa transfer to GitLab to be approved before they are eligible to start working for GitLab in the US. A TN visa must be renewed every 3 years and can be renewed an indefinite number of times.

For candidates: When a candidate discloses they’ll need a TN Visa to work at GitLab, it is important to let them know that GitLab will not submit the Form I-129 application on their behalf. GitLab can provide a letter of support once the job offer is signed, and they will need to submit their visa application at a Port of Entry if they are Canadian or a US Embassy or Consulate if they are Mexican (no need to ask which they are, always provide the information for both countries of origin). Note that it may take a couple months for a visa application to be reviewed and approved, so it is also important to set expectations with the hiring manager and take that into consideration when choosing a start date. Employers are permitted to set a date by which a new hire must be eligible to begin work, and you may point out that the employment agreement is contingent upon having and maintaining work authorization (typically section 10 or 11), and that an offer may be rescinded if they are not authorized for work at GitLab by the prescribed date.

#### USA Green Card

Not actually a visa, candidates with a Green Card are permanent residents and are eligible to work in the US without sponsorship. As long as someone has already been issued a Green Card they are able to start working for GitLab in the US. We will not sponsor new Green Cards or transfer Green Card applications that are still pending. If a candidate says they have a pending I-140, that means their Green Card application is still in process, and they will both require sponsorship for the continued Green Card application and for whatever visa they are currently working under (a pending I-140 or Green Card application does not grant work authorization). We would not be able to hire someone at the I-140 stage, but they will be eligible to work at GitLab once they have received their Green Card.

#### USA H-4 EAD

This visa grants full work rights and is sponsored by the visa holder’s spouse’s employer when the spouse has an H-1B. There is a risk that if the H1-B holder’s employment ends and they do not find a new job within 60 days, their partner will also lose their H-4 EAD. Team members with this visa and their hiring managers should understand that if in the future they end up losing this work authorization they will be required to stop working for GitLab and we will not be able to sponsor them for a new visa.

#### USA F-1 CPT/OPT Student Visa

F-1 is a visa for students studying at universities in the US in undergraduate or graduate programs. An F-1 visa holder may be approved for Curricular Practical Training (CPT) and/or Optional Practical Training (OPT) which grants them work authorization in the US in addition to their study rights as long as the role is related to their field of study. F-1 holders approved for CPT may work as interns, and if the internship takes place while classes are in session they are allowed to work a maximum of 20 hours per week (they may work more than 20 hours per week if the internship takes place during a class break). F-1 holders with OPT approval may work full-time after graduation and must work a minimum of 20 hours per week. OPT work rights are initially granted for one year, but visa holders with a STEM degree may apply for a two year extension (for a total of three years of OPT work authorization). GitLab can hire F-1 visa holders but should make it clear that when their work authorization expires we will be unable to sponsor them for a new visa and we will be required to terminate their employment if their work authorization lapses. Hiring managers should also understand that we will not be able to make exceptions to our sponsorship policy in these situations. Typically OPT holders will need assistance filling out paperwork that includes company information and details of their job and performance and must be signed by a company authorized signatory.

#### USA J-2 Visa

This visa grants full work rights and is sponsored by the visa holder’s spouse’s J-1 visa exchange program, and does not place any obligations on GitLab. However, there is a risk that if something happens to the spouse’s J-1 visa their partner will also lose their J-2. Candidates with this visa and their hiring managers should understand that if in the future they end up losing this work authorization they will be required to stop working for GitLab and we will not be able to sponsor them for a new visa.

## How to talk to candidates about work authorization

Employers are obligated to ensure their employees are legally authorized to work in the country where they are hired. It is okay, and even expected, to talk about work authorization with candidates to ensure that they understand what support GitLab is able to offer.

Do:

- Ask all candidates the following two questions:
  - Are you legally authorized to work for GitLab in [country of hire]?
    - If yes, no further information needed. Please keep a written record of this answer in candidate notes so that if conflicting information arises in the future we know that this question was previously addressed with the candidate.
    - If no or any other answer is given, please let them know about our Visa Sponsorship policy and state that we’re required to ensure that all new hires are authorized to work at GitLab at the time of hire. If they are unable to secure work authorization by the proposed start date without our sponsorship or other assistance with securing such authorization, we will not be able to move forward with their application. If they state that they’ll need a certain type of visa that they do not currently hold (like a TN or Blue Card) in order to secure work authorization, please consult the preceding section or reach out to People Connect via HelpLab to confirm that it is a visa we can accept.
  - Will you now or in the future require sponsorship for an employment visa?
    - If yes, please point them to our Visa Sponsorship policy and let them know that we will not be able to sponsor their work visa. If they are unable to secure authorization to work at GitLab without sponsorship then we will not be able to move forward with their application.
    - If no, no further information is needed. Please keep a written record of this answer in candidate notes so that if conflicting information arises in the future we know that this question was previously addressed with the candidate. Even if a person answers no, you should still tell them about GitLab’s sponsorship policy.
    - If the answer is anything else, like they mention needing to apply for a certain type of visa, please let them know about our Visa Sponsorship policy and consult this page for more information on that visa type.
- Tell all candidates that they must be currently authorized to work in the country of hire on a full-time basis.
- Tell all candidates that GitLab will not sponsor work visas.
- Consult this document or People Connect for more context if a candidate offers information about the type of visa or work permit they are currently on without you asking. Some countries prohibit employers from making hiring decisions on the basis of visa type as long as the person is authorized to work without sponsorship, so it’s important to ensure that this information is used only to confirm that this is a visa we can support without issue.
- If you are concerned that visas or sponsorship may be an issue for a candidate, we are required to wait until after the candidate has accepted a job offer to ask for further details about their visa type and expiration date.

Don’t:

- Treat a candidate differently based on your perception/guess that they may have or may need a visa or work permit for their location.
- Ask a candidate if they have a visa or what type of visa they have. If a candidate mentions having a visa you may reiterate that GitLab does not sponsor work visas and confirm that they do not require sponsorship in order to work for GitLab.
- Ask a candidate about their nationality or citizenship status. If a candidate offers this information do not ask follow-up questions, do not include it in their candidate notes, and do not take it into consideration when deciding whether to move forward with their candidacy.
