---
title: "Sales Diversity Inclusion & Belonging Initiatives"
description: "The GitLab Women in Sales Mentorship Program pilot aims to create and cultivate mentorship opportunities for women in the Sales division."
---

## Women in Sales Mentorship Program Pilot

As discussed in [GitLab's Remote Playbook](/handbook/company/culture/all-remote/), the intentionality behind communication, especially in remote settings, is a critical element of success. This pilot program aims to support GitLab's communications plan by purposefully creating and cultivating opportunities for mentors, mentees, and connection.

The goal of the Women in Sales Pilot Program is to provide mentorship opportunities to women in Sales as a ***pilot***. If successful, we will consider an expansion to other groups across the company. In the spirit of [iteration](/handbook/values/#iteration), we would like to get started soon and expand and improve as we go.

## Program Benefits

***Mentees:***

- Increased visibility with leadership
- Increased professional development opportunities
- Career coaching and guidance
- Opportunity to form relationships with leaders on other teams

***Mentors:***

- Faster feedback loop between team members and leadership
- Opportunity to form relationships with team members in other departments
- Opportunity to support Women at GitLab and live our values

## Program Structure

### 1:1 Coaching Sessions

The program proposes a mentor/mentee relationship between selected applicants on the sales team and mentors in leadership roles across the company. Sessions will take place every other week for 30-minutes and will last for *up to 3 months (with the possibility of an extension)*, as long as both mentors and mentees remain engaged. The mentor/mentee relationship will be cross-divisional, meaning that both parties will have the opportunity to work with and learn from team members outside of your respective divisions.

### Coaching Panels

Every 3 weeks a panelist of mentors will host a `Coaching Panel` to discuss several topics mentees indicated to be of interest as a group. There will be pre-work for mentees prior to Coaching Panels (I.E. reading an article, an expert of the first chapter of a book, etc.) to help stimulate discussion and basic understanding of the topic to be discussed. We will share material to review at least one week prior to the sessions.

Coaching panels will be held over Zoom with Q&A on the identified topic. They will be moderated by the program managers. As Coaching Panels are an extension of mentorship sessions with the wider pilot group, they will not be livestreamed.

Potential Coaching Panel topics include:

| Topic | Explanation  | Panelists| Date  |
|----------------|--------|------------------|-----------------|
| Effective Mentor/Mentee Partnerships | Mentee expectations, How mentors can help drive a productive career conversation, identification and selection of a personal development goal | All Mentors | 2020/07/08 |
| Leadership @ all levels in Sales | Goal setting, accountability, influence and collaboration | David Sakamoto, Craig Mestel, Michelle Hodges and Mark Rogge | 2020/08/24 |
| Career Transitions | Transitioning into a manager role; leadership pipeline; career inflection points | Eric Brinkman, Mike Pyle, Robin Schulman and Ryan O'Nell |  2020/10/13 |
| Crucial Conversations | Identifying key conversation moments and how to have those conversations successfully | Michael McBride, Bryan Wise and Danielle Morrill |2020/07/27|
| Work/Life Integration | Balancing family, friends, and careers in leadership | Kristen Lawrence, Dale Brown, Carol Teskey and Brandon Jung | 2020/09/23 |

### Program Communications

All program communications will be sent through the slack channel #women-in-sales-mentorship-pilot including any pre reading before coaching panels.

### Timeline

We will continue iterating on the pilot as we go, but the initial structure will be:

| Phase                         | Timeline  |
|-----------------------------------|-----------------|
| Application Process for Mentors and Mentees | May 7 - May 21, 2020 |
| Selection and program topic identification* | May 22 - 28, 2020 |
| Mentor Program Kick-Off Meeting to review: expectation setting, mentor/mentee roles, program structure details, etc. | June 10, 2020 |
| Continued mentorship and implementation of concepts discussed in day-to-day | mid June - mid September 2020  |
| Feedback survey at the midpoint of the pilot program <br> *[Survey for Mentees](https://docs.google.com/forms/d/1kh1jv5MkRkcpXfMczF0y3z0KOszM1EaS0A_gZfGH4LY/edit) <br>* [Survey for Mentors](https://docs.google.com/forms/d/10XFCHYTBICdruNUphLZGdUiPLn-7GhgHoilUhfTl1nA/edit) | end July 2020 |
| Feedback survey at the end of the pilot program | end September 2020 |

## Engagement Criteria

The program will last for up to 3-months if both the mentor and the mentee remain engaged. Being engaged in the program will be defined as:

- Attending all scheduled sessions
- Actively participating in all sessions
- Preparing for calls (mentees will drive agenda)
- Implementing learnings (namely for mentees)

## First Iteration Program Participants

|Mentor  | Mentee  |
|-----------------------------------|-----------------|
| **Michael McBride** CRO| **Helen Mason** Area Sales Manager, SMB |
| **Robin Schulman** CLO| **Madeline Hennessy** Area Sales Manager, SMB |
| **Brandon Jung** VP, Alliances| **Allison Mueller** Strategic Account Executive |
| **Mike Pyle** VP, Enterprise | **Alyssa Belardi** Account Executive - Mid Market |
| **Carol Teskey** Sr. Director, People Success | **Christine Yoshida** Manager, Professional Services Practice |
| **Danielle Morrill** Head of Corporate Marketing|  **Tanuja Paruchuri** Senior Program Manager, Sales Enablement|
| **Mark Rogge** Director, Regional Sales|  **Taylor Medlin** Solutions Architect |
| **Dale Richard Brown** Principal Accounting Officer| **Amy Brandenburg** Technology Partner Manager |
| **Michelle Hodges** VP of Global Channels| **Susannah Reed** Strategic Account Executive|
| **Bryan Wise** VP, IT|  **Sophie Pouliquen** Senior Customer Success Manager |
| **Eric Brinkman** Senior Director, Product Management| **Jenna McCarthy** Customer Success Manager|
| **Kristen Lawrence** Director, Customer Success|  **Chloe Whitestone** Customer Success Manager|
| **Craig Mestel** VP, Finance |  **Kyla Gradin** Account Executive - Mid Market|
| **David Sakamoto** VP, Customer Success|  **Annette Kristensen** Strategic Account Executive |
| **Ryan O'Nell** VP, Commercial Sales |  **Katherine Evans** Strategic Account Executive |
| **Ryan O'Nell** VP, Commercial Sales| **Anja Loether** Strategic Account Executive |

## Success Metrics

- 80 or greater NPS score across mentors and mentees (9's or 10's for the following question: *"Overall, I would recommend this program to another GitLab team member"* at the end of the pilot program survey).
- 100% participation in program-related calls
- Addtional criteria to be added once we gather intial feedback from selected participants

## Application Process

### Mentees

**Eligibility:**

- You are in the Sales organization (i.e. Enterprise Sales, Commercial Sales, Customer Success, Channels, Alliances, or Field Operations)
- You have been with GitLab for at least 3 months at the time of application

**Considerations:**

Applications will be prioritized on a few different factors including:

- Job grade with higher levels prioritized
- Team members on a management career track
- Performance in current role

***If you meet the eligibility criteria and are interested in applying, please fill out the [Mentee Google Form application](https://forms.gle/BRqvr7nBCedvsXz2A)! Applications are due by May 21st!***

### Mentors

You are eligible to apply for the program if you meet the requirements below:

- You have been with GitLab for at least 3 months at the time of application
- In a role with a [job grade]({{< ref "compensation-calculator#gitlab-job-grades" >}}) of 10 or above (10 indicates you are in a "director" level role)

***If you meet the eligibility criteria and are interested in applying, please fill out the [Mentor Google Form application](https://forms.gle/eSoFesdtHhq2xo4J6)! Applications are due by May 21st!***

## FAQ

**Q. Why is this program just for women?**

- A. Across GitLab's 5 primary divisions (Engineering, G&A, Marketing, Product, and Sales) 4 out of 5 of the divisions have a significantly higher number of men in management roles versus women.
- While each participant will set the priorities for their mentor discussions, we are intentional with this cohort as we encourage discussions to include challenges, opportunities and issues unique to women in sales. We aim to keep removing barriers to those discussions and ensure transparent engagement across GitLab.

**Q. Why is this program just for Sales?**

- A. We needed to chose a place to start to validate that a mentorship model/framework would deliver the intended value to the mentees and mentors. When we looked at the data, women in Sales represented one of the lowest percentages in management and leadership when compared to the other functional areas. Additionally, Women in Sales were vocal about seeking out this opportunity. If this pilot is successful, we hope to expand for our second iteration.

**Q. Does participation in this program guarantee a promotion?**

- A. No, participation in this program does not guarantee a promotion. Benefits for mentees include: Increased visibility with leadership in various areas of the organization, increased professional development opportunities, career coaching and guidance, and opportunity to form relationships with leaders on other teams. You can review these benefits in the [Program Benefits](https://gitlab.com/-/ide/project/gitlab-com/www-gitlab-com/edit/master/-/source/handbook/people-group/women-in-sales-mentorship-pilot-program/index.html.md#program-benefits) section above.

Interested in what other mentorship opportunities exist at GitLab? Check out the [Minorities in Tech](/handbook/company/culture/inclusion/erg-minorities-in-tech/mentoring/) pilot program!

## Reverse Ask Me Anything

For details on hosting and scheduling a Reverse AMA, please visit the [Reverse AMA section]({{< ref "ask-me-anything#reverse-ask-me-anything" >}}) in the Handbook.
