---
title: People Policies
description: "GitLab's People policies support all GitLab team members and ensures their safe and thriving work environment."
controlled_document: true
---

## Purpose

All of the policies listed below are important for GitLab team members to read and understand as they deal with people benefits, entity specific issues, and procedures and requirements of the company. If you have any questions around the internal policies, please reach out to People Operations via HelpLab.

## Scope

These policies apply to all GitLab team members, contractors, advisors, and contracted parties interacting with GitLab computing resources and accessing company or customer data.

## Roles and Responsibilities

| Role | Responsibility |
|-----------|-----------|
| GitLab Team Members | Responsible for following the requirements in these policies |
| PeopleOps | Responsible for implementing and executing these policies |
| Legal & PeopleOps Management (Code Owners) | Responsible for approving significant changes and exceptions to these policies |

## Translations

There are translations available of many of our policies, for reference purposes, currently in Dutch, French, German and Spanish, with further additions planned during FY25. They can be accessed [here](https://drive.google.com/drive/folders/1ZYIAuqGcIpaYVg8hMVDneK1FJg1b8zkN?usp=drive_link).

## General Employment Practices

### Open Door Policy

We encourage communication between team members at all levels of the organization. This is an important part of our culture. Whenever problems or concerns arise, it is expected that they will be addressed as quickly as possible. Your immediate manager is the person on the management team who is closest to you and your work. When you need help or have questions, concerns, problems, or suggestions, please contact your manager first. It is your manager's responsibility to assist you - so please ask, and be willing to work the issue out with your manager. They are interested in your success, the success of every team member in their department, and the overall success of GitLab.

If your manager cannot help you or answer your questions, your questions will be referred to someone who can. If you feel your particular question, concern, or suggestion cannot be discussed with your manager, you are encouraged to contact your manager's manager, your assigned People Business Partner or Team Member Relations. It is important to remember that a team member who takes these steps will not be subject to retaliation. You can expect to be treated fairly and with respect.

### Romantic and Family Relationships at Work

**Hiring Significant Others or Family Members**

GitLab is committed to a policy of opportunities based on **qualifications and merit** and does not discriminate in favor of or in opposition to the employment or affiliation of significant others or family members. Due to the potential for perceived or actual conflicts, such as favoritism or personal conflicts from outside the work environment, which can be carried into the daily working relationship, GitLab will hire or consider for hire significant others and/or family members of persons currently serving as team members only if **all** points below are true:

- Candidates for open roles or current team members will not be working directly for or supervising a significant other or family member.
- Candidates for open roles or current team members will not occupy a position in the same line of authority in which team members can initiate or participate in decisions involving a direct benefit to the significant other or family member. Such decisions include hiring, retention, transfer, promotion, wages, talent assessment, and leave requests.
- The team member does not have access to sensitive company and/or personal information including payroll, compensation, personnel reviews/files, job performance, etc., unless the team member's job duties require access to such information. If the position in question requires access to such information, the team member in that position shall comply with the duty to maintain confidentiality as governed by applicable law and policy, and must seek approval from the team member's direct manager for any decisions affecting the significant other or family member's personnel information.

This policy applies to all current team members and candidates for open roles. In the spirit of our [Transparency](/handbook/values/#transparency) value, we ask the team member and the candidate to disclose the family relationship to the recruiter at the beginning of the hiring process. For purposes of this policy, a significant other or family member is any person who has a relation by blood, marriage, adoption, or domestic partnership within the third degree of our team member. If the candidate progresses through the process as a final candidate, and prior to any offer, the recruiter should notify the hiring manager and the People Business Partner of the family relationship to ensure there is not a conflict of interest. In addition, the GitLab team member should not be part of their family member's interview process. If there is a concern that either the team member or the candidate may progress to a position that would trigger one of the conditions above, a waiver will be signed by both parties acknowledging that future work assignments, promotions, etc may be impacted by enforcement of this policy.

**Active Team Member Relationships (Significant Other or Family Members)**

Please report any relationship with a significant other or family member to your People Business Partner, if you find yourself in a reporting relationship with the significant other or family member. Furthermore, if two team members who are in a reporting relationship become significant others or family members in the course of their employment, they should also report the relationship to the People Business Partner. Transfers, promotions, and future work assignments will be made in accordance with all applicable anti-discrimination laws and policies.

## Workplace Conduct

### Confidentiality

As stated in the **Confidentiality and Corporate Assets and Corporate Opportunities** section of the [Code of Business Conduct and Ethics](https://ir.gitlab.com/static-files/7d8c7eb3-cb17-4d68-a607-1b7a1fa1c95d), team members are, on occasion, entrusted with confidential GitLab information and with the confidential information of GitLab suppliers, customers, or other business partners. This information may include:

1. technical or scientific information about current and future services or research;
1. business or marketing plans or projections;
1. earnings and other internal financial data;
1. personnel information;
1. supply and customer lists; and
1. other non-public information

This information, if disclosed, might be of use to competitors, or harmful to GitLab's suppliers, customers or other business partners. This information is the property of GitLab, or the property of its suppliers, customers, or business partners, and in many cases was developed at great expense. All team members, upon commencement of their role with GitLab, shall sign offer letters or contractor agreements that contain confidentiality provisions (the "Confidentiality Agreement") provided by GitLab. Strict adherence to the Confidentiality Agreement is required of each team member.

Team members shall not take for themselves, or for family members, or any other entities with which they are affiliated, any opportunity of which they become aware through the use of GitLab property or information, or through their position with GitLab, and shall not use GitLab property or information, or their position with GitLab, for personal gain other than actions taken for the overall advancement of the interests of GitLab.

Team members also have obligations to protect the personal and sensitive information of our fellow team members. Therefore, you may not access and/or disseminate any team member's personal information (i.e. address, personal phone number, salary, etc.) that the team member has not made publicly available, unless the team member has provided written permission to share this information. An exception to this restriction would be when access is a necessary function of your job duties. A violation of this obligation is considered severe and could result in disciplinary action, up to and including termination.

#### Exceptions

Exceptions to this procedure will be tracked as per the [Information Security Policy Exception Management Process](/handbook/security/controlled-document-procedure/#exceptions). For reference see the [Parent Policy: Information Security Policy](/handbook/security).

### Anti-Harassment

Please see the [Anti-Harassment Policy]({{< ref "anti-harassment" >}}).

### Anti-Retaliation

Please see the [Anti-Retaliation Policy](/handbook/legal/anti-retaliation-policy/).

### Complaint Procedure

Please see the [Complaint Procedure](/handbook/people-group/#how-to-report-violations).

### Social Responsibility

Please see our [Environmental, Social, and Governance](/handbook/company/esg/) page.

### Personal Appearance

The image GitLab projects to the public is reflected in the appearance of our team members. Simply stated, team members should be dressed and groomed appropriately for their specific duties. Team members are expected to use good judgment in their appearance and grooming. Read our [GitLab Events Code of Conduct](/handbook/company/culture/ecoc/) for more information. Please read our GitLab Events Code of Conduct for more information regarding team member responsibility during attendance at company-sponsored events.

### Job Abandonment

When a team member is absent from work for three consecutive workdays, there is no entry on the availability calendar for time off, and fails to contact their supervisor, they may be [terminated](/handbook/people-group/offboarding/#involuntary-terminations) for job abandonment unless otherwise required by law. If a manager is unable to reach a team member via email or slack within a 24 hour period they should contact their [People Business Partner](/handbook/people-group/#how-to-reach-the-right-member-of-the-people-group). The People Business partner will access the team member's information to obtain additional contact methods and numbers. The manager and People Business Partner will create an action plan to make all attempts to contact the team member.

#### Exceptions

GitLab understands there are extenuating circumstances that can occur. In the instance that a team member is absent from work for three consecutive workdays due to an emergency outside of the team members' control (ex. an internet outage in their country of residence), the recommendation is:

- The team member should notify their manager about the situation, should a period of unavailability be a foreseen possibility.
- The team member and manager should consider exchanging cell phone numbers to stay in contact as much as possible in the case that the situation should escalate. If you are based in different countries, consider ensuring you and your manager both have an app that facilitates international communication (ex. Whatsapp, Zalo, etc.). If costs are incurred when trying to contact your manager, this can be considered a business expense and can be submitted for reimbursement through [Navan Expense](/handbook/finance/expenses/).
- Consider leveraging GitLab's flexible [time off policy]({{< ref "paid-time-off" >}}) to take the time you need.

## Team Member Safety

### Preventing Unsafe Situations

While GitLab is 100% remote, there may be times when team members travel for work-related functions or co-working events. GitLab is committed to the value of a safe, violence-free work environment and ensuring and exhibiting equal commitment to the safety and health of team members.

In general, please consider the following recommendations to ensure safety when traveling or coworking:

1. Do the research. Have some familiarity with the destination before you arrive. Check with your country's government department that provides advice for traveling overseas:
    - United States: check the State Department's website for country updates and enroll in a Traveler Program such as [Smart Traveler Enrollment Program (STEP)](https://step.state.gov/step/).
    - New Zealand: [Safe Travel](https://safetravel.govt.nz/).
1. Try not to draw attention. People who appear to be from out of town are more vulnerable to crimes. Try to respect the culture you are visiting by blending in. Consider protective clothing to avoid pickpockets or other theft. Do not flash money or credit cards unnecessarily.
1. Make copies of important documents. Consider carrying hard copies of important documents (passport, driver's license) in a separate location in the event your documents are misplaced or stolen.
1. Keep friends and family updated. No matter whether you're going on an overnight jaunt or a week-long international journey, it's always a good idea to let friends or family know your plans. Before you leave, send a copy of your itinerary to a few trusted people who can keep tabs on your whereabouts. Check in regularly with your contacts so they know you're where you're supposed to be.
1. Be wary of public Wi-Fi. Be aware that hackers can steal sensitive information in the public forum. Use a VPN or other secure access if you plan to access sensitive data. More information on [VPN usage at GitLab](/handbook/security#why-we-dont-have-a-corporate-vpn) and the [Personal VPN]({{< ref "personal-vpn" >}}) page.
1. Safeguard your hotel. Lock and deadbolt the door while you are in the room. Ensure the door is locked when you leave. Keep the windows closed. Try to give the impression that you're in your room even when you're away, such as placing the Do Not Disturb sign on the outside of your door and keeping the blinds or windows closed. Don't let any strangers into your room, even if they say they work for the hotel. You can always call the front desk to check whether someone was ordered by hotel staff to come to your room.
1. Be aware of your surroundings. Always keep an eye on your personal belongings and use good judgment when talking to strangers. A big part of the joy of traveling is the opportunities it affords to meet new people and learn about their cultures. But if someone near you is acting suspiciously, or if you feel uncomfortable, leave the area immediately. Trust your instincts.
1. Adhere to any recommended safety recommendations made by the GitLab group. For all large self-hosted events we (jointly completed by our internal security team and our contracted security agency) will do a full risk assessment before we converge. It will be up to employees to read said risk assessment and adhere to recommendations outlined.
1. If you are sick please do not come or participate in person workplace activities. This is for your safety and for others. We recommend that GitLab team members not travel while sick.

### Measures GitLab Takes to Aid Employee Health and Safety

- Hand sanitizers placed around the venue of live events or attendees are given hand sanitizer.
- Team members can expense masks for traveling if suggested in the risk assessment outlined above.
- Sick team members should not travel per our travel policy.
- Team members who become sick while traveling should expense masks if flying back home.
- If health risk is considered high, all food to be served by food health professionals rather than team.
- Fist bumps over handshakes.

### Responding to Unsafe Situations

The following are GitLab's procedures in the event a team member feels threatened or unsafe:

1. If at any point, a team member feels that they are in danger of physical harm, please contact the local authorities immediately. Local law enforcement can act quickly to protect the individual and neutralize any threats.
1. If at any point, a team member feels like they or another team member may require immediate medical assistance, please contact the local authorities.
1. Once the immediate threat is controlled, team members should report any safety concerns to People Connect.
1. If you believe that a certain location, event or area presents greater risk or exposure to individuals, please notify People Connect. People Connect will strive to proactively communicate the concerns to other potentially affected team members.
1. If at any point you believe you, personally, may commit an unsafe act, People Connect can assist in providing information about available [Employee Assistance](/handbook/total-rewards/benefits/general-and-entity-benefits/#employee-assistance-program) options.

## Workers' Compensation

If you have been injured at work, at a co-working site, or traveling to a customer location please contact the Absence Management team (leaves@gitlab.com). The Absence Management team will provide you with paperwork to file your claim and explain your benefits.

**CA Team Members Only**: Complete this [form](https://www.dir.ca.gov/dwc/DWCForm1.pdf) and email to the Absence Management Team at leaves@gitlab.com.

The following states are considered "monopolistic" workers compensation states, meaning employers must purchase workers compensation coverage directly from the state. If a team member in these states is injured, they may file the claim themselves or the Absence Management Team will file on their behalf. **Team members in these States are still required to contact the Absence Management Team, even if they file their own claim through the State**:

- [Ohio](https://info.bwc.ohio.gov/)
- [Washington](https://www.lni.wa.gov/)
- [North Dakota](https://www.workforcesafety.com/)

## Substance Abuse

GitLab strives to maintain a workplace that is free from illegal use, possession, sale, or distribution of alcohol or controlled substances. Legal or illegal substances shall not be used in a manner that impairs a person's performance of assigned tasks. This will help to maintain the efficient and effective operation of the business, and to ensure customers receive the proper service. GitLab team members must also adhere to the local laws of where they reside and where they travel to for company-sponsored events.

## Mental Health Awareness Statement

1. Why is awareness of Mental Health important at GitLab?
    - It can affect any and all of us. Statistics indicate that [1 in 4](https://www.who.int/news-room/detail/28-09-2001-the-world-health-report-2001-mental-disorders-affect-one-in-four-people) of us will be affected by mental or neurological disorders at some point in our life. That said, we are all subject to periods where we or those around us find the "the normal stresses of life" harder than usual to deal with.
    - The more we are aware of mental health, the more inclusive we are. That will help encourage any colleagues currently experiencing mental health issues to talk about it.
    - Our business at its core is a group of people working together towards a common goal. With awareness of what might affect our colleagues, we are better equipped to help them if they do discuss it with us and therefore help our business.
    - Mental health has so much emotional baggage as a topic that it can initially seem scary to talk about. Promoting mental health awareness helps to remove the stigma and taboos associated with it.
    - GitLab can offer "productive and fruitful" work for all of our employees. That should not be [underestimated](https://www.google.co.uk/url?sa=t&rct=j&q=&esrc=s&source=web&cd=1&cad=rja&uact=8&ved=0ahUKEwitr7eP18_XAhWIORoKHY2_CA4QFggrMAA&url=https%3A%2F%2Fcardinal-management.co.uk%2Fwp-content%2Fuploads%2F2016%2F04%2FBurton-Waddell-is-work-good-for-you.pdf&usg=AOvVaw0ROXJdWquGML5bIsBEIRLo).
    - In the cold-light of business metrics, the healthier we are, [the more productive we are](https://www.rand.org/randeurope/research/projects/workplace-health-well-being-productivity.html).
1. At GitLab we strive to create a stigma-free workplace. In accordance with the National Mental Health Association and the National Council for Behavioral Health we would like to:
    - Educate employees about the signs and symptoms of mental health disorders.
    - Encourage employees to talk about stress, workload, family commitments, and other issues.
    - Communicate that mental illnesses are real, common, and treatable.
    - Discourage stigmatizing language, including hurtful labels such as "crazy," "loony" or "nuts."
    - Help employees transition back to work after they take leave.
    - Encourage consultation with our employee assistance programs.
1. What are we doing to get there?
    - Talk about mental health issues and ideas in the #mental_health_aware Slack channel.
    - GitLab would also like to encourage GitLab team members to take [time off]({{< ref "paid-time-off" >}}) to properly take care of themselves. We encourage the team to go to yoga, take a long lunch, or anything else in their day to day life that assists in their mental and emotional well-being.
    - In addition to our current EAP programs available for employees, we encourage GitLab team members to take a look at these [Resources for Employees](https://www.workplacestrategiesformentalhealth.com/topic/Resources-for-employees) for insight into reclaiming well-being at work, off work, and return to work.
    - We believe that our values and culture lends itself to being able to discuss mental health open and honestly without being stigmatized, but let's work together to make it even more inclusive. For example, Finding the right words:
        - "How can we help you do your job?"
        - "You're not your usual self."
        - "Do you want to talk about it?"
        - "It's always OK to ask for help."
        - "It's hard for me to understand exactly what you're going through, but I can see that it's distressing for you."

        For additional information, please see the Mental Wellness Services offered through [Modern Health](/handbook/total-rewards/benefits/modern-health/) and tips on [Leading Through Adversity](/handbook/leadership/managing-conflict/leading-through-adversity/). Additionally, team members should learn to [recognize burnout](/handbook/people-group/paid-time-off/#recognizing-burnout) and to [prevent it](https://about.gitlab.com/blog/2022/05/03/preventing-burnout-a-managers-toolkit/).

Any questions or concerns? Please feel free to contact the People Connect team via HelpLab.

## Other People Policies

- [Backgound Screenings](/handbook/people-group/contracts-probation-periods/#background-screenings)
- [Contracts, Background Screenings, Probation Periods, and PIAA](/handbook/people-group/contracts-probation-periods/#piaa-proprietary-information-and-assignment-agreement)
- [Outside Employment and Activities](/handbook/people-group/contracts-probation-periods/#outside-employment-paid-or-unpaid-projects-and-potentially-conflicting-activities)
- [Paid Time Off]({{< ref "paid-time-off" >}})
- [General Benefits](/handbook/total-rewards/benefits/general-and-entity-benefits/)
- [Leave of Absence](/handbook/people-policies/leave-of-absence/)
- [Return of Property](/handbook/people-group/offboarding/#returning-property-to-gitlab)

## GitLab Legal Policies

There are a number of GitLab Legal Policies which are important for GitLab team members to read and understand, and they are listed [here](/handbook/legal/#gitlab-policies).

## Entity-Specific Employment Policies

{{% details summary="GitLab BV (Belgium)" %}}

### Belgium

**Workplace Regulations**

- [Draft GitLab BV (Belgium) Work Regulations - Dutch](https://docs.google.com/document/d/13Esmk87xUd01Ub4Wg3VKhARs7HntrH-Jb4Rn6FU_Xtk/edit?usp=sharing)
- [Draft GitLab BV (Belgium) Work Regulations - French](https://docs.google.com/document/d/1ywSSzRY74PEMJbyK52WjOj1apu42Rm0_TxAM1B0ePNQ/edit?usp=sharing)
- [Draft GitLab BV (Belgium) Work Regulations - English](https://docs.google.com/document/d/1HKxLs8AQ9TM-ud2y7EWS6R1ZJ982eeXR1UTKyIu9kPo/edit?usp=sharing)
- [Comment book](https://docs.google.com/document/d/1UDsYcvkGPHJUF_--EZgxu_ONoiImFzxAavaAFkL5AtA/edit?usp=sharing)
{{% /details %}}

{{% details summary="GitLab BV (Netherlands)" %}}

### Netherlands

**Health and Safety**

- [Safety Regulations for Remote Work](https://docs.google.com/document/d/1tKqPcjPeEgWdYWol3X8YWhqcbbS6SWrJ/edit?usp=sharing&ouid=106298195226644329866&rtpof=true&sd=true)
{{% /details %}}

{{% details summary="GitLab Canada Corp." %}}

### Canada

- [Right to Disconnect Policy](https://docs.google.com/document/d/1XaVIy3J1depX8s9yUM7YcgpKm6RSNS7V9CPS_rx_K5I/edit?usp=sharing)
{{% /details %}}

{{% details summary="GitLab France S.A.S." %}}

### France

- [Remote Work Charter]({{< ref "france-sas/remote-work-charter" >}})
- [Right to Disconnect Charter]({{< ref "france-sas/right-to-disconnect-charter" >}})
{{% /details %}}

{{% details summary="GitLab GmbH (Germany)" %}}

### Germany

**Health and Safety**

To ensure the health and safety of our team members in Germany, and to maintain compliance with the German Occupational Safety and Health Act, all team members in Germany will complete the following checklist at onboarding. If you think you may need accommodations in order to achieve and/or maintain a healthy and safe work environment, please contact the People Connect team via HelpLab. If you need to report an accident or injury, please contact [Team Member Relations](mailto:teammemberrelations@gitlab.com).

- [Work from Home Checklist](https://docs.google.com/document/d/1Z3i-vrkcU5ald0j-scf2rgTumwFCc_sI/edit?usp=sharing&ouid=106298195226644329866&rtpof=true&sd=true)
{{% /details %}}

{{% details summary="GitLab GK (Japan)" %}}

### Japan

- [Work Rules](https://drive.google.com/file/d/1_xXSlx8e3PX_hM5GBgUPgfAlMhe0DkvM/view?usp=sharing)
{{% /details %}}

{{% details summary="GitLab Inc. (US)" %}}

### United States

**Health and Safety**

- [Workplace Evaluation](https://docs.google.com/document/d/12o3YXX6fIi2-V7yS_bhc1Vx_5jokQh3Oracc-ZIBsGE/edit?usp=sharing) (for existing team members)
- [Onboarding Checklist](https://docs.google.com/document/d/1DqbNBL6QIFBQlxqi7rWQiodFt6KvSp5fml3llu94Byw/edit?usp=sharing) (for new team members)

{{% /details %}}

{{% details summary="GitLab Ireland LTD" %}}

### Ireland

**Complaint and Disciplinary Procedures**

- [Bullying, Harassment, and Sexual Harassment Policy](https://docs.google.com/document/d/192-0TKUm1x0EmP_SQCnTDOJlDiT_O-O4n7qFFfhWnyA/edit?usp=sharing)
- [Disciplinary Procedure](https://docs.google.com/document/d/1cTSESXTt1Fn8680AVAcpq1g3wkJ_voFj192ak3rXNcA/edit?usp=sharing)
- [Grievance Procedure](https://docs.google.com/document/d/1RJ5rWMz_FRiKDOOyAgCn5b4XZkV0dcrKZ82D7etBlUo/edit?usp=sharing)
- [Protected Disclosure Policy](https://docs.google.com/document/d/1cIRHYLBCKJy2doHcpL4Yg-A4PWaw16IgjWLUCb34OyE/edit?usp=sharing)
- [Right to Disconnect Policy]({{< ref "ireland-ltd/right-to-disconnect-policy" >}})

**Health and Safety**

- [Display Screen Equipment Regulations 2007](https://www.irishstatutebook.ie/eli/2007/si/299/made/en/print#partii-chapv)

- To ensure the physical and mental health and safety of our team members in Ireland, and to maintain compliance with local employment regulations, all team members in Ireland will complete a [home working checklist](https://forms.gle/bmXqNdH1xEw2bFTa8) at onboarding. This checklist will be reviewed annually. If you think you may need accommodations in order to achieve and/or maintain a healthy and safe work environment, please contact the People Connect team. If you need to report an accident or injury, please contact [Team Member Relations](mailto:teammemberrelations@gitlab.com).
{{% /details %}}

{{% details summary="GitLab Korea LTD" %}}

### Korea

None currently applicable specific to team members in Korea.
{{% /details %}}

{{% details summary="GitLab LTD (UK)" %}}

### United Kingdom

[GitLab LTD (UK) Homeworking and Flexible Working Policy](https://docs.google.com/document/d/1zUNgTR-PBPNbL0mNJMNs8kSDOJm_VDqil_Rv3EHAb2E/edit?usp=sharing)

**Health and Safety**

[GitLab Ltd (UK) Health and Safety Risk Assessment](https://docs.google.com/document/d/1c1Miem37ysMvddyhhQYfp1Tz07rQ7P3MnyUrFyhoTmc/edit#)

To ensure the physical and mental health and safety of our team members in the UK, and to maintain compliance with local employment regulations, all team members employed by GitLab Ltd. must review the [guidelines for working comfortably at home](https://docs.google.com/document/d/1aFVBgpfLIyuV14kE0kavHsdl5_fWjnnP/edit?usp=sharing&ouid=106298195226644329866&rtpof=true&sd=true) and complete a [home working risk assessment](https://docs.google.com/document/d/1hJDuR1wqEcSCq3us2FnsV_b4My7STgctyM-c_FDqfAU/edit?usp=sharing) at onboarding. If you think you may need accommodations in order to achieve and/or maintain a healthy and safe work environment, please contact the People Connect team via HelpLab. If you need to report an accident or injury, please contact [Team Member Relations](mailto:teammemberrelations@gitlab.com). Team members should regularly inspect their home offices for potential hazards related to the following:

- Electrical equipment: make sure that your plugs, wiring, and casings are in good working order and there is no fraying.
- Fire: regularly check your smoke detectors and develop an escape plan in case of fire, if you haven't already.
- Slips and trips: keep your work area clear of boxes, cables, uneven surfaces, and other obstacles that may cause a trip hazard.
- First aid: Keep first aid provisions in your home and be careful when handling sharp objects and hot or cold liquids.

The handbook also has a wealth of information and recommendations for setting up your workspace and procuring the proper equipment:

- [How to Create an Ergonomic Workspace](/handbook/company/culture/all-remote/tips/#create-an-ergonomic-workspace)
- [Focus your Workspace](/handbook/company/culture/all-remote/getting-started/#focus-your-workspace)
- [Combating Burnout, Isolation, and Anxiety in a Remote Workplace](/handbook/company/culture/all-remote/mental-health/)
- [Considerations for a Productive Home Office](/handbook/company/culture/all-remote/workspace/#introduction)
- [Equipment Examples](/handbook/finance/procurement/office-equipment-supplies/)

**Working Time Regulations**

*What are the Working Time Regulations?*

The Working Time Regulations (1998) were introduced to support the health and safety of workers by setting maximum requirements for the number of hours that they can work, paid time off and rest periods.

*The 48-hour working week*

The regulations state it is illegal for you to work any time over a total of 48 hours each week. You can agree to exceed this limit if you want to, but you cannot be mandated to work more than 48 hours per week.
Average working hours are calculated over a 'reference' period, which is usually 17 weeks. This means you can work more than 48 hours one week, as long as the average over 17 weeks is less than 48 hours a week.
For more information about the 48-hour working week restrictions, please visit the [government's website](https://www.gov.uk/maximum-weekly-working-hours).

*How to opt-out of the 48-hour working week*

It is entirely your decision if you would like to work more than an average of 48 hours a week. GitLab is committed to enabling team members to maintain a healthy work-life balance, but on occasion (for example during periods of high customer demand) you may be asked to work longer hours. To ensure that we remain compliant with the regulations, we ask you to opt out of them, in case such a need arises.
If you would like to opt-out, you can do this by signing this written agreement, known as the opt-out agreement. You may have chosen to sign/confirm this agreement already during your onboarding. The duration of the agreement is indefinite. If you haven't already signed [this agreement](https://docs.google.com/document/d/1DRu62fqQW7OQV0lS6evf_XxdQ-0IVZl1Jk_LmSgEhDo/edit#heading=h.tkxekwf0szl9) but would like to do so, you can make a copy of this document, add your name and sign it, and attach a copy of it to a new case to the People Connect team within HelpLab, with a request that it be saved with your documents in Workday.

*How do I cancel my opt-out agreement?*

You can choose to cancel your opt-out agreement at any time. The notice period you are required to give is three months.
{{% /details %}}

{{% details summary="GitLab PTY (Australia)" %}}

### Australia

**Health and Safety**

To ensure the physical and mental health and safety of our team members in Australia, and to maintain compliance with local employment regulations, all team members in Australia will complete the following checklist at onboarding. This checklist will be reviewed annually. If you think you may need accommodations in order to achieve and/or maintain a healthy and safe work environment, please contact the People Connect team via HelpLab. If you need to report an accident or injury, please contact [Team Member Relations](mailto:teammemberrelations@gitlab.com).

- [Remote Work Checklist](https://docs.google.com/document/d/1_sHk3ksGLDVxBZsnO3pMD-U_R_Fy0Yyu/edit?usp=sharing&ouid=106298195226644329866&rtpof=true&sd=true)

**Right to Disconnect**

- [Right to Disconnect](/handbook/total-rewards/benefits/general-and-entity-benefits/pty-benefits-australia/#gitlab-pty-australia-right-to-disconnect)
{{% /details %}}

{{% details summary="GitLab PTY (New Zealand)" %}}

### New Zealand

**Health and Safety**

To ensure the physical and mental health and safety of our team members in New Zealand, and to maintain compliance with local employment regulations, all team members in New Zealand will complete the following survey at onboarding. The responses will be reviewed annually. If you think you may need accommodations in order to achieve and/or maintain a healthy and safe work environment, please contact the People Connect team via HelpLab. If you need to report an accident or injury, please contact [Team Member Relations](mailto:teammemberrelations@gitlab.com).

- [Remote Work Checklist](https://forms.gle/DszZNkBA22Rhy3VW7)
{{% /details %}}

{{% details summary="GitLab Singapore PTE LTD" %}}

### Singapore

**Health and Safety**

- [How to Create an Ergonomic Workspace](/handbook/company/culture/all-remote/tips/#create-an-ergonomic-workspace)
- [Focus your Workspace](/handbook/company/culture/all-remote/getting-started/#focus-your-workspace)
- [Combating Burnout, Isolation, and Anxiety in a Remote Workplace](/handbook/company/culture/all-remote/mental-health/)
- [Considerations for a Productive Home Office](/handbook/company/culture/all-remote/workspace/#introduction)
- [Equipment Examples](/handbook/finance/procurement/office-equipment-supplies/)

**Data Protection/Privacy Policy**

- [Employee Privacy Policy](/handbook/legal/privacy/employee-privacy-policy/)
- [GitLab Privacy Policy](https://about.gitlab.com/privacy/)

**Workplace Harassment Policy**

- [Anti-Harassment Policy]({{< ref "anti-harassment#introduction" >}})
- [Code of Business Conduct & Ethics](https://ir.gitlab.com/static-files/7d8c7eb3-cb17-4d68-a607-1b7a1fa1c95d)

**Fair Employment Practices Policy**

- [GitLab PTE LTD Fair Employment Practices Policy](https://docs.google.com/document/d/1osJfO9BysOqjpt5iLnqygXX7B5Imb9NXIXA3KBtDCJk/edit?usp=sharing)
{{% /details %}}
