---
title: United States Leave of Absence Policies
description: "GitLab's United States Leave of Absence policies."
---

These GitLab and US-specific leave policies are intended to provide team members time away from work to care for themselves as they recover from a serious health condition, care for a family member recovering from a serious health condition, or to bond with a newborn or a newly placed child for adoption.

This page is designed to educate our team members about the different US-specific leave types available, how a team member can expect to be paid, and if their job is protected. These leave programs are coordinated and run concurrently with the [Family Medical Leave Act](https://www.dol.gov/sites/dolgov/files/WHD/legacy/files/fmlaen.pdf) or (FMLA), and other State leave programs team members are eligible for.

Taking time away can be confusing, so your Absence Managment team is here and available to help before, during, or after your leave. If you have any questions related to your time away after reviewing this page, please contact leaves@domain to discuss or request a 1:1 with the Absence Management team.

**Please note:** When sending emails to the Absence Management team, please replace `@domain` with `@gitlab.com`.

## Which leave is right for me?

Below are the GitLab and US-specific leave policies available to US team members, as well as common examples of how each leave may be used. This list may not be all inclusive, so if you have questions regarding which leave may be right for you please contact leaves@domain.

| Leave Program | Description | Eligibility |
|:---:|:---:|:---:|
| Parental Leave | I am expecting a child<br>My partner is expecting a child<br>My family is adopting a child | All team members as long as their child was born or newly adopted during their employment at GitLab |
| Family Medical Leave Act<br>(FMLA) | I am having surgery<br>My family member* is seriously injured<br>I have recurring appointments for follow up care (chemotherapy, prenatal exams, etc)<br>I am bonding with my newborn or newly placed adopted child<br>I am caring for a family member seriously injured while on active duty | 1 year of service, AND<br>1250hrs worked in the <br>year immediately prior<br>to the start of leave |
| California Family Rights Act (CFRA) | I am having surgery<br>My family member** is seriously injured<br>I have recurring appointments for follow up care (chemotherapy, etc)<br>I am bonding with my newborn, newly placed adopted or foster care child<br>I am caring for a family member seriously injured while on active duty | 1 year of service, AND<br>1250hrs worked in the <br>year immediately prior<br>to the start of leave |
| Military Leave (USERRA) | I am being deployed<br>I am a reservist reporting for extended training (5 days or more) | Provided written or <br>verbal notice prior to<br>leave (if able) |

*FMLA Eligible Family Members: Spouse, Son, Daughter, Parent.

**CFRA Eligible Family Members:  Spouse, Registered Domestic Partner, Parent, Parent-In-Law, Child (including children of a domestic partner), Grandparent, Grandchild, and Sibling.

### How Much Time Do I Get Off?  Is my Job Protected?

| Leave Program | Total Time Off | Job Protection |
|:---:|:---:|:---:|
| [Parental Leave]({{< ref "general-and-entity-benefits#parental-leave" >}}) | 16 weeks | Yes* |
| [Family Medical Leave Act<br>(FMLA- Own Condition)](#the-family-medical-leave-act-fmla) | Up to 12 weeks | Yes* |
| [Family Medical Leave Act<br>(FMLA - Care for a Family Member)](#the-family-medical-leave-act-fmla) | Up to 12 weeks | Yes* |
| [California Family Rights Act (CFRA)](https://edd.ca.gov/en/disability/faqs-fmla-cfra) | Up to 12 weeks** | Yes |
| Military Leave (USERRA) | Cumulative 5 years | Yes, up to 5 years* |

*Except in certain circumstances

### How Will My Pay Be Calculated?

| Leave Program | Pay Calculations |
|:---:|:---:|
| Parental Leave | 100% paid by GitLab (minus any State Disability and/or Paid Family Leave benefits) |
| [Family Medical Leave Act<br>(FMLA - Own Condition)](#payroll-processing-during-fmla) | 66.67% (STD) + 33.3% paid by GitLab per week<br>After 12 weeks:  <br>     66.67% (LTD) per month |
| [Family Medical Leave Act<br>(FMLA - Care for a Family Member)](#the-family-medical-leave-act-fmla) | 100% for up to 25 working days |
| California Family Rights Act<br>(CFRA) | First 8 weeks:  60% (SDI/PFL) + 6.66% (STD) + 33.3% paid by GitLab<br>8-12 weeks:  60% (SDI - if applicable) + 6.66% (STD) + 33.3% paid by GitLab<br>After 12 weeks:  66.67% LTD paid by Cigna monthly (if eligible) |
| [Military Leave (USERRA)](#us-military-leave) | First 25 days:  paid 100% by GitLab<br>After 25 days:  Unpaid |

*If leave is taken continuously

If you live in a state where disability or paid family leave benefits are available, GitLab will offset your pay minus these benefits. Please refer to GitLab's [Parental Leave]({{< ref "inc-benefits-us#parental-leave" >}}) policy for more information.

## What Happens Next?

Team members can use this [checklist](https://docs.google.com/document/d/1NCf6NcDkSn5TlBcPLnP0eyjxIWOQ5lVfRVR_cvdZ9zI/edit?usp=sharing) as a reference for what steps to complete before, during, and after you return from leave. For questions specific to your leave or pay, please contact `leaves@domain`. *This checklist is currently in its first iteration. Please continue to check back for updates.*

### State-Specific Leaves

Each US state varies when it comes to types of leave employers are required to allow employees to take. Employees of GitLab Inc. are eligible for our paid time off policy and our Sick Time policy; which will run concurrently with any State or FMLA leave entitlement. Please refer to the [Sick Time Procedures - USA](/handbook/people-group/paid-time-off/#sick-time-procedures---usa) or [Paid Time Off](/handbook/people-group/paid-time-off/#a-gitlab-team-members-guide-to-time-off) policy for more information.

### The Family Medical Leave Act (FMLA)

The Family Medical Leave Act [FMLA](https://www.dol.gov/agencies/whd/fmla) provides eligible U.S team members up to 12-weeks, or up to 26- workweeks (in one 12 month period to care for an injured service member), unpaid time away from work for their own serious health condition, to care for a family member with a serious health condition, or to bond with a newborn or newly adopted child.  FMLA eligible leave time can be taken in continuous segments or intermittently as certified by a physician.  If FMLA is used to bond with a child, or newly adopted child, all eligible time must be used prior to the child's first birthday or date of adoption. For more information  please see [Employee Rights Under the Family Medical Leave Act](https://www.dol.gov/sites/dolgov/files/WHD/legacy/files/fmlaen.pdf).

Team members must have 12 months of continuous service and 1250 hours worked in the year immediately before the start of their leave to be eligible for FMLA leave.  Working hours are calculated as actual hours worked and does not include PTO or vacation time.  GitLab calculates FMLA eligibility as a "rolling" 12-month period measured backward from the date of any FMLA leave usage. (Each time a team member takes FMLA leave, the remaining leave is the balance of the 12 weeks not used during the 12 months immediately before the FMLA leave is to start.)   All FMLA entitled leave will run concurrently with any State specific leave and disability or paid family leave programs (if applicable), GitLab's sick leave policy (including COVID leave), and/or Short-Term disability benefits.  GitLab's Flexible PTO policy can not be used to delay, extend, or in lieu of FMLA.

#### How to Apply

Any medical related absence (for yourself or a family member) requiring you to be away from work for at least 3 but no more than 5 days (either continuously or non-continuous but related to the same condition) must be reported either in Workday or to the Absence Management Team (leaves@domain.com). You will be contacted within 24-48 business hours (whenever possible) and provided with information regarding your request.  If approved, please adjust your Slack status noting you are OOO.

#### Payroll Processing During FMLA

The Absence Management team will review the team members eligibility for Short-Term Disability benefits, State pay benefits, and/or GitLab's Sick Time policy, and will communicate how the team member can expect to receive their pay while on leave.

### California Family Rights Act (CFRA)

GitLab will grant time off to eligible team members in accordance with the requirements of the California Family Rights Act ("CFRA") and the federal Family and Medical Leave Act (Fed-FMLA). Where both the CFRA and Fed-FMLA apply, the leave provided by each will count against the team member's entitlement under both laws and must be taken concurrently. A team member who is eligible for leave under only one of these laws will receive benefits in accordance with that law only. In any case, team members will be eligible for the most generous benefits available under applicable law.

The following policy addresses team member rights under the CFRA only. Team members should refer to [GitLab's Team Member Handbook](#the-family-medical-leave-act-fmla) for additional detail regarding the Fed-FMLA. All questions concerning this policy should be directed to leaves@domain.

**Team Member Eligibility**

To be eligible for CFRA leave, team members who reside in California must have been employed by the Company for a total of at least 12 months (52 weeks) at any time prior to the commencement of the leave and have worked at least 1,250 hours over the previous 12 months as of the start of the leave.

**Qualifying Reasons For Leave**

Eligible team members may request leave under the CFRA for one or more of the following reasons:

- For the birth of a team member's child or the placement of a child with the team member for foster care or adoption, so long as the leave is completed within 12 months of the birth or placement of the child;
- To care for the team member's spouse or registered domestic partner, child (regardless of age or dependency status), parent, grandparent, grandchild, or sibling, with a serious health condition;
- For the team member's own serious health condition, except for disability from pregnancy, childbirth or a related medical condition; or
- For a qualifying exigency related to the covered active duty or call to covered active duty of an team member's spouse, domestic partner, child, or parent in the Armed Forces of the United States;
  - For purposes of this policy, a "parent" includes a biological, foster or adoptive parent, a stepparent, parent-in-law, a legal guardian or other person who stood in loco parentis to the employee when the employee was a child.
  - "Serious health condition" means an illness, injury (including, but not limited to, on-the-job injuries), impairment or physical or mental condition that involves either:
- Inpatient care (including, but not limited to, substance abuse treatment) in a hospital, hospice or residential medical care facility, including any period of incapacity (that is, inability to work, attend school or perform other regular daily activities) or any subsequent treatment in connection with this inpatient care; or
- Continuing treatment (including, but not limited to, substance abuse treatment) or continuing supervision by a health care provider that includes one or more of the following:
  - A period of incapacity (that is, inability to work, attend school or perform other regular daily activities due to a serious health condition, its treatment or the recovery that it requires) of more than three consecutive calendar days, and any subsequent treatment or period of incapacity relating to the same condition, that also involves treatment two or more times via an in-person visit to a health care provider, or at least one visit to a health care provider that results in a regimen of continuing treatment under the supervision of the health care provider;
  - Any period of incapacity or treatment for incapacity due to a chronic serious health condition that requires periodic visits to a health care provider, continues over an extended period of time and may cause episodic incapacity;
  - A period of incapacity that is permanent or long-term due to a condition for which treatment may not be effective, such as Alzheimer's, a severe stroke and the terminal stages of a disease; or
  - Any period of absence to receive multiple treatments (including any period of recovery) by a health care provider either for (a) restorative surgery after an accident or other injury; or (b) a condition that would likely result in a period of incapacity of more than three consecutive calendar days in the absence of medical intervention or treatment.

**Length of Leave**

Team members are entitled to a maximum of 12 workweeks of CFRA leave in a 12-month period. The applicable "12-month period" used by the Company is a rolling 12-month period measured backward from the date an employee uses CFRA leave. Under this method the 12-month period is measured backward from the day the employee uses any CFRA leave.

CFRA leave is not available when a team member is disabled by pregnancy, childbirth or a related condition. However, team members disabled by pregnancy, childbirth or a related medical condition may be entitled to pregnancy disability leave under California law and the Federal FMLA. Federal FMLA leave will generally run concurrently with pregnancy disability leave. CFRA leave is in addition to and will not run concurrently with leave taken in accordance with California's pregnancy disability leave law.

When CFRA leave is for the birth or placement of a child and both parents work for the Company, they will each be allowed up to 12 weeks of CFRA leave within 12 months of the child's birth or placement.

When the reason for CFRA leave is the team member's serious health condition, which also constitutes a "disability" under California's Fair Employment and Housing Act ("FEHA"), and the team member cannot return to work at the conclusion of the CFRA leave, the Company will engage in an interactive process to determine whether an extension of leave would be a reasonable accommodation under the FEHA.

**Intermittent or Reduced Schedule Leave**

Under some circumstances, team members may take CFRA leave intermittently, which means taking leave in blocks of time or reducing the team member's normal weekly or daily work schedule. A team member may take leave intermittently or on a reduced schedule whenever it is medically necessary to care for the team member's child, parent, spouse, registered domestic partner or registered domestic partner's child with a serious health condition or because the team member has a serious health condition. The medical necessity of the leave must be determined by the health care provider of the person with the serious health condition.
Intermittent or reduced schedule leave may also be taken for absences where the team member or their family member is incapacitated or unable to perform the essential functions of the job because of a chronic serious health condition, even if the person does not receive treatment by a health care provider.

Leave due to military exigencies may also be taken on an intermittent or reduced leave schedule basis.

Leave taken intermittently may be taken in increments of no less than one hour. Team members who take leave intermittently or on a reduced work schedule basis for planned medical treatment must make a reasonable effort to schedule the leave so as not to unduly disrupt the Company's operations. Please contact leaves@domain prior to scheduling medical treatment. If CFRA Leave is taken intermittently or on a reduced schedule basis due to planned medical treatment, the Company may require team members to transfer temporarily to an available alternative position with an equivalent pay rate and benefits, including a part-time position, to better accommodate recurring periods of leave.

If a team member using intermittent leave or working a reduced schedule finds it physically impossible to start or stop work mid-way through a shift in order to take CFRA leave and is therefore forced to be absent for the entire shift, the entire period will be counted against the team member's CFRA entitlement. However, if there are other aspects of work that the team member is able to perform that are not physically impossible, then the team member will be permitted to return to work, thereby reducing the amount of time to be charged to the team member's CFRA entitlement.

CFRA leave for Bonding Leave does not have to be taken in one continuous period of time, but the minimum duration is two weeks. However, the Company will grant a request for CFRA leave lasting less than two weeks' twice during the 12-week period. **Additional requests for Bonding Leave lasting less than two weeks may be directed to the Absence Management team (leaves@domain)** and will be considered on a case-by-case basis depending on the needs of the Company. If the request is granted, the Company may require the team member to transfer temporarily to an available alternative position. Bonding Leave must be concluded within one year of the birth or placement of the child.

**Requesting Leave**

Team members who wish to take planned family or medical leave must notify leaves@domain with reasonable promptness when they become aware of the need for leave and should identify the planned dates of the leave. The Company may require team members to provide written notice of the need for leave, except where written notice is not possible because of the need for immediate health care consultation or treatment.

When the need for the leave is foreseeable (such as for the expected birth or placement of a child) team members must, if possible, provide at least 30 days' advance notice. For events that are unforeseeable, team members should notify the Company (at least verbally) as soon as they learn of the need for leave. Employees should provide notice by emailing leaves@domain.

Team members who need CFRA leave that is foreseeable due to a planned medical treatment should make reasonable efforts to schedule leave to avoid disruption to Company operations.
In addition to other notice provisions, team members requesting leave for CFRA qualifying reasons must respond to any questions designed to determine whether an absence is potentially qualifying for leave under this policy. Failure to respond to permissible inquiries regarding the leave request may result in denial of CFRA leave protections

**Certification of Health Care Provider**

When the leave relates to medical issues (i.e., the serious health condition of a team member or family member), team members will be required to provide a medical certification within 15 calendar days of the Company's request, unless it is not practicable to do so. Certification forms are available from the Absence Management Team (leaves@domain). Team members on CFRA leave for their own or a family member's serious health condition may be required to provide a recertification when the original certification expires, if additional leave is requested.

At the Company's expense, the Company may also require a second medical opinion regarding a team member's own serious health condition. Team members are expected to cooperate with the Company in obtaining additional medical opinions that the Company may require.

**Qualifying Exigency Leave Requirements**

Team members are required to provide:

- As much advance notice as is reasonable and practicable under the circumstances;
- A copy of the covered servicemember's active duty orders when the team member requests leave and/or documentation (such as Rest and Recuperation leave orders) issued by the military setting forth the dates of the servicemember's leave; and
- A completed Certification of Qualifying Exigency form within 15 calendar days, unless unusual circumstances exist to justify providing the form at a later date.

Certification forms are available from the Absence Management team (leaves@domain).

**Failure to Provide Notice or Certification and to Return From Leave**

Absent unusual circumstances, failure to comply with these notice and certification requirements may result in a delay or denial of the leave. If a team member fails to return to work at the leave's expiration and has not obtained an extension of the leave, the Company may presume that the team member does not plan to return to work and has voluntarily terminated their employment.

**Benefits**

The Company will continue making contributions for a team member's group health benefits during a leave on the same terms as if the team member had continued to work. This means that, if a team member wants benefits coverage to continue during CFRA leave, the team member must continue to make any premium payments they were required to make for themselves or their dependents prior to the leave. Team members will generally be provided with group health benefits for a 12-workweek period. In some instances, the Company may recover premiums it paid on a team member's behalf to maintain health coverage if the team member fails to return to work following CFRA leave for reasons other than the continuation, recurrence, or onset of a serious health condition or circumstances beyond the team member's control.

A team member's length of service will remain intact, but benefits such as vacation and sick leave may not accrue while on an unpaid CFRA leave.

No loss of benefits accrued prior to the leave will occur as a result of leave under the CFRA, but team members are not entitled to any benefit or position that they would not have been entitled to if they did not take the leave.

**Compensation During Leave**

Leave taken under this policy is generally unpaid, although depending upon the circumstances, team members may be eligible to receive benefits through state-sponsored programs or the Company's sponsored wage-replacement benefit programs. Also, team members may choose to use PTO and sick leave, to the extent permitted by law and the Company's policy. The Company may require team members to use PTO to cover some or all of the leave, only if the CFRA leave is otherwise unpaid. The CFRA leave is not unpaid if the team member is receiving state disability insurance, short or long term disability payments pursuant to an employer provided plan, or is receiving Paid Family Leave through the state. The use of paid benefits will not extend the length of CFRA leave.

**Job Reinstatement**

Under most circumstances, team members will be reinstated to the same position they held at the time of the leave or to an equivalent position with equivalent pay, benefits and other terms and conditions of employment. If a team member becomes unqualified during CFRA leave as a result of not attending a necessary course, or renewing a license, the team member will be given a reasonable opportunity to fulfill those conditions upon returning to work. Further, the Company may grant a team member's request to work a different shift, in a different or better position, or in a different location, that is better suited to the team member's personal needs upon returning from CFRA leave. The Company will also consider a reasonable accommodation under the FEHA if the team member is returning from CFRA leave for their own serious health condition. However, team members have no greater right to reinstatement than if they had been continuously employed rather than taken leave. For example, if a team member would have been laid off or the team member's position would have been eliminated even if they had not gone on leave, then the team member will not be entitled to reinstatement. However, if a team member has been replaced or the team member's position was restructured to accommodate the team member's absence, the team member is entitled to reinstatement. The Company will not limit or deny reinstatement from CFRA leave on the basis that an employee is considered a "key employee" under the FMLA.

Prior to being allowed to return to work, a team member wishing to return from leave for their own serious health condition must submit an acceptable release from a health care provider that certifies the team member is able to resume work. For a team member on intermittent or reduced schedule CFRA leave, such a release may be required up to once every 30 days if reasonable safety concerns exist regarding the team member's ability to perform their duties, based on the serious health condition for which the team member took the intermittent or reduced schedule leave.

**Confidentiality**

Documents relating to medical certifications, recertifications or medical histories of team members or team members' family members will be maintained separately and treated as confidential medical records, except that in some legally recognized circumstances, the records (or information in them) may be disclosed to supervisors and managers, first aid and safety personnel or government officials
Fraudulent Use of CFRA Leave Prohibited
A team member who fraudulently obtains CFRA Leave from the Company is not protected by the CFRA's job restoration or maintenance of health benefits provisions. In addition, the Company will take all available appropriate disciplinary action against a team member due to such fraud.

**Nondiscrimination**

The Company takes its CFRA leave obligations very seriously and will not interfere with, restrain or deny the exercise of any rights provided by the CFRA. We will not terminate or discriminate against any individual for exercising their right to family and medical leave under the CFRA or for giving information or testimony regarding their own or another person's leave in an inquiry or proceeding related to rights under the CFRA. If a team member believes that their CFRA rights have been violated in any way, they should immediately report the matter to Team Member Relations.

Team members should contact leaves@domain as to any CFRA questions they may have.

### New York Paid Family Leave (NYPFL)

**Paid Family Leave Overview**

New York Paid Family Leave provides job-protected, paid time off so you can:

- Bond with a newly born, adopted or fostered child,
- Care for a close relative with a serious health condition, or
- Assist with family situations when a family member is deployed abroad on active military service.

Paid Family Leave may also be available for use in situations when you or your minor dependent child are under an order of quarantine or isolation due to COVID-19. See PaidFamilyLeave.ny.gov/COVID19 for full details.

**Benefits**

Eligible employees may take up to 12 weeks of leave. This leave can be taken either all at once or intermittently, but must be taken in full-day increments. You may take the maximum time-off benefit in any given 52-week period.

- Paid Family Leave can be taken by employees who are eligible for time off under the provisions of FMLA. PFL will run concurrently with designated FMLA leave and GitLab's 16 weeks Parental Leave, when the reason for leave qualifies under PFL, FMLA, and GitLab's Parental Leave policy. Eligible employees must apply for both PFL and FMLA.
- Generally, you may not receive short-term disability and Paid Family Leave benefits at the same time. You may not take more than 26 combined weeks of short-term disability and Paid Family Leave in a 52-week period.
- If you are unable to work and qualify for workers' compensation benefits, you may not use Paid Family Leave benefits at the same time as you are receiving workers' compensation benefits. If you are working and receiving reduced earnings, you may be eligible for Paid Family Leave.

**Pay**

Paid Family Leave benefits provide 67% of your average weekly wage, capped at the same percentage of the New York State Average Weekly Wage. Visit PaidFamilyLeave.ny.gov for information on this year's maximum weekly benefit, as well as a calculator to estimate your own benefits.

- EXAMPLE: An employee who earns $1,000 a week would receive a benefit of $670 a week.

**Eligibility**

All eligible employees are entitled to participate in Paid Family Leave. Employees are eligible regardless of citizenship and/or immigration status.

- Full-time employees: Employees who work a regular schedule of 20 or more hours per week are eligible after 26 consecutive weeks of employment.
- Part-time employees: Employees who work a regular schedule of less than 20 hours per week are eligible after working 175 days, which do not need to be consecutive.

**Funding**

Paid Family Leave is funded through employee payroll contributions that are set each year to match the cost of coverage. The rate of employee contributions is reviewed annually, and is subject to change by the New York State Department of Financial Services. Visit PaidFamilyLeave.ny.gov for information on this year's employee contribution rate, as well as a calculator to estimate your own payroll contributions.

**Qualifying Events**

**New Child:** You can take Paid Family Leave during the first 12 months following the birth, adoption, or fostering of a child. Expectant mothers cannot take Paid Family Leave for their own pregnancy. Paid Family Leave for the birth of a child begins after the birth. It is not available for prenatal conditions.

**Serious Illness:** You can take Paid Family leave to care for a family member with a serious health condition. These relatives can live outside of New York State and even outside the country. You cannot take Paid Family Leave for your own health condition.
A serious health condition is an illness, injury, impairment, or physical or mental condition that involves:

- Inpatient care in a hospital, hospice, or residential health care facility, or
- Continuing treatment or continuing supervision by a health care provider

A family member includes:  Spouse, Domestic Partner, child and stepchild, Parent and stepparent, Parent-in-law, Grandparent, Grandchild, and effective 2023 Sibling (biological, adopted, half, and step).

**Military Active Service Deployment:** You can take Paid Family Leave to assist with family situations arising when your spouse, domestic partner, child, or parent is deployed abroad on active military service or has been notified of an impending military deployment abroad. You cannot use Paid Family Leave for your own qualifying military event.

**COVID-19 Quarantine:** Paid Family Leave may also be available for use in situations when you or your minor dependent child are under an order of quarantine or isolation due to COVID-19. See PaidFamilyLeave.ny.gov/COVID19 for full details.

**Your Rights and Protections**

- You have job protection, ensuring you can return to the same job (or a comparable one) when you return from Paid Family Leave.
- You can keep your health insurance while on leave. If you contribute to the cost of your health insurance, you must continue to pay your portion of the premium cost while on leave.
- Your employer is prohibited from discriminating or retaliating against you for requesting or taking Paid Family Leave.

**Taking Paid Family Leave**

1. Notify your employer. When you want to take Paid Family Leave, you must notify your employer at least 30 days before your leave will start if it's foreseeable. Otherwise, notify your employer as soon as possible.
1. Obtain required forms. Contact your employer, employer's insurance carrier, or visit PaidFamilyLeave.ny.gov to obtain the required forms.
1. Complete and attach: The Request For Paid Family Leave (Form PFL-1) has sections that need to be completed by you and by your employer. Fill out your section, make a copy and give the form to your employer to fill out Part B. Your employer is required to return Form PFL-1 to you within three business days. If there is a delay, you do not have to wait to proceed. Send the Form PFL-1 that you have filled out, along with the rest of your request package, directly to your employer's insurance carrier.
1. Obtain and attach supporting documentation. The specific documentation or additional forms required for each type of leave are described on the request for Paid Family Leave and at PaidFamilyLeave.ny.gov/Apply.
1. Submit your request forms and supporting documentation. You must submit your completed request package to your employer's insurance carrier within 30 days after the start of your leave to avoid losing benefits. In most cases, the insurance carrier must pay or deny benefits within 18 calendar days of receiving your completed request or your first day of leave, whichever is later.

**Paid Family Leave Process and Contacts**

At GitLab, requests for Paid Family Leave forms and forms submissions should be directed to the Absence Management Team (leaves@domain).  Our Paid Family Leave carrier is NYLife.

**Disputes**

If your Paid Family Leave claim is denied, the insurance carrier (NYLife) will provide you with information about how to request arbitration. A neutral arbitrator will decide claim-related disputes.

**Discrimination Complaints**

Employees are protected from discrimination and retaliation for requesting or taking Paid Family Leave. If your employer terminates your employment, reduces your pay and/or benefits, or disciplines you in any way as a result of you requesting or taking Paid Family Leave, send your employer's designated Paid Family Leave contact a formal request for job reinstatement using the Formal Request For Reinstatement Regarding Paid Family Leave (Form PFL-DC-119), which can be found in the forms section of PaidFamilyLeave.ny.gov. File the completed form with your employer and send a copy to:

> Paid Family Leave, P. O. Box 9030, Endicott, NY 13761-9030

If your employer fails to comply with the request for reinstatement within 30 days, you may file a Paid Family Leave discrimination complaint with the Workers' Compensation Board using Paid Family Leave Discrimination Complaint (Form PFL-DC-120), which is also available on the Paid Family Leave website. Once your complaint is received, the Board will assemble your case and schedule a preliminary hearing in front of a Workers' Compensation Law Judge.

## Other Leave Types By State

| Leave Type                              | State or City/Region |
|-----------------------------------------|-------|
| Bereavement Leave                       | IL, OR, WA (Tacoma)  |
| Blood/Bone Marrow/Organ Donation Leave  | AR, CA, CT, HI, IL, LA, ME, MD, MN, NE, NJ, NY, OR, SC, WI |
| Court Attendance/Witness Leave          | CA, CT, DC, FL, GA, HI, IL, IN, IA, KY, MD, MA, MN, MO, NV, ND, OH, OR, PA, RI, TX, UT, VT, VI, WI, WY |
| Crime Victims' Leave                    | AL, AK, AZ, AR, CA, CO, CT, DE, MD, MA, MI, MN, MS, MO, MT, NH, NY, OH, OR, PA, RI, SC, VT, VA, WY |
| Domestic/Sexual Violence Victims' Leave | AZ, AR, CA, CO, CT, DC, FL, HI, IL, IA, KS, ME, MD, MA, MI, MN, NV, NJ, NM, NY, NC, OR, PA, RI, TX, VT, VA, WA |
| Drinking and Driving Class Leave        | IA      |
| Drug/alcohol Rehabilitation Leave       | CA      |
| Election Officials' Leave               | AL, CA, DE, IL, KY, MN, NE, NC, OH, VA, WI  |
| Emancipation Day Leave                  | DC      |
| Emergency Evacuation Leave              | TX      |
| Legislative/Political Leave             | CT, IA, ME, MN, MT, NV, OK, OR, SD, TX, VT, WV      |
| Literacy Leave                          | CA      |
| Mobile Support Unit Leave               | IN      |
| Paid Family/Disability Leave            | CA, CO, CT, DC, DE, HI, MA, MD, NH, NJ, NY, OR, Puerto Rico, RI, VA, WA       |
| Pregnancy Disability Leave              | CA, CT, HI, IA, LA, MN, MT, NH, OR, WA      |
| Public Health Emergency (Quarantine/Isolation) Leave | AZ, CA (San Diego), CO, DE, IL (Cook Co), MA, MD (Montgomery Co), MI, MN, NJ, NY (Westchester Co & NYC), OR, PA (Pittsburgh), RI, SC, VT, WA  |
| School Activities/Visitation Leave      | CA, CO, DC, IL, LA, MA, MN, NV, NJ, NC, OR, RI, TN, VT   |
| State Family Medical Leave              | AK, CA, CT, DC, FL, GA, HI, IL, IN, IA, KS, KY, LA, ME, MD, MA, MN, MO, MT, NE, NV, NH, NJ, NM, NY, NC, OH, OR, PA, Puerto Rico, RI, TN, VT, VA, WA, WI  |
| Student Leave                           | DC      |
| Volunteer Emergency Responder Leave     | AL, CA, CO, CT, DE, IL, IN, IA, KS, KY, LA, ME, MD, MA, MO, NE, NV, NH, NJ, NM, NY, NC, ND, OH, OR, PA, RI, SC, TN, UT, WA, WV, WI |
| Voting Leave                            | AL, AK, AZ, AR, CA, CO, DC, GA, IL, IA, KS, KY, MD, MA, MN, MO, NE, NV, NM, NY, ND, OH, OK, SD, TN, TX, UT, VT, WV, WI, WY   |

## U.S Military Leave

GitLab, Inc. recognizes the obligation of those team members serving in any branch of the military or other uniformed services of the United States. Employment status within GitLab is protected by the Uniformed Services Employment and Reemployment Rights Act of 1994 ("USERRA").

**Leave and Re-Employment**

Team members who serve on active or reserve duty will be granted a leave of absence up to the maximum time required by law. GitLab is committed to preserving the job rights of team members absent on military leave in accordance with law.

**Compensation**

Military leave runs concurrently with GitLab PTO. Team members on unpaid military leave will be paid at 100% of their salary for the first 25 days of leave. Exempt team members will not incur any reduction in pay for partial week absences for leave under this policy.

**Health Care Continuation**

During a military leave of less than 31 days, a team member is entitled to continued group health plan coverage under the same conditions as if the employee had continued to work. For military leaves of more than 30 days, an employee may elect to continue their health coverage in accordance with USERRA and COBRA. For additional information on health care continuation contact the Absence Management team `leaves@domain`.

**Notification of Supervisor/Manager**

Team members needing **3 or more consecutive business days** away from work due to Military Service are expected to provide GitLab with as much advance notice as possible. In some instances providing advance notice may not be possible, so we ask team members to notify us as soon as they are able.

Team Members should report their Military Service in Workday by selecting the `Military Leave` option under the `Leaves` dropdown.

- Note: For absences resulting in more than 3 consecutive business days away from work, team members will need to provide a copy of your orders as soon as you receive them. Please email your orders to leaves@domain.

**No Retaliation**

Team members who request military leave will not be retaliated against or penalized in any manner. Any team member who believes they have been retaliated against in violation of this policy should notify the Absence Management team (leaves@domain) immediately.
