---
title: Product Handbook
description: "Most of the content in the product handbook talks about _how_ we do product at GitLab."
---

## Welcome to the Product Team Handbook

- The Product Team  is led by [David DeSanto](/handbook/company/team/#david).
- The Product Handbook focuses on *how* we do product at GitLab.
- Please see [Product Direction](https://about.gitlab.com/direction/) to learn about *what* the Product Team plans to build.

## Product Team Functions

- [Product Management](/handbook/product/product-management/)
- [User Experience](/handbook/product/ux/)
- [Product Technical Program Management](/handbook/product/groups/product-technical-program-management)

## Product Team Mission

**We create products and experiences that customers love and value.**

- **Consistency wins as you scale**. Our organizational goal is to create a Product Manager (PM) system that maximizes the chances of success across new products, new features, and new team members.
- **We are shipping an experience**, and not just a product. Don't forget about the links between the product and the website, pricing & packaging, documentation, sales, support, etc.
- **It's about our customers and doing a job for them**, not the product itself. Think externally about customer problems, not internally about the technology.
- **It's about love AND value**. Will customers value what we are building? We need to make sure what we build helps build and extract customer value.

## Contributing to the Product Handbook

The product handbook is widely referenced by product managers and cross-functional team members. Therefore, we want to follow a consistent change management process so all affected collaborators are aligned and informed when there are changes (specially new requirements, processes, meetings, etc.) that affect their workflow.

It is helpful to indicate which type of change you are suggesting:

- Small improvement (typos, clarifications, etc.)
- Adding a new section
- Modifying existing section
- Documenting a new process
- Adding a new page or directory
- Other

For a small improvement, please feel free to merge the MR yourself. Otherwise, please tag the appropriate code owner for review and approval. The guidance below should be followed for driving awareness:

### Informing team members about the changes

It is your responsibility to communicate with relevant team members about your merge request. Here are some best practices to follow:

- For significant changes affecting the whole Product or Engineering team, consult your manager or product leader for the best communication strategy.
- For changes specific to product management, tag `@gl-product-pm` in the merge request before merging.
- Indicate in the comment whether you are requesting contributions and feedback or simply providing information.
- For changes relevant to other teams, tag department leads such as the VP of UX, VP of Development, or the Director of Quality Engineering in the merge request before merging.
- Share and cross-post the merge request link with a brief description in relevant channels such as Slack `#product`, `#product-leadership`, `#eng-managers`, and `#ux-managers`.
- For more guidance on communication, refer to the [GitLab Communication tips and best practices](/handbook/communication/#top-tips-and-best-practices).

## Product Management

If you'd like to collaborate with product management see [How to Engage](/handbook/product/product-management/#how-to-engage-product-managers) guide.

### **Product Principles**

The [Product Principles](/handbook/product/product-principles/) section is where you can learn about our strategy and philosophy regarding product development here at GitLab.

### **Product Processes**

For a detailed view on how we do Product Development, read up on our established [Product Processes](/handbook/product/product-processes/).

### **Product sections, stages, groups, and categories**

To learn how the GitLab product and our Teams are organized review our [Product Categorization section](/handbook/product/categories/).

### **About the GitLab Product**

Learn about [GitLab as a product](/handbook/product/categories/gitlab-the-product), including what does it mean to be a single application, our subscription tiers and pricing model, and the basics of permissions in the platform.

### **Product Manager Responsibilities**

Understand the [roles and responsibilities of product managers](/job-families/product/product-manager).

### **Being a Product Manager at GitLab**

Want to know more on what being a Product Manager at GitLab is like? Checkout our [Product Management](/handbook/product/product-management/) guide for helpful information like our Career Development Framework and learning/development resources.

### **Product Performance Indicators**

Learn how we measure success in Product via our [Product KPIs](https://internal.gitlab.com/handbook/company/performance-indicators/product/), which are tracked in our [Product project](https://gitlab.com/gitlab-com/Product). For best practices and guidance on how to add instrumentation for features please review our [Analytics Instrumentation workflow](https://internal.gitlab.com/handbook/company/performance-indicators/product/#analytics-instrumentation-workflow).

### **Product OKRs**

Understand the OKR Process for the GitLab Product Team and review [current and past OKRs](/handbook/product/product-processes/product-okrs/).

### **Our Product Leadership Team**

Learn about [our Product Leadership Team](/handbook/product/product-leaders/product-leadership/) and learn about them via their personal README's.

### Communicating with the Product Division

Below are team emails and handles that can be used for different departments and sub-departments in the Product Division. These groups are used for internal communication and the `@mention` can only be used by project members. Please remember that tagging `@mention` on issues will generate in-product [to-do items](https://docs.gitlab.com/ee/user/todos.html) and email notifications to **all** team members in that project, so use it only when you need to communicate with the entire team. For communication specifically for product managers, please leverage [How to Engage](/handbook/product/product-management/how-to-engage/).

- `@gl-product-leadership` tags all group managers, directors and VPs in the Product Division
- `@gl-product-plt` tags all direct reports to the VP Product in the Product Division
- `@gl-product-pm` tags to all members of Product Management, Product Monetization and Program Managers in the Product Division
- `@gl-product` tags to all members in the Product Division: Product Management, Product Monetization, Program Management, Product Design, User Research, and Technical Writing
- `product@gitlab.com` emails all members of Product Management, Product Monetization and Program Management in the Product Division
- `ux-department@gitlab.com` emails all members of UX (UX Research, Technical Writing and Product Design) in the Product Division
- `@gitlab-com/gitlab-ux` tags all members of UX (UX Research, Technical Writing and Product Design) in the Product Division
- `@gitlab-com/gitlab-ux/managers` tags all people managers within UX (UX Research, Technical Writing, and Product Design)
- `@gitlab-com/gitlab-ux/designers` tags all Product Designers and Design Managers in UX
- `@gl-docsteam` for all Technical Writers in UX
- '#technical-program-management' a place to reach the entire TPgM team across organizations

When you are tagging `@mention`:

- Clearly state why you are tagging the entire product team and what action you need product team members to take.
- Write a short summary in the same comment so team members can quickly understand the necessary context.
- Review the issue title and description to ensure it has relevant details other product team members need **BEFORE** submitting the comment. The issue title will be the subject of email notifications and in-product to-do items.
- If asking team members to review a change, please directly link to the specific page on the [review app](https://docs.gitlab.com/ee/ci/review_apps/#how-review-apps-work) and any relevant issues or MRs.
