---
title: Crash Course for Product Stage Resources
---

## Objectives for this page

This page is intended to provide a crash course style overview of the most important Product Analytics related resources for each product Stage.
As a Product Analyst or other curious GitLab team member, it can be helpful to have a quick and easy reference for each product Stage to quickly understand high-level functionality, key objectives or a distilled product roadmap, and key data resources currently used under a specific Stage or Group within GitLab before jumping in to an analysis.

If this page serves it's purpose, Product Analysts should be able to visit this handbook page before working with a Stage or Group to obtain helpful contextual information without needing to do a scavenger hunt search across dozens of handbook pages to find relevant information.

## Helpful places to start

- [Internal handbook performance indicators (PIs)](https://internal.gitlab.com/handbook/company/performance-indicators/) - This internal handbook page is a great place to understand the PIs for each Stage / Group to understand what results each team is trying to acheive.

- [Product categories handbook page](/handbook/product/categories/) contains a huge amount of helpful information and defines sections, stages, groups, and categories.

- Need to quickly learn how a certain Stage/Group feature works? [GitLab Docs](https://docs.gitlab.com/)

- [Metrics dictionary](https://metrics.gitlab.com/) contains metrics and events collected in Service Ping and Snowplow. For more information visit the dedicated [Analytics Instrumentation Guide](/handbook/product/product-processes/analytics-instrumentation-guide/#metrics-dictionary).

- [Features by Group handbook page](/handbook/product/categories/features/#planproject-management-group) contains a tabular breakdown of features included in each Stage Group by Core, Premium or Ultimate categories.

- [Definitive guides to data subject areas](/handbook/enterprise-data/data-catalog/#definitive-guides) managed by the Data team.

- [Centralized Metrics](https://10az.online.tableau.com/#/site/gitlab/workbooks/2069845/views): Key reporting dashboard for GitLab product usage metrics.

- The [Technical Marketing handbook page](/handbook/marketing/developer-relations/technical-marketing/) contains links to product demos, webinars and release videos.

- GitLab's Fiscal Year runs from February 1 to January 31. [Here](/handbook/finance/#fiscal-year) is a link to GitLab's Fiscal Quarter to Month map.

## Learn about analytics relevant product stage topics grouped by Section

Why are these groupings called 'Stages'? At GitLab, we build a product that supports every **stage** of the DevOps Lifecycle.

### Dev Section

#### Manage Stage

This Stage helps teams manage their software delivery lifecycle with metrics and value stream insight in order to streamline and increase their delivery velocity. Insights, authentication, audits, compliance, user management, group & sub-group management, and project management.

<details markdown="1"><summary>Click to expand</summary>

**Top dashboards referenced by this team**

- [Centralized Metrics](https://10az.online.tableau.com/#/site/gitlab/workbooks/2069845/views): Key reporting dashboard for GitLab product usage metrics.

**Helpful video resources**

[Plan:Optimize YouTube Channel](https://www.youtube.com/playlist?list=PL05JrBw4t0KopcuINFaWBEHYlaDnbDxpl)

Team meetings, AMAs, etc. for the Plan:Optimize Group

[Manage:Access YouTube Channel](https://www.youtube.com/playlist?list=PL05JrBw4t0Kot4GcDlWPsZOM8YgncnPUi)

Team meetings, AMAs, etc. for the Manage:Access Group

[Manage:Organization YouTube Channel](https://www.youtube.com/playlist?list=PL05JrBw4t0Kq-9cR2cz4uxUIfVYtB4Gq8)

Team meetings, AMAs, etc. for the Manage:Organization Group

**Product direction**

[Problems to Solve from Product Direction Page](https://about.gitlab.com/direction/manage/#problems-to-solve)

The Problems to Solve section of Manage's Product Direction Page is the most condensed documentation to understand Manage's big picture focus quickly.

**Performance indicators**

[Metrics from Product Direction Page](https://about.gitlab.com/direction/manage/#metrics)

This link breaks down the performance indicators for each Manage Group clearly and links out to the Internal Handbook PI page.

**Key handbook pages**

[Manage Direction Page](https://about.gitlab.com/direction/manage/)

[Main Manage Stage Page](/handbook/engineering/development/dev/manage/)

**Slack channels**

**#s_manage**

**Team members**

[Handbook page to find Manage team members to collaborate with](/handbook/product/categories/#manage-stage)

</details>

#### Plan Stage

Enable teams to effectively plan and execute work in a single application. This stage enables portfolio planning and management through epics, groups (programs), milestones, etc. to organize and track progress

<details markdown="1"><summary>Click to expand</summary>

**Top dashboards referenced by this team**

- [Centralized Metrics](https://10az.online.tableau.com/#/site/gitlab/workbooks/2069845/views): Key reporting dashboard for GitLab product usage metrics.

- [Plan stage .com events](https://10az.online.tableau.com/#/site/gitlab/workbooks/2325883/views)  Analyses dealing with Snowplow events tables

- [Fulfillment:Platform PIs Dashboard](https://10az.online.tableau.com/#/site/gitlab/workbooks/2131145/views)

- [Growth Section Analytics Hub](https://10az.online.tableau.com/#/site/gitlab/workbooks/2058563/views)

- [Code Suggestions](https://10az.online.tableau.com/#/site/gitlab/workbooks/2260169/views)

- [Verify Performance Indicator Hub](https://10az.online.tableau.com/#/site/gitlab/views/VerifyPerformanceIndicatorDashboard/VerifyPerformanceIndicatorHub)

**Helpful video resources**

[Plan Stage YouTube playlist](https://www.youtube.com/playlist?list=PL05JrBw4t0KoceqcTneOVmAzhEp6NinY0)

**What the Plan Stage team is working on**

[Link to 1 Year Plan](https://about.gitlab.com/direction/plan/#1-year-plan)

A great handbook page to skim to understand the roadmap and focus for Plan

**Performance indicators**

[Link to performance indicators](https://internal.gitlab.com/handbook/company/performance-indicators/product/dev-section/)

Resource to understand the Performance Indicators for the Dev Section - Page can be searched by Stage and Group

**Key handbook pages**

[Main Plan page](/handbook/product/categories/#plan-stage)

[Plan direction page](https://about.gitlab.com/direction/plan/)

**Slack channels**

**#s_plan**

**Team members**

[Handbook page to find Plan team members to collaborate with](/handbook/product/categories/#plan-stage)

</details>

#### Create Stage

Create provides tools that support the beginning of the DevOps Life Cycle. Source Code management, Code Review, Wiki, Web IDE, etc.

[Start on the GitLab website page](https://about.gitlab.com/features/) dedicated to Create to get an understanding of features included in this Stage.

<details markdown="1"><summary>Click to expand</summary>

**Top dashboards referenced by this team**

- [Centralized Metrics](https://10az.online.tableau.com/#/site/gitlab/workbooks/2069845/views): Key reporting dashboard for GitLab product usage metrics.

- [Performance indicators internal handbook page](https://internal.gitlab.com/handbook/company/performance-indicators/product/dev-section/)  The Create : Gitaly Group primarily uses the Performance Indicators Internal Handbook Page to guide decisions

- [Handbook page containing engineering analytics dashboards](/handbook/engineering/development/dev/create/engineering-managers/dashboards/)  Used by Create Stage Engineering Managers

**Helpful video resources**

Must be logged into GitLab Unfiltered account

[Create Stage YouTube playlist](https://www.youtube.com/playlist?list=PL05JrBw4t0KrJEKqwt57ljmbkOuVwaR0d)

[Create Stage UX YouTube playlist](https://www.youtube.com/playlist?list=PL05JrBw4t0KrUvA91eFQedd6zrvH0_kGY)

**Product roadmap link**

[Link to product direction / vision](/handbook/engineering/development/dev/create/#vision)

Resource to understand the goals for this team

**Performance indicators**

[Link to performance indicators](https://internal.gitlab.com/handbook/company/performance-indicators/product/dev-section/)

Resource to understand the Performance Indicators for the Dev Section - Page can be searched by Stage and Group

**Key handbook pages**

[Primary Create Stage handbook page](/handbook/engineering/development/dev/create/)

Contains helpful information about how Create operates and current team members

**Slack channels**

**#s_create**

**#s_create_pm**

**Team members**

[Handbook page to find Create team members to collaborate with](/handbook/product/categories/#create-stage)

</details>

### CI Section

#### Verify Stage

Verify provides teams with tools that help facilitate continuous integration. This includes but is not limited to pipelines and runners.

<details markdown="1"><summary>Click to expand</summary>

**Top dashboards referenced by this team**

- [Centralized Metrics](https://10az.online.tableau.com/#/site/gitlab/workbooks/2069845/views): Key reporting dashboard for GitLab product usage metrics.

- [Verify Performance Indicator Dashboard](https://10az.online.tableau.com/#/site/gitlab/views/VerifyPerformanceIndicatorDashboard/VerifyGitLab_comPerformanceIndicators)

- [Error Budget Dashboard](https://10az.online.tableau.com/#/site/gitlab/workbooks/2270342/views)

**Important data documentation**

There are a few models that are exclusive to the Verify stage that you can reference as a SSOT:

- `wk_gitlab_dotcom_monthly_ci_compute_minutes` is a model you can use to identify the number of runners, pipelines, and CI Build Minutes used on a per project, per namespace level.
**Helpful video resources**

[Tanuki Tech: Verify and Secure](https://youtu.be/TgRamhC3ujg)

This video showcases the product functionality of Verify and Secure and how to talk about those functionalities from a sales perspective.

[Verify Team Overview](https://youtu.be/9iF9zWAxdH0)

**Product roadmap link**

[Section Direction: Verify Stage](https://about.gitlab.com/direction/ops/#verify)
Resource to understand the long-term goals for the Verify team

**Performance indicators**

[Ops Section PI](https://internal.gitlab.com/handbook/company/performance-indicators/product/ops-section/)
An internal handbook page that lists all performance indicators under the Operations section

**Key handbook pages**

[Verify Stage Product Page](/handbook/engineering/development/ops/verify/)

A central hub for all pages related to the Verify stage

**Slack channels**

**#s_verify**
Overall channel for Verify

**#g_pipeline-execution**
Slack channel for the Verify:Pipeline Execution product category.

**#g_pipeline-authoring**
Slack channel for the Verify:Pipeline Authoring product category.

**#g_runner**
Slack channel for the Verify:Runner product category.

**#g_pipeline-security**
Slack channel for the Verify:Pipeline Security product category.

**Team members**

[Handbook page to find Verify team members to collaborate with](/handbook/product/categories/#verify-stage)

</details>

#### Package Stage

The Package team works on the package and container registries, as well as the Dependency Proxy.

<details markdown="1"><summary>Click to expand</summary>

**Top dashboards referenced by this team**

- [Package Performance Indicator Hub](https://10az.online.tableau.com/#/site/gitlab/workbooks/2284774/views)

Primarily time series analyses for Package features on GitLab.com

- [Centralized Metrics](https://10az.online.tableau.com/#/site/gitlab/workbooks/2069845/views): Key reporting dashboard for GitLab product usage metrics.

**Important data documentation**

- `wk_gitlab_dotcom_package_events` is a model you can use for all Snowplow events related to Package. This includes but is not limited to, package actions for all available Package types on GitLab.com

**Helpful video resources**

[User Interviews YouTube Channel](https://www.youtube.com/playlist?list=PL05JrBw4t0KpxCv3B5S-6LFCpBB6NCnga)

General and feature specific user interviews for the Package team

[Demos and Speedruns](/handbook/engineering/development/ops/package/#demos--speedruns)

Package Handbook section with feature and roadmap demos

**Product roadmap link**

[Link to product roadmap](/handbook/engineering/development/ops/package/#roadmap)

Resource to understand the long-term goals for this team

**OKRs**

[Link to OKRs handbook page](/handbook/engineering/development/ops/package/#okrs)

Resource to understand the current OKRs for this team

**Key documentation**

[Main Package Team Handbook Page](/handbook/engineering/development/ops/package)

It can be helpful to search for specific topics on the Package team's main page

[GitLab Docs Package Page](https://docs.gitlab.com/ee/administration/packages/)

GitLab Docs are awesome!

**Slack channels**

**#s_package**

**Team members**

[Handbook page to find Package team members to collaborate with](/handbook/product/categories/#package-stage)

[List of Package team members and their stable counterparts to contact if needed](/handbook/engineering/development/ops/package/#team-members)

</details>

### CD Section

#### Deploy Stage

The Deploy team covers the deployment and release functionality of GitLab

<details markdown="1"><summary>Click to expand</summary>

**Top dashboards referenced by this team**

- [Centralized Metrics](https://10az.online.tableau.com/#/site/gitlab/workbooks/2069845/views): Key reporting dashboard for GitLab product usage metrics.

- [Deploy Performance Indicator Dashboard](https://10az.online.tableau.com/#/site/gitlab/workbooks/2280622/views): Primarily time series analyses for Deploy features on GitLab.com

**Product roadmap link**

[Product Direction - Delivery](https://about.gitlab.com/direction/delivery/)
Resource to understand the long-term goals for this team

**Performance indicators**

[Link to performance indicators](https://internal.gitlab.com/handbook/company/performance-indicators/product/ops-section/)

Resource to understand the Performance Indicators for the Ops Section - Page can be searched by Stage and Group

**Key handbook pages**

[Deploy Primary Handbook Page](/handbook/engineering/development/ops/deploy/)

**Slack channels**

**#cd-section**

**#g_environments**

**#s_deploy**

**Team members**

[Handbook page to find Create team members to collaborate with](/handbook/engineering/development/ops/deploy/environments/)

</details>

### Sec Section

#### Secure Stage

Static Application Security Testing (SAST), Dynamic Application Security Testing (DAST), Container Scanning, and Dependency Scanning

<details markdown="1"><summary>Click to expand</summary>

**Top dashboards referenced by this team**

- [Dynamic Analysis Metrics](https://10az.online.tableau.com/#/site/gitlab/views/PDSecDynamicAnalysisMetrics/DynamicAnalysisDashboard) Secure:Dynamic Analysis Group

Some seemingly duplicate charts in Dynamic Analysis Metrics are used by the team to compare totals from different data sets.

- [Threat Management Metrics](https://10az.online.tableau.com/#/site/gitlab/workbooks/2238072/views) Govern:Threat Insights Group

- [Centralized Metrics](https://10az.online.tableau.com/#/site/gitlab/workbooks/2069845/views): Key reporting dashboard for GitLab product usage metrics.

**Helpful video resources**

[DevSecOps Overview](https://www.youtube.com/watch?v=XnYstHObqlA&t=15s) A great place to start for a high-level overview relating to Secure functionality.

**Product direction link**

[Secure product direction page - 1 year plan](https://about.gitlab.com/direction/secure/#1-year-plan)

**Performance indicators**

[Performance indicators linked in Secure handbook page](/handbook/engineering/development/sec/#performance-indicators)

**Key handbook pages**

[Secure stage primary handbook page](/handbook/engineering/development/sec/secure/)

**Slack channels**

**#s_secure**

**Team members**

[Product categories page section to find Secure team members to collaborate with](/handbook/product/categories/#sec-section)

[Secure Handbook page section to find Secure engineering team members to collaborate with](/handbook/engineering/development/sec/secure/#team-members)

</details>

#### Software Supply Chain Security Stage

Manage security vulnerabilities, policies, and compliance across your organization.

<details markdown="1"><summary>Click to expand</summary>

**Top dashboards referenced by this team**

- [Centralized Metrics](https://10az.online.tableau.com/#/site/gitlab/workbooks/2069845/views): Key reporting dashboard for GitLab product usage metrics.

- [PD: Sec: Software Supply Chain Security Metrics](https://10az.online.tableau.com/#/site/gitlab/workbooks/2200383/views)

**Helpful video resources**

[Software Supply Chain Security Stage YouTube Channel](https://www.youtube.com/playlist?list=PL05JrBw4t0Kq4CHpCTMv3OdquJXm6ggYr)

[Software Supply Chain Security UX YouTube Channel](https://www.youtube.com/playlist?list=PL05JrBw4t0KrUL59mDTOdERpYEXGyMPVz)

**Product direction link**

[Software Supply Chain Security product direction page - 1 Year Plan](https://about.gitlab.com/direction/software_supply_chain_security/#1-year-plan)

**Performance indicators**

[Internal handbook performance indicators for the Secure section](https://internal.gitlab.com/handbook/company/performance-indicators/product/sec-section/)

**Key handbook pages**

[Software Supply Chain Security stage primary handbook page](/handbook/engineering/development/sec/software-supply-chain-security/)

**Slack channels**

**#s_software-supply-chain-security**

**Team members**

[Handbook page to find Software Supply Chain Security team members to collaborate with](/handbook/product/categories/#software-supply-chain-security-stage)

[Software Supply Chain Security Handbook page section to find Software Supply Chain Security engineering team members to collaborate with](/handbook/engineering/development/sec/software-supply-chain-security/#sub-department-development-people-leaders)

</details>

### Core Platforms Section

#### Systems Stage (Distribution, Gitaly, Geo Groups)

Supports enterprise-grade operational experience of GitLab products from streamlined deployment and maintenance, disaster recovery, secure search and discoverability, to high availability, scalability, and performance. The Systems Stage includes Distribution, Gitaly and Geo Groups.

<details markdown="1"><summary>Click to expand</summary>

**Top dashboards referenced by this team**

- All Tableau Dashboards are organized in Collections, specifically [Core & SaaS Platforms General Collection](https://10az.online.tableau.com/#/site/gitlab/collections/78d30546-2f24-4a4a-8378-c88711f479c4?:origin=card_share_link) and [Core & SaaS Platforms SAFE Collection](https://10az.online.tableau.com/#/site/gitlab/collections/1c106c47-64b3-4cbf-b95d-c75fe2a0e9b4?:origin=card_share_link)

**Important data documentation**

There are no Enablement metrics currently collected in our Postgres Replica data for GitLab.com

The following tables can be used for Service Ping metric reporting.

- common_mart.mart_ping_instance_metric_all_time - Use for all time timeframe metrics

- common_mart.mart_ping_instance_metric_7_day - Use for 7 day timeframe metrics

- common_mart.mart_ping_instance_metric_28_day - Use for 28 day timeframe metrics

- common_mart.mart_ping_instance_metric_monthly - Use for all, 7, 28 timeframe metrics pre filtered to the last ping of the month (does not include none or null timeframe metrics)

- workpace_product.wk_fct_ping_instance_metric_none - Use for metrics with a none timeframe

- workpace_product.wk_fct_ping_instance_metric_null - Use for metrics with a null timeframe

Use the [metrics dictionary](https://metrics.gitlab.com/) to determine the timeframe value for any service ping metric.

**Helpful video resources**

Enablement::Systems is a relatively new Stage. PDI will add helpful video overviews as they become available.

**Product roadmap link**

[Enablement Product Direction](https://about.gitlab.com/direction/enablement/)
Includes Stage and Group level details

**Performance indicators**

[Enablement Section PI handbook page](https://internal.gitlab.com/handbook/company/performance-indicators/product/enablement-section/)

**Key handbook pages**

[Overall Enablement Section Handbook page for Engineering](/handbook/engineering/development/enablement/)

**Slack channels**

**#s_enablement**

**#g_distribution**

**#g_geo**

**Team members**

[Handbook page to find Systems team members to collaborate with](/handbook/product/categories/#systems-stage)

OR

[All team members section of engineering page](/handbook/engineering/development/enablement/#all-team-members)

</details>

#### Data Stores Stage (Memory, Global Search, Database, Pods Groups)

Supports enterprise-grade operational experience of GitLab products from streamlined deployment and maintenance, disaster recovery, secure search and discoverability, to high availability, scalability, and performance. The Data Stores Stage includes Memory, Global Search, Database and Pods Groups.

<details markdown="1"><summary>Click to expand</summary>

**Top dashboards referenced by this team**

- All Tableau Dashboards are organized in Collections, specifically [Core & SaaS Platforms General Collection](https://10az.online.tableau.com/#/site/gitlab/collections/78d30546-2f24-4a4a-8378-c88711f479c4?:origin=card_share_link) and [Core & SaaS Platforms SAFE Collection](https://10az.online.tableau.com/#/site/gitlab/collections/1c106c47-64b3-4cbf-b95d-c75fe2a0e9b4?:origin=card_share_link)

**Important data documentation**

There are no Enablement metrics currently collected in our Postgres Replica data for GitLab.com

The following tables can be used for Service Ping metric reporting.

- common_mart.mart_ping_instance_metric_all_time - Use for all time timeframe metrics

- common_mart.mart_ping_instance_metric_7_day - Use for 7 day timeframe metrics

- common_mart.mart_ping_instance_metric_28_day - Use for 28 day timeframe metrics

- common_mart.mart_ping_instance_metric_monthly - Use for all time and 28 day timeframe metrics, pre filtered to the last ping of the month (does not include 7 day, none, or null timeframe metrics)

- workpace_product.wk_fct_ping_instance_metric_none - Use for metrics with a none timeframe

- workpace_product.wk_fct_ping_instance_metric_null - Use for metrics with a null timeframe

Use the [metrics dictionary](https://metrics.gitlab.com/) to determine the timeframe value for any service ping metric.

**Helpful video resources**

Enablement::Data Stores is a relatively new Stage. PDI will add helpful video overviews as they become available.

**Product roadmap link**

[Enablement Product Direction](https://about.gitlab.com/direction/enablement/)
Includes Stage and Group level details

**Performance indicators**

[Enablement Section PI handbook page](https://internal.gitlab.com/handbook/company/performance-indicators/product/enablement-section/)

**Key handbook pages**

[Overall Enablement Section Handbook page for Engineering](/handbook/engineering/development/enablement/)

**Slack channels**

**#s_enablement**

**#g_memory**

**#g_global_search**

**#g_database**

**Team members**

[Handbook page to find Data Stores team members to collaborate with](/handbook/product/categories/#data-stores-stage)

OR

[All team members section of engineering page](/handbook/engineering/development/enablement/#all-team-members)

</details>

### Growth Section

Although the [Growth Section](/handbook/marketing/growth/) falls within the Maketing & Strategy division, the Growth Section has dedicated support from Product Data Insights on topics within our ownership areas.

#### Growth Stage (Acquisition, Activation Groups)

Growth owns the free and trial registration and new user onboarding experiences.

<details markdown="1"><summary>Click to expand</summary>

**Top dashboards referenced by this team**

- - All Tableau Dashboards are organized in Collections, specifically [Growth General Collection](https://10az.online.tableau.com/#/site/gitlab/collections/9fce437d-d001-412a-a4c4-a327aeb882ff?:origin=card_share_link) and [Growth SAFE Collection](https://10az.online.tableau.com/#/site/gitlab/collections/8740c9bc-6d9d-4e3e-af5a-11b48f48e925?:origin=card_share_link)

- [Growth Section Product Data Insights Hub in Tableau](https://10az.online.tableau.com/t/gitlab/views/GrowthSectionProductDataInsightsHub/GrowthSectionProductDataInsightsHub)

- [Filterable Growth Experiment Analysis Dashboard](https://10az.online.tableau.com/#/site/gitlab/views/USETHISFINALGLEX/GLEXExperimentAnalysisDashboard?:iid=1)

- [Growth Experiment Event Validation](https://10az.online.tableau.com/#/site/gitlab/workbooks/2241316/views)

- [Snowplow Event Exploration L30D](https://10az.online.tableau.com/#/site/gitlab/views/SnowplowEventExplorationLast30Days/SnowplowEventExplorationLast30D) - commonly sent to engineers for event validation.

**Important data documentation**

- [workspace_product.wk_rpt_namespace_onboarding](https://dbt.gitlabdata.com/#!/model/model.gitlab_snowflake.wk_rpt_namespace_onboarding) This model contains all of the most commonly analyzed Growth use cases including namespace and namespace creator attributes and SaaS product behavior. This model can be contributed to by PDI, DEX and Marketing Analytics teams.

- Because Growth topics are broad and cross-functional, there are many data models that are commonly used to answer Growth product analytics questions. More comprehensive documentation can be found in [Product Data Insights Data Models Cheat Sheet](/handbook/product/groups/product-analysis/data-model-cheat-sheet/).

**Helpful video resources**

[Growth YouTube playlist](https://www.youtube.com/playlist?list=PL05JrBw4t0Kr_-AowJmbhGk9yj_zIZySf)

**Product roadmap link**

[Growth Direction handbook page](/handbook/marketing/growth/)

**Performance indicators**

- [SaaS Team Activation](https://docs.google.com/presentation/d/1rJG8FaqEjfgA-Nz9Ww3blgcUwRGzri7CeKkn1e2eEHY/edit?usp=sharing)

- [Valuable Signup](https://docs.google.com/presentation/d/1xHBrnvwdMxQGqmX0TtcQz5tUYsAeU6CAMnpcDlhHUpc/edit?usp=sharing)

- Both of the above metrics are monitored in [Growth Section Product Data Insights Hub in Tableau](https://10az.online.tableau.com/t/gitlab/views/GrowthSectionProductDataInsightsHub/GrowthSectionProductDataInsightsHub)

**Key handbook pages**

[Overall Growth Section Handbook page for Engineering](/handbook/engineering/development/growth/)

[Growth Direction Page](/handbook/marketing/growth/)

**Slack channels**

**#s_growth**

**Team members**

[All team members section of engineering page](/handbook/engineering/development/growth/#all-team-members)

</details>
