---
title: Product Internship - Best Practices
---

This document describes best practices for [internship for learning](/handbook/people-group/learning-and-development/internship-for-learning/) with Product.

## Interning for Learning - Product Best Practices

Internships are a great way for a GitLab team member to learn about being a Product Manager at GitLab. Use this guide for planning and executing an internship under an IC PM who acts as the 'Intern Mentor'.

## How to find a mentor in the Product Management team

The first step you will need to take in order to start an internship in Product Management is to find a mentor from the [Product Management team](/handbook/company/team/?department=product-management).

You can reach out on slack to the [#product](https://gitlab.slack.com/archives/C0NFPSFA8) channel and express your interest in an internship and that you are looking for a mentor.

Another option is using the table below that will help match mentors and interns. If you are interested in participating in an internship, either as a mentor or intern, please fill out your details in the table below. If you see an empty slot for a mentor/intern, feel free to reach out to that person to see if they are available to be your internship match.

| Mentor | Intern | Group | Mentor Timezone | Intern Timezone |
| ------ | ------ | ----- | --------------- | --------------- |
|        |        |       |                 |                 |

## Coffee Chat with PM internship Alumni

  Feel free to schedule a coffee chat with any of the [PM internship Alumni](/handbook/product/internship/#alumni). You can review the list of PM internship below. These chats can be helpful when deciding whether to apply to participate or if you're unable to participate but want to hear about the experience and what alumni have learned during their internship.

## Planning the internship

The [Product Development Flow](/handbook/product-development-flow/) at GitLab offers a systematic way to scope Product Internships for learning. While not mandatory, it is helpful to select one of the tracks to focus on for the internship. Available tracks:

- [Validation Track](/handbook/product-development-flow/#validation-track) - PM Intern will learn how to develop business cases for new ideas based on potential customer problems. This may also include the solution validation workflow where the PM Intern will collaborate with UX to create designs for solutions to validated problems.
- [Build Track](/handbook/product-development-flow/#build-track) - PM Intern will learn how to break down issues and collaborate with engineering to turn UX designs into working software.

Selection of which track to pursue for the internship should be based on the goals of the PM intern.

## Pre-internship tasks

1. Get manager approval from the intern's existing manager, identify an IC PM to be the 'Intern Mentor', identify the IC's manager as the 'Intern Manager' and define a start date. Set an expectation with the intern's current manager that the intern will give > 40% of their time to the internship.
1. Create an issue in the [Training project](https://gitlab.com/gitlab-com/people-group/Training) using the **Internship for learning** template. Check out this [issue](https://gitlab.com/gitlab-com/people-group/Training/-/issues/831) as an example.
1. Schedule a weekly recurring 1:1 with the Intern Mentor to foster regular communication regarding intern role and responsibilities. Create a notes doc using the [internship agenda template](https://docs.google.com/document/d/1sZEdLyHj3DsHayshfmpsxHN1GFSwIXTlzaGjBDcmyBc/edit). This document will be used to document the plan, progress, and take notes during weekly 1:1s.
1. Before the start date, provide the intern with resources such as books and articles relating to Product Management. The Medium Blog [A Living List Of Product Management Resources You'll Want To Bookmark](https://medium.com/infinitypm/a-living-list-of-product-management-resources-youll-want-to-bookmark-c80b45aa1026) provides a comprehensive list of books, courses, templates, podcasts and tools for PM interns to explore.
1. Add the intern to the email groups, GitLab groups, relevant slack channels and recurring meetings.
1. Discuss workload with current manager in 1:1s to ensure workload percentage between both roles is balanced.
1. Before the start date of the internship, prepare a detailed plan and document it in training issue. Make sure to define actionable results for the intern to focus on and set incremental deadlines.
1. The Intern Manager and Mentor will prioritize the intern like an additional team member and provide regular feedback and guidance.

## Alumni

| Start date | End date | Group | Track | Name | Title | Takeaways |
| ---------- | -------- | ---- | ----- | --------- | --------- | --------- |
| 2024-08-01 | 2024-10-28 | Secure | Validation | @bskierlak | Customer Success Engineer | Learned about problem validation, created and presented opportunity canvas to PM and Directors of product. Created a framework for friction logs and had internal users complete it to identify product gaps. Conducted competitive analysis and documented inconsistencies within a GitLab subsets of products. |
| 2023-01-23 | 2023-04-17 | Create | Build | @agulina | Frontend Engineer | Collaborated with engineers in assessing a feature readiness, and prepare strategy, for general availabilty release: verified existing Issues relevance, and created new ones. Went through various steps of PM work: milestone planning, PI review. Participated in discussion with engineers, and Product Designers regarding user journey map. In the last phase on the internship, learned about problem and solution validation. |
| 2023-02-27 | 2023-05-22 | Verify | Validation | @atanayno | Sr. Support Engineer | Learnt various aspects of PM workflow: milestone planning, PI review, direction update, competitor review, opportunity canvas, release post items & blog posts, customer interviews; worked on the experiment with funnels to encourage upgrade from Premium to Ultimate; explored CI components & catalog, discussed dogfooding of CI components within GitLab. |
| 2022-03-21 | 2022-06-10 | Foundations | Validation | @m_frankiewicz | Backend Engineer | Practiced qualitative customer interviewing: prepared discussion guide, led 7 customer interviews, documented results in Dovetail. Derived key insights and patterns from customer interviews and surveys' feedback. Created and presented opportunity canvas to the Director and VP of Product. |
| 2021-10-25 | 2022-03-23 | Organization | Build | @aciciu | Support Engineer | Learned the PM workflow on how to triage and plan for a release. I collaborated and participated in discussions with engineers, EM and product designer, regarding scheduling. |
| 2021-08-02 | 2021-10-29 | Plan | Project Management | @cbazan1 | Sr. Customer Success Manager | Conducted a joint webinar before the internship program on [How GitLab does Product Management](https://www.youtube.com/watch?v=kdstqjmcYgY). Learned the day-to-day of a product manager, including triaging issues and managing expectations with customers, UX, and other stakeholders. Learned how Product Managers use operational metrics and performance indicators to measure the success of feature adoption. And experienced the validation and build track for prioritizing and breaking down work. |
| 2021-06-14 | 2021-08-19 | Editor  | Build | @mmacfarlane | Team Lead, Enterprise Sales Development  | Delivered Snippet rendering feature in 14.2 and published accompanying release post. Learned Build track workflow and relationship management between Engineering Manager, Product Designer, and Technical Writer. |
| 2021-01-18 | 2021-04-18 | Release | Release | @iganbaruch | Sr. Technical Product Marketing Manager  | During GitLab 13.9 planning and development I worked closly with the PM of the Release group, and learned all the main PM tasks around development of a milestone. Then I was acting as a PM and led the planning, development and release of GitLab 13.10 and GitLab 13.11 in the Release group.  |
| 2020-08-05 | 2020-11-01 | Monitor | Validation | @mmacfarlane | Team Lead, Enterprise Sales Development  | Created and presented opportunity canvas to VP and EVP or Product at GitLab. Conducted 8 interviews utilizing UX Research team, Respondent.io, and Dovetail. Create discussion guide for interviews. Learned Validation process from start to finish. |
| 2020-02-01 | 2020-04-30 | Monitor | Build | @williamchia | Sr. Product Marketing Manager | I got to PM the release of [Status Page](https://about.gitlab.com/releases/2020/04/22/gitlab-12-10-released/#status-page). |
