---
title: Product Management CDF and Competencies
---

On this page, you'll find an overview as well as links to helpful resources for evaluating a product manager's performance at GitLab. To better understand a product manager's responsiblities at GitLab, please visit [The Product Manager Role at GitLab](/handbook/product/product-manager-role/)

## Product Management Career Development Framework

<kbd class="required">Required 🔎</kbd><br>
<br>
We track progress through the skills required to be a product manager at all levels via the Product Management Career Development Framework (CDF). The single source of truth for that framework is the table below but you can use this [CDF template](https://docs.google.com/document/d/1MT_Xks-oF-D-2R_N380h4Phg_9s7BbO0U8k0eP-u8EI/edit) to track your career development with your manager. We are transitioning the CDF to include the company-wide standard of evaluating performance per the [Performance/Growth Matrix](/handbook/people-group/talent-assessment/#the-performancepotential-matrix). In this model, performance will be considered in categories of Developing, Performing, and Exceeding, alongside evaluation of Developing, Growing, and Exceeding in [Growth Output](/handbook/people-group/talent-assessment/#growth-output) instead of using Growing, Learning, Thriving, and Expert categories of the [compa-ratio](/handbook/total-rewards/compensation/compensation-calculator/#compa-ratio).

---

### What is the expected outcome of a CDF Review?

CDF reviews should result in actionable improvement focus areas for the product manager. When conducting a CDF review, managers should consider drilling into specific items within the PM's purview to highlight where the team member can focus on improving. [PM competencies](/handbook/product/product-manager-role/learning-and-development) are also valuable for identifying improvement areas.

We use KPIs by function in the CDF. These KPIs feature a guideline for results that are meant to be suggested indicators for ideal behaviors for Product teammates at GitLab. These are target results and are not meant to be an exhaustive list for Product teammate performance. As a manager and individual contributor, have a dialogue about the right measures of success and define those at the beginning of each performance cycle. Keep the KPIs consistent as you measure them over each CDF review for the best comparative results of growth.

### Selecting a Focus Area

In each CDF review, it's recommended to select an improvement area to focus on until the next CDF review. This could be anywhere from 1 to 3 improvement areas that you and your manager select together. Once selected, the teammate and manager check in on those focus areas in each 1:1 reviewing progress, discussing feedback, and adjusting any plans for the quarter to continue to improve. Selecting a focus provides a structure to say "no" to other areas that may not be as timely, critical, or worth the additional focus.

## CDF for Individual Contributor Product Managers

### Competencies

Product Managers must be able to demonstrate a variety of skills across our CDF. We provide additional career development guidance by listing [competencies](/handbook/people-group/competencies/) for each CDF category in order of priority.

We have four core competencies for Product Managers:

1. Product Roadmap & Product Led Growth
2. Sensing Mechanisms
3. Thought Leadership
4. Aligning Teams With HPT

### Product Roadmap & Product Led Growth

This competency is about setting and attaining the product direction as defined by the teammate. The teammate is being evaluated on connecting data to product strategy, influencing communication skills internally, plan ambitiously, while effectively practicing iteration, and delivering on the needs of the market.

_Example outcomes: MAU Attainment, Dogfooding Implementation %, Use of Growth Experiments_

#### Skills

- [Iteration](/handbook/product/product-management/learning-and-development/#-iteration)
- [Jobs to Be Done]( /handbook/product/product-manager-role/learning-and-development/#-jobs-to-be-done)
- [Lean Product Development](/handbook/product/product-management/learning-and-development/#-lean-product-development)
- [User Stories](/handbook/product/product-management/learning-and-development/#-user-stories)
- [Backlog Management](/handbook/product/product-management/learning-and-development/#-backlog-management)
- [KPIs and Metrics](/handbook/product/product-management/learning-and-development/#-kpis-and-metrics)
- [Product Strategy](/handbook/product/product-management/learning-and-development/#-product-strategy)
- [Growth, Product-led Growth, and Experimentation](/handbook/product/product-management/learning-and-development/#-growth-product-led-growth-and-experimentation)

#### Role Expectations

| [PM](/job-families/product/product-manager/#product-manager)| [Senior PM](/job-families/product/product-manager/#senior-product-manager) | [Principal PM](/job-families/product/product-manager/#principal-product-manager) | [Senior Principal PM](/job-families/product/product-manager/#senior-principal-product-manager) |
| ------ | ------ | ------ |------ |
| [Example behaviors](/job-families/product/product-manager/#product-roadmap--product-led-growth-pm)\* | [Example behaviors](/job-families/product/product-manager/#product-roadmap--product-led-growth-spm)\* | [Example behaviors](/job-families/product/product-manager/#product-roadmap--product-led-growth-ppm)\* | [Example behaviors](/job-families/product/product-manager/#product-roadmap--product-led-growth-sppm)\* |
| Adept at setting product direction for assigned product categories on a monthly cadence as informed by the stage direction. Capable of breaking epics into issues and issues into minimal valuable changes (MVCs). Partners with stable counterparts in product group Engineering to practice iteration and attain monthly active users as set by teammate. Manages product direction and maintains updates to category direction pages. Capable of using data about install base, growing customers, and prospects to prioritize features in a milestone with guidance from product leadership. Capable of using experimentation frameworks with support from growth and product leadership. Monitors monthly active users, error budgets, and other product performance indicators to inform product direction. | Excellent at setting product direction for assigned categories on monthly basis and informs stage direction. Adept at setting quarterly and annual plans. Skilled at breaking epics into issues and issues into minimal valuable changes (MVCs). Works across the stage to practice iteration and attain monthly active users as set by teammate. Proactively manages product direction and maintains updates to category direction pages. Skilled at using data about install base, growing customers, and prospects to prioritize features in a milestone. Skilled at using experimentation frameworks. Proactively and independently monitors monthly active users, error budgets, and other product performance indicators to inform product direction. |Expert at setting product direction for assigned categories on monthly basis and informs section direction. Skilled at setting quarterly and annual plans. Expert at breaking epics into issues and issues into minimal valuable changes (MVCs). Works across the section to practice iteration and attain monthly active users as set by teammate. Coaches others on direction updates and proactively manages product direction updates to category direction pages. Expert at using data about install base, growing customers, and prospects to prioritize features in a milestone. Expert at using experimentation frameworks. Deep understanding of trends in monthly active users, error budgets, and other product performance indicators and how those PIs shape their product direction. Capable of coaching others on PLG methods. | Expert at spotting the need for setting product direction for cross-section and intra-section initiatives. Able to coach others at setting quarterly and annual plans. Mentors, leads by example, and coaches others on breaking epics into issues and issues into minimal valuable changes (MVCs). Works across sections to practice iteration and attain monthly active users as set by teammate. Mentors, leads by example, and coaches others on direction updates. Proactively manages product direction pages. Mentors, leads by example, and coaches others at using data about install base, growing customers, and prospects to prioritize features in a milestone. Mentors, leads by example, and coaches others in using experimentation frameworks. Applies a deep understanding of trends in monthly active users, error budgets, and other product performance indicators and how those PIs shape their product direction. Actively coaches others on PLG methods.|

\* Example behaviors are intended to complement rather than replace the above CDF role expectations. These behaviors illustrate examples of the differences between various levels; however, as the needs and circumstances of each role are unique, not all of these behaviors will be necessary for every role. Additionally, exibiting all the behaviors of a given role does not guarantee a promotion into that role (see the section below on [typical requirements for promotion](#typical-requirements-for-promotions)).

### Sensing Mechanisms

This competency is about being able to balance and understand the various inputs of the user, customer, market, and landscape for GitLab. This will include the various levers the teammate will use to inform the product direction and use to shape the execution plans. Each function will have different mixes of sensing mechanisms required for that function, although, in order to effectively satisfy the requirements of the Product Competency all sensing mechanisms should be addressed at some level in the development framework for the teammate's development.

_Example outcomes: Uses appropriate methods of Customer Interviewing, Competitive Landscape, Market Research, and new persona research as the basis for Product Direction; Measurement: Direction page updates, DevOps tools updates, Recording of competitive tools walkthroughs, PM Standup Sharing, Opportunity canvases, [category mapping](https://internal.gitlab.com/handbook/corporate-development/#category-mapping)_

#### Skills

- [User Research](/handbook/product/product-management/learning-and-development/#-user-research)
- [Customer Interviewing](/handbook/product/product-management/learning-and-development/#-customer-interviewing)
- [Design](/handbook/product/product-management/learning-and-development/#-design)
- [Competitive Analysis](/handbook/product/product-management/learning-and-development/#-competitive-analysis)
- [Relationships with Customers](/handbook/product/product-management/learning-and-development/#-relationships-with-customers)

#### Role Expectations

| [PM](/job-families/product/product-manager/#product-manager)| [Senior PM](/job-families/product/product-manager/#senior-product-manager) | [Principal PM](/job-families/product/product-manager/#principal-product-manager) | [Senior Principal PM](/job-families/product/product-manager/#senior-principal-product-manager) |
| ------ | ------ | ------ |------ |
| [Example behaviors](/job-families/product/product-manager/#sensing-mechanisms-pm)\* | [Example behaviors](/job-families/product/product-manager/#sensing-mechanisms-spm)\* | [Example behaviors](/job-families/product/product-manager/#sensing-mechanisms-ppm)\* | [Example behaviors](/job-families/product/product-manager/#sensing-mechanisms-sppm)\* |
| Adept at qualitative customer interviewing. Familiar with prioritization frameworks like RICE to organize opportunity backlogs. Capable of deriving key insights and patterns from customer interviews, and using that input to clarify problem statements. Proficient at story mapping. Proficient at collaborating with Design on prototypes to bring potential solutions to life. Understands and communicates the business value of epics and issues. Sets success metrics for epics and issues, and tracks metrics post-launch to guide investment in iterative improvements. Spends up to 20% of time researching & defining category vision & strategy. Evaluates potential and fit of products for acquisition.|Skilled at qualitative customer interviewing. Excellent at deriving key insights and patterns from customer interviews, and using that input to clarify problem statements. Skilled at story mapping. Excellent at collaborating with Design on prototypes to bring potential solutions to life. Able to ensure activities are consistent with GitLab's go-to-market and business model. Drives evaluation of build, buy and partner options for solving customer problems. Can identify new market opportunities & author business cases, as well as forecast the approximate benefits of new features, projected against competition in the space. Spends up to 30% of time researching & defining category vision & strategy|Expert at qualitative customer interviewing. Skilled at story mapping. Capable of teaching product validation techniques to others. Expert at business case creation. Capable of managing business results across a range of product domains.| Mentors, leads by example, and coaches in qualitative customer interviewing practices. Highly Proficient at story mapping. Mentors, leads by example, and coaches others in product validation techniques. Expert at business case creation delivering cross-section, intra-section, and company-wide investment cases for consideration by Product Leadership. Proven execution of business results across multiple product domains.|

\* Example behaviors are intended to complement rather than replace the above CDF role expectations. These behaviors illustrate examples of the differences between various levels; however, as the needs and circumstances of each role are unique, not all of these behaviors will be necessary for every role. Additionally, exibiting all the behaviors of a given role does not guarantee a promotion into that role (see the section below on [typical requirements for promotion](#typical-requirements-for-promotions)).

### Thought Leadership

This competency is about the recognition of having technical ownership and being a resource or authority in the domain that the teammate is an expert in. This measure will vary across the Product organization and will be evaluated as an illustration of the Product teammate's capacity to deliver on the domain expertise or represent GitLab to the community.

_Example outcomes: Participation in Webinars, Prospect calls, #thanks shoutouts by others, engagement in social with community, Analyst recognition and engagement, Creation of artifacts for community and users, Conference participation, and OSS collaboration_

#### Skills

- [Product management thought leadership](/handbook/product/product-management/learning-and-development/#product-management-thought-leadership)

#### Role Expectations

| [PM](/job-families/product/product-manager/#product-manager)| [Senior PM](/job-families/product/product-manager/#senior-product-manager) | [Principal PM](/job-families/product/product-manager/#principal-product-manager) | [Senior Principal PM](/job-families/product/product-manager/#senior-principal-product-manager) |
| ------ | ------ | ------ |------ |
| [Example behaviors](/job-families/product/product-manager/#thought-leadership-pm)\* | [Example behaviors](/job-families/product/product-manager/#thought-leadership-spm)\* | [Example behaviors](/job-families/product/product-manager/#thought-leadership-ppm)\* | [Example behaviors](/job-families/product/product-manager/#thought-leadership-sppm)\* |
| Capable written and verbal communicator internally and externally. Trusted resource for customer calls and meetings. Builds rapport with stakeholders to align around priorities. Drives clarity in area. Takes action to improve behavior based on impact to others. High-level understanding of GitLab product and the relevant product domain(s). High-level understanding of GitLab's architecture and tech stack | Capable of representing GitLab externally at trade shows, customer events, conferences, etc. Appropriately influences & persuade others to a course of action. Solid presentation skills at all levels of the company. Deep familiarity with GitLab's product and the relevant product domain(s). Deep understanding of GitLab's architecture and tech stack. | Recognized as a thought leader internally and externally. Escalates issues cleanly to appropriate levels of authority when decisions or progress are blocked. Excellent presentation skills at all levels of the company. Expert in the relevant product domain(s) and capable of teaching others about the domain. Capable of coaching others on the GitLab product, architecture, and tech stack.| Celebrated as a thought leader internally and externally. Actions on escalations and transparently triages issues to appropriate levels of authority when decisions or progress are blocked. Mentors, leads by example, and coaches others on presentation skills at all levels of the company. Actively teaches others about the owned domain. Actively mentors and coaches others on the GitLab product, architecture, and tech stack.|

\* Example behaviors are intended to complement rather than replace the above CDF role expectations. These behaviors illustrate examples of the differences between various levels; however, as the needs and circumstances of each role are unique, not all of these behaviors will be necessary for every role. Additionally, exibiting all the behaviors of a given role does not guarantee a promotion into that role (see the section below on [typical requirements for promotion](#typical-requirements-for-promotions)).

### Aligning Teams with HPT

This competency is about how the teammate facilitates team execution and performance using GitLab values.

_Example outcomes: Say/Do, MR Rate, Validation Track Cycle Time and Build Track Cycle Time, OKR Attainment (70-85% is success, 100% means place for improvement), 360 feedback from counterparts, Values demonstration per our Company Competencies_

#### Skills

- [Leadership and influence](/handbook/product/product-management/learning-and-development/#-leadership-and-influence)
- [Communicating to inspire, align, and activate](/handbook/product/product-management/learning-and-development/#-communicating-to-inspire-align-and-activate)
- [Cross-functional team management](/handbook/product/product-management/learning-and-development/#-cross-functional-team-management)

#### Role Expectations

| [PM](/job-families/product/product-manager/#product-manager)| [Senior PM](/job-families/product/product-manager/#senior-product-manager) | [Principal PM](/job-families/product/product-manager/#principal-product-manager) | [Senior Principal PM](/job-families/product/product-manager/#senior-principal-product-manager) |
| ------ | ------ | ------ |------ |
| [Example behaviors](/job-families/product/product-manager/#aligning-teams-with-values-pm)\* | [Example behaviors](/job-families/product/product-manager/#aligning-teams-with-values-spm)\* | [Example behaviors](/job-families/product/product-manager/#aligning-teams-with-values-ppm)\* | [Example behaviors](/job-families/product/product-manager/#aligning-teams-with-values-sppm)\* |
| Responsible for the health of working relationships with peers in the stage. Familiar and comfortable with using iteration methologies and collaborating across the product group. | Skilled at applying agile development methodologies. Able to elevate performance of the Group through excellent PM outputs. Skilled at applying iteration methodologies and managing with influence while collaborating across the product stage. | Expert at applying agile development methodologies. Able to elevate performance of the peers in the stage. Expert at applying iteration methodologies and managing with influence while collaborating across the product section. | All Principal Behaviors, while proactively building strong cross-section relationships. Able to elevate performance of the peers across the company. Mentors and coaches others on our values including applying iteration methodologies and managing with influence while collaborating across GitLab. |

\* Example behaviors are intended to complement rather than replace the above CDF role expectations. These behaviors illustrate examples of the differences between various levels; however, as the needs and circumstances of each role are unique, not all of these behaviors will be necessary for every role. Additionally, exibiting all the behaviors of a given role does not guarantee a promotion into that role (see the section below on [typical requirements for promotion](#typical-requirements-for-promotions)).

## CDF for Individual Contributor Pricing Managers

Below, you'll find the CDF framework and potential discussion topics for [Pricing Product Managers](/job-families/product/pricing/).

### Product Roadmap & Product Led Growth

This competency is about setting and attaining the product direction as defined by the teammate. The teammate is being evaluated on the ability to plan ambitiously, while effectively practicing iteration, and delivering on the needs of the market. Connecting strategic data-informed skills with influencing communication skills internally. Product is often a cross-functional domain and requires leadership to work across engineering, field, and sales, as well as marketing, to effectively engage the community to grow as well as retain users.

_Example outcomes: Pricing, packaging and data analytics strategies aligned with product and business objectives (e.g. user adoption, cost savings, revenue monetization, etc.) and Pricing and packaging aligned to product value drivers (clear articulation of customer's perceived value and how monetization is aligned with perceived value)._

| [Pricing Analyst](/job-families/product/pricing/#pricing-analyst)| [Senior Pricing Analyst](/job-families/product/pricing/#senior-pricing-analyst)| [Principal Pricing Manager](/job-families/product/pricing/#principal-pricing-manager) |
| -------- |-- | -- |
| Adept at establishing processes and analytical methods to measure success metrics for pricing initiatives. Adept at communicating data insights. Skilled at creating dashboards to inform team members on success metrics. Partners with Product and Pricing Managers to understand project goals and develop a data strategy to support overall initiative. Light-weight project management of data analytic initiatives. Adept at identifying root drivers of problem statements. Skilled in analyzing data to validate connection between root drivers to problem statements. Adept in sourcing data used to validate problem statements. Skilled in using data to clarify problem statements. Adept in using data to refine solution options. | Excellent at establishing processes and analytical methods to measure success metrics for pricing initiatives. Excellent at communicating data insights. Skilled at determining the right dashboards to create that allows team members to review performance of initiatives against success metrics. Partners with Product and Pricing Managers to understand project goals and develop a data strategy to support overall initiative. Advanced project management of data analytic initiatives. Skilled at identifying root drivers of problem statements and analyzing data to validate connection between root drivers to problem statements. Skilled in sourcing and analyzing data to derive key insights to support/drive pricing initiatives. Skilled in using data to clarify problem statements and refine solution options. | Expert at setting success metrics for pricing initiatives and communicating business value of pricing projects. Expert at aligning GitLab's Go-to-market activities and business model with pricing. Expert at identifying monetization drivers and incorporating findings into pricing recommendations. Partners with Product Managers and Sales to understand product vision and sales challenges to build pricing and packaging intiatives. Leads pricing and packaging intiatives. Expert at identifying root drivers of problem statement, forming solution hypotheses, and identifying research needed to validate potential solutions. Skilled at qualitative customer and sales interviewing. Skilled at creating surveys for quantitative analysis. Expert at aggregating data and insights to form a cohesive pricing and packaging recommendation. Capable of teaching pricing validation techniques to others.|

### Sensing Mechanisms

This competency is about being able to balance and understand the various inputs of the user, customer, market, and landscape for GitLab. This will include the various levers the teammate will use to inform the product direction and use to shape the execution plans. Each function will have different mixes of sensing mechanisms required for that function, although, in order to effectively satisfy the requirements of the Product Competency all sensing mechanisms should be addressed at some level in the development framework for the teammate's development.

_Example outcomes: Uses appropriate methods of customer interviewing, competitive landscape, customer/sales data and market research as basis for Product Direction._

| [Pricing Analyst](/job-families/product/pricing/#pricing-analyst)| [Senior Pricing Analyst](/job-families/product/pricing/#senior-pricing-analyst)| [Principal Pricing Manager](/job-families/product/pricing/#principal-pricing-manager) |
| -------- |-- | -- |
|Basic understanding of pricing research methodologies. Adept in analyzing data gathered from different pricing surveys to drive insights. Adept at identifying, collecting, and analyzing customer, product usage and sales data to form insights used to drive pricing decisions. | Basic understanding of pricing research methodologies and skilled in analyzing data gathered from different pricing surveys to drive insights. Skilled at identifying, collecting and analyzing customer, product usage and sales data to form insights used to drive pricing decisions. Skilled at consolidating data and insights to form a comprehensive story. | Expert at incorporating customer options (build, buy and partner) into pricing and packaging recommendations. Be able to clearly articulate the customer's next best alternatives and how it impacts PnP recommendations. Excellent in the understanding of pricing research methodologies and being able to identify appropriate method(s) to be used for a given situation: basic survey questions on interests/needs, Van Westdorp, Gabor-Granger, Max-Diff, Conjoint, etc.|

### Thought Leadership

This competency is about the recognition of having technical ownership and being a resource or authority in the domain that the teammate is an expert in. This measure will vary across the Product organization and will be evaluated as an illustration of the Product teammate's capacity to deliver on the domain expertise or represent GitLab to the community.

_Example outcomes: Participation in Webinars, Prospect calls, #thanks shoutouts by others, engagement in social with community._

| [Pricing Analyst](/job-families/product/pricing/#pricing-analyst)| [Senior Pricing Analyst](/job-families/product/pricing/#senior-pricing-analyst)| [Principal Pricing Manager](/job-families/product/pricing/#principal-pricing-manager) |
| -------- |-- | -- |
| Adept at identifying data needs in order to support/drive pricing initiatives. Adept at driving improvements to data collection and analysis methods when data gaps are identified. Adept at driving data infrastructure improvements when required. Trusted resource for internal teams to provide pricing insights based on data. | Skilled at identifying data needs in order to support/drive pricing initiatives. Skilled at identifying data gaps and developing the data infrastructure to provide the required insights. Trusted resource for internal teams to provide pricing insights based on data. | Recognized as a thought leader internally and externally. Escalates issues cleanly to appropriate levels of authority when decisions or progress are blocked. Excellent presentation skills at all levels of the company. Expert in the relevant product domain(s). Capable of coaching others on the pricing frameworks, discount methodologies, and sales operations based on in-depth knowledge of the relevant product domain's value proposition. |

### Aligning Teams with Values

This competency is about the teammate facilitates the team execution and performance using GitLab values.

_Example outcomes: Say/Do, MR Rate, Validation Track Cycle Time and Build Track Cycle Time, OKR Attainment (70-85% is success, 100% means place for improvement), 360 feedback from counterparts, Values demonstration per our Company Competencies_

| [Pricing Analyst](/job-families/product/pricing/#pricing-analyst)| [Senior Pricing Analyst](/job-families/product/pricing/#senior-pricing-analyst)| [Principal Pricing Manager](/job-families/product/pricing/#principal-pricing-manager) |
| -------- |-- | -- |
| Responsible for the health of working relationships with peers in the stage. Familiar and comfortable with using iteration methologies and collaborating across the product group. | Skilled at applying agile development methodologies. Able to elevate performance of the Group through excellent PM outputs. Skilled at applying iteration methodologies and managing with influence while collaborating across the product stage. | Expert at applying agile development methodologies. Able to elevate performance of the peers in the stage. Expert at applying iteration methodologies and managing with influence while collaboration across the product section. |

## CDF for Product Leadership

The below table outlines the Career Development Framework used for [Product Leaders](/handbook/product/product-leaders/product-leadership/#product-leaders).

Typical scope and reporting structure is documented in the [Product Management Leadership job family](/job-families/product/product-management-leadership/).

### Competencies

All Managers and above in the Product function are considered product leaders. The Product Leader competencies describes important leadership concepts specific to the product management team. See also our page on general [GitLab leadership guidance](/handbook/leadership/).

### Product Roadmap & Product Led Growth

This competency is about setting and attaining the product direction as defined by the teammate. The teammate is being evaluated on connecting data to product strategy, influencing communication skills internally, plan ambitiously, while effectively practicing iteration, and delivering on the needs of the market.

_Example outcomes: MAU growth/retention, ARR Influence, Cross-company alignment for product roadmap_

#### Responsibilities

Responsibilities outlined in the [Group Manager of Product Job Family page](/job-families/product/product-management-leadership/#group-manager-product-gmp).

##### Group Manager

- Coaching of team members on validation track skills
- Strategic research
- Driving cross-group connections in service of a single-app experience
- Adoption Funnel across product groups
- Partnership with GTM via Use Case assignment

#### Role Expectations

| [Group Manager](/job-families/product/product-management-leadership/) | [Director](/job-families/product/product-management-leadership/)| [Senior Director](/job-families/product/product-management-leadership/) | [VP](/job-families/product/product-management-leadership/) |
| --- | --- | --- | --- |
| Leads strategic research that spans and extends beyond product scope. Plans on an annual and quarterly product vision cadence. Spots opportunities for cross-group, cross-stage, or cross-section collaboration and learning. Demonstrates and coaches business skills to others. Regularly maintains high-level Direction and ensures Direction alignment across the scope. Develops a deep understanding of the adoption funnel across groups and stages. | Executes research and customer interviewing across the section as a GitLab representative. Plans on a 3-year to annual product vision cycle. Creates opportunities for cross-stage and cross-section collaboration. Active coach for business skills across the product organization, including feedback on opportunity canvases, product proposals, and MVCs. | Represents GitLab product in strategic customer calls, Customer Advisory Board Sessions, and prospects to inform 5-year+ product vision and strategy. Contributes to annual themes, yearlies, and OKRs to align section with broader company strategy. Provides coaching to direct reports on crafting vision in respective areas. |  |

### Sensing Mechanisms

This competency is about being able to balance and understand the various inputs of the user, customer, market, and landscape for GitLab. This will include the various levers the teammate will use to inform the product direction and use to shape the execution plans. Each function will have different mixes of sensing mechanisms required for that function, although, in order to effectively satisfy the requirements of the Product Competency all sensing mechanisms should be addressed at some level in the development framework for the teammate's development.

_Example outcomes: Continuous evaluation of competitive landscape, active participation and execution of merger and acquisition, drives GTM alignment on key product deliveries, and engages SUS/PNPS for user interviews._

#### Responsibilities

Responsibilities outlined in the [Group Manager of Product Job Family page](/job-families/product/product-management-leadership/#group-manager-product-gmp).

##### Group Manager

- Coaching of team members on business skills
- Acquisitions
- Deep understanding, synthesis, and communication of competitive landscape and emergent solutions
- Business Cases for new investment
- Direction updates

#### Role Expectations

| [Group Manager](/job-families/product/product-management-leadership/) | [Director](/job-families/product/product-management-leadership/)| [Senior Director](/job-families/product/product-management-leadership/) | [VP](/job-families/product/product-management-leadership/) |
| --- | --- | --- | --- |
| Partners with GTM on assigned Use Cases. Establishes a deep understanding of competitive and emergent solutions. Leads acquisition and new investment business case creation. Capable of managing business results across a range of product domains. | Capable of making key pricing & packaging recommendations for section. Champions acquisition opportunities including business case creation. Proactively manages adoption funnels and performance indicators across stages. Identifies GTM opportunities and engages with leaders to capitalize on them for the section. | Contributes to pricing discussions across the portfolio and makes recommendations on strategy. Identifies and champions acquisition opportunities and provides coaching to direct reports on effective positioning and business case creation. Leads cross-section dialogue on product performance indicators and helps identify opportunities for cross-section partnership. Works with GTM and Customer success leadership to deliver on portfolio priorities. |  |

### Thought Leadership

This competency is about the recognition of having technical ownership and being a resource or authority in the domain that the teammate is an expert in. This measure will vary across the Product organization and will be evaluated as an illustration of the Product teammate's capacity to deliver on the domain expertise or represent GitLab to the community.

_Example outcomes: Represent GitLab externally in industry talks, podcasts, or conferences. Creates content for product vision. Coaches teammates on employing effective thought leadership mechanisms. Actively engages analysts for generating market priorities._

#### Responsibilities

Responsibilities outlined in the [Group Manager of Product Job Family page](/job-families/product/product-management-leadership/#group-manager-product-gmp).

##### Group Manager

- Presenting broader GitLab Roadmap
- Represent GitLab at Conferences

#### Role Expectations

| [Group Manager](/job-families/product/product-management-leadership/) | [Director](/job-families/product/product-management-leadership/)| [Senior Director](/job-families/product/product-management-leadership/) | [VP](/job-families/product/product-management-leadership/) |
| --- | --- | --- | --- |
| Consistently communicates a product vision and creates a bias towards action in their communication. Recognized as a thought leader internally and externally. Excellent presentation skills at all levels of the company. Spots murkiness and escalates issues cleanly to appropriate levels of authority when decisions or progress are blocked. Able to represent GitLab Section Direction deeply and company-wide roadmap broadly. | Establishes a compelling team purpose that is aligned with the overall organizational vision. Inspires a broader team to achieve results. Identifies disconnects to vision and takes appropriate action. | Actively engages the market, analysts, and other software leaders in the industry to represent GitLab and our product management philosophy. Active participant in industry conferences. Engages analysts in portfolio discussions. |  |

### Aligning Teams with Values

This competency is about how the teammate facilitates team execution and performance using GitLab values.

_Example outcomes: Lives CREDIT values. Coaches others on CREDIT Values. OKR execution and completion by the team. Stage and Section Say/Do ratios or MR rates are attaining targets._

#### Responsibilities

Responsibilities outlined in the [Group Manager of Product Job Family page](/job-families/product/product-management-leadership/#group-manager-product-gmp).

##### Group Manager

- Partnership with Design leadership
- High-performing team
- Enabling direct reports to be more efficient
- Shared understanding of team goals and targets
- Hiring and at managing underperformance.
- Caring personally for team members.
- Candid real-time feedback.

**Note** Aligning Teams with Values includes People Management Skills

#### Role Expectations

| [Group Manager](/job-families/product/product-management-leadership/) | [Director](/job-families/product/product-management-leadership/)| [Senior Director](/job-families/product/product-management-leadership/) | [VP](/job-families/product/product-management-leadership/) |
| --- | --- | --- | --- |
| Develops strong partnership with Cross-functional counterparts leadership in Stage. Ensures effectiveness of R&D investment. Partners with Engineering Leadership to ensure product groups attain cross-functional performance indicators and that R&D resources are being effectively allocated. Establishes and executes a portfolio management strategy across stages in sections. Aligns team with larger Stage vision and goals. Translates and aligns strategy in a meaningful way for the team, building a shared understanding of team goals and targets. Uses situational leadership techniques to provide the appropriate level of guidance and latitude to team members. Proactively identifies and fills talent gaps. Adept at caring personally for team members. Provides candid real-time feedback. | Enables strong partnership with UX Research and Product Design to ensure our R&D investment is effective across stages and the section. Responsible for the health of working relationships with fellow Engineering Directors. Evaluates and optimizes product hierarchy to ensure we are organized to efficiently deliver on our R&D investments. Coaches groups to create a high-performance organization that meets performance indicators across functions. Establishes and executes portfolio management strategy across scope with peer Directors. Aligns team with scope's larger vision and goals. Provides appropriate level of guidance and latitude to managers and individuals. Experienced at hiring and at managing underperformance. Excellent at caring personally for team members. Provides candid real-time feedback. | Enables strong partnership with UX Research and Product Design to ensure our R&D investment is effective across the portfolio. Responsible for the health of working relationships with Engineering functions and product organization. Provides coaching on the effective use of R&D investments. Coaches product team to create a high-performance organization that meets performance indicators across functions. Coaches direct reports on portfolio management strategy. Aligns product team with scope's larger vision and goals. Provides appropriate level of guidance and latitude to managers and individuals. Expert at hiring and at managing underperformance. Excellent at caring personally for team members. Provides candid real-time feedback. |  |

## Evaluating Product Manager's potential

When evaluating a product manager's potential, in addition to the [generic information](/handbook/people-group/talent-assessment/#what-is-potential) outlined, we also want to evaluate potential based on the unique and outsized impact PMs can have. We acknowledge that the evaluation will remain more qualitative than quantitative, but rather than shy away from making an evaluation, we will lean in using the information below.

We can think about the Product Manager's potential primarily on two axis: value creation and leadership.

### Value Creation

Product managers are in the business of creating value, measurable by [Product KPIs](https://internal.gitlab.com/handbook/company/performance-indicators/product/#structure). They prioritize the most important thing to unlock the most value at the intersection of the business and the user or buyer. At GitLab, Product Managers are often the [business owner](https://www.svpg.com/product-managers-vs-business-owners/) of their segment and outputs are not just in the delivery of features to production, rather can include go-to-market, sales enablement, partner/channel/alliances relationships, and understanding revenue impact of the product offering.

We expect product managers to create value across the business by excelling at execution in at least the following levels. When thinking of a PM's potentials, consider their capacity to expand their influence beyond their current level.

| **Level**        | **Value created at..** |
| ---------------- | ---------------------- |
| **PM**           | features and categories |
| **Senior PM**    | features, categories and stage |
| **Principal PM** | features, categories, stage, and cross-stage |
| **GPM**          | stage and cross-stage |
| **Director**     | cross-stage, cross-department |
| **VP and up**    | company-wide or new business/industry |

### Leadership

As product managers grow in experience and seniority, they are tasked with shaping alignment, producing results, and leading with increasing responsibilities. Understanding how to set the tone with vision and strategy, and knowing how to control output in a system comprised of people, culture, technology, and process is how product managers lead.

We expect product managers to be a leader at the following levels. When evaluating potential, consider the PM's capacity to be a leader with more scope.

| **Level**                  | **Leadership level** |
| -------------------------- | -------------------- |
| **PM**                     | product group |
| **Senior PM/Principal PM** | product group, stage, and cross-group alignment |
| **GPM/Director**           | multiple groups and stages |
| **Senior Director**        | cross-department |
| **VP**                     | company-wide |

### A framework for evaluating potential

It can be challenging objectively evaluating product managers for categorization of Low, Medium and High potential as suggested in the [Performance/Potential Matrix](/handbook/people-group/talent-assessment/#the-performancepotential-matrix). Consider using the following framework to rank a PM's potential. Assign a ranking, 1 (Low) - 5 (High) to each attribute below. Add up the rankings for a total score. A score between 5-11 is low potential, 12-18 is medium potential, 19-25 is high potential.

| Attribute                 | Reasoning |
| ------------------------- | --------- |
| Self-motivation and drive | The intrinsic drive enables PMs to learn, be passionate, and ultimately be effective. |
| Influence                 | High potential PMs build rapport with their team, which supports accomplishing results. |
| Resourcefulness           | PMs should seek to learn and grow. What they learn is ultimately meaningful if the learning can be applied. |
| Ambitious                 | High potential PMs stretch themselves and make themselves available to new responsibility. |
| Self-awareness            | A large part of leadership is knowing where you are not strong and building relationships to fill in the gaps. |

#### Make evaluating potential actionable

Product managers are typically driven and high performing individuals, and we often overestimate our own abilities relative to others. Seeing even a medium potential may be disappointing to many PMs. It should be made clear that a perceived lower than desired potential does not mean the PM is not valued and not performing to expectation. Managers should use a CDF Review to discuss the scoring of the potential. The outcome should be to identify opportunities for the PM to grow and areas for the manager to mentor and coach the PM.

## Supporting a Product Manager's Career

We want Product Managers to succeed in their careers at GitLab and beyond. Product Managers are encouraged to fill out and talk to their managers about their longer-term career goals either as part of their CDF reviews or as a separate career coaching discussion. To help facilitate, track and make time for overall career growth, Product Managers can fill out this specific template for career coaching conversations in the main [CDF template](https://docs.google.com/document/d/1MT_Xks-oF-D-2R_N380h4Phg_9s7BbO0U8k0eP-u8EI/edit#heading=h.6wqbupmuee9o) (internal only). Having all career development and progression in one document will help both Product Managers and their Managers keep track of progress.

### Typical Requirements for Promotions

 Promotions follow the [standard promotion process](/handbook/people-group/promotions-transfers/#twice-per-year-promotion-calibration-process--timeline) and adhere to the [promotion philosophy](/handbook/people-group/promotions-transfers/#promotion-philosophy). When reviewing a proposed promotion, we consider: 1) readiness of the individual, and 2) business justification/opportunity. Team members should already be demonstrating some of the next level job frameworks levels before promotion and a [promotion document](/handbook/people-group/promotions-transfers/#promotion-document) should be completed. For promotions to take effect, the budget needs to be available and approved. If there is not a business need substantial enough to justify a promotion opportunity, it is possible that otherwise qualified individuals may not be able to be promoted until an opportunity becomes available.

 Unless there is a justifiable exception, the requirements below are also typically required to be met for individual contributor promotions within the Product department:

| **Levels**                      | PM | Senior PM | Principal PM | Senior Principal PM |
| ------------------------------- | ------------ | ------ | --------- | ---------------- |
| **Typical Business Need**       | A Group requires PM support and the manager has bandwidth to support a PM. | A Group requires PM support including deeper strategic direction and cross-group coordination within the Stage. | A Stage requires extensive PM support, strategic leadership, and cross-stage coordination within the Section. | The company requires broad PM support, strategic leadership, and cross-section coordination. |
| **Typical Reporting Structure** | Reports to a Group Manager or Director | Reports to a Group Manager or Director | Reports to a Group Manager, Director, or Senior Director | Reports to a Senior Director, or VP |

## Contributing to our PM Competencies and CDF Criteria

Every GitLab team member is encouraged to contribute to the list of prioritized Product Manager competencies and CDF criteria, as well as the content for each competency via merge requests to this page.

To contribute to the competencies, open an issue in the Product project using the [Product Competencies](https://gitlab.com/gitlab-com/Product/-/blob/main/.gitlab/issue_templates/Product-Competencies.md) template. The steps in the issue will guide you through getting a future competency merged into this page.
