---
title: "Product Design"
description: "At GitLab, our Product Design team drives the business forward by becoming experts in their specific stage groups staying informed about the entire product, and aligning with user and business goals. We partner closely with our stable counterparts in Product Management and Development to deliver exceptional user experiences."
---

### Role of Product Designers

Product Designers are assigned to a specific area of the product, known as Stage Groups, where they immerse themselves in user workflows to solve real customer problems.

They are also responsible for broader UX department efforts, such as:

- Supporting community contributions
- Contributing to the Pajamas Design System
- Reviewing other designers' work

Each designer works as a [manager of one](/handbook/values/#managers-of-one) to solve customers problems and align with the direction of the product. They collaborate with stage peers and managers to [manage their capacity](/handbook/product/ux/product-designer/capacity-management) and deliver results on time. For a detailed view into how Product Designers work, review the [Product Designer workflow page](/handbook/product/ux/product-designer/).

For more information on Stage Groups, team member assignments, and product direction, visit [the product category page](/handbook/product/categories/).

### Process and Design Responsibility

#### Owner of design judgment

As Product Designers, we are entrusted with the authority of **design judgment**. Our process begins with understanding the problem and prioritizing for the best user experience. When additional constraints or insights (e.g. technical considerations or marketing strategies) arise, we collaboratively evaluate and adjust our designs accordingly. We proactively communicate how these constraints impact our designs and what changes will affect the user.

In cases where our counterparts have differing opinions, we consider their perspectives but hold the final say on design decisions as we are the ultimate guardians of design judgment.

### Design Principles and Tools

Our [design principles](https://design.gitlab.com/get-started/principles) are outlined in the Pajamas Design System.

Product Designer Tools

- [UX Scorecard](/handbook/product/ux/ux-scorecards/)
- [Category Maturity Scorecard](/handbook/product/ux/category-maturity/category-maturity-scorecards/)
- [UX Issue Triage](/handbook/engineering/infrastructure/engineering-productivity/issue-triage/#ux)
- [Heuristics](/handbook/product/ux/heuristics/)
- [Competitor Evaluation](https://gitlab.com/gitlab-org/competitor-evaluations) (*GitLab Team Member access only*)
- [UX Cloud Sandbox](/handbook/product/ux/ux-research/ux-cloud-sandbox/)

Figma and Figjam are our primary design tool of choice. Refer to the [usage and access details](/handbook/product/ux/product-designer/figma).

## Product Design Workflow

Product Designers adhere to the [Product Development flow](/handbook/product-development-flow/) in collaboration with stable counterparts. Key aspects include:

- [Planning and managing capacity](/handbook/product/ux/product-designer/capacity-management)
- [Prioritization](/handbook/product/ux/product-designer/capacity-management/#priorities)
- [Working on Issues](/handbook/product/ux/product-designer/#working-on-issues)
- [Design Process](/handbook/product/ux/product-designer/#product-design-process)
- [Partnering with UX Research](/handbook/product/ux/product-designer/#partnering-with-ux-researchers)
- [Partnering with Technical Writers](/handbook/product/ux/product-designer/#partnering-with-technical-writers)
- [Contributing to Pajamas](https://design.gitlab.com/get-started/contributing/)
- [Designing with AI](/handbook/product/ux/product-designer/#designing-with-ai)

New GitLab Product Designers should refer to the [Product Designer Workflow handbook page](/handbook/ux/product-design/workflow/) for a comprehensive guide to getting started.

## Product Design Management Workflow

- [Product Design Manager Workflows](/handbook/product/ux/product-design/product-design-manager)

## Learning and Development

Our continuous learning initiatives are documented in the [UX Department Learning and Development](/handbook/product/ux/learning-and-development/) section.

## Cross-functional Initiatives

### Beautifying our UI

This initiative aims to enhance our product's usability by leveraging the best practices from the "Macro UX" experiment, which paired Product Designers and Engineers to make self-directed improvements. See the [retro issue](https://gitlab.com/gitlab-org/gitlab/-/issues/351288) for details.

Key Elements:

- **Self-directed improvements:** Product Designers and Engineers are empowered to fix usability issues they identify without strict prioritization constraints.
- **No restrictions on product area:** Improvements can be made across any product area, fostering broad collaboration.
- **Work in MRs, not issues:** Direct changes are made through Merge Requests (MRs), with comprehensive documentation and explanations.
- **Length of rotation:** Pairings last 1-3 milestones, depending on what the pairing believes is appropriate. Multiple pairs can be working simultaneously on Beautifying our UI.
- **Prioritization:** Participants coordinate with their managers to balance their involvement with regular responsiblities.
- **Documentation:** All changes must be documentated, adhering to the [Definition of Done](https://docs.gitlab.com/ee/development/contributing/merge_request_workflow.html#definition-of-done), and involving [relevant Technical Writers](/handbook/product/ux/technical-writing/#assignments).

#### Volunteering and Participation

To volunteer, Product Designers and Engineers should:

1. Create an MR to add their name to the volunteer table and assign it to their manager for review.
1. Indicate the percentage of capacity dedicated to the initiative.
1. Create an issue and link all related MRs for transparency and tracking.
1. Ensure all changes align with the Pajamas Design System and leverage feature flags where appropriate.

Volunteers:

| Milestone          | Product Designer  | Engineer          |
| ------------------ | ----------------- | ----------------- |
| 17.5               |                   |                   |
| 17.6               |                   |                   |
| 17.7               | Emily Bauman      | Anna Vovchenko    |
| 17.8               |                   |                   |
| 17.9               |                   |                   |

{{% details summary="Previous Volunteers" %}}

| Milestone         | Product Designer  | Engineer          |
| ----------------- | ----------------- | ----------------- |
| [17.1 (2024-05-13)](https://gitlab.com/gitlab-org/gitlab/-/issues/442453) | Veethika M         | Miguel Rincon |
| [16.1 (2023-05-18)](https://gitlab.com/gitlab-org/gitlab/-/issues/394768) | Veethika M         | Payton Burdette |
| [15.11 (2023-03-18)](https://gitlab.com/gitlab-org/gitlab/-/issues/387070)| Annabel Gray       | Phil Hughes     |
| [15.6 (2022-10-18)](https://gitlab.com/gitlab-org/gitlab/-/issues/378259) | Matej Latin        | Deepika Guliani |
| [15.5 (2022-09-18)](https://gitlab.com/gitlab-org/gitlab/-/issues/374580) | Katie Macoy        | Anna Vovchenko  |
| [15.4 (2022-08-18)](https://gitlab.com/gitlab-org/gitlab/-/issues/370364) | Nadia Sotnikova    | Alex Kalderimis |
| [15.2 (2022-06-18)](https://gitlab.com/gitlab-org/gitlab/-/issues/362122) | Emily Bauman       | Jannik Lehmann  |
| [15.1 (2022-05-18)](https://gitlab.com/gitlab-org/gitlab/-/issues/361641) | Sascha Eggenberger | Robert Hunt     |
| [15.0 (2022-04-18)](https://gitlab.com/gitlab-org/gitlab/-/issues/356703) | Annabel Gray       | Phil Hughes     |

{{% /details %}}

#### Measuring Success

Success of the program will be tracked by the total number of MRs merged with the "Beautifying our UI" label.

#### Risks and Considerations

- Time commitment: The time required for these pairings is variable, potentially impacting regular milestone work and OKRs.
- No user research: Focusing on heuristic reviews might introduce new friction points without direct user feedback.

By following these guidelines, GitLab's Product Design team can continue to drive meaningful, user-centric improvements across the platform.
