---
title: "Hiring Product Designers"
description: "Product Designers, Product Design Managers, the Director of Product Design, and Product Managers participate in our hiring process by interviewing Product Designer candidates. We have created guidelines to help support a consistent end-to-end hiring process."
---

## Hiring process

Product Designers follow the [Hiring & Talent Acquisition process](/handbook/hiring/).

General resources:

- [Interviewing at GitLab](/handbook/hiring/interviewing/#conducting-a-gitlab-interview)
- [Product Designer job family](/job-families/product/product-designer/)

## Interviews for Product Designers

Each Product Designer candidate is interviewed by a panel of interviewers that include:

- Product Designer
- Product Design Manager
- Senior Manager of Product Design
- Product Manager, Engineering Manager

A [detailed description of each stage of our interview process](/job-families/product/product-designer/#hiring-process) is available along with the job description.

We have established a set of questions we ask at each stage of the process. All questions are available in the Greenhouse scorecard for the candidate. We ask the same questions to every candidate to ensure fairness--during the interview and when evaluating each candidate.

An interview rubric has been defined that provides a set of positive answer traits and characteristics to look out for when asking each of the Greenhouse interview questions. It's recommended that you:

1. Open the appropriate GDoc version for your interview level (i.e. Senior or Intermediate candidate) for quick access after your interview to aid in completing your Greenhouse Scorecard.
1. Compare your notes with the rubric on each question and
1. Assess how the candidate's answer compares to the desired positive traits/characteristics provided.

Use this rubric comparison/assessment to help with your final scorecard assessment prior to your scorecard submission.

### Interview rubrics

1. Product Designer (peer) interview - [Senior Candidate Rubric](https://docs.google.com/document/d/1LLWyEmegVh1m78r4UMTdgGpgB1fpCCqQ6dB6WASBNAw/edit?usp=sharing)
1. Product Designer (peer) interview - [Intermediate Candidate Rubric](https://docs.google.com/document/d/1EjD-G1KUADLeoGpPEOs2e19_oNeDnL8jC95UMSUo864/edit?usp=sharing)
1. Manager interview - [Senior Candidate Rubric](https://docs.google.com/document/d/1iiMrOtnEc9XRheJ1AAfLSKcPk4Qbr1WKPiubKFCHhbY/edit?usp=sharing)
1. Manager interview - [Intermediate Candidate Rubric](https://docs.google.com/document/d/1Z8MlKQ5S7sMR2jJTNR5weYxMu9c1tpmvUE4ZXpDcqBo/edit?usp=sharing)

## Interview training

Any Product Designer can participate in the hiring process after completing the [company interview training](https://gitlab.com/gitlab-com/people-group/Training/-/blob/master/.gitlab/issue_templates/interview_training.md) and a [Product Design-specific interview training](https://gitlab.com/gitlab-org/gitlab-design/-/blob/master/.gitlab/issue_templates/Product%20Designer%20Job%20Interview%20Training.md). These trainings will teach you how to perform successful interviews at GitLab.

In the last steps of the training, you will:

- Shadow an experienced Product Designer interviewer in two separate interviews, so that you can see how a successful interview is conducted.
- Be shadowed by your coach in two separate interviews. They will act as your coach and provide feedback on your interviewing skills.

You may request additional shadow opportunities, if you'd like additional practice and support.

### Scorecard completion tips

Everyone who interviews a candidate must complete a scorecard and is required to input pros and cons as well as an overall recommendation.

#### Interview scorecards

- [Talent Acquisition Process: Hiring team to complete feedback in Greenhouse](/handbook/hiring/talent-acquisition-framework/hiring-manager/#step-6hm-hiring-team-to-complete-feedback-in-greenhouse)

##### Tips for completing interview scorecards

- Enter your notes into each of the text areas provided in the candidate's Greenhouse Scorecard.
- Clean up any typos, misspellings, or incomplete statements as desired to aid the hiring manager's review process.
- Review the notes of the candidate's answers against the appropriate [Rubric document](#interview-rubrics) and consider how their answers compared to it.
- Add your assessment of the candidate in the Pros/Cons sections of the Greenhouse Scorecard.
- Complete your assessment of the candidate's Attributes, only providing an assessment of the attributes that were discussed, and were available on their resume/CV, or portfolio. If an assessment didn't come, leave it unanswered.

### Manager resources

#### Reference scorecards

- [Talent Acquisition Process: Complete references](/handbook/hiring/talent-acquisition-framework/hiring-manager/#step-7hm-complete-references)

#### Justification scorecards

##### Tips for completing justification scorecards

This Justification should provide a summary of all the submitted Scorecards while incorporating any additional commentary around how the hiring manager plans on helping the candidate be successful.

1. In what specific way(s) does this candidate make the team better?
    1. Consider how the candidate meets each of the Must Have's and Nice-to-Have's outlined in the recruiting kickoff issue.
    1. List and explain any other strengths and/or unique skills the candidate brings to the role and team.
1. What flags were raised during the interview process?
    1. Consider how the candidate doesn't meet some of the Must Have's and Nice-to-Have's outlined in the recruiting kickoff issue and explain your reasoning for moving forward, and how you will address them.
    1. Consider any concerns raised during the interviews and explain your reasoning for moving forward, and how you will address them.
1. How do we intend on setting this candidate up for success?
    1. Consider the candidate's soft skills and values, how will you help them progress and succeed at GitLab?
    1. Consider the above "raised flags" and explain how you're going to help set the candidate up for success, helping them to overcome these or any weaknesses they may have.
1. Is the offer in-plan, and why? E.g. it is a critical budgeted hire, backfill, or transfer.
    1. Provide the correct answer. If you're unsure, work with your manager to determine the correct answer.
1. Does the candidate meet a simple majority of nice-to-have requirements (5 of 9) for the role?
    1. Review the Nice-to-have attributes across the scorecards and provide the answer.
1. Attributes
    1. Answer these based on a sum of all the scorecards submitted. For example, if they got 4 `stars` and one `thumbs-up` on the Collaboration value from the scorecards, pick the `star` to summarize that feedback. You do not need to leave notes.
