---
title: UX Forum
description: >-
  The UX Forum is a recurring meeting for UX team members to share and discuss their work.
---

## About UX Forum

{{% ux-forum %}}

### Purpose

- Increase awareness of the value delivered through UX by highlighting business, product, and user outcomes
- Increase visibility into findings, opportunities, solutions
- Increase exposure of UX activities to the broader organization
- Increase work quality by promoting cross-stage collaboration in the meeting and after it

### Audience

- Product designer, researcher, and/or technical writer (speaker)
- UX department
- Product division
- Engineering division
- Relevant leadership (VP of UX, VP of Development, VP of Product, E-Group)

### Schedule

Forums are scheduled every two weeks. They are 60 minutes long to allow up to three team members to share for 15 minutes, plus 5 minutes of discussion time with the attendees.

- To be inclusive of our distributed team, we alternate the meeting start time every other occurrence to be either Americas/LAC/EMEA friendly or APAC friendly.
- Each forum is hosted by a Product Design Manager.
  - Due to time zone restrictions for managers, the APAC UX Forum is hosted by another Product Designer, Technical Writer or UX researcher.
- Product Designers are assigned dates based on a randomly generated rotation:
  - We ensure each designer has the opportunity to share twice a year.
  - Gaps are left throughout the schedule for additional speakers.
- Anyone can sign up to share and discuss their work. Coordinate with the host to claim an available slot.
- Each person who shares is expected to fill out the agenda (attached to the meeting invite) for that week prior to speaking.
- It is the responsibility of the host to know when they are scheduled to host and the responsibility of the speaker to know when they are scheduled to share. To help, a Slack reminder has been set up in the `#ux` channel to review the schedule.

If a speaker can't share on their assigned date, it's their responsibility to make a trade. To make a trade:

- Announce in the `#ux` channel and during the UX weekly call that you'd like to trade.
- After you identify a trade, make an MR to update the schedule.
- Ask your Product Design Manager to review and merge.

{{% include "includes/ux-forum-schedule.md" %}}

<a href="https://gitlab.com/-/ide/project/gitlab-com/content-sites/handbook/edit/main/-/assets/includes/ux-forum-schedule.md" class="btn btn-primary">Update schedule</a>

## Sharing your work

You have up to 15 minutes to share some of your work.
If you need more time to share and discuss a complex topic, ask the host about having fewer people speak at that forum.

Preparation for a forum should be minimal.
You should come prepared with just enough to tell a story and ellicit feedback from the audience.
Successful forums share these aspects:

- **Informal**:
    Avoid creating dedicated slides or assets, but use your best judgment to determine what's most effective: a prototype, a series of mockups, a process diagram, a journey map, a few slides, or something else.
    The UX Forum is to share and discuss your work informally, not fancy storytelling.
- **Just enough sophistication**:
    Help us strive for a [low level of shame](/handbook/values/#low-level-of-shame) and share your work with as little sophistication as possible.
    While some topics gain from a more sophisticated story, this sophistication raises the perception of quality, puts unnecessary pressure on other speakers, and might make it harder for others to engage.
- **Relatable**:
    Structure your story with the audience in mind, to elicit feedback from them, and highlight potential overlaps.
    This makes it easier for people to relate, find value, and engage.
    For example, intentionally pinpoint overlaps or add questions for the audience.
- **Iteration mindset**:
    Use it as an opportunity to learn from and collaborate with others.
    Make iteration shine not only in the work you've done so far, but how you might iterate forward and what's missing.
    For example, list your current challenges, open questions, and where others might help.

See [helpful tips](#helpful-tips-for-those-sharing).

Examples of minimal forums:

- [Fulfillment: Improve provisioning and onboarding of new sales assisted GitLab com subscribers](https://youtu.be/JYl2_Pnh_-I )
- [Secure: Validating and prioritizing your roadmap](https://youtu.be/FVhZ_XNiR6U)
- [Secure: Group-level security scanner status widget](https://youtu.be/4W-cWcEae_o)
- [Secure: Security Workflow Iterations](https://youtu.be/v3gv-rplcBI)

### Preparation

- Prior to the UX Forum, add your specific topic to the meeting agenda.
- If this is an APAC forum and there is no host yet, consider [hosting](#hosting).
- Provide context for the problem:
  - The scope of the problem
  - Why was/is it important to solve?
  - What did we learn during research?
  - Any constraints that impact the solution?
- State the desired goals of the work:
  - What is the desired business and customer outcome?
  - Ideally, describe the [JTDB](https://jtbd.info/replacing-the-user-story-with-the-job-story-af7cdee10c27)
    - When, [user's context]. I want to [user's goal]. So I can [user's desired outcome].
  - What were/are the constraints?
  - How did you/are you planning to iterate toward an MVC?
- Walk your audience through the solution iterations:
  - Be yourself and tell the story of the work.
  - Use existing mockups and flows, rather than creating something new.
- Invite discussion:
  - How might this overlap with or help other teams?
  - What are the current challenges, next steps, and open questions?
  - How might others approach this or help you?

### Helpful tips for those sharing

- Introduce yourself and provide [context](#preparation) for your topic.
- [Make the participant experience an enjoyable one](/handbook/tools-and-tips/zoom/#make-the-participant-experience-an-enjoyable-one): avoid moving around too fast (for example, when showing a Figma prototype), or back and forth between views because you forgot to say one thing at the previous one.
- [When sharing your screen](/handbook/tools-and-tips/zoom/#how-to-share-a-presentation-in-zoom), consider going fullscreen so that the audience can see the details.
  - Useful Figma keyboard shortcut on macOS to show/hide UI: `⌘\` or `⌘.`.
- Make sure the minimum font size of text in your story is large enough so that it can easily be read by everyone.
- [Provide links](/handbook/tools-and-tips/zoom/#provide-links-rather-than-sharing-while-you-present-or-edit) in the agenda doc that are relevant to your story, such as, issues, epics, Figma files, FigJam boards, and recordings.
- When sharing directly from Figma files and issues, consider preparing an outline of the things you want to cover beforehand, filling in a few details of points you want to mention. Use this as a guide while you speak to make it more linear and easy to follow for the audience.
- Is your internet connection limited? Stop the Zoom camera feed or try [these tips](https://www.canr.msu.edu/od/educational-technology/tips-zoom-slow-connection).
- Ask people to share their questions after a section of your story.
- It's normal to have anxiety when everyone is looking at you. Remember: We're here to support each other, not to judge each other.
- To increase collaboration and transparency after the meeting, consider linking to your recording from the related epics or issues.

For more tips, see the [communication handbook page](/handbook/communication/#presentations).

## Hosting

Product Design Managers take turns hosting the UX Forum. Managers can use the [UX Forum issue template](https://gitlab.com/gitlab-org/gitlab-design/-/issues/new?issuable_template=UX%20Forum) to create a tracking issue for their hosting date. See [how to use templates](https://docs.gitlab.com/ee/user/project/description_templates.html#use-the-templates).

### Recording the sessions

To limit the amount of post-UX Forum editing, please start and stop (not pause) the recording after each topic. This will ensure that each topic saves as an individual clip, which is much faster to edit than a 1-hour clip. Choose "record to computer" each time you record.

### Sharing on GitLab Unfiltered

If you need to edit the videos at all, you can use a video editor like iMovie.

Otherwise:

1. Locate the video clips on your computer.
1. Name the videos with "UX Forum" + the title of the topic.
1. Check with speakers to make sure the video is appropriate for the public (no customer names).
1. Upload the videos to [GitLab Unfiltered](https://m.youtube.com/playlist?list=PL05JrBw4t0Kq89nFXtkVviaIfYQPptwJz).
1. Add the videos to the [UX Forum playlist](https://www.youtube.com/playlist?list=PL05JrBw4t0Kq89nFXtkVviaIfYQPptwJz) and [UX Team playlist](https://www.youtube.com/playlist?list=PL05JrBw4t0KqkW0oPW3n0HqVgKcONVnO5).
1. Set the visibility to Public.
   1. NOTE: If the video content contains items that are un[SAFE](/handbook/legal/safe-framework/) mark the video as Private.
1. Share the YouTube links in `#ux` and `#product` Slack channels with a brief description of each topic.
   1. Add the same update to the Engineering Week-In-Review document. The document is available in the description of our internal [`engineering-fyi` Slack channel](https://gitlab.slack.com/archives/CJWA4E9UG).

#### Helpful tips

- If you cannot find the videos in your Zoom account, reach out to the calendar event owner, as it probably uploaded to their account.
- In iMovie, you can upload a video straight to YouTube, as long as it's under 15 minutes long. But you still have to go to YouTube to select the playlist.
- You can pick a better thumbnail and edit other settings after uploading by going to the [Uploads page](https://studio.youtube.com/channel/UCMtZ0sc1HHNtGGWZFDRTh5A/videos/upload) and selecting your video.
- [More about using YouTube](/handbook/marketing/marketing-operations/youtube/).

### Updating the schedule

After the sessions are over, update the [UX Forum schedule](https://gitlab.com/-/ide/project/gitlab-com/content-sites/handbook/edit/main/-/assets/includes/ux-forum-schedule.md).
