---
title: "UX Research at GitLab"
description: "The UX Research team delivers key and timely insights to drive user-centric innovation, support and influence decisions from design tactics to product strategy."
---
{{< youtube "EQ750KX_6nU" >}}

### Who the UX Research team works with

We works closely with designers, product managers, and developers to ensure that the product meets user needs and expectations. We serve as a bridge between the user and the product team.

### Who we research

The UX Research team researches customers, end users, potential users, stakeholders, competitor users, and specialized user groups to ensure the product meets diverse needs and expectations.

### How the UX Research team works

Using a range of research methodologies (including user interviews, surveys, usability testing, diary studies, and card sorting) we collect raw data on user behaviors, needs, and preferences.

We then apply rigorous data analysis and synthesis to transform this data into valuable insights that inform and shape the design and development of our products.

Note that UX Researchers are **one of the many** GitLab Team Members who conduct user research. Other roles, such as Product Managers and Product Designers, frequently conduct research with guidance from the UX Research team. All Research DRIs are supported by our [UX Research Operations Coordination team](/handbook/product/ux/ux-research-coordination/) to conduct efficient and high-quality research.

If you are planning to lead a research project, you can get started [here](/handbook/product/ux/ux-research/resources-for-research-dris).

### Our two years vision and strategic pillars

Our vision statement consists of two parts:

- **On our impact and scope**: We deliver key and timely insights to drive user-centric innovation, and support and influence decisions from design tactics to product strategy.
- **On our methodology and reach**: Our team excels in impactful research that balances rigour and adaptability, democratizing research, and providing accurate and actionable insights to decision makers across GitLab, from Product to Field.

We focus on 3 strategic themes:

- Create a structured, accessible and impact-driven UX Research ecosystem for all, this includes:
  - Deepen strategic impact of insights
  - Establish insight repository
  - Streamline research Operations
  - Implement global research prioritization
- Cultivate engaged partnerships across the organization, this includes:
  - Communicate & evangelize research
  - Scale research & enable counterparts
  - Collaborate across divisions, and join up insights and share metrics
- Encourage a culture of curiosity and experimentation, this includes:
  - Embrace lean and experimental practices
  - Establish service design as a new function
  - Facilitate workshops for innovation
  - Lead with recommendations

Detailed breakdown of our strategic pillars and our 2 years action plan can be found in [the UXR Vision and Strategy Board](https://www.figma.com/board/ew58pbcIXOGG5Xb2LP9szx/UXR-Vision-and-Strategy-Board?node-id=0-1&node-type=CANVAS&t=hCuDtehJ9pv4q0fM-0) (internal access only).

### Work with UX Research

#### Working with us as a research participant or a research panelist

We want to learn from you! We are always looking for a range of professionals to take part in our studies, and would love to have you sign-up. You can read more about [what to expect as a research participant](https://docs.google.com/presentation/d/1r0WMYS-ZvvEaqRvW3AazdIipCyz8xAynMFnp7PqjDMA/edit#slide=id.g2873bc64769_0_0), and register your interest in [taking part in future research](https://research.rallyuxr.com/gitlab/lp/csmsignup?channel=app).

**What you get in return**:

- **Influence Over Design and Product Decisions**: Your feedback will be heard and considered in future design and product decisions directing anything from feature improvements to product strategy.
- **Smoother Experience and Better Product**: Your insights will help us shape a product that better fits your day-to-day needs, improving your overall experience and productivity.

#### Working with us as a GitLab internal team

We’d love to collaborate with you, gather your perspective, and partner with you to engage our customers. If your team interacts with customers and users as part of your daily role or make decisions that influence the customer/user experience of GitLab products, we’d love to hear from you!. Here’s how you can partner with us:

- **Ensure Your Customers Are Represented in UX Research**: You can nominate customers as research participants by sharing their details in the #ux_reops channel or direct your customers to [the UX Research Panel](https://research.rallyuxr.com/gitlab/lp/csmsignup?channel=app) to register their interest.
- **Share what you know through GitLab User Insight Repository**: Share what you learn about your customers in the #ux_research channel, or connect with a designated UX researcher for specific stages or themes.
- **Identify Areas for Improvement That Need Further Research (unknown)**: If you notice areas that could benefit from deeper exploration, feel free to mention it in the #ux_research channel or contact [the UX researcher for the relevant stage or theme](/handbook/product/ux/ux-research/how-uxr-team-operates/#how-ux-researchers-are-assigned). Providing a related issue for reference would be a bonus!
- **Leverage UX Research Insights to Guide Your Work**: Stay updated by checking out the #ux_research_reports channel for the latest insights. You can also explore [Dovetail](https://gitlab.dovetail.com/start/), our research insights management tool, to search by keywords or watch interview session recordings. You can also consult with [the UX researcher for the relevant stage or theme](/handbook/product/ux/ux-research/how-uxr-team-operates/), to be more informed when making design, product or customer engagement decisions.

**What you get in return**:

- **Informed Decision-Making**: The UX research team provides valuable insights based on user behavior and feedback, helping internal teams make informed, data-driven decisions throughout the product development process.
- **Risk Mitigation**: UX research helps identify potential issues early in the development process, allowing internal teams to address these challenges before they escalate, thereby reducing the risk of costly mistakes or misaligned products.

### Do you have questions about UX Research?

The UX Research team is here for you! Reach out in the #ux_research Slack channel. Below is a full list of our UX Research team handbook content:

#### Conducting UX Research at GitLab

- [Resources for research DRIs](/handbook/product/ux/ux-research/resources-for-research-dris)
- [When to conduct UX Research](/handbook/product/ux/ux-research/when-to-conduct-ux-research/)
- [Defining goals, objectives, and hypotheses](/handbook/product/ux/ux-research/defining-goals-objectives-and-hypotheses/)
- [Problem Validation and methods](/handbook/product/ux/ux-research/problem-validation-and-methods/)
- [Solution Validation and methods](/handbook/product/ux/ux-research/solution-validation-and-methods/)
- [Foundational research](/handbook/product/ux/ux-research/foundational-research/)
- [Strategic research at GitLab](/handbook/product/ux/ux-research/strategic-research-at-gitlab/)
- [UX Research tools/applications](/handbook/product/ux/ux-research/research-tools/)
- [UX Cloud Sandbox](/handbook/product/ux/ux-research/ux-cloud-sandbox/)
- [UX research in the Artifical Intelligence (AI) space](/handbook/product/ux/ux-research/research-in-the-AI-space/)

#### Research methods we use at GitLab

- [Choosing a methodology](/handbook/product/ux/ux-research/choosing-a-research-methodology/)
- [Surveys](/handbook/product/ux/ux-research/surveys/)
  - [Designing your survey](/handbook/product/ux/ux-research/surveys/designing-your-survey/)
  - [Common types of survey questions](/handbook/product/ux/ux-research/surveys/common-types-of-survey-questions/)
  - [Survey question scales](/handbook/product/ux/ux-research/surveys/survey-question-scales/)
  - [Sample sizes for surveys](/handbook/product/ux/ux-research/surveys/sample-sizes-for-surveys/)
  - [Piloting your survey](/handbook/product/ux/ux-research/surveys/piloting-your-survey/)
  - [Qualtrics Tips and Tricks](/handbook/product/ux/ux-research/surveys/qualtrics/)
  - [How to identify low quality data when designing and reviewing your survey](/handbook/product/ux/ux-research/surveys/how-to-identify-low-quality-data-when-designing-and-reviewing-your-survey)
- [Jobs to be Done](/handbook/product/ux/jobs-to-be-done/)
- [Longitudinal studies](/handbook/product/ux/ux-research/longitudinal-studies/)
- [Diary studies](/handbook/product/ux/ux-research/diary-studies/)
- [Mental modeling studies](/handbook/product/ux/ux-research/mental-modeling)
- [Kano Model for feature prioritization](/handbook/product/ux/ux-research/kano-model/)
- [User story mapping](/handbook/product/ux/ux-research/user-story-mapping/)
- [Rapid Iterative Testing and Evaluation (RITE)](/handbook/product/ux/ux-research/rite/)
- [Usability testing](/handbook/product/ux/ux-research/usability-testing/)
- [Usability benchmarking](/handbook/product/ux/ux-research/usability-benchmarking/)
- [Unmoderated usability testing](/handbook/product/ux/ux-research/unmoderated-testing/)
  - [Writing a website usability testing script](/handbook/product/ux/ux-research/writing-usability-testing-script/)
- [UX Bash](/handbook/product/ux/ux-research/ux-bash/)
- [Preference testing](/handbook/product/ux/ux-research/preference-testing/)
- [Facilitating user interviews](/handbook/product/ux/ux-research/facilitating-user-interviews/)
  - [Writing a discussion guide for user interviews](/handbook/product/ux/ux-research/discussion-guide-user-interviews/)
- [How to create a user persona](/handbook/product/ux/persona-creation/)
- [Evaluating navigation](/handbook/product/ux/ux-research/evaluating-navigation/)
  - [Testing navigation: early Solution Validation](/handbook/product/ux/ux-research/early-solution-validation-process-for-navigation/)
    - [First click testing for navigation](/handbook/product/ux/ux-research/first-click-testing/)
      - [Creating a first click study in Qualtrics](/handbook/product/ux/ux-research/creating-first-click-study-qualtrics/)
    - [RITE testing for navigation](/handbook/product/ux/ux-research/using-rite-to-test-navigation/)
    - [Comparative testing for navigation](/handbook/product/ux/ux-research/comparative-testing-for-navigation/)

#### Finding participants

- [How to write an effective screener](/handbook/product/ux/ux-research/write-effective-screener/)
  - [The Common Screener: an efficient way to screen for multiple studies](/handbook/product/ux/ux-research/recruiting-participants/common-screener/)
- [Recruiting participants](/handbook/product/ux/ux-research/recruiting-participants/)
- [Using the UX Research Google Calendar](/handbook/product/ux/ux-research/ux-research-google-calendar/)
- [Attending a research event](/handbook/product/ux/ux-research/attending-a-research-event/)
- [Creating and managing a research participant panel](/handbook/product/ux/ux-research/research-panel-management/)

#### Data and research insights

- [Finding existing research](/handbook/product/ux/ux-research/finding-existing-research/)
- [Collecting useful data](/handbook/product/ux/ux-research/collecting-useful-data/)
- [Using quantitative data to find insights](/handbook/product/ux/ux-research/quantitative-data/)
- [Analyzing and synthesizing user research data](/handbook/product/ux/ux-research/analyzing-research-data/)
- [Analyzing survey verbatim](/handbook/product/ux/ux-research/analyzing-survey-verbatim/)
- [Research insights](/handbook/product/ux/ux-research/research-insights/)
- [Documenting research insights in Dovetail](/handbook/product/ux/dovetail/)
- [Product Analytics for UX Research](/handbook/product/ux/ux-research/product-analytics-for-ux-research/)

#### Templates

- [UX research report template (internal link)](https://docs.google.com/presentation/d/1E8eZpf0T3p6Wf-aEmLjIOFZ_6jdvxc4eySwQ6FnHCZs/copy)
- [User interview note-taking template (internal link)](https://docs.google.com/spreadsheets/d/1_zFp_WXg9jM84dBqv4ARPFTtwPlJGxAi_IVDeED8VFY/copy)
- [Usability testing script template (internal link)](https://docs.google.com/document/d/15tvKXmFUxOT7fo550efuFLQ_ZSDZ2fyuVX_XTQSDBJk/copy)
- [Usability testing rainbow analysis chart template (internal link)](https://docs.google.com/spreadsheets/d/1_bGO9uUxWL5dKe5r1vxTo4J4QAEHfp6mu7VIQDsTu_E/copy)
- [Recommendations alignment Figjam template (internal link)](https://www.figma.com/file/a21e4ULruQzsO4fyhZaQuU/Recommendations-Alignment-Workshop-Template?type=whiteboard&node-id=0-1&t=0LqkJLlll3QfLy41-0)
- [Usability benchmarking alignment Figjam template (internal link)](https://www.figma.com/file/QQ30XlTxTSFx80lq8UpNDo/Usability-Benchmarking-Alignment-Template?type=whiteboard&node-id=0-1&t=0O9YiYfk2KYVNGfv-0)
- [Auto Time on Task (internal link)](https://docs.google.com/spreadsheets/d/1rvhUcNlSzs6STv3EGWDddohxOo3F99ZRHN9W7wjBzIo/copy)

#### Checklists

- [User interviews (internal link)](https://docs.google.com/document/d/1Sg0-4U5W_iop-W1TWDZiECkGkhRkscLgsC-jFUhytBM/copy)
- [Surveys (internal link)](https://docs.google.com/document/d/1Rj8LZuj-ATDKFt19F0dKy6J6-FokChMgCyr7OvfqZ_k/copy)
- [Usability testing (internal link)](https://docs.google.com/document/d/14UWLmbZwVwHkTf1Ncza90WFWk4zLN05fglnNAP4oL9w/copy)

#### UX Research training

- [Interview Carousel - Becoming a better interviewer 15 minutes at a time](/handbook/product/ux/ux-research/interview-carousel/)
- [UX Research shadowing](/handbook/product/ux/ux-research/research-shadowing/)
- [When to conduct UX Research training (internal LevelUp course)](https://levelup.gitlab.com/learn/course/when-to-conduct-ux-research)

#### Resources for UX Researchers

- [How the UX Research team operates at GitLab](/handbook/product/ux/ux-research/how-uxr-team-operates/)
- [UX Researcher pairings](/handbook/product/ux/ux-research/ux-researcher-pairings/)
- [Research prioritization](/handbook/product/ux/ux-research/research-prioritization/)
- [The IP Assignment and when to show it](/handbook/product/ux/ux-research-coordination/IP-Assignment/)
- [How to fill in for a UX Research Operations Coordinator](/handbook/product/ux/ux-research-coordination/research-coordinator-fill-in/)
- [UX Research growth and development](/handbook/product/ux/ux-research/ux-research-growth-and-development/)
- [Non-Disclosure Agreements for UX Research](/handbook/product/ux/ux-research-coordination/NDAs/)
- [How to publish a blog post to encourage community contributions on Actionable Insights](/handbook/product/ux/ux-research/community-contributions-for-actionable-insights/)
- [How to Conduct UX Research Workshops](/handbook/product/ux/ux-research/how-to-conduct-ux-research-workshops)

#### Resources for UX Research Operations Coordinators

- [UXR Operations Coordination at GitLab](/handbook/product/ux/ux-research-coordination/)
- [Recruitment methods](/handbook/product/ux/ux-research-coordination/recruitment-methods)
- [Research participation gratuities](/handbook/product/ux/ux-research-coordination/incentives)
- [Getting the word out about research insights](/handbook/product/ux/ux-research-coordination/shareouts)
- [ReOps procurement best practices](/handbook/product/ux/ux-research-coordination/reops-procurement)
- [Finding SaaS users](/handbook/product/ux/ux-research/finding-saas-users/)
- [UX research recruiting email tips](/handbook/product/ux/ux-research/recruiting-participants/recruiting-email-tips/)

#### Measures and processes the UX Research team is responsible for

- [Product Customer Satisfaction (CSAT) Survey](/handbook/product/ux/performance-indicators/csat/)
- [System Usability Scale](/handbook/product/ux/performance-indicators/system-usability-scale/)
  - [System Usability Scale responder outreach](/handbook/product/ux/performance-indicators/system-usability-scale/sus-outreach/)
- [Assessing Category Maturity](/handbook/product/ux/category-maturity/)
  - [Category Maturity Scorecards](/handbook/product/ux/category-maturity/category-maturity-scorecards/)
  - [Category Maturity - Competitor Comparison](/handbook/product/ux/category-maturity/competitor-comparison/)
- [Tracking research velocity](/handbook/product/ux/ux-research/tracking-research-velocity/)
- [Tracking gold, silver, and bronze UX research projects](/handbook/product/ux/ux-research/tracking-research-projects/)
- [Tracking actionable insights](/handbook/product/ux/ux-research/tracking-actionable-insights/)
