---
title: "Analyzing and synthesizing user research data"
description: "Guidelines for how to analzye survey verbatim"
---

It can be tempting to complete a set of interviews or usability tests and think your research project is done. However, without a process for systematically reviewing and making sense of the data you've collected, you risk leaving valuable insights on the table. The next step is to zoom out and look at your findings through a process called **research synthesis**.

Synthesis helps us take all of the info we've collected, organize it into patterns and themes, and translate those themes into [research insights](/handbook/product/ux/ux-research/research-insights/). At the end of this process, you should have answers to the core research questions you set out to answer and evidence that proves or disproves your [hypotheses](/handbook/product/ux/ux-research/defining-goals-objectives-and-hypotheses/).

Below are some guidelines for how to set yourself up for successful analysis and synthesis while you're conducting research sessions and after your interviews are complete.

### During interviews: Gather data and discuss with your team

While capturing your research data, you'll focus on documenting **observations** (what you saw the users do, or what problems you saw/heard users experience) and **quotes** (verbatim of what the user actually said, in quotation marks). You may also want to make notes on early **interpretations** (what you believe users said or did means) and possible **solutions** (concrete ways to solve the problems identified).

While the bulk of research synthesis happens after you've finished gathering all your data, analysis can start right away. After every user interview, debrief with your teammates who observed the session about what stood out.

Capturing these insights while the session is fresh in your minds makes the overall process much faster and easier. Discussing observations as a group leads to a more thoughtful analysis, reduces [cognitive bias](https://betterhumans.pub/cognitive-bias-cheat-sheet-55a472476b18), and helps your team form a strong shared understanding of the problem space you're investigating.

### After interviews: Find patterns and themes

**Synthesizing user interview data**
Affinity diagramming is one way of finding themes in a collection of ideas, quotes, or observations. This method helps you draw out insights from qualitative data quickly and collaboratively. This is traditionally done in person with sticky notes on a large blank wall or whiteboard. At GitLab, we use a tool called [Figjam](https://www.figma.com/figjam/online-whiteboard/) to recreate this experience remotely.

We use Dovetail to capture notes from each participant session and to store the insights which result from synthesizing the data. As you record data from research sessions, please remove any [personal identifiable information](/handbook/support/workflows/pii_removal_requests/#overview) or PII (such as first and last names). Additionally, Dovetail has the option of allowing you to highlight and tag your notes within the platform.

Aside from Dovetail, Figjam is a helpful tool when you are just learning how to synthesize and analyze your data.

#### 1. Put your notes into Figjam

Don't just copy your notes word for word into a sticky note in Figjam. Read through them and choose the most salient information to create a sticky note from. Best practice is to use one piece of information per sticky note. Have each contributor take one participant to create sticky notes for. At the end of this step, you should have groups of sticky notes for each participant.

#### 2. Cluster the data into themes

Once all your individual notes are in Figjam, begin by grouping similar stickies together. The themes you use should tie directly to your research hypotheses, research goals, and objectives. You can copy these right into your Figjam board so you can keep them top-of-mind while you group individual findings into broader themes. You might also reference the questions listed in this article to ask yourself and your team throughout the synthesis process.

Here are some potential ways to group findings:

- **Equivalence:** "This finding is the same as this other finding."

- **Association:** Around the same area of the experience being analyzed, or "This finding is best considered at the same time as this other finding."

- **Hierarchy:** Larger thematic trends which several findings support, or "This finding is an example of this other finding."

As your groupings start to come together, add text headings that summarize each cluster of similar stickies.

#### 3. Discuss and revise as needed

Organize and reorganize your findings into meaningful categories. See if you need to adjust any of your themes before moving onto the next step.

You also need to check for possible bias. Try "[arguing the other side](https://uxdesign.cc/how-to-look-at-evidence-and-not-translate-it-into-your-own-agenda-9860171b7ba9)." In other words, build a case from your research *against* your key insights to see if they still stand up.

#### 4. Distill findings into insights

Once you're happy with your groupings, distill your findings into [actionable or informative insights](/handbook/product/ux/ux-research/research-insights/) and put them in your [Dovetail](/handbook/product/ux/dovetail/#getting-started-with-dovetail) project. Insights you uncover should come from multiple sources in your research. Depending on how much research you did, the number of insights you uncover may vary.

### Using Dovetail in research synthesis

Dovetail is a powerful tool available to GitLab Team Members which allows you to [upload research data and tag to help distill insights](/handbook/product/ux/dovetail/#the-ux-research-teams-guide-to-documenting-insights-in-dovetail). GitLab Team Members can create their own custom tags or follow the UX Research Team's set of GitLab Global Tags or GitLab Section Tags. More information on the Global Tags and helpful tips on creating custom tags can be found on our [Documenting Research Insights in Dovetail](/handbook/product/ux/dovetail/#tagging-data-in-dovetail) handbook page.
