---
title: "Writing a discussion guide for user interviews"
description: "A discussion guide is a set of questions and topics that you would like to discuss with a participant during a user interview"
---

## How to write a discussion guide

{{< youtube "/sXE8F5Vu1sA" >}}

### Video transcript

A discussion guide is a set of questions and topics that you would like to discuss with a participant during a user interview. It typically consists of an introduction, warm-up questions, exploratory questions and a debrief. Today, I'm going to walk you through how to create a discussion guide.

#### Introduction

Introduce yourself and let the participant know what to expect during the interview. Give them a chance to ask questions. Most people have not been interviewed before, so take some time to put them at ease. Prior to the interview, you should have already obtained written consent to record (through a screener question or email communication). However, it's a good idea to double check verbally that the participant agrees to be recorded and consents to having the recording shared internally at GitLab.

#### Warm-up questions

Start by asking the participant a few easy questions about themselves and their job. This will help the participant get used to the process of answering questions. It's also an opportunity to begin building rapport with the participant, so that they are more inclined to open up to you when you begin asking exploratory questions. Listen closely, their answers may help provide context for any later responses they give. Some warm-up questions you could ask are:

- On the screening survey, you mentioned that you are a DevOps Engineer. How long have you been in that role?
- What kind of work does your company do?
- What does your typical working day involve?
- What tasks do you commonly do within GitLab?

#### Exploratory questions

When you start writing your exploratory questions, you'll want to group questions into common topics, so that your interview naturally flows from one topic to the next. As you begin to structure your questions, allocate time for each topic. This will help keep your interview on track. Move from general questions to more specific questions related to your research goals. For example 'How do you currently go about this task? to 'What's the hardest part about task?' to 'What could be better about how you currently do this?'. At the same time, don't leave your most important questions until the very end in case a user spends more time than you anticipate answering an earlier question. By allocating time to each topic ahead of time, you can assess when you've spent too much time on one topic and need to skip ahead to another topic.

It's okay to ask questions about past experiences, as long as you recognize the limitations of people's memory. The human memory is fallible and it can often be difficult for people to remember specific details. For example, if I asked you whether you had breakfast three days ago? You could probably tell me 'Yes' or 'No'. Yet, if I asked you to recall how long your breakfast took to eat, you'd probably struggle to provide an answer or you might even be tempted to hazard a guess. Ask questions which delve into participants' general experiences and opinions but don't press participants for details they can't provide. Otherwise, they may be tempted to make up their answers.

Participants can't predict the future. If you ask them a question like: 'Would you use this feature?' their response may not be an accurate reflection of what they would actually do. For example, some people might say 'No' because they might not be able to visualise how the feature would work from a description alone. Others might say 'Yes' because they don't want to rule out the possibility that at some point in the future the feature might be useful to them.

Instead of asking people to think about how they might act in the future, ask them about what they are doing in the present and/or what they have done in the past. Instead of asking "Would you use this feature?" ask instead "How are you currently accomplishing this task?" or "How have you accomplished this task in the past?" However, if you are asking about past experience, be aware that there are limitations on memory. As a best practice, don't ask about past behavior that occurred **more than 2 months ago**. In those cases, it's best to stick to asking about the present.

If you're interested in improving your interviewing skills, consider signing up for the [Interview Carousel](/handbook/product/ux/ux-research/interview-carousel/), a lightweight interview training program run by the UX Research team.

#### Debrief

Thank the participant for their time and explain what happens next with the feedback they have given you today. Give the participant a chance to ask any questions about the research. If you are paying a participant for taking part in your study, ensure you share details of how they will be paid and when they can expect payment. Leave your contact details with them in case they have any follow-up thoughts they want to share with you.

#### After your guide is written

Once you have written your discussion guide, you should rehearse and test out your guide with a colleague. This will give you a sense of how long your script will take to run through, and it will help you spot any questions that people may have difficulty answering.

### Discussion guide and interview tips

- Remember your discussion guide is just that: a guide. It's a reference tool to help facilitate conversation.
- If a participant says something interesting that is not covered by your guide, listen to them and explore what they are saying. You may uncover something you hadn't previously considered.
- Active listening is key. You should react to what your participant is saying.
- Ask open ended questions to keep a conversation flowing.
- Remember to probe participant's answers. Ask: Why? Why not? Who? What? Where? When? How?
- Never ask participants what they want.

## Example discussion guide

- [Discussion guide template](https://docs.google.com/document/d/1dQ29KkJOZlwrNkxV9z58lR9bNkG2-lSiJPMUpmsiOTw/copy)

## Example questions for user interviews

**Note:** Don't use all the questions below! Select a couple to build your discussion guide.

### Warm-up questions

- What's your current role?
- What made you become a [job title]?
- How long have you held the role of [job title]?
- What kind of work does your company do?
- What does your typical working day involve?
- What would you say are the top 3 tasks in your role?
- How long have you used GitLab?
- What do you use GitLab for?

### Exploratory questions

- What are you trying to [achieve/get done]? Why?
- How do you currently go about this [task/process]?
- Can you show me how you currently do this [task/process]?
- Has anything about the way you do this [task/process] changed over time? How? Why?
- Do you anticipate [task/process] changing? Why?
- What do you like about [task/process]?
- What's the hardest part about [task/process]?
- What could be better about how you currently do this [task/process]?
- Tell me about the last time you tried to [task/process]
- Why do you keep doing [task/process] Why is it important to you?
- How often do you do [task/process]?
- How often do you experience [problem]?
- What happens before/after you experience [problem]?
- What work-arounds have you implemented to help you with this?
- What are you currently doing to make this [task/process] easier?
- Are you looking for an alternative solution for [task/process]? Why? Why not?
- How does this [task/process] impact other areas of your work?
- Could you describe step by step how you do [task/process]?
- What step is the most time-consuming? Why is that?
- If you could remove one step from the process, which step would it be?
- What other products have you tried?
- How did you hear about these other products?
- Why did you decide to try [product]?
- What made you choose [product] in the end?
- What do you like about [product]?
- What do you dislike about [product]?
- What's the hardest part about using [product]?
- How does the cost of [product] compare to the value it provides?
- How important is [product] to your organization? How would you rate its level of important on a scale of 1 to 10, with 10 being most important?
