---
title: "Foundational research"
---

Foundational research (also referred to as generative research, exploratory research, pathfinding research, or discovery research) attempts to identify and solve a real human problem. This problem should center on a topic or area that has not been clearly defined or explored in the past.

![FoundationalResearchImage](/handbook/product/ux/ux-research/foundational-research/FoundationalResearchImage.png)

This type of research is not necessarily focused on answering questions about the product, but is more about [answering deeper questions from the user perspective](/handbook/product/ux/ux-research/problem-validation-and-methods/#what-is-problem-validation) (for example: how do users search for information within their roles? How do users engage with security tools in their development process?). In other words, it's about understanding people (their actions, motivations, goals) and the contexts in which they live/work. Understanding people and their context helps to reveal users' pain points or problem areas. The insights can be examined in situations such as workshops or ideation sessions to generate new ideas that could help teams address known pain points.

## The purpose of doing foundational research

Foundational research focuses on users' mental models, behaviors, unmet needs, and problem areas. This facilitates a holistic understanding of current and prospective users (who they are, what they believe, how they behave, why they think/feel/act the way they do). By taking an in-depth look at users outside of a single product feature or product area, teams can address more long-term user needs.

## When to conduct foundational research

Foundational research is needed:

- When there is little to no information on a particular topic area.
- To develop a deeper understanding about our users.
- To uncover unknown user problems.
- To keep up with competition.
- To help inform product direction, especially when the future roadmap is not fully defined.
- When you know that a solution currently in place is not working well for users.
- At the early stages of product development, but can be valuable later on to understand the changing contexts and needs of users.

## How foundational research is different from other types of research

Foundational research is different because the research outputs have a greater business impact in the long term. The research process is more intensive because it can involve multiple methodologies within a single study to answer a broad set of research questions.

### Foundational research compared to problem validation research

[Problem validation research](/handbook/product/ux/ux-research/problem-validation-and-methods/#what-is-problem-validation) seeks to learn more about a customer problem. Foundational research is a subset of problem validation that helps to develop a deeper understanding of users to generate solutions.

### Foundational research compared to solution validation research

[Solution validation research](/handbook/product/ux/ux-research/solution-validation-and-methods/) assesses how well a product meets users' needs by examining how users interact with new designs prior to development or the current product. This research is typically done later in the product lifecycle.

Alternately, foundational research helps generate new ideas by answering unknown questions about your users. This goes beyond a product, prototype, or experience to provide high-level feedback that reveals opportunities, which can be tackled within future sprints of a product roadmap.

## Process for proposing foundational research

Before proposing a foundational research project, ask yourself the following questions:

- Is there a business driven reason to conduct this research? In other words, is this research a high priority for the company?
- What do we already know about the topic?
- Which team(s) would benefit from understanding this topic?
- Which team(s) would make strategic decisions based on the research findings?

If the topic is [high priority](/handbook/product/ux/ux-research/research-prioritization/), unexplored, and teams would get value from the research, first create a `research issue` (using the problem validation template) in the [UX research project](https://gitlab.com/gitlab-org/ux-research/-/issues), and then contact your UX researcher to explore next steps. This template should be used because foundational research is an [area within problem validation](/handbook/product/ux/ux-research/problem-validation-and-methods/#what-is-problem-validation).

What are common user research methods associated with foundational research?
Some of the common methods for foundational research include [interviews](/handbook/product/ux/ux-research/facilitating-user-interviews/), [focus groups](https://www.nngroup.com/articles/focus-groups/), [diary studies](/handbook/product/ux/ux-research/diary-studies/), [field studies/contextual inquiries](https://www.nngroup.com/articles/contextual-inquiry/), [competitive testing](https://www.nngroup.com/articles/competitive-usability-evaluations/), and [desk research](https://www.nngroup.com/articles/secondary-research-in-ux/).

## Tips for conducting foundational research

- Foundational research can involve a larger number of user sessions because more data is needed (across various user groups and personas) to ensure the insights are representative of the overall user base. As you conduct sessions, make sure to record and update participants' progress within the recruiting issue. This way, the UX research operations coordinator can assist with payment over the course of the project.
- The [research analysis process](/handbook/product/ux/ux-research/analyzing-research-data/) can take a long time, so be sure to allot enough time to space out the work. You are strongly encouraged to divide up the work amongst team members to make the data analysis process more efficient and to invite unique perspectives when trying to determine potential solutions to uncovered pain points.
- Consider who your audience is for the research. This will determine the most compelling way to share the outcome of the research (in person talks, sharing final documents async). If there are multiple stakeholder groups connected to the research, it can be useful to implement more than one way to communicate the project findings.
- [Make findings actionable](/handbook/product/ux/ux-research/research-insights/) by providing concrete recommendations on how to address user problems, demonstrating how the recommendations can provide value to users, and creating next steps for what will be done after the research is concluded (open `Actionable Insights` issues, work with the product team to prioritize updates within the existing backlog/roadmap, conduct additional research on unanswered questions).

## Examples of foundational research projects

There are a few recent examples of foundational research projects completed by our GitLab team members:

- [Learnability longitudinal study](https://docs.google.com/presentation/d/16hWaDGqkrIg2qQW-uJ7pIDWlwfyDwaXG3q9EXGlXZaI/edit?usp=sharing)
- [Developer engagement study](https://gitlab.com/gitlab-org/ux-research/-/issues/1599)

## Useful information to started

There are several ways to come up with a potential foundational research topic. These include looking at existing information such as internal analytics data (metrics on product usage) or examining open-ended customer feedback ([SUS surveys](/handbook/product/ux/sus-database/), social media posts) for areas that need further exploration.

Another valuable resource for generating research questions is existing research insights (commonly referred to as [desk research](https://www.nngroup.com/articles/secondary-research-in-ux/)). You can examine this data across multiple studies (findings collected on a particular topic or set of related topics) to understand what is still unknown about users.

## Additional resources on foundational research

- [Foundational Research Article: Everything You Need to Know to Run a Successful Study](https://dscout.com/people-nerds/generative-research-complete-guide)
- [LinkedIn Learning: UX Deep Dive - Foundational Research](https://www.linkedin.com/learning/ux-deep-dive-foundational-research/diving-into-foundational-research?autoAdvance=true&autoSkip=false&autoplay=true&resume=false&u=2255073)
- [YouTube Video: Foundational Research Basics](https://www.youtube.com/watch?v=0VbJDMZhcA8)
- [YouTube Video: How to Mix and Match Foundational Research Frameworks](https://www.youtube.com/watch?v=BHR6oZzsy6E)
