---
title: "How to Conduct UX Research Workshops"
description: "The UX Research workshop process at GitLab"
---

UX research workshops are activities that UX Researchers can utilize to collaborate with other team members at various phases of a research project. They can be performed before or after research is conducted to gather consensus from the group.

## Benefits of UX research workshops

UX research workshops are useful because they offer UX Researchers a way to collaborate with their Product teams to plan out a future research study or align on how to tackle users' pain points. They are a very collaborative activity, especially when teams are not co-located or lack a recurring meeting time to focus on a research project.

## Getting started

This handbook page covers the main steps involved to conduct a UX research workshop. If you have any questions about this process, please contact your [UX Researcher](/handbook/product/ux/ux-research/how-uxr-team-operates/#how-ux-researchers-are-assigned). They can assist with setting up and/or leading a UX research workshop for your team.

## Step 1: Select a UX research workshop

There are 5 different types of UX research workshops that can be used whenever a UX Researcher is about to start or finish a project. Within this section, we define each of the workshops and provide links to FigJam templates, which can help UX Researchers with the initial setup process.

*Early phases of research*

- **Research project planning workshop:** A process for coming to a consensus about a future research project direction and vision. This type of workshop is used to obtain stakeholder buy-in before a research effort is started. ([FigJam board template](https://www.figma.com/file/xrI7hK8PrX8z5NgaTZnRbI/Research-Project-Planning-Workshop-Template?type=whiteboard&node-id=0-1&t=iGsKsCszM2IkhEBQ-0))
- **Usability benchmark kickoff workshop:** Similar to a research planning workshop, but with a focus on the main jobs to be done (JTBD) statements, user tasks, recruiting criteria, research questions, and metrics for an upcoming benchmarking study. ([FigJam board template](https://www.figma.com/file/qB8dve7WnicflTG8UTykp5/Usability-Benchmarking-Kickoff-Workshop?type=whiteboard&node-id=0-1&t=xwLSPezaqJXQLMOB-0))

*Late phases of research*

- **Research recommendations alignment workshop:** A process for coming to a consensus with a Product team on which user pain points, identified through the research, the team should fix and how to fix them. This type of workshop helps to eliminate any surprises in a final research report since recommendations are discussed and agreed upon ahead of time by the team. ([FigJam board template for async based workshop](https://www.figma.com/file/a21e4ULruQzsO4fyhZaQuU/Recommendations-Alignment-Workshop-Template?type=whiteboard&node-id=0-1&t=BPMkNjhREFLGyYzS-0); ([FigJam board template for sync based workshop](https://www.figma.com/file/bNZAvYidhtMXJUFl7PeO88/Recommendations-Alignment-Workshop-(Sync-based)-Template?type=whiteboard&node-id=0-1&t=SttgOyzOTq40QJpg-0)))
- **Research retrospective workshop:** An open dialog between UX Researchers and/or stakeholders that is used to reflect on the positives and negatives of a research project. Also, this workshop is used to identify areas of improvement and action items for future related projects. ([FigJam board template](https://www.figma.com/file/UwcCFflMdTKU9yuODH14Vm/Research-Retrospective-Workshop-Template?type=whiteboard&node-id=0-1&t=R6aJN08Ek2aQOtTR-0))
- **Research summary workshop:** A way to collaboratively analyze research data within the team as it is obtained, so stakeholders are able to contribute to the final research output. This is used to increase stakeholder buy-in with the research findings and help reduce the amount of time spent on data analysis. This type of workshop helps to eliminate any surprises in a final research report since recommendations are discussed and agreed upon ahead of time by the team. ([FigJam board template](https://www.figma.com/file/7Hln5gBmLIGlpjKCwbV7Pf/Research-Summary-Workshop-Template?type=whiteboard&node-id=0-1&t=g90bNFAAgEeTBYxa-0))
- **Usability Benchmark recommendations alignment workshop:** After running a [Usability Benchmark](/handbook/product/ux/ux-research/usability-benchmarking/) this is a process for running a recommendations alignment workshop with your stakeholders. ([FigJam board template](https://www.figma.com/file/QQ30XlTxTSFx80lq8UpNDo/Usability-Benchmarking-Alignment-Template?type=whiteboard&node-id=0-1&t=IUk08tJPc7mocTdS-0))

If the UX Researcher determines a UX research workshop would be best for their project, they should allocate approximately **1 week** of setup time for a workshop. The following sections highlight the main aspects to consider ahead of time.

## Step 2: Choose between async or sync workshops

At GitLab, we lean towards [async communication by default](/handbook/values/#bias-towards-asynchronous-communication), so we recommend utilizing async workshops whenever possible. However, there are some situations when sync workshops may work better for your use case. The table below highlights some of the main differences between async and sync workshops.

*Pros of async workshops*

- Allows more attendees to contribute across a variety of timezones since there is no set meeting time.
- Provides attendees the flexibility to complete the workshop tasks on their own time.
- Workshop tasks are broken up into smaller more manageable chunks instead of having to be completed all at once.

*Pros of sync workshops*

- Allows attendees to have open discussions and get questions answered in real time.
- Workshop tasks can be completed in a faster time frame since everything is condensed into one or a few large scale meetings.

## Step 3: Determine time needed to complete workshops

### Async workshops

Any async tasks assigned to attendees should include a clear due date with ample time to complete. In most cases, **1-2** weeks of notice should suffice. There will be times where a due date conflicts with an event (e.g., company or country holiday, milestone deadline, etc.). When messaging the attendees, be open to feedback about the proposed due date and be willing to compromise to ensure greater overall participation.

### Sync workshops

The length of a sync workshop depends on the size and scope of the effort. UX Researchers can estimate the amount of time needed in general by thinking through how long the individual workshop tasks should take. Since there will often be group discussions happening during a sync workshop, it is better to overestimate the amount of time allotted to each task, so UX Researchers don't end up rushing through their planned agenda.

When sync workshops are expected to last longer than **2 hours**, UX Researchers need to include ample breaks or consider splitting up the workshop across multiple days to avoid burning out their attendees. It is important that attendees are able to stay focused in the workshop. By limiting what you ask attendees to accomplish in a single sync session, UX Researchers will get a higher quality of output from them.

## Step 4: Identify list of workshop attendees

UX Researchers need to ensure that they are being inclusive of any team members who can assist with conducting the research and implementing changes from the uncovered actionable insights. The following roles should be considered when setting up a new research workshop:

- Product Managers
- Product Designers
- Engineering Managers
- Frontend Engineers
- Backend Engineers
- UX Researchers who support other teams (if applicable)
- UX Research Managers (if applicable)

If UX Researchers are unsure about who to invite to the workshop, they can ask the team's Product Manager or their UX Research Manager for guidance.

## Step 5: Provide workshop materials

When setting up a research workshop, attendees need to have context about what they are being asked to do, so they can understand how they can best support the effort. UX Researchers should consider providing various resources and giving explicit pre-work upfront to attendees, so they can start the workshop feeling fully prepared. The list below can be used to advise on what kinds of resources or pre-work to include:

- Research report
- Research issue/epic
- Highlight reels of relevant research clips (ex: usability feedback, participant interviews) contained within Dovetail
- FigJam board with instructions
- YouTube video(s) with instructions

At GitLab, we lean towards overcommunication to ensure that attendees are aware of the upcoming workshop. Thus, we encourage you to share resources and pre-work in multiple applications (for example: Slack, GitLab, Google Calendar), so attendees do not miss any details about the workshop.

### Async workshop kickoff message example

![asyncstartingworkshopmessage](asyncstartingworkshopmessage.png)

### Sync workshop kickoff message example

![syncstartingworkshopmessage](syncstartingworkshopmessage.png)

#### Make the FigJam board available to team members

This [handbook page](/handbook/product/ux/product-designer/#figma--figjam) has information on how to set the appropriate level of access for your FigJam boards.

## Step 6: Create and share workshop outcomes

When the workshop is complete, the UX Researcher should review the FigJam board to determine if there is some synthesis required before communicating any final outcomes. In most cases, there will be some additional analysis needed to identify themes or reorganize the workshop data into a final state.

From there, the UX Researcher can broadly share the outcome of the workshop with attendees and other interested teams. It is recommended to communicate outcomes through GitLab issue comments and relevant Slack channels (#UX_Research_Reports, #Product, #UX).

Some types of workshop outcomes include:

- Actionable insight issues
- Completed FigJam board
- Summary of insights or learnings
- Retrospective issue threads
- Video recordings of workshops (sync workshops only)

### Async workshop outcome message example

![asyncworkshopoutcomemessage](asyncworkshopoutcomemessage.png)

### Sync workshop outcome message example

![syncworkshopoutcomemessage](syncworkshopoutcomemessage.png)
