---
title: "Problem validation and methods"
description: "How to conduct problem validation research at GitLab"
---

At GitLab, we practice both Problem Validation research and [Solution Validation](/handbook/product/ux/ux-research/solution-validation-and-methods/) research, depending on the questions we need answers to and where we are in the design process. The end result of these methods is a high degree of confidence which results in a better overall user experience. Generating solutions, developing the product experience, and launching to the market is much more effective when we start with a deep understanding of our customer problems. We leverage [Opportunity Canvases](/handbook/product/product-processes/#opportunity-canvas) to track quick iterations on levels of confidence, hypotheses, and lessons learned as our learning about the problem evolves.

### What is problem validation?

Problem validation research seeks to provide decision makers with a well understood and clearly articulated customer problem. At GitLab, problem validation encompasses [foundational research](/handbook/product/ux/ux-research/foundational-research/) as well as descriptive and informative research.

- **Foundational research** helps develop a deeper understanding of users to uncover opportunities for solutions and innovation.

- **Descriptive and informative research** begins with a problem statement in mind and is used to gain a detailed understanding of the context of the problem.

### When to use problem validation?

Problem validation happens [earlier on in the product life cycle](/handbook/product/ux/ux-research/when-to-conduct-ux-research/#design-the-right-thingproblem-validation) when we want to get insight into a problem and scope down the focus of a problem.

**Foundational research** is done when we don't have a good understanding of what the problem is we need to solve. Often this occurs at the very beginning of the product design process. The purpose is to formulate a problem to solve and have a decent level of confidence that the problem is a relevant one.

**Descriptive and informative research** starts with a problem statement, which provides us a concrete problem to solve. This research is used to gain a better understanding of the context we are trying to solve for through our design and is imperative to fill the knowledge gaps of the solution environment by what our participants know.

When you are conducting a problem validation research effort, make sure to apply the `UX Problem Validation` label to the research issue.

### What questions can problem validation answer?

**Foundational research** provides answers to these questions:

- Is there a problem? If so, what is it?
- Who are the users?
- What are the users' mental models as they relate to the problem(s)?

**Descriptive and informative research** provides answers to these questions:

- What are the pain points today?
- How do users feel about it?
- How is this done today?
- Why is it done this way?

### Problem validation methods & when to use them

When choosing the right method for problem validation research, first ask yourself if you need foundational or informative research.

- **Foundational research** helps develop a deeper understanding of users to uncover opportunities for solutions and innovation.
- **Descriptive and informative research** begins with a problem statement in mind and is used to gain a detailed understanding of the context of the problem.

Problem validation research is not only conducted with end users. Often, sales, support, and CSMs (technical account managers) can offer valuable insights into customer behavior. They typically interact with a large number of customers and have a well developed understanding of what needs customers have and what issues they have faced.

### Foundational research methods

To choose the right ***foundational*** research method, you need to identify the purpose for your research. Ask yourself ***"Why am I doing this research?"*** Your answer will help you choose which method to use. You should also ask yourself [how much detail you need, what kind of participants you need, and the fidelity of insight you require](/handbook/product/ux/ux-research/choosing-a-research-methodology/).  If you are still unsure, please reach out to your UX Researcher.

|                                                  Overall Purpose for Research                                                  |            Research Method            |
|:-------------------------------------------------------------------------------------------------------------------------------|:--------------------------------------|
| <ul><li>Understand a phenomenon</li> <li>Expand a theory</li> <li>Challenge the dominant view</li> <li>Propose a new theory</li> <li>Justify the need for a new technology</li></ul>| [Diary study](/handbook/product/ux/ux-research/diary-studies/)<br> [Contextual inquiry](https://www.nngroup.com/articles/contextual-inquiry/)        |
| <ul><li>Redesign a product</li> <li>Make a technology more usable/accessible/inclusive</li> <li>Innovate</li> <li>Solve a new problem</li></ul>                            | [Diary study](/handbook/product/ux/ux-research/diary-studies/) <br>[Contextual inquiry](https://www.nngroup.com/articles/contextual-inquiry/)        |
| <ul><li>Motivate change</li> <li>Empower people</li> <li>Increase visibility and scrutiny</li> <li>Apply a critical lens</li></ul>                                        | [Contextual inquiry](https://www.nngroup.com/articles/contextual-inquiry/)<br> [In-depth interview](https://www.usability.gov/how-to-and-tools/methods/individual-interviews.html) |

### Descriptive and informative research methods

To choose the right ***descriptive and informative*** research method, ask yourself, ***"What do I need to understand better?"*** Your answer will help you choose which method to use. If you are still unsure, please reach out to your UX Researcher.

|                                                  What I need to understand better                                                  |            Research Method            |
|:-------------------------------------------------------------------------------------------------------------------------------|:--------------------------------------|
| <ul><li>How users perform in their natural environment</li> <li>What tools they use</li> <li>How their space is set up</li></ul> | [Contextual inquiry](https://www.nngroup.com/articles/contextual-inquiry/)        |
| <ul><li>What users' attitudes, beliefs, desires, and experiences are</li></ul>                             | [In-depth interview](https://www.usability.gov/how-to-and-tools/methods/individual-interviews.html)        |
| <ul><li>How users complete tasks over an extended period of time (hours, days or weeks)</li></ul>                                         | [Diary study](/handbook/product/ux/ux-research/diary-studies/) |
| <ul><li>How my customers might solve product problems for themselves</li></ul>                                          | [Participatory design](https://uxmag.com/articles/participatory-design-in-practice) |
| <ul><li>What the entire experience is from the user's standpoint</li></ul>                                          | [User journey mapping](https://www.nngroup.com/articles/journey-mapping-101/) |

Check out our guidance for [writing your discussion guide](/handbook/product/ux/ux-research/discussion-guide-user-interviews/) and [facilitating user sessions](/handbook/product/ux/ux-research/facilitating-user-interviews/) for In-depth interviews.

You can also frame questions using the [Taxonomy of Cognitive Domain](https://knowledgejump.com/hrd/bloom.html), which explains how certain verbs target particular thought processes. This is a great way to expand your questioning in order to help trigger specific responses from participants.

| Domain        | Critical Thinking Process            | Verbs to use                                  | Sample Questions                                                                                                                                                                                                                    |
|---------------|--------------------------------------|-----------------------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| Knowledge     | Remembering <br>Memorizing <br>Recognizing   | Who <br>What <br>When <br>Where <br>How                       | <ul><li>What do you like about how you currently [problem/task]?</li> <li>What is the biggest pain point related to [problem/task]?</li> <li>Tell me about the last time you tried to [problem/task].</li> <li>How much time do you typically spend on [problem/task]?</li></ul>  |
| Comprehension | Interpreting <br>Translating <br>Describing  | Explain <br>Outline <br>Distinguish <br>Compare <br>Define    | <ul><li>Why is [problem/task] important to you? </li></ul>                                                                                                                                                                                           |
| Application   | Problem-solving <br>Applying information | Show <br>Use <br>Complete <br>Classify <br>Relate             | <ul><li>Show me how you currently go about [problem/task].</li></ul>                                                                                                                                                                                  |
| Analysis      | Separating <br>Finding structure         | Contrast <br>Categorize <br>Identify <br>Separate <br>Diagram | <ul><li>What type of workarounds have you created to help with [problem/task]?</li> <li>What do you like or dislike about these other products or tools?</li> <li>What's the hardest part about [problem/task]?</li></ul>                                               |
| Synthesis     | Creating <br>Combining                   | Create <br>Imagine <br>Design <br>Propose <br>Invent          | <ul><li>Create your ideal pipeline status page. Explain your design.</li></ul>                                                                                                                                                                        |
| Evaluation    | Judging <br>Resolving                    | Select <br>Decide <br>Prioritize <br>Rate <br>Discuss         | <ul><li>Rank the following features in order of their usefulness to you in completing your tasks. Explain your answers. </li></ul>                                                                                                                    |
