---
title: Resources for Research DRIs
description: "All you need to know to run a research study at GitLab."
---

## Getting started

UX Researchers are one of the many GitLab Team Members who conduct user research. Other roles, such as Product Managers and Product Designers, frequently conduct research with guidance from the UX Research team. All Research DRIs are supported by our [UX Research Operations team](/handbook/product/ux/ux-research-coordination/) to conduct efficient and high-quality research.

### Who is the Research DRI?

- The Designated Research Individual (DRI) is the primary point of contact for overseeing and managing research projects.
- In GitLab, **anyone can be the DRI of a UX Research project**. If the Research DRI is not a UX Researcher, they are partnered with a UX Researcher acting in a supporting role.
- They ensure research efforts align with the project goals and stakeholder expectations.

### Responsibilities of a Research DRI

- Act as the central coordinator for research-related activities.
- Define the scope and objectives of research initiatives.
- Ensure research outcomes address the key questions and provide actionable insights.
- Communicate findings effectively to stakeholders.
- Advocate for user needs and evidence-based decision-making in project development.

## Research Process

### How to Plan Research

Planning for research in GitLab is no different than in any other places. Research DRIs pair up with their corresponding UX Researchers on the following steps:

- **Identify Goals**: Determine what the research aims to achieve and define success criteria.
- **Stakeholder Alignment**: Collaborate with key stakeholders to clarify the scope and ensure alignment.
- **Select Methods**: Choose appropriate qualitative or quantitative research methods based on objectives.
- **Create a Timeline**: Establish key milestones and deliverables.
- **Recruit Participants**: Identify the target audience and develop a plan for recruiting research participants.
- **Prepare Materials**: Develop research guides, scripts, and data collection tools.
- **Conduct Research**: Execute the plan while ensuring ethical and unbiased practices.
- **Analyze Results**: Synthesize findings into actionable insights.
- **Share Findings**: Present results in a format tailored to the audience (for example - reports, presentations, blueprints, dashboards).

### How to Set Up Research Projects the GitLab Way

GitLab is an async-first and remote-first company. We use the **GitLab UX Research Project** to track all research work and research operations efforts. Every project is a collaboration between the Research DRI, UX Researcher and Research Operations team.

#### Roles and Responsibilities by Phases

**1. Scoping**

- The Research DRI documents all context and goals in a **Research Issue**, and assign it to themselves, and their UX Research partner (if they are not UXR themselves).
- They then discuss with the UXR to assess and determine if research is necessary (more on [how UXR prioritize our work](/handbook/product/ux/ux-research/research-prioritization)).
  - If yes, they collaborate on the issue, set priorities, agree on support level, and due date.
  - If no, the UX Researcher will close the issue, and label it as "closed::will not do".

**2. Drafting**

- The Research DRI and the UX Researcher draft **the research plan, the screener, and the script**.
- All documents are peer reviewed, either by the UX Researcher partnering with the DRI, or another UX Researcher, if the DRI is a UXR themselves.

**3. Recruitment kick-off**

- Once the screener is peer reviewed, the Research DRI creates **the recruiting request issue**.
- The issue is then assessed by the Research Operations team on the recruitment complexity and assigned a recruitment grade.
  - If Grade 1, or Grade 2: The DRI can self-serve the recruitment by following a simple How-To guide provided by the Research Operations team.
  - Otherwise, the Research Operations team will set up and launch the recruitment.

**4. Inviting Participants and Conducting the Research**

- The Research DRI can monitor in real time whether the quota has been met directly in our recruitment tool.
- For Grade 1 or 2 recruitment requests, the DRI can invite participants for study themselves.
- For other recruitment requests, the Research Operations team does the invite instead.

**5. Paying out**

- With in 1-2 business days of a session or the study's completion, the Research DRI should inform the Research Operations team, and the UX Researcher they partnered with if they are not UXR themselves.
- If the DRI is a UX Researcher, they can pay out incentives for studies they lead.
- If the DRI is not a UX Researcher, the Research Operations team will pay out the incentives.

**6. Analyzing and Reporting**

- The Research DRI, and their UX Researcher partner if applicable, synthesise findings, validate key takeaways, and create the report.
- Though Google Slides is the most popular format, the report can really be in any form, for example, a doc, an issue, a board, or an diagram.
- It should be put through a peer review process in the ux_research_team_lounge channel. The peer review may results in further analysis.
- The final report is shared in the ux_research_reports channel (using the template in the research issue itself), and any other relevant channels and sync meetings.
- It is expected that stakeholders and / or the Research DRI will follow up the report by identifying and issuing actionable insights for the Product and Design team to action on.

#### Useful to know

- A research project may be put in the backlog due to the team's capacity constraints. For more information on how we make that decision, see [how UXR prioritize our work](/handbook/product/ux/ux-research/research-prioritization).
- A research issue may be closed / terminated before being turned into an actual project, if we agree that the research is not needed.
- The Research Operations team only support research recruitment requests of projects that have been vetted by a UX Researcher.

## Templates and Tools

- [Screening Question Repository](https://docs.google.com/document/d/1v8_a3DH9UKhakn61Z1vFXUT-IOAPC6-FwJegaquYUS4/edit?usp=sharing) (internal access only)
- [Research Issue Template](https://gitlab.com/gitlab-org/ux-research/-/blob/master/.gitlab/issue_templates/Research%20Issue.md?ref_type=heads)
- [Recruiting Request Template](https://gitlab.com/gitlab-org/ux-research/-/blob/master/.gitlab/issue_templates/Recruiting%20request.md?ref_type=heads)
