---
title: "Solution Validation and methods"
description: "Solution validation research critically assesses if the product/feature/design has indeed solved the problem that was initially intended to be solved"
---

At GitLab, we practice both Problem Validation and Solution Validation research, depending on the questions we need answers to and where we are in the design process. The end result of these methods is a high degree of confidence that results in a better overall user experience.

### What is Solution Validation?

After identifying and understanding a problem, its context, and the people around it (also known as [problem validation](/handbook/product/ux/ux-research/problem-validation-and-methods/)) the next step is to learn which solutions will work and which ones do not. Solution validation research critically assesses if the product/feature/design has indeed solved the problem that was initially intended to be solved.

### When to use Solution Validation?

Solution validation happens [later on in the product life cycle](/handbook/product/ux/ux-research/when-to-conduct-ux-research/#design-things-rightsolution-validation) when we want to get feedback on potential solutions or solutions made available to users.

Solution validation research is conducted after we have a working design or prototype that was created to solve the problem(s) discovered in Problem Validation research. It is not necessary for the design or prototype to be high fidelity, it only needs to be able to support the task(s) it was designed for.

You can and should conduct solution validation research when confidence in the proposed solution isn't high, as it can help identify issues that may have been missed during other stages of the project. A great way to increase the confidence in your solution is to base design decisions on prior user research.

Apply the `UX Solution Validation` label to your research issue in the GitLab UX Research project.

### What questions can Solution Validation answer?

- How do participants leverage the new product/feature/design to achieve a task?
- What pain points exist?
- What other information should be made available to ensure task success?
- Does the product/design/feature meet the user's expectations?
- Which design allows the best task completion?
- How does the new product/design/feature impact user's existing workflows?

### Different Solution Validation research methods

When choosing the appropriate methodology for your research question, there are [multiple factors](/handbook/product/ux/ux-research/choosing-a-research-methodology/) to consider.

If you choose to conduct Usability Testing, take advantage of our tips on how to write a [usability testing script](/handbook/product/ux/ux-research/writing-usability-testing-script/). We also have an [unmoderated usability testing tool](/handbook/product/ux/ux-research/unmoderated-testing/), UserTesting.com.

There is a [UX Cloud Sandbox](/handbook/product/ux/ux-research/ux-cloud-sandbox/) which is a reserved instance of GitLab for UX testing and research. The referenced handbook page has everything you need to get started, and there is also a #ux-cloud-sandbox Slack channel to reach out to for help.

If you want help creating a pristine test environment separate from the sandbox be sure to reach out to the [Demo Systems](/handbook/customer-success/demo-systems/) group on the #demo-systems Slack channel. They can create a demo environment for users and help build any particular parameters needed for your testing environment. Be aware that setting up a test environment for a research study this way can be time consuming and difficult.

To choose the right **solution validation** research method, you need to identify the purpose for your research. Ask yourself ***"What information do I need to learn to increase my confidence in the design?"*** Your answer will help you choose which method to use. If you are still unsure, please reach out to your UX Researcher.

|                                                  Overall Purpose for Research                                                  |            Research Method            |
|:-------------------------------------------------------------------------------------------------------------------------------|:--------------------------------------|
| <ul><li>Evaluate a change to a feature and/or process</li> <li>Evaluate how well a current design supports user's goals</li></ul> | [Usability Testing](/handbook/product/ux/ux-research/usability-testing/)        |
| <ul><li>Understand how the current information architecture performs</li> <li>Learn if the current labels make sense to users</li> <li>Learn if users can find the information they need easily and quickly</li></ul>                           | [Tree Testing](https://www.optimalworkshop.com/101guides/tree-testing-101/tree-testing-overview) <br>[Card Sorting](https://www.usability.gov/how-to-and-tools/methods/card-sorting.html)        |
| <ul><li>Identify usability concerns within a specific workflow</li> <li>Scope and track the effort of addressing usability concerns within a specific workflow</li></ul>                                         | [UX Scorecard](/handbook/product/ux/ux-scorecards/) |
| <ul><li>Verify that the first click a user makes on an interface is the intended starting point for a given workflow or a navigation element</li></ul>                                          | [First Click Testing](/handbook/product/ux/ux-research/first-click-testing/) |
