---
title: "Strategic research at GitLab"
---

### What is Strategic research?

Strategic research is focused on answering [future facing](/handbook/product/ux/product-design/ux-roadmaps/#timeframe) questions about users that help inform the long term product direction and roadmap. This kind of research can consist of one or more connected projects to better understand a larger topic area. Usually, the topic is broad enough to cover multiple stage groups and/or stages. Thus, strategic research can be [high impact](https://uxdesign.cc/how-to-be-a-more-strategic-55915d8e9ef7) for the product teams and company as a whole.

{{< youtube "pYJEiC9Cs-A" >}}

We can use Strategic research to:

- Understand how to apply a solution across different territories or groups of people. For example, consider how a different industry, like lawyers curating legal documentation, could leverage source control management for versioning.
- Explore additional constraints to the current problem to make it more future proof -- for example, adding the number of concurrent users to support on a feature.
- Consider upstream and downstream experiences -- for example, enhancing the Verify experience for GitLab users by using Auto DevOps to help them get started more easily with Continuous Integration.
- Identify emerging market trends. For example, if customers are signaling an interest in their maturity for adopting DevOps, uncover ways can GitLab coach people in their maturity using Machine Learning or AI.

### How does GitLab think about Strategic research?

**Strategic research is research that is:**

- Conducted to directly inform the strategy of a team and/or organization
- Aimed at answering broader research questions, not specific to a single stage area or feature
- More closely tied to [problem validation](/handbook/product/ux/ux-research/problem-validation-and-methods/) than [solution validation](/handbook/product/ux/ux-research/solution-validation-and-methods/)
- Independent from the monthly release cycle
- Focus is 6 months to 3 years ahead to best support the long term product roadmap

**What it is NOT:**

- [Solution validation](/handbook/product/ux/ux-research/solution-validation-and-methods/)
- Specific to a single stage group (in most cases)
- [Problem validation](/handbook/product/ux/ux-research/problem-validation-and-methods/) research tied to a specific issue/feature

**What does Strategic research look like?**

- Informs the UX and/or product direction
- Spans the user journey, rather than product group
- Seeks to understand and challenge current assumptions of feature functionality
- Engages cross-stage or multi-stage stakeholders
- Defines unmet needs
- Results in the addition, refinement, or removal of personas

**How is Strategic research measured?**

- Success will be measured by the impact of the research, at the project level.  As strategic research matures at GitLab, we will look for common measures of success that could be applied to all strategic research projects.

**Examples of Strategic research topics:**

- Understanding stage usage trends
- Expanding understanding of our customers' motivations, goals, challenges, and needs
- Identifying our customers' biggest IT initatives/goals
- Understanding how GitLab can overcome DevOps adoption pains
- Understanding more about cross-stage use cases and workflows
- Identifying ways Ops can drive adoption across multiple stages and stage groups
- Creating [Actionable Insights](/handbook/product/ux/ux-research/research-insights/) connected to cross-stage group issues to be scheduled in the next 1 year

**Examples of Strategic research from recent projects:**

1. [Release Manager Persona Addition](https://gitlab.com/gitlab-org/ux-research/-/issues/316) was a great example of a cross-stage and multi-group strategic research effort that resulted in an update to the [Roles and Personas page](/handbook/product/personas/). This positively impacted the entire Ops Section and helped us reach new audiences in the Ultimate tier.
1. [KubeCon Ops Product Direction Survey](https://gitlab.com/gitlab-org/ux-research/-/issues/1740) was a large scale project that was able to inform the [future product roadmap](https://about.gitlab.com/blog/2022/05/31/the-kubecon-summary-from-a-product-perspective/) within Ops. This was done through obtaining valuable feedback about what CI/CD workflows are most challenging for GitLab users and learning what perference users had in mind for their ideal secrets solution.

### Strategic research outputs

The outputs from Strategic Research can be found in issues, changes made to documentation, and in published changes to a category direction page (which includes 1 year and 3 year visions), such as:

- [GitLab Stage Group 1-year Plans](https://about.gitlab.com/direction/ops/#one-year-plans)
- [GitLab 3-year strategy](https://about.gitlab.com/direction/#3-year-strategy)
- [GitLab's Direction Personas](https://about.gitlab.com/direction/#personas)

### Resources for Strategic research

- [Developing Research Hypothesis](https://dovetailapp.com/projects/1c8ab3b2-5804-4f33-b2d7-80a7420f36cb)
- [New Persona Template](https://dovetailapp.com/projects/922698a3-e770-45bb-8fe1-6aee240f1df9)
