---
title: "UX Resources"
description: "This page includes information about UX Resources to help you do your job as a product desginer at GitLab."
---

This page includes information about UX Resources to help you do your job. It is not intended to be an all-inclusive list or to limit the methodologies or approaches you might take in your daily work. If you believe that something useful is missing, please submit an MR!

## UX team workflows

- [Product Designer workflows](/handbook/product/ux/product-designer/)
- [UX Researcher workflows](/handbook/product/ux/ux-research/)
- [Technical Writing workflows](/handbook/product/ux/technical-writing/workflow/)

## UX Department Google Calendar

We use the shared [UX Department Google Calendar](https://calendar.google.com/calendar/embed?src=gitlab.com_9psh26fha3e4mvhlrefusb619k%40group.calendar.google.com) (link is only available to GitLab employees) to advertise upcoming meetings and events. Anyone in the UX Department can add events to this calendar but only managers can make changes to events and manage sharing. These invites are only viewable by GitLab employees.

To add the UX Department Calendar to your list of calendars:

1. Go to your [calendar](https://calendar.google.com/)
1. Scroll the left sidebar down to `Other calendars`
1. Press on `+`
1. Select `Subscribe to calendar`
1. Enter in the search field `gitlab.com_9psh26fha3e4mvhlrefusb619k@group.calendar.google.com` and then press enter on your keyboard

NOTE: Please do NOT remove any meetings from this calendar or any other shared calendars, as it removes the event from everyone's calendar.

## Design resources

The following resources are intended primarily to help Product Designers.

### GitLab Design project

The GitLab design project is primarily used by the Product Design team to document workflows and processes. For details, please visit the project [README](https://gitlab.com/gitlab-org/gitlab-design/blob/master/README.md).

- [View the project](https://gitlab.com/gitlab-org/gitlab-design/)

### YouTube Channels

- [UX Team](https://www.youtube.com/playlist?list=PL05JrBw4t0KqkW0oPW3n0HqVgKcONVnO5)
- [UX Scorecards](https://www.youtube.com/playlist?list=PL05JrBw4t0KrDmSVDZfwW0jxOQyl1wW9G)
- [UX Forum](https://www.youtube.com/playlist?list=PL05JrBw4t0Kq89nFXtkVviaIfYQPptwJz)
- [GitLab Design Talks - Iteration](https://youtube.com/playlist?list=PL05JrBw4t0KpgzLWbRCXf8o7iap-uoe7o)
- [GitLab Design Talks - Collaboration](https://www.youtube.com/playlist?list=PL05JrBw4t0KrER807JktsL-addVZa4N0-)
- [GitLab Design Talks - Design Leadership & Career Development](https://youtube.com/playlist?list=PL05JrBw4t0KqmiCAEF-Bb7VD4YWUuA_Nf)

### Pajamas Design System

The GitLab Design System, [Pajamas](https://design.gitlab.com), was developed to increase iteration speed and bring consistency to the UI through reusable and robust components. This system helps keep the application [DRY](https://en.wikipedia.org/wiki/Don%27t_repeat_yourself) and allows designers to focus their efforts on solving user needs, rather than recreating elements and reinventing solutions. It also empowers Product, Engineering, and the Community to use these defined patterns when proposing solutions.

- [Visit design.gitlab.com](https://design.gitlab.com)
- [View the Pajamas UI Kit on Figma](https://www.figma.com/community/file/781156790581391771)
- [View the project](https://gitlab.com/gitlab-org/gitlab-services/design.gitlab.com)
- [View dev object model (video)](https://www.youtube.com/watch?v=GMCS1sBzw9I&feature=youtu.be)

### SVGs

Our SVG repository manages all GitLab SVG assets by creating an SVG sprite out of icons and optimizing SVG-based illustrations.

- [SVG Previewer](https://gitlab-org.gitlab.io/gitlab-svgs/)
- [View the project](https://gitlab.com/gitlab-org/gitlab-svgs)

### Jobs to be Done (JTBD)

We use the JTBD framework for viewing products and solutions in terms of the jobs customers are trying to achieve. It's about understanding the goals that people want to accomplish. JTBD is used throughout the design process to determine scope, validate direction, evaluate existing experiences with [UX Scorecards](/handbook/product/ux/ux-scorecards/), and assess our [Category Maturity](https://about.gitlab.com/direction/#maturity) with [Category Maturity Scorecards](/handbook/product/ux/category-maturity/category-maturity-scorecards/).

- [JTBD Overview](/handbook/product/ux/jobs-to-be-done/)
- [JTBD Deep Dive](/handbook/product/ux/jobs-to-be-done/)
- [Mapping JTBD](/handbook/product/ux/jobs-to-be-done/mapping-jobs-to-be-done/)

### Design Reviews

View how we collect [synchronous and asyncrhonous design feedback](/handbook/product/ux/product-designer/#design-reviews).

### Tools

**Figma** We use [Figma](https://www.figma.com/design/) for designing and prototyping. Our [Pajamas UI kit](https://www.figma.com/file/qEddyqCrI7kPSBjGmwkZzQ/Pajamas-UI-Kit) contains design assets, components, and styles for GitLab's design system, [Pajamas](https://design.gitlab.com/). Additionally, there is a [Figma plugin](https://www.figma.com/community/plugin/860845891704482356/GitLab) available that allows designers to upload design files directly into a GitLab issue. Every product designer should receive access to Figma during onboarding. If you don't have the access you need, reach out to your manager. If you are not a product designer but want View access (including the ability to leave comments), create a free Figma account and ask your stage group designer for a link to the relevant files.

Figma admins and their role scope are defined as:

|Admin|Scope|
|-----|-----|
|@tauriedavis|Tech stack owner, user management (Provisioning/deprovisioning), billing|
|@vkarnes|Tech stack owner fall back|
|@jeldergl|User management (Provisioning/deprovisioning), design ops|
|@danmh|Design ops|

**Figjam** We use [Figjam](https://www.figma.com/figjam/) for collecting design feedback, mapping workflows, brainstorming, affinity mapping, and anything else where we need a visual, whiteboard-like workspace.

Everyone in the UX department and all Product Managers can get a Figma account with the ability to create new Figjam boards. If you want to share your Figjam board to get feedback from members of your team who do not have a Figma account, you can send an anonymous link via the Share dialog.

**Dovetail** We use [Dovetail](https://dovetailapp.com/) to manage and analyze research findings. If you need access, please submit an [Access Request](https://gitlab.com/gitlab-com/team-member-epics/access-requests/-/issues).

### Tutorials

The UX team is encouraged to make improvements directly in the product when they find something that is small and easy to change.

- [Technical Tutorials for Product Designers](https://www.youtube.com/playlist?list=PL05JrBw4t0Kra6RseLWXFIXtu9UPzjzbT) - video playlist for best practices on technical topics
- [How to do UI Code Contributions](designers-guide-to-contributing-ui-changes-in-gitlab/)
- [Step by Step Guide to Make Code Changes](designers-step-by-step-guide-to-make-code-changes/)
- [Using data for design decisions](designers-guide-to-data/)
- [Implementing frontend click tracking for designers](https://www.youtube.com/watch?v=95wNcGMrpMg&ab_channel=GitLabUnfiltered)

### Prototypes

Coming soon.

## Research resources

The following resources may be helpful to UX Researchers, Product Designers, and Product Managers, since all of these roles conduct user research. For more information, see the [UX Research](/handbook/product/ux/ux-research) section of the handbook.

### UX Research project

The UX Research project contains all research undertaken by GitLab's UX researchers and is only used for the organization and tracking of UX research issues.

- [View the project](https://gitlab.com/gitlab-org/ux-research)

### System Usability Scale

Once each quarter, we run a [System Usability Scale (SUS)](/handbook/product/ux/performance-indicators/system-usability-scale) survey to measure user perception of the GitLab product. We send the survey to members of the wider GitLab community, with the goal of asking for a response from any individual no more than once per year.

- [SUS results by quarter](/handbook/product/ux/performance-indicators/#perception-of-system-usability)

## UX performance indicators

We track our effectiveness through [UX performance indicators](/handbook/product/ux/performance-indicators/) (PIs). Our e-group reviews these PIs once a month in the Engineering Key Review.

## User personas

User personas represent the people who actually use GitLab. The UX and Marketing teams use personas to inform decisions around the user experience and design.

- [View our user personas](/handbook/product/personas/#user-personas)

## From the GitLab team

Not only do our team members create great work for the wider GitLab community, but they also create some amazing industry-related resources to push our craft forward.

- [Building Design Systems: Unify User Experiences through a Shared Design Language](https://www.amazon.com/Building-Design-Systems-Experiences-Language/dp/148424513X), by Taurie Davis and Sarrah Vesselov
- [Craft Awesome Web Typography](https://betterwebtype.com/web-typography-book/), by Matej Latin
- [Hemingway - Figma plugin](https://www.figma.com/community/plugin/760035865558407437/Hemingway), by Michael Le
- [GitLab-ipsum](https://gitlab-com.gitlab.io/gitlab-ux/ux-foundations/gitlabipsum/), by Patrick Deuley and Jeremy Elder
