---
title: Account Planning
description: >-
  Account planning helps all AE's and the larger account team elevate
  opportunity-driven conversations into value-based conversations that focus on
  the customer's value drivers.
---

## Overview

An account plan is a document or record that contains important details about a customer or prospect, including information about the organization's business, strategic objectives, mission-critical priorities, goals and motivations, competitive landscape, pertinent technology stack details, key contacts and relationship maps, and the Account Executive's strategy and action plan over varying time horizons (6 months, 12 months, 18 months) to establish and expand a mutually beneficial, long-term strategic relationship.

The AE should think about account planning as if they were the CEO of their own territory. If you were a CEO, what information would you need to give banks, investors, or employees to demonstrate that you have a viable business plan that you can execute? An account plan is a business plan that helps the team analyze and execute on the business with a specific account. Like a CEO, the SAE need a leadership team to effectively plan for the account. Be sure to leverage the Solutions Architect, Customer Success Manager, Renewal Managers and Channel Partners as you strategize and build the account plan!

**Get started with the [Account Planning template](https://docs.google.com/presentation/d/1eZvbplyD5btVKW_QET2X4Whr6GOB2Etub8jjEJpQ_Ks/edit#slide=id.g16fb994af68_0_4) in our shared Google Drive** (internal team members only).

## Why Account Planning?

Account planning helps the AE and the larger account team elevate opportunity-driven conversations into value-based conversations that focus on the customer's [value drivers](https://gitlab.highspot.com/items/64da83a5f9fbeee46d8ad909?lfrm=srp.2). Good account plans help the team focus on what matters to earn strategic partner status with the customer which, in turn, will drive increased share of wallet and predictable growth. Account planning is NOT about creating a report for management--it's about helping the team create a strategic plan for long-term customer growth and retention.

An effective account plan defines a clear strategy and action plan to grow and expand customer relationships and will help the AE and the team:

- Better understand the customer's financial health, market position, strategic objectives, risks, key partners, tech stack, relationships with other DevOps vendors, and more
- Prioritize pursuits based on where GitLab can alleviate challenges and pain points that the customer is currently experiencing that are getting in the way of reaching desired business outcomes
- Assess the "health" of relationships within the account (access to power, strength of champions, breadth of relationships across lines of business, etc.)
- Identify resources and/or support needed to successfully execute against strategic account objectives and supporting action plans
- Determine risks and developing proactive risk mitigation plans

### What is the Difference Between an Account Plan and a Success Plan?

The account plan focuses on the account team's strategy to win, retain, and expand the partnership and business relationship with key customers. Success plans, on the other hand, clearly document what and how GitLab will deliver value throughout the customer lifecycle to help the customer optimize their return on investment and achieve specific business objectives aligned to the value drivers in the account plan. Success plans and the associated outcomes can also help inform and validate the account plan.

### What is the Difference Between an Account Plan and an Opportunity Plan?

The opportunity plan (aka the [Command Plan](/handbook/sales/command-of-the-message/command-plan/)) outlines the strategy for closing business related to a single budgeted customer initiative. In contrast, the account plan is a more comprehensive, holistic, organization-wide strategy and action plan for earning the trust and respect of the customer. This is achieved by delivering value to the customer over and over again. Unlike opportunity plans, account plans span multiple customer engagements and lines of business across the account over a longer period of time and may include actions that don't directly align to revenue (e.g. customer appreciation initiatives, other).

## Components of an Account Plan

There are a few different components that are part of an account plan.

1. Account Profile
1. Relationship and Influence Mapping
1. Whitespace Mapping
1. *Action Plan*

### Account Profile

Basic account details should already be entered into SalesForce. The purpose of the Account Profile section of the account plan is to capture important details about the customer or prospect, including information about the organization's business, strategic objectives, goals and motivations, competitive landscape, pertinent technology stack details, and more. The account profile is all about the customer (not GitLab).

Start at a high level, for example:

1. What are the organization's goals and the prioritized strategic initiatives aligned to each goal? What [value drivers](/handbook/sales/command-of-the-message/#customer-value-drivers) are most important and why?
1. What macro environment factors are affecting the organization (e.g. market conditions, competition, regulatory and compliance changes, etc.) and what impact and implications do these factors have on the organization's business strategy?
1. Who are the organization's primary competitors and how does the organization plan to maintain and/or grow market share?
1. What are the biggest risks facing the organization (for short, medium, and longer term time horizons) that may get in the way of the customer achieving their goals?
1. How does the organization's IT department and/or strategy support (or hinder) the above strategic objectives or initiatives?
1. What is the organization's digital transformation strategy and how does that support the strategic business objectives?
1. What is the perception of how IT is enabling and/or hindering progress against these strategic business objectives?
1. How does the customer currently view GitLab? How long have they been a customer? What is their annual spend with GitLab? For what DevOps stages does the customer use GitLab today and where have expansion opportunities already been identified?

### Relationship and Influence Mapping

Mapping the org (multi-threading) allows us to analyze where we are strong and where we have vulnerabilities which will drive some of our actions later in the plan. Relationship mapping includes but is not limited to assessing:

- The breadth and depth of relationship "coverage" within an account (both within and across lines of business)
- Access to power, champions, and key influencers
- The strength or health of key relationships (identify which contacts are promoters, detractors, or somewhere in between)
- How different parts of the organization engage with and/or influence each other. This can be idependent of reporting structure.
- Who and what has influence over key contacts in the account (e.g. specific analysts, partners, events, trade publications, user groups, other)

If the account plan is with an existing customer, Net Promoter Score (NPS) data may provide helpful insights into and help track relationship health and trends.

As the AE builds and continues to refine the account plan, consider the following:

- What existing relationships does the team need to continue to nurture and strengthen?
- What new relationships does the team need to establish, why, and how will we do it?
- Who is a GitLab champion, potential champion, detractor?
- Who are the champions and detractors for the primary competitors in the account?
- What is each person's level of influence and their professional/career trajectory?
- Do any GitLab channel and/or alliance partners have relationships that the team may be able to leverage with a co-selling strategy/approach?
- Is the team aware of any key contacts who plan to retire or leave the company soon? If yes, what is their succession plan (so the team can proactively begin to engage with whomever will be assuming new responsibilities and influence)?

### White Space Mapping

This is the part of the account plan where account teams seek to understand and document the customer's technology stack as it relates to how they develop and deploy applications and begin to identify where and how GitLab can deliver value. This mapping can be done for each discrete buying center or line of business within an account and/or at an aggregate account-level view.

1. Start by identifying what vendor technologies are used across [each stage of the DevSecOps lifecycle](https://about.gitlab.com/stages-devops-lifecycle/), how that aligns to the [customer's use case](https://docs.google.com/presentation/d/1bC_TdQO917hLbj4jfdkhtP0l7w8p1SKEK9vVjga5Wec/edit#slide=id.g7fe53431a5_0_33), and how the customer develops and deploys applications
1. Seek to understand what the customer would like to improve with how they develop and deploy applications and why
    - Do they want/need to accelerate their software delivery process? Reduce costs? Mitigate security and compliance risk? Other?
    - By how much?
    - What would it mean to the organization if they were to achieve these improvements? What are the implications if they fail to do so?
    - What is getting in the way of achieving these goals?
1. Engage in a discovery dialogue to identify positive business outcomes the organization hopes to achieve and the gap between their current state of operations and their desired future state.
1. Once you've earned the customer's trust, try to determine what the customer likes and dislikes about each of the vendor technologies currently being utilized, their annual investment with each vendor, when those contracts are up for renewal, etc.

With this understanding, you can begin to formulate a strategy for where and how GitLab can streamline the customer's DevSecOps adoption journey in pursuit of achieving their positive business outcomes. The pace of adoption within and across lines of business will vary from customer to customer, and the account plan identifies the strategic objectives and supporting actions that facilitate this adoption and growth. This plan will be supported by one or more opportunity plans when the customer allocates budget to a defined purchase initiative (at which point a Command Plan should be developed to support each unique opportunity).

### Action Plan

*This is the most important part of the account plan!* Once the AE and the team plan the work, be sure to work the plan! Account plans are meaningless if there is no clear plan of action for achieving the objectives. Once the AE and the team identify a prioritized set of objectives that will help the team deliver more value to the customer in support of the customer's strategic business initiatives, begin to identify and assign action items that will enable the team to achieve each objective. An action plan should clearly document the following:

1. What is each team member trying to achieve?
1. How will each team member achieve success?
1. Who is taking the action?
1. What is the timeline for completing the action?
1. What resources or support are needed

Be sure to communicate and socialize the action plan with your account team to ensure alignment and understanding. Schedule periodic check-ins to drive accountability in execution.

Lastly, one of the fundamental benefits of an account plan is to figure out what you don't know and what you need to learn, so iterating frequently on the plan will help identify and address gaps. This will put you in a much better position to make decisions and take actions which will lead to success.

## Building the Account Plan

### Step 1: Account Prioritization

Rather than building an account plan for each and every one of your accounts, it is recommended that you prioritize your accounts with a process sometimes called [Territory Planning](/handbook/sales/territory-planning/). Ideally, focus your efforts on building up to three account plans at one time. A limited number of thoughtful and robust account plans for the most strategic accounts is a much better approach than spreading yourself too thin by trying to create, manage, and maintain a large number of account plans.

### Step 2: Build the Account Profile

Invest time in researching the customer and gathering data and insights. Document what you know about the account and try to answer the questions outlined in the Account Profile section above. Identify and work on closing information gaps with your team until you have enough information to formulate a strategy.

### Step 3: Relationship & White Space Mapping

Collaborate with your account team to conduct this analysis. Discuss the implications of the team's observations and insights from this exercise. Identify and prioritize what additional information is needed to fill in gaps and help inform your account strategy.

### Step 4: Define Strategic Objectives

Based on the information gathered, work with your account team to define a short and a long term 'vision' for the account. Even better, do this with your customer (or share your plan and solicit feedback). A good place to start is with a 6 month plan. You can start by asking the customer: "Where do you want to be in the next year as it pertains to your DevSecOps maturity and implementation?" Take that answer and continue to ask the question in different ways to drive to clarity with the customer. Sometimes we might have to push the customer to think about things is a fresh way. Based on this, identify and prioritize 2-3 objectives that will improve your position in and/or understanding of the account and/or that support the customer's strategic business initiatives.

#### Samples

The one year vision:
**The Customer says..."In the next year, the business will be …"**

- "To get there, the business will need to…"
- "Software development will play the role of…"
- "Our software teams will need to be able to…"
- "Our use of GitLab to support this will be…"
- "To get to that stage with GitLab, we will need to do…"
- "How we do that, is something … will need to own on our side"

Build out a plan of required capabilities, prioritize them, and then order them.
Some examples:

- In the next year, the business will be operating in 6 new countries, with 2 new product lines.
- To get there the business will need to hire new talent, we will need to build the products, we will need to open 6 new regional entities. We will also need to ensure that we are not over-extending the core profit making part of the business.
- Software development's role will be: 1) the products will be either fully or partially digital; 2) to launch the new product lines, in the new markets we wish to enter, will require new technical expertise in… AI/robotics/VR etc; 3) dev will need to ensure that the core cash-cow products at least keep their current margins while reducing cost.

### Step 5: Document and Begin Executing the Action Plan

See the Action Plan section above for details. When the team is ready, share the plan with your manager and confirm next steps, resources needed, and review any information that is unclear. If appropriate, share the plan with partners to ensure alignment and commitment.

### Step 6: Review, Monitor and Iterate

Account plans are living documents and are never truly complete. Plans will continue to evolve, and the account team should continue to iterate on them. Once you build the initial plan ask yourself and the team:

- How can we determine the validity of the plan?
- What can we measure?
- Have I verified my understanding with my champion?

If a Customer Success Manager is assigned to this customer, check in with them on their [Success Plan](/handbook/customer-success/csm/success-plans/#overview) and ask if they are planning any [Executive Business Reviews](/handbook/customer-success/csm/ebr/). These documents can help validate the account plan and determine if the vision is aligned with each customer's goals.

A quarterly cadence to review and update plans can help to ensure that plans reflect our current understanding of the account and keep the account team aligned on plan strategy and execution. Major changes such as personnel changes, mergers/aquisitions, and competitive threats may trigger immediate review and updates. Structured review sessions can help keep the account team aligned and keep leadership informed of changes involving customers.

### Additional Considerations

- Account plans should be thoughtful, collaborative, and cross-functional with contributions and input from the entire account team including Solutions Architects, Customer Success Managers, Sales Leadership, Renewal Mangagers, Partners, and more
- Account plans are living documents, and a customer's business and strategies are always subject to change; share the account plan with the account team regularly to maintain a fresh understanding of the customer's needs and to keep everyone informed and aligned
- Account reps should use QBRs and/or other recurring meetings such as AE-SA-RM-CSM calls to review progress, update objectives and/or action plans, and align on next steps
- If you would like to work with your customer to build an account plan, there is a [GoogleSlide Template](https://docs.google.com/spreadsheets/d/1Rqpy6qz9f90GBw4XNn5RyJIZU0ShboraF7LR9gHmQw0/edit?usp=sharing) you can print out and bring to the customer meeting to work on together.
- Review the below ten reasons why strategic plans fail according to [this Forbes article](https://www.forbes.com/sites/aileron/2011/11/30/10-reasons-why-strategic-plans-fail/) and take proactive steps to avoid these pitfalls
    1. Having a plan simply for plan's sake
    1. Not understanding the environment or focusing on results
    1. Partial commitment
    1. Not having the right people involved
    1. Writing the plan and putting it on the shelf
    1. Unwillingness or inability to change
    1. Overcomplication the plan (inspired from [this article](https://www.forbes.com/sites/jeroenkraaijenbrink/2019/09/10/20-reasons-why-strategy-execution-fails/))
    1. Ignoring marketplace reality, facts, and assumptions
    1. No accountability or follow through
    1. Unrealistic goals or lack of focus and resources
