---
title: "Command of the Message"
description: "GitLab has adopted Force Management's Command of the Message customer value-based sales messaging framework and methodology"
---

## Overview

GitLab has adopted and operationalized Force Management's Command of the Message value-based sales messaging methodology. Due to IP constraints, we have migrated content from this page to GitLab's internal Handbook. GitLab team members may access additional content and resources on the [Command of the Message Internal GitLab Handbook page](https://internal.gitlab.com/handbook/sales/command-of-the-message/) (note: if you are a GitLab team member and cannot access the internal Handbook, please sign into the GitLab Internal Handbook app via [Okta](https://gitlab.okta.com/)).

## Customer Value Drivers

Value drivers describe what organizations are likely proactively looking for or needing and are top-of-mind customer topics that exist even if GitLab doesn't. Value drivers may cause buyers to re-allocate discretionary funds, and they support a value-based customer conversation. Organizations adopt and implement GitLab for the following value drivers:

1. **Increase Operational Efficiencies** - *Simplify the software development toolchain to reduce total cost of ownership*
1. **Deliver Better Products Faster** - *Accelerate the software delivery process to meet business objectives*
1. **Reduce Security and Compliance Risk** - *Simplify processes to comply with internal processes, controls and industry regulations without compromising speed*
1. **Accelerate Cloud Adoption & Transformation** - *Standardize cloud processes to accelerate business outcomes*

## GitLab Differentiators

| GitLab Differentiator | Description |
| ------ | ------ |
| **Single Application for Entire DevOps Lifecycle** | - Complete DevSecOps platform delivered as a single application<br> - One interface, one user-model, one data model<br> - A software "factory" that supports the entire DevOps lifecycle<br> - Deeply integrated, making developers happier and more efficient<br> - Centralized collaboration for a wide variety of roles (collaborate without waiting) |
| **AI-powered workflows across the SDLC** | - AI-powered workflows through the entire SDLC, not just code, to create software faster, remove inefficiencies, & iterate rapidly |
| **Leading SCM and CI / CD in One Application** | - The backbone of a DevOps toolchain in one application<br> - Streamlines code review and collaboration<br> - Start with SCM or CI (or both)<br> - One interface, one user-model, one data model<br> - Interoperable with other tools (continue using tools you love!)<br> - Proven enterprise scale |
| **Built In Security and Compliance** | - Security features out-of-the-box (code scanning, dependency scanning, secrets detection, etc.)<br> - Automated security testing and audit controls to facilitate policy compliance<br> - Shift left: move security testing earlier in the development lifecycle; security testing at the point of code commit<br> - Developers get immediate feedback about new vulnerabilities they introduce<br> - Enables better collaboration between development and security teams<br> - One interface, one user-model, one data model for DevSecOps |
| **Built to Scale** | - GitLab allows for horizontal scaling to 50k+ users using documented reference architectures<br> - GitLab's single DevSecOps platform allows organizations to know how their costs will increase as they grow<br> - GitLab gives the ability to plan across the entire organization |
| **Deploy Your Software Anywhere** | - Deploy to any environment, any cloud<br> - Support for GCP, AWS, Azure, OpenShift, VMWare, On Prem, Bare Metal, etc.<br> - Workflow portability: one deployment workflow regardless of destination |
| **Optimized for Kubernetes** | - Enables adoption of modern cloud-native development patterns such as microservices and serverless<br> - Minimizes the Kubernetes learning curve by enabling setup and use of clusters from the GitLab user interface<br> - View and manage Kubernetes deployment pod details and logs from the GitLab user interface<br> - Automatic monitoring of every Kubernetes deployed application and the clusters they are deployed to<br> - Built-in canary and incremental deployment strategies with automatic canary metric collection and display<br> - Active contributor to the future of cloud native technologies (through the Cloud Native Computing Foundation) |
| **End-to-End Insight and Built-In Value Stream Management** | - Common data model uniquely allows for insights across the entire DevSecOps lifecycle<br> - Configurable insights dashboard that shows status of work items over time<br> - Cycle analytics data helps identify areas of improvement of cycle times<br> - Security insights provide a roll-up of vulnerabilities<br> - Program level insights help keep projects on-track |
| **Flexible GitLab Hosting Options** | - Use in the cloud or install in your own environment (cloud or on-prem)<br> - Feature parity between GitLab.com and self-managed<br> - Migrate from one hosting option to another when needs change<br> - Implement hybrid hosting models to support scaling (like CI Runners in the cloud)<br> - Easy to upgrade and maintain in any environment |
| **Rapid Innovation** | - Releases every month, for 100+ months running<br> - A constant stream of new features –> GitLab gets more valuable over time<br> - Uniquely transparent product development process; customers, partners and community can contribute |
| **Open Source; Everyone Can Contribute** | - Open core development model allows anyone to contribute to the functionality of the product<br> - Uniquely transparent product development process engaging customers, partners and the community<br> - Strong and growing community (100K+ organizations and millions of users)<br> - Harness open source innovations within the product experience (e.g. Prometheus) |
| **Collaborative and Transparent Customer Experience** | - We operationalize our core values into how we develop our product and engage with our community and customers<br> - Extreme transparency around roadmaps, issues, company meetings and processes<br> - We use GitLab for collaborating with customers in a transparent way, for both issue resolution and roadmap iteration<br> - GitLab provides an evolving case study of DevSecOps and agile practices at scale, accessible through the public handbook |
