---
title: "Command Plan"
description: "The Command Plan is how GitLab has operationalized a customer value-driven sales methodology with strategic opportunity management into the opportunity management process"
---

## Overview

The Command Plan is how GitLab has operationalized [Command of the Message](/handbook/sales/command-of-the-message/) (*a customer value-driven sales methodology*) and [MEDDPPICC](/handbook/sales/meddppicc/) (*a proven methodology used for strategic opportunity management and complex sales process orchestration for enterprise organizations*) into the opportunity management process. Access the [Effective Command Plans to Help You Win More Deals](https://levelup.gitlab.com/access/saml/login/internal-team-members?returnTo=https://levelup.gitlab.com/learn/course/sal-effective-command-plans-to-help-you-win-more-deals) e-learning course for ENT or [Strategic Opportunity Management](https://university.gitlab.com/learn/course/strategic-opportunity-management-the-process/main/strategic-opportunity-management-the-process?client=internal-team-members&page=6) for Commercial.

## Command Plan Requirements

The Command Plan consists of the below 3 sections. The Opportunity Overview section is **required for ALL opportunities in stage 2-Scoping or later for current quarter and next quarter as a minimum global standard**. The remaining sections (MEDDPPICC and Close Plan Details) are only required for opportunities *at or above defined ARR thresholds* (**$100K+ for Enterprise**, **$50K+ for Mid-Market**).

By day 1 of the current quarter, all Command Plans and Opportunity Consults should be updated for both the current and next quarters. Note: These thresholds are minimum global standards, and geographic and segment specific teams can and should aim to exceed these expectations by extending the command plan process to lower deal thresholds where appropriate.

1. [**Opportunity Overview**](/handbook/sales/command-of-the-message/command-plan/#opportunity-overview)
1. [**MEDDPPICC**](/handbook/sales/command-of-the-message/command-plan/#meddppicc)
1. [**Close Plan Details**](/handbook/sales/command-of-the-message/command-plan/#close-plan-details)

At the sales level, the Command Plan is owned by the [Strategic Account Executive](/job-families/sales/enterprise-account-executive/) or [Commercial Account Executive](/job-families/sales/account-executive/) who creates the plan and updates the contents accordingly. It is used as a living pre-sales document, and its objectives are converted into [Gainsight Success Plan objectives](/handbook/customer-success/csm/success-plans/#objectives) at the time of [account onboarding](/handbook/customer-success/csm/onboarding/).

You can find the Command Plan button in the `Opportunity Detail` section of the Salesforce opportunity object (see image below) or in Clari or in the top right dropdown menu on the Opportunity Record in Salesforce Lightning. Please note that Command Plans are capped at 5000 characters in Salesforce to encourage sales team members to be crisp and succinct. To do so, the Command Plan should focus on future-looking plans and remove details that are no longer relevant to the current close plan. For information you'd like to remove from the Command Plan but keep for historical purposes, please add that information as a new activity record on the opportunity.

![Where to find the Command Plan](/handbook/sales/command-plan.png)

## Opportunity Overview

This section consists of 5 mandatory fields:

1. **Why Now?** - *What is the compelling event? Why does the customer need to make the purchase now including both qualitative and quantitative implications?*
1. **Primary Value Driver** - *What is the primary business problem that the customer is trying to solve (even if GitLab didn't exist) that is causing the economic buyer to allocate discretionary funds to solve?*
1. **Solution** - *What is the primary GitLab solution (Automate Software Delivery, Continuous Software Security Assurance, Software Compliance, or DevOps Platform) that best aligns with the problem the customer wants to solve?*
1. **Primary Capability** - *What is the primary capability that the customer is pursuing to achieve the above value driver(s)?*
1. **Why GitLab?** - *Why is the customer choosing GitLab over the competition? What are GitLab's key differentiators from the customer's perspective?*
1. **Why Do Anything At All?** - *What are the negative consequences if the customer does nothing? What happens if the customer doesn't do this deal on the forecasted timeline?*

## MEDDPPICC

There are a total of **9 MEDDPPICC fields** (see details [here](/handbook/sales/meddppicc)).

## Close Plan Details

This section is comprised of the following 3 fields:

1. **Close Plan** - *What is the full beginning to end close plan with dates (day by day or week by week)?*
1. **Risks** - *What is the biggest risk with this opportunity? What would be the possible reasons for why the deal doesn't come in on time? What are we doing to proactively address and/or mitigate key risks?*
1. **Help** - *How can the extended GitLab team help (i.e. Product Management/Engineering needs, Legal requirements, Deal Desk, Finance, Execs)?*

## Manager Review

Continuing to improve the fidelity of Command Plans is a critical success factor to winning more deals and improving productivity and predictability. As such, at the bottom of the Command Plan is a section for Managers and above to enter review notes from [opportunity consults](/handbook/sales/command-of-the-message/opportunity-consults/) (and/or Lightweight Deal Reviews for Commercial Sales) conducted. Manager Review notes should begin with "YYYY-MM-DD" to indicate the date when the opportunity consult was conducted, and the notes should succinctly highlight:

1. Prioritized gaps identified during the opportunity consult
1. Specific action items that were agreed to (who will do what by when)

Note: The Manager Review Info section (immediately below the Manager Review section) will auto-populate based on information entered in the Manager Review section.

### Enterprise Area Sales Manager Expectations

An opportunity consult should be conducted with Strategic Account Leaders (SAEs) at least once a month for every $250K+ opportunity in stage 3 or greater for current quarter and next quarter. For AEs with fewer than three $50K+ opportunities, consider conducting monthly opportunity consults for their top 3 opportunities or run group review sessions at leadership discretion, where possible.

### Commercial Area Sales Manager Expectations

An opportunity consult should be conducted with Mid Market Account Executives (AEs) at least once a month for every $100K+ opportunity. This is the minimum global standard, and geographic and segment specific teams can and should aim to exceed these expectations by extending the command plan process to lower deal thresholds where appropriate.

## Additional Resources

### Command Plan templates

- [Blank template](https://drive.google.com/open?id=1uTHRRUQx4IP_dXUnsrfG2x9Ti-XpMneX3IDu2v0TZtY)
- [Template with helper text](https://drive.google.com/open?id=1SH7yfGFda0jsHcM9QmVI9BQO54fuaMujt-aJfFg-EUA)
- [Sample Command Plan](https://drive.google.com/open?id=1SdfgEds7NvCezcrFjirdLygIp4715iQn7u2ts-9avwg)

### Opportunity Consults

- [Opportunity Consults](/handbook/sales/command-of-the-message/opportunity-consults/) Handbook page
- [Opportunity Coaching Guide](https://docs.google.com/document/d/1IZA9Fo2SvZOrtUVpXOjwwqs76lKdXFs4hTezbxRq5v8/copy)
