---
title: "Demystifying the Metrics Conversation"
description: "Practical tips for sales reps to demystify the Metrics component of the Command of the Message customer conversation framework"
---

## Overview

Many sales reps find the Metrics component of the Command of the Message customer conversation framework to be a difficult one. To learn more, check out the Force Management blog, ["Why Sales Reps Struggle with Metrics in the Sales Conversation."](https://www.forcemanagement.com/blog/why-sales-reps-struggle-with-metrics-in-the-sales-conversation) One of the most common challenges is that many customers don't have good metrics, they aren't measuring, and they may not know what to measure. Check out the below video from Nico Ochoa (Strategic Account Executive, US West).

<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/wkhVEg2C11M" frameborder="0" allowfullscreen="true"> </iframe>
</figure>

Below are some additional challenges your peers have shared.

- Customers may be reluctant to share metric details for negotiation purposes (they don't want to admit how compelling of an ROI GitLab can provide!)
- Sales team members struggle with finding the perfect proof point(s) to demonstrate how we've helped similar organizations (e.g. similar industry, business challenge, geography, etc.)
- Difficulty connecting Metrics with Positive Business Outcomes (PBOs)
- Metrics, if used in the wrong way, can get complex and technical

The following sections outline practical tips to help demystify the Metrics conversation and overcome the challenges identified above.

## Embrace Your Role as the Trusted Advisor

Keep in mind that many customers may not understand why their DevOps initiatives are not delivering desired or optimal results. Assist them in their diagnosis and lead with insights to help them accomplish their Positive Business Outcomes (PBOs). Listen to how Nico approaches initial discovery conversations.

<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/ImjQqcHoI3U" frameborder="0" allowfullscreen="true"> </iframe>
</figure>

Below is just one example of how you could leverage Nico's approach to open the conversation with your customers to begin to understand the specific challenges they are experiencing.

"If you're like other organizations we speak with, below are some of the common challenges they encounter in their software development life cycle:

1. There is still significant room for improvement in their DevOps processes
1. They lack visibility across their entire Software Development Life Cycle
1. They are unable to clearly measure and assess developer productivity
1. Silos persist between Development, Security, and Operations teams

Are any of these true for your organization?"

Another critical way to embrace your role as a trusted advisor is to become and stay intimately familiar with the specific problems that GitLab helps to solve. Watch the below video and master your knowledge of [GitLab's customer use cases](/handbook/marketing/use-cases/).

<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/4wZQ_oxOcRs" frameborder="0" allowfullscreen="true"> </iframe>
</figure>

## Be a Good Storyteller

The best Metrics conversations are **STORIES** that articulate quantifiable measurements and proof of the business benefits of the solution to the customer's problem(s). John May (Strategic Account Executive, US East) leverages this [DORA State of DevOps 2019 slide](https://docs.google.com/presentation/d/1cNcqXbcYR5pEfz-t8_VBE86fqdma_Jc7ws5Icm9FDKY/edit?usp=sharing) to emotionally appeal to individuals' desire to become elite performers and highlight relevant success stories of organizations ([Ticketmaster](https://about.gitlab.com/blog/2017/06/07/continuous-integration-ticketmaster/), [Verizon Connect](https://www.youtube.com/watch?v=zxMFaw5j6Zs), [Paessler AG](https://about.gitlab.com/customers/paessler/), and more) that have become Elite Performers by adopting and expanding their GitLab footprint. Learn more from John in this [Art Behind Command of the Message](https://youtu.be/-iIK7SlplEo) sales enablement videocast (GitLab internal only, Oct 2019, 26 minutes).

Listen to how Nico Ochoa (Strategic Account Executive, US West) explains the value of GitLab by talking in terms of a software factory and applying lean manufacturing principles. More specifically, GitLab applies these principles to take waste out of the process of developing and deploying applications to increase operational efficiencies, deliver better products faster, and reduce security and compliance risk.

<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/vtlAs68YY8M" frameborder="0" allowfullscreen="true"> </iframe>
</figure>

As a follow on to the above, be sure to familiarize yourself with GitLab's [Value Stream Management (VSM)](https://about.gitlab.com/solutions/value-stream-management/) & Value Stream Analytics capabilities. Effectively articulating these capabilities plays to two of GitLab's key differentiators:

1. Single Application for Entire DevOps Lifecycle, and
1. End-to-End Insight and Visibility

Watch the below video and check out GitLab's [Value Stream Management](https://about.gitlab.com/solutions/value-stream-management/) solutions page to learn more. In addition, access short customer-facing VSM videos in the [Agile Management](https://about.gitlab.com/learn/#agile_management) section of the Learn@GitLab page.

<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/e2XQB5HFJmc" frameborder="0" allowfullscreen="true"> </iframe>
</figure>

## Know the Difference Between Economic and Technical Metrics

### Economic Metrics

**Economic metrics** highlight how your solution attaches to the customer's large strategic initiatives.

- Economic metrics typically align to one or more of three [customer value drivers](/handbook/sales/command-of-the-message/#customer-value-drivers)
- To help you document your customer's ROI of adopting GitLab, use the GitLab ROI Model
  - Watch the video below
  - Check out the [GitLab Standard ROI Models enablement webcast](https://youtu.be/znCrnpTDRoE) (36 minutes, Sept 2020)
  - [GitLab Standardized ROI Model](https://docs.google.com/spreadsheets/d/1zYeKV51thbqUjKKQqOtE0a0iVuXBWytc_5ThNV6U_1c/edit?usp=sharing) (GitLab internal only)
  - [Standardized GitLab ROI Model presentation](https://docs.google.com/presentation/d/1-Qq6TLpgOuooAlmHj1tumwHxUTK86uWBD_7Lv6K47w8/edit?usp=sharing) (GitLab internal only)
- Check out the [Forrester Total Economic Impact Study](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/analyst-relations/forrester-tei/) Handbook page
  - Watch the [Forrester TEI Report webcast](https://youtu.be/J_6QgemCz2E) (1 hour, July 2020, internal only) featuring Forrester analysts
  - Check out the [online Forrester TEI Estimator/Calculator](https://tools.totaleconomicimpact.com/go/gitlab/devopsplatform/index.html)
  - More resources in the Handbook page referenced above!

<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/jE56J-kQRao" frameborder="0" allowfullscreen="true"> </iframe>
</figure>

Listen to Nico Ochoa (Strategic Account Executive, US West) describe his role in [helping a large tech firm be able to measure success and improve business outcomes](https://youtu.be/m1Gori76d-I) (GitLab internal only, June 2020, 3 minutes).

### Technical Metrics

**Technical metrics** highlight measurable results that prove the solution's capabilities.

- Review [Getting Started with Agile Metrics](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/devops-metrics/)
- Consider reading ["Accelerate: The Science of Lean Software and DevOps: Building and Scaling High Performing Technology Organizations"](https://itrevolution.com/book/accelerate/)

Hear what Nico says about cycle time compression, helping organizations do more with less, and improving developer satisfaction.

<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/91wfyVNRLVw" frameborder="0" allowfullscreen="true"> </iframe>
</figure>

<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/MUrGWgDcxMs" frameborder="0" allowfullscreen="true"> </iframe>
</figure>

To better navigate Metrics conversations, listen to the 7-minute Force Management [Metrics in the Sales Conversation podcast](https://soundcloud.com/force-management-1/metrics-in-the-sales-conversation) and implement these practices:

1. Recognize that your solution impacts decision-makers in different ways and their reasoning for choosing your solution over alternatives is also different
1. Understand what each stakeholder/decision-maker cares about and help them (especially your Champions) understand how your solution impacts
    - What they care about, and
    - What other stakeholders/decision-makers care about
1. Be sure you understand what technical metrics align to the value drivers your customer cares about most (see next section)

## Connect Metrics with Positive Business Outcomes

Link your **technical buyers** to the metrics and their role in driving the positive business outcomes. If you can emotionally connect those technical metrics-focused buyers on the impact they have for the entire company, they will be better able to internally sell the importance of your solution. With **economic or non-technical buyers**, lead with and continue to reinforce the Positive Business Outcomes your solution will deliver and help them understand how those Positive Business Outcomes are associated with the project's technical metrics.

| **Value Driver** | **Metrics** |
| :------: | ------ |
| **Increase Operational Efficiencies** | - Lower costs (license, FTEs and compute) of development<br> - Increase developer/team productivity<br> - Reduce cycle time (lead time)<br> - Increase [deployment frequency](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/devops-metrics/#deployment-frequency)<br> - Reduce [change failure rate](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/devops-metrics/#change-failure-rate-cfr)<br> - Reduce [MTTR (mean time to recover/restore)](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/devops-metrics/#mean-time-to-recover-mttr)<br> - Improve developer satisfaction and retention |
| **Deliver Better Products Faster** | - Improve revenue, # of customers, and/or market share<br> - Increase developer/team productivity<br> - Reduce cycle time (lead time)<br> - Increase [deployment frequency](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/devops-metrics/#deployment-frequency)<br> - Reduce [change failure rate](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/devops-metrics/#change-failure-rate-cfr)<br> - Reduce [MTTR (mean time to recover/restore)](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/devops-metrics/#mean-time-to-recover-mttr) |
| **Reduce Security and Compliance Risk** | - Decrease % of critical security vulnerabilities that escaped development<br> - increase the % of code scanned<br> - improve audit pass rate<br> - Reduce time spent on audits and/or compliance adherence efforts<br> - Reduce mean time to resolve security vulnerabilities |

## Know Your Proof Points

- Reference and leverage the proof points listed in the GitLab Value Framework and in slides 22 and 23 of the Customer Deck (see the [Command of the Message Core Content](https://internal.gitlab.com/handbook/sales/command-of-the-message/#resources-core-content)) (internal only)
- Familiarize yourself with GitLab's [Proof Points](/handbook/sales/command-of-the-message/proof-points/) to the point where you can talk about various success stories in a conversational manner
- Check out the short videos in the [Customer Success Stories playlist](https://www.youtube.com/playlist?list=PL05JrBw4t0KrRRGEIdtGsiCtgLy8dJhlk) on GitLab Unfiltered (GitLab internal-only)
- [Listen to the Maximize the Effectiveness of Proof Points](https://podcasts.apple.com/us/podcast/26-maximize-the-effectiveness-of-proof-points-w-john-kaplan/id991362894?i=1000488439478) podcast (12.5 minutes)

## Embrace the Tension

- Early in the sales process, a difficult metrics conversation is a good sign that the customer wants and needs a trusted advisor (you!!) to help them with their DevOps adoption journey. Leverage relevant proof points to instill confidence that GitLab is uniquely suited to help them achieve their desired outcomes.
- As the opportunity progresses, customers will ask for and expect discounting because that's what they've been trained to do. Maintain conviction in and continue to reiterate the VALUE of the GitLab solution and the defensible differentiators that make GitLab the best choice.

## Leverage Metrics to Create Urgency

By understanding your customer's desired outcomes and their strategic business initiatives, be sure you fully understand and can articulate the answer to the following questions:

1. Why should the customer buy anything?
1. Why should the customer buy now?
1. Why should the customer buy the GitLab solution?
1. What is the cost and impact to the customer of doing nothing?
1. Is there a compelling event that impacts any of the above?

And once you have identified compelling answers to these questions, continue to reiterate and reinforce that value with key influencers and decision makers (keeping in mind that different stakeholders may care about different things).

## Assess the Health of Your Metrics

Periodically, conduct a critical review of the below questions. This can be done via a self-assessment and/or with your account team, peers, mentors, or your manager. In some instances, you may even consider reviewing this with your Champion.

1. Has the customer bought into the identified metrics?
1. Are the metrics aligned with the desired business outcomes?
1. Are your Champions leveraging the identified metrics?
1. Are the identified metrics in the customer's business justification and/or decision criteria?
1. Has the economic buyer made reference calls based on the identified metrics?

## Practice, Practice, Practice
<!-- vale handbook.InclusionGender = NO -->
Purposeful practice (combined with on-the-job experience) leads to skill mastery. [Read the article](https://www.mikekunkle.com/sales-leaders-its-time-to-get-serious-about-purposeful-practice-skill-mastery/). Michael Jordan became the greatest basketball player of all time, at least in part, because he worked hard at practicing, and perfecting his craft. Practice having the metrics conversation with yourself, with a peer, a mentor, your manager, or other. As you become more comfortable and confident, positive results will follow.
<!-- vale handbook.InclusionGender = YES -->
