---
title: "Opportunity Consults"
description: "Opportunity consults are deal reviews that focus on helping a sales team member maximize the likelihood of winning and securing the customer's business"
---

## Overview

Opportunity consults are deal reviews that focus on helping a sales team member maximize the likelihood of winning and securing the customer's business. They are based on a joint inspection of the "health" of the opportunity's [Command Plan](/handbook/sales/command-of-the-message/command-plan/) and a 2-way dialogue to identify and commit to specific actions that aim to increase the likelihood of success. During every opportunity consult, the sales manager should assess whether or not the sales team member is able to do the below and provide coaching to help the sales team member address gaps identified.

1. Concisely explain the opportunity background leveraging information from the [Opportunity Overview](/handbook/sales/command-of-the-message/command-plan/#opportunity-overview) fields
1. Describe the customer's pain points and desired outcomes
1. Highlight challenges or gaps in qualification aligned to the [MEDDPPICC](/handbook/sales/meddppicc/) opportunity qualification framework
1. Articulate a [Close Plan](/handbook/sales/command-of-the-message/command-plan/#close-plan-details) (or a prioritized set of actions to help formulate a Close Plan)
1. Identify the biggest opportunity risk(s) and action(s) to mitigate those risks

## Opportunity Consult Format

Below is a general recommendation of the format and flow of an opportunity consult.

| **Step (duration)** | **Description** |
| ------ | ------ |
| Manager Set-Up (5 minutes) | - Set expectations of the call by stating the purpose, process and payoff of the session |
| Seller-Led Opportunity Overview (10 minutes uninterrupted) | - Job aid: [Opportunity Qualifier](https://docs.google.com/document/d/1Tz6bQKD4Ff2-XqpSXRQslD8yvrphwXaL6oEl74DAjeQ/edit?usp=sharing) <br> - Provides brief opportunity background (e.g., relevant account history, recent changes on opportunity) <br> - Describes current deal state (e.g., sales process stage, forecast stage, key business issues, compelling event) <br> - Identifies gaps in Mantra, [MEDDPPICC](/handbook/sales/meddppicc/), and additional challenges for discussion |
| Manager Consult (30 minutes) | - Job aid: [Opportunity Coaching Guide](https://docs.google.com/document/d/1IZA9Fo2SvZOrtUVpXOjwwqs76lKdXFs4hTezbxRq5v8/edit?usp=sharing) <br> - Ask open-ended, two-sided questions around focus areas to inspect (in a good, helpful way) the opportunity <br> - Provide relevant feedback and coaching based on the identified gaps and challenges <br> - Assist the seller in defining an action plan and exactly "how" to execute on the next steps |
| Manager + Seller Agree to Action Plan (5 minutes) | - Seller recaps opportunity-specific sales strategy <br> - Seller documents next steps/critical actions in CRM or via email to manager |

## Opportunity Consult Coverage

Regular opportunity consults on strategic deals are a linchpin to successfully reinforcing and sustaining the critical skills and behaviors underlying [Command of the Message](/handbook/sales/command-of-the-message/) and [MEDDPPICC](/handbook/sales/meddppicc/) that maximize the likelihood of winning and securing the customer's business. To improve win rates, forecast accuracy, and predictability, front-line sales managers should conduct at least one opportunity consult every 30 days for any and all opportunities that warrant a full Command Plan as outlined [here](/handbook/sales/command-of-the-message/command-plan/#overview). **Opportunity Consult Coverage** is a pair of metrics that measures how well sales managers are adhering to the above policy. More specifically, Opportunity Consult Coverage measures:

1. The % of Stage 3+ opportunities at or above defined ARR thresholds (**$250K+ for Enterprise**, **$100K+ for Mid-Market**) that have had a documented opportunity consult (as measured by the [Manager Review](/handbook/sales/command-of-the-message/command-plan/#manager-review) field in the Command Plan) in the last 30 days.
1. Same as above parameters but calculated based on opportunity pipeline *value* (versus opportunity count)

The higher the Opportunity Consult Coverage, the greater confidence sales leadership will have in the accuracy of the forecast.

### Opportunity Consult Coverage Dashboards

- [Enterprise Sales](https://gitlab.my.salesforce.com/00O4M000004aic2) (internal only)
- [Mid-Market Sales](https://gitlab.my.salesforce.com/00O4M000004apxr) (internal only)
- [SMB Sales](https://gitlab.my.salesforce.com/00O4M000004apy1) (internal only)

## Best Practices

- Conduct regular weekly Opportunity Consults with each rep on your team to review Command Plans for strategic opportunities
- Focus on continually driving higher fidelity Command Plans through each customer communication/interaction
- Coaches/managers should first seek to understand the current level of understanding of those they are coaching before explaining key or misunderstood concepts
- Coaches/managers should encourage reps to
    1. **Commit to specific, concrete, actionable next steps** (e.g., "I am going to do X, Y, and Z to test my Champion" instead of "I am going to test my Champion") and
    1. **Document action items in a shared way** (e.g. document in Salesforce or send a summary wrap-up communication after the meeting)
- Consider including key account team members (e.g. SAs and CSMs) in Opportunity Consults from time to time to facilitate improved transparency and collaboration
- Coach sales team members on the best practices related to the Close Plan within a [Command Plan](/handbook/sales/command-of-the-message/command-plan/)
  - Close plans should be updated in real time and, at minimum, on a weekly basis for later-stage (Stage 4+) deals
  - Time stamp the latest update at the top with the date of the refresh so each line item starts with a specific date
  - Liberally use ( ) or **** between line items or at the end of line items to denote Close Plan gaps that the sales team member intends to address during the next communication with the prospect/customer
  - Keep documented actions as crisp and succinct as possible; endeavor to keep it on one line so as not to make it a blog
  - Refer to the [Paper Process](/handbook/sales/meddppicc/#paper-process) field when appropriate so efforts aren't duplicated

## Additional Resources

Familiarize yourself with the Command of the Message and MEDDPPICC [Sales Manager Materials](https://internal.gitlab.com/handbook/sales/command-of-the-message/sales-manager-materials/) (internal only).
