---
title: "Commercial Sales Opportunity Stages"
description: "Sales stages activities and exit criteria"
---

## <i class="fas fa-users fa-fw icon-color font-awesome"></i>Why Are Sales Stages So Important?

Pipeline management is key to predictable, scalable revenue attainment and can make the difference between simply hitting your number and overachieving. Proper sales pipeline management helps you allocate your time correctly, increase deal velocity, and increase total deal volume, size, and revenue through accurate forecasting practices.

A well-managed sales pipeline requires a clear process with defined activities and exit criteria that serve as a roadmap to getting a deal from discovery to closed won (or qualified out quickly). The following process is specific to the Commercial Sales team and will ensure you have a clean pipeline and accurate forecast.

## <i class="fas fa-users"></i>Commercial Sales Stages Activities and Exit Criteria

To view these stages in Google sheet format please [click this link](https://docs.google.com/spreadsheets/d/1tVtJvfSsmWL2L1vTcJZgARlzC9Qy3Ae7pPqGBH9_KOQ/edit#gid=1399111321).

[Exit Criteria at a Glance:](https://docs.google.com/presentation/d/1x6ycY7SdPET5ioD2bPyV6RURafdU_fn4P7vD6X0QRsM/edit#slide=id.p)

![comm-sales-stages-exit-criteria](/handbook/sales/commercial/comm-sales-opp-stages/comm-sales-stages-exit-criteria.png)

---

### 0-Pending Acceptance

*This is the initial stage once an opportunity is created. The Sales Development team will scope business need/ challenge and validate commitment from prospect/customer to have a discovery conversation with the GitLab Team.
It is important to note that Sales Development opportunities could come from inbound interest or outbound interest. There will be additional levels of qualification for inbound interest or existing customers as opposed to opportunities coming from outbound efforts.*

**Primary Activities** to Complete in This Stage:

- Begin filling out [MEDDPPICC](/handbook/sales/meddppicc/) (in required qualification criteria section of the opportunity) - Identify pain/need, Economic buyer, or path to the economic buyer for prospects, plus decision process for inbound leads or current customers.
- Schedule discovery call with AE or SAE
- For SDR sourced opportunities, the opportunity meets [Sales Accepted Opportunity](/handbook/marketing/sales-development/#qualification-criteria-and-saos) criteria.
- SDR schedules call, sends invites, creates an event on the account object, names the event: GitLab Introductory Meeting - {{Account Name}}. -
- Input the next step date to highlight when the meeting is set for. Once the invite is accepted by both parties the opportunity ownership will be transferred to the AE/SAE.
- After the discovery conversation and once the sales team has validated that the opportunity meets our Sales Accepted Opportunity criteria, the SAE or AE will move the opportunity to the next stage (Stage 1) and the Amount field must be populated with estimated pipeline. The date the opportunity moves from this to the next stage in the sales cycle will populate the Sales Accepted Date field on the opportunity record.
- If the details on the opportunity do not meet our Sales Accepted Opportunity criteria, the SAE or AE should move the opportunity to an 9-Unqualified stage (this is the only time an opportunity can move into 9-Unqualified stage): SAE / AE should provide a reason as to why the opportunity is deemed unqualified for coaching purposes.
- All Opps that are sales assisted must first enter this stage before they can be moved further in the pipeline. If they do not enter this stage at some point you will encounter a validation rule error.
- For renewal opportunities, 0-Pending Acceptance is only to be used if the renewal is not being actively worked by the Account Executive/Strategic Account Executive.
- Sales Dev team will not create renewal opportunities.

**Exit Criteria:**

*These activities must be completed before moving the prospect to the next stage*

- Completion of sales qualification meeting
- Validation by SAE/AE of the information collected by the Sales Development team member
- Agreed upon next step

---

### 1-Discovery

*Uncover as much intelligence about the project as you can, which will be confirmed at later stages throughout the sales cycle. Identify a business need or challenge the customer/prospect is trying to address and the potential for GitLab to solve.*

**Primary Activities** to Complete in This Stage:

- Begin filling out [MEDDPPICC](/handbook/sales/meddppicc/) - Partner, Identify Pain, Competition
- Send Plan Letter/Recap Email to Attendees- [Example](https://docs.google.com/document/d/16Gurj_MVREmKoqXTdB1F0OQ3eyq1gzbTNU8LNHHuoEM/edit)
- Create [custom deck](/handbook/sales/commercial/#opportunity-specific-slide-deck) and share with customer
- Identify Customer [contact role](/handbook/sales/meddppicc/#economic-buyer)
- Confirm Cloud Strategy & Partner engagement

**Secondary Activities** to Complete in This Stage:

*These are the more granular steps required to complete the primary activities in this stage*

- Fill out the [Opportunity Overview](/handbook/sales/command-of-the-message/command-plan/#opportunity-overview) of the Command Plan (Deal amount requirement thresholds: $5k SMB, $10k MM)
- [Rank](/handbook/sales/commercial/#account-ranking) account
- [Size the opportunity](/handbook/sales/commercial/enablement/#opp-management---managers-check-this)
- Understand the customers' partner landscape
- [Custom deck](/handbook/sales/commercial/#opportunity-specific-slide-deck) shared with customer
- Understand customer's cloud strategy
- [Identify the role](/handbook/sales/meddppicc/#economic-buyer) of customer contact: Champion, Influencer, Economic Buyer, Technical Buyer, etc.
- Deliver the [GitLab single app pitch](/handbook/sales/commercial/#custom-deck-requirements) and gather feedback from customer on vision
- Customers' [near and long term priorities](https://gitlab.edcast.com/journey/introduction-to-the-required-introduction/cards/1342269) identified
- [Next steps](/handbook/sales/commercial/#opportunity-next-steps-best-practices) filled out

**Exit Criteria:**

*These activities must be completed before moving the prospect to the next stage*

- Recap email sent to customer confirming pain points, key stakeholders, next steps, project timeline
- Scoping meeting scheduled
- Provide an estimate for the Expected Number of Users and the Expected Product for the Opportunity. This information is used to help the Customer Success team to predict their future workload as well as to help them with their hiring plans.

---

### 2-Scoping

*Validate the pain points & determine how these pain points attach to the Customer/Prospect's top business challenges, the required capabilities to achieve the desired future state, and determine how GitLab is uniquely positioned to solve the challenge.*

**Primary Activities** to Complete in This Stage:

- High-level technical requirements discussion
- Understand & document business requirements
- Internal technical resources identified
- [MEDDPPICC:](/handbook/sales/meddppicc/) Decision Criteria, Decision Process, Metrics, Champion, Economic Buyer, Competition

**Secondary Activities** to Complete in This Stage

- Recap/validation of current state of customers' SDLC
- High-level technical requirements discussion
- Understand & document business requirements
- Technical requirements captured
- [Metrics/ROI](/handbook/sales/command-of-the-message/metrics/) conversation started
- Review how GitLab will be implemented and by who, opening a discussion about GitLab and/or partner [professional services](/handbook/customer-success/professional-services-engineering/selling/#selling-gitlab-professional-services) where appropriate
- Introduce [partner/channel](https://docs.google.com/document/d/18xqRRCkIXlR7r4BvBQnK9n9zE70q-KPga-lVHhVw4n4/edit) where appropriate
- [Competitive differentiation](https://internal.gitlab.com/handbook/sales/command-of-the-message/#gitlab-differentiators)
- Provide [proof points](/handbook/sales/command-of-the-message/proof-points/), [case studies](https://gitlab.com/gitlab-com/marketing/strategic-marketing/customer-reference-content/case-study-content/-/boards/1804878?scope=all&utf8=%E2%9C%93), and [competitive info](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/competitive-intelligence/#competitive-intelligence-at-gitlab) (defensible differentiators)
- Create a [GitLab maturity/adoption](/handbook/product/product-principles/#multi-feature-usage-adoption-journey) roadmap with customer
- [Multi-thread](/handbook/sales/playbook/discovery/#lack-of-multi-threading) across the customer org
- Create an SA engagement request using the **SA Request button** on the Salesforce Opportunity. Read more about engaging SAs in the [Commercial SA Engagement Model Handbook Page](/handbook/solutions-architects/processes/commercial/).
- [Custom deck](/handbook/sales/commercial/#opportunity-specific-slide-deck) is shared with GitLab internal team members to ensure the SA that picks up the opportunity has immediate access to the custom deck
- Meeting set with SA to create a shared agenda/strategy/outcome for the technical evaluation
- SA/Account team create pre-engagement discovery/demo questions  based off of reviewed information
- [Next Steps](/handbook/sales/commercial/#opportunity-next-steps-best-practices) updated

**Exit Criteria:**

- Stakeholders and engagement plan identified
- [Command Plan](/handbook/sales/command-of-the-message/command-plan/) updated
- Completed SA/AE strategy session/meeting
- Channel and/or Alliances partner(s) engaged (if applicable)
- Establish [two engagement approaches](/handbook/sales/commercial/#custom-deck-requirements) to evaluation ([Two-Lane Selling](https://docs.google.com/document/d/1h7DCIRAQ1pRiqDF6Aebl354uoMXiXbSVLaC_XefzM6w/edit))

---

### 3-Technical Evaluation

*Validate the technical qualifications are a fit for the customer/prospect needs.*

**Primary Activities** to Complete in This Stage:

- [Channel and/or Alliances](https://docs.google.com/document/d/18xqRRCkIXlR7r4BvBQnK9n9zE70q-KPga-lVHhVw4n4/edit) partner(s) engaged (if applicable)
- Customized demo
- Trial if applicable; SA determines if this will be SA assisted or self-managed by customer
- Follow up with additional stakeholders as needed
- [MEDDPPICC:](/handbook/sales/meddppicc/#economic-buyer) Decision Criteria, Decision Process, Paper Process
- Vision pitch (why you should buy)

**Secondary Activities** to Complete in This Stage:

- Review/validate understanding of technical requirements with customer
- Recorded Tailored Demo with customer
- [First Order](/handbook/sales/commercial/#mid-market-key-accounts-first-order) or [Named Accounts](/handbook/sales/commercial/#mid-market-account-executive): SA may submit a request for a Slack channel if the technical evaluation has a need for a more asynchronous communication approach.
- SA will determine if trial is assisted by the SA or self-managed by customer
- Work with customer to determine success criteria for eval, time frame, and next steps
- Understand buying process, e.g. paper process, approvals, signatures, etc.
- If a [trial license extension](/handbook/support/license-and-renewals/workflows/self-managed/trials/) is being requested from a customer, discuss with AE and prepare a project plan with the customer before granting an extension.
- Other teams/business units identified that may need to be involved  (Other points of entry)
- Additional demos scheduled for stakeholders with unique needs
- [Opportunity Consults and Lightweight Deal Reviews](/handbook/sales/commercial/#opportunity-consults-and-lightweight-deal-reviews) with manager if monetary thresholds are met
- Identify  the "why" if customer decides not to move forward and document reasons in SFDC/notes
- [Next steps](/handbook/sales/commercial/#opportunity-next-steps-best-practices) updated
- If the relationship is owned by a Partner, share applicable case studies, example projects, and/or relevant documentation
- If going through a Partner, ensure SA is briefed on the opportunity and any services SOWs

**Exit Criteria:**

- Demo output shared with customer (slide decks, recordings, collateral, etc.)
- ROI measures determined and validated
- Mutual agreement to move to proposal and identified next steps
- Professional Services identified and sourced (Partner or internal) if applicable
- [MEDDPPICC](/handbook/sales/meddppicc/#economic-buyer): Decision Criteria, Decision Process, Paper Process

---

### 4-Proposal

*Business and technical challenges and been uncovered and resolved. The goal is to meet with the customer, review & collaboratively fine-tune an ROI/justification. Prepare with the champion to meet with Economic Buyer on proposal OR enable champion to sell internally on GitLab's behalf. Prepare deck or pricing doc that will be presented to Economic Buyer.*

**Primary Activities** to Complete in This Stage:

- Deliver MSA and Subscription Agreement
- Proposal provided
- Create mutual close plan; identify risks
- Create & share SOW
- Understand the procurement process & requirements
- Understand timeline

**Secondary Activities** to Complete in This Stage:

- Quote through partner where applicable
- [Next steps](/handbook/sales/commercial/#opportunity-next-steps-best-practices) updated
- If a [referenceable customer](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/customer-advocacy/) update the Referenceable Customer section on the Account object with appropriate reference information
- AE builds the quote and prepares for review with buyer
- Deliver formal contract to prospect
- Proposal is aligned with customers [Positive Business Outcomes](/handbook/sales/command-of-the-message/metrics/#connect-metrics-with-positive-business-outcomes)
- Partner includes any relevant services SOWs
- Deliver MSA separately if applicable
- Create mutual close plan
- Identify any risks
- Creation of SOW and scoping of work for Professional Services

**Exit Criteria:**

- Agreement on mutual close plan/timeline (work with the customer on short/long term purchase options to understand timeline)
- Procurement process confirmed (consider if using a Partner)
- Implementation strategy confirmed
- [MEDDPPICC](/handbook/sales/meddppicc/#economic-buyer) - paper process

---

### 5-Negotiating

*Finalize the agreement, pricing, business, and legal terms.*

**Primary Activities** to Complete in This Stage:

- Negotiate business terms
- Negotiate pricing
- Negotiate [legal terms](https://about.gitlab.com/terms/#subscription/)
- Confirm contacts to receive the [digital onboarding](/handbook/sales/field-operations/customer-success-operations/cs-ops-programs/#digital-customer-programs) emails post deal closure (< $50K)

**Secondary Activities** to Complete in This Stage:

- Under $50K: SA and AE can begin preparing the contacts to receive [digital onboarding](/handbook/sales/field-operations/customer-success-operations/cs-ops-programs/#digital-customer-programs) emails upon closing of a deal
- Agreement on business terms (All proposals should include the standard [GitLab Terms](https://about.gitlab.com/terms/#subscription/))
- If the Account is seeking to use their own paper, requests will only be entertained if the opportunity is greater than $100k, and the request should be sent to Legal by creating a Legal case in SalesForce, following the process found [here](/handbook/sales/field-operations/order-processing/#request-for-gitlab-review-of-customer-edits-to-gitlab-template-or-review-of-customer-agreement-template).
- Determine if customer will be referenceable when the opportunity closes
- Price/ Final terms negotiations
- Leverage partner to help close deal or support them in closing a Partner Sourced deal

**Exit Criteria:**

- Customer has agreed to business terms
- Customer has agreed to legal terms
- Quote & Agreement ready to be routed for signature
- AE has a clear timeline for when the OA will be signed and returned and implementation start date

---

### 6-Awaiting Signature

*Documents are in their final state ready to be executed.*

**Primary Activities** to Complete in This Stage:

- $50K+ deals- [SA/AE introduce CSM](/handbook/customer-success/comm-sales/#sa-to-csm-new-accounts) (introducing Partner were applicable)
- Under $50K: SA and AE can begin preparing the contacts for receiving [digital onboarding](/handbook/sales/field-operations/customer-success-operations/cs-ops-programs/#digital-customer-programs) emails upon closing of a deal
- CSM creates [Success Plan](/handbook/customer-success/csm/csm-manager/#success-plan-review) (working with Partner where applicable)

**Exit Criteria:**

- Fully executed documents received
- Attach fully executed documents to SFDC opportunity (validate AE uploads)
- Fully executed documents received
- PO (if applicable) has been received
- Complete vendor registration process
- [EULA](/handbook/legal/subscription-agreement/#subscription-agreement) (End User License Agreement) accepted by end-user

---

### 7-Closing

*Verifying the completeness of the documentation and opportunity to confirm ready to be Closed Won. Applies to sales assisted transactions only.*

**Primary Activities** to Complete in This Stage:

- SFDC Opp, AE clicks "Submit for Approval" and adds Closed Won reason and details. This submits opp for approval and puts it to 7-Closing and locks the record from any further edits.
- Opp flows into a report for Deal Desk to review for booking
- Signed Order Form (OF) or [PO referencing Quote](/handbook/sales/field-operations/order-processing/#opportunity-booking-requirements)
- Order Form matches quote and opportunity
- Order Form fully executed (Signature & Date)
- Approve with optional reason noted
- Approval status = Deal Desk Approved and goes to billing
- Billing reviews/approves and the becomes Closed Won and Approval Status = Approved
- If rejected, add notes on reasons and sends an email to the opp owner. Opp can take action based on comments.
- If complicated, reject and send chatter to rep. Opp will revert back to Awaiting Signature, which unlocks the opp and the rep can respond.

**Exit Criteria:**

- Once Deal Desk and Billing approve the opp and change the Approval Status to Approved, the system automatically moves it to Closed Won

---

### Closed Won

*Congratulations!! The terms have been agreed to by both parties and the quote has been approved by Finance.*

- CSM starts new [customer engagement](/handbook/customer-success/comm-sales/#account-executive-to-csm-existing-accounts-without-a-csm) ($50K+)
- AE engages with the customer & Partner (where applicable) to ensure success
- Kick-off Partner Services (if applicable)
- AE to schedule an initial 30 day follow up meeting with the customer (Named/Territory, + higher value opportunities)
- Named/Territory AE - create account review cadence with customer
- Named/Territory AE creates 18-24 month growth plan based on [Account Rank](/handbook/sales/commercial/#account-ranking) of 1, 1.5, and 2
- AE builds case study expectations with the customer (how far out will you be able to give me feedback about what's working, what's not, and when we might be able to go to legal with a case study? What would we need to do to earn your respect to build a case study, or would you be willing to meet with another customer as a reference? Or participate in a panel, e.g.)
- CSM assigned account - establish [EBR](/handbook/customer-success/csm/ebr/) process for high priority accts
- Professional Services introduced (if applicable)
- Initiate customer onboarding or premium support onboarding (accts with no CSM)
- [First Order handoff](/handbook/sales/commercial/#first-order-handoff-process) to Named Account AE

---

### 8-Closed Lost

*An opportunity was lost and the prospect/customer has decided not to pursue the purchase of GitLab*

**Primary Activities** to Complete in This Stage:

- Select all applicable SFDC Closed Lost Reasons
- Evaluate if the prospect should be placed in a specific nurture campaign
- Ensure all notes/next steps for potential re-engagement have been updated
- Schedule "check-in" calls to uncover new opportunities in high potential closed-lost accounts
- Where applicable schedule Partner call to review loss and explore future opportunities
- What lesson learned should you share with your manager to help progress your career?
