---
title: Mid-Market First Order
description: >-
  Mid-Market First Order processes for prospecting, managing, and cultivating accounts.
---

## Mid Market Key Accounts First Order Mission Statement

The Mid-Market Key Accounts First Order team was started to create and scale the process of landing key new logos for GitLab Mid-Market Sales. We venture to do this efficiently, scalably, and repeatably while fostering the core [CREDIT values of GitLab](/handbook/values/). As we grow, the goal is to take these processes throughout Commercial and Enterprise Sales.

As a First Order team, we strive to be obsessed with customer success, and aim to sell to IT professionals in a manner that is efficient, comfortable, and honest. We give first and use the resources available to us to create a buying environment that will enable a relationship to foster naturally with GitLab.

We uphold GitLab brand integrity though our outreach, and we collaborate to ensure we have the skills necessary to execute at the highest level possible.

## Prospecting

### Account Research

This part will help you with:

1. Becoming effective in Account Research
2. Prioritizing the right accounts
3. Finding new greenfield accounts
4. Building a monthly target account strategy

#### SalesForce existing accounts

Everyone has a book of business of 700-1000 accounts. In order to prioritize your time effectively use the [MMKAFO - My Accounts Report](https://gitlab.my.salesforce.com/00O8X000008QuqP). This [training video](https://gitlab.zoom.us/rec/share/MNUlHlU-91xHVg8nMBHM-rpd74Cg9xGQMrbYbNFqj4LtvG2qGVHJhg5hm8CbzmVv.yAzAYbT7hjU1N-1r) will explain how we use the report, what we focus on in the report, and how often we should be using this report. Please contact Jacob Potter for the video passcode.

This report filters by 6 main categories:

| Prospecting Filters    |  Description       |
| :---- | :---- |
| [LamDevCount](/handbook/sales/field-operations/sales-systems/gtm-technical-documentation/#landed-addressable-market-lam) | minimal 50 developers and for Rank 1.5 prospecting 100+ |
| Industries | FinTech, Healthcare (US only), IT, Internet Software, Software (excluding IT Software Consulting firms)|
| CE users | Companies that are using the free Community Edition of our product |
| Location | Accounts that have Headquarters located in Metropolean cities |
| Free users with CI runner minutes bought | uncovered new accounts that are using GitLab free but are paying for CI runner minutes |
| [DemandBase](/handbook/marketing/account-based-marketing/demandbase/)  | shows traction / interest of accounts that are engaging with GitLab |

#### Greenfield accounts (accounts not in Salesforce)

| Source    |  Description       |
| :---- | :---- |
| Salesforce Navigator | Training video|
|[Termsheet](https://fortune.com/newsletter/termsheet)| Subscribe to the newsletter |
|Channel & Alliances | collaborate with your Territory responsible Channel Manager / Alliances Manager|
| [Built In](https://builtin.com/) | Prospecting Resource |
| [Seeking Alpha](https://seekingalpha.com/) | Prospecting Resource |
| Google Alerts | Follow a company with their new google content |
| Local Country Financial Newspaper | Online versions |

#### Monthly Account Strategy

1. Every month it's important to review if you are still going after the accounts that are most likely to start conversations with us
2. The [Monthly Account Strategy Checklist](https://gitlab.com/gitlab-com/sales-team/commercial-sales/-/issues/237) helps to keep this focus
3. At the start of the month review your account view and pick from the top 100 accounts 15-20 accounts to focus on for the month. For each account pull 1-2 contacts from Zoominfo into Salesforce
4. The 15-20 accounts are a dynamic list. Once you have spoken with an account and know you can unqualify that account, remove the account from the 15-20 list and add a new account
5. Monday and Fridays are best used for Account research, adding new accounts, import new contacts and enroll in sequence
6. Tuesday, Wednesday, Thursday are best used for Outbound Sequence Activities

## First Order Skills and Skills Development

### First Meeting

### Paid POC

#### **What is a Paid Proof of Concept?**

1. This is part of Two Lane Selling
1. A paid POC is a year-long GitLab subscription we offer prospects we are in active discussions with so that a small segment of their tech team can get started using GitLab Premium or Ultimate immediately. It is at the forefront of what First Order is about as it encourages a quick adoption to demonstrate GitLab's value sooner and enables the Named team to grow the account.
1. We would typically recommend a team of 5-20 people get started on the Paid POC
1. We would typically recommend a team that is embarking on a new project be involved with the Paid POC so that they can start fresh using GitLab for the whole SDLC.
1. The duration is a minimum of 12 months
1. A discount can be applied according to the [discount matrix](https://docs.google.com/document/d/1-CH-uH_zr0qaVaV1QbmVZ1rF669DsaUeq9w-q1QiKPE/edit#). Beware that in order for an opportunity to count as a new logo, it needs to be above $1,000 ARR and have a growth potential of more than 50 seats in the future.

#### **Why recommend the Paid POC to an active opportunity?**

1. A Paid POC promotes a shorter sales cycle as the financial investment is significantly lower and the allocated resources required from the customer to get started are much smaller. It mitigates any perceived risk prospects have to get started.
1. It typically enables our champion to get started as soon as possible as they will not need budget approval since the investment is typically below the approval threshold.
1. It doesn't restrict customers to a 1 month trial which many find limiting and therefore postpone initiating it.
1. It gives customers much needed time to explore the GitLab features and formulate a concise and robust ROI to make internal justification of a wide team adoption easier.
1. It provides the customer with a GitLab Account Manager.
1. It provides them with [Priority Support](https://about.gitlab.com/support/).
1. It can be an exciting initiative for a GitLab champion starting a new project as it empowers them to use GitLab as Single Platform without having to go through all the lengthy approvals which delays the start of their project.
1. You can use [this presentation deck](https://docs.google.com/presentation/d/1MoiL4EkI2goklfSk-rCp_vivbsag9hrEHbd6FVwKy7Q/edit#slide=id.g889353d428_0_0) to help you pitch the Paid POC (particulary refer to slide 9)

### Discovery

### FORC Calls

1. First Order Reviewed Call ('FORC') pronounced Force are Chorus calls First Order AEs review on behalf of their peers to provide feedback and encourage collaboration and skill development.
1. Ideally, AEs should review 1-2 calls per week per AE.
1. The AE should send the call to someone transatlantic to review for early AM local time.
1. The AE who wishes their call to be reviewed should name 1-2 concrete things they were working on during that call and send the Chorus link. Examples include, two lane selling, active listening, price negotiation, GitLab pitch, back of napkin ROI etc.
1. The reviewer should review the call they receive and log their notes in SFDC under the opportunity using the following format "FORC for Company Name" so that we can report on them.

## Working Cross-Functionally

### Field Marketing

Collaboration with Field Marketing helps to speed up outbound efforts by changing cold engagements into warmer contacts and help to speed up conversations for pipeline building.

1. Understand who is the Field Marketing Manager that is responsible for the events in your region
1. Join the Bi-weekly Field Marketing calls where the Field Marketing Manager gives updates about the upcoming events in your territory. If you're not aware who this is, reach out to your team members that can add you to these calls
1. Participate in events - Remote or In-Person. This is a great way to make yourself a trusted face for GitLab in your territory community. Be proactive yourself in participation. The more you participate the more Field Marketing will include you. You can even become a speaker if you have aspirations to do this.
1. Be on top of events that Field Marketing organizes which are tailored for Executives. These events give you a door into directly speaking with decision makers.
1. Use events for prospecting purposes. When you know there is an event coming up that is of interest to your contact at a target account - provide value and drive attendance to the event.
1. Field Marketing is also there to help to organize prospect specific events (Lunch and Learn sessions). Reach out to the Territory Field Marketing Manager to discuss how to schedule this
1. Work closely together with your BDR / SDR who are the ones that follow up on the leads that participated in events. Make sure to explain which leads are important for you to get a priority follow up

### SDR/BDR Team

The BDR and SDR team are responsible for pre-qualifying leads and setting meetings (IQM's) for the First Order team. [BDR's](/handbook/marketing/sales-development/#sales-development-representatives-sdrs---inbound-focused)  are focused on outbound while [SDR's](/handbook/marketing/sales-development/#sales-development-representatives-sdrs---inbound-focused) are responsible for the inbound lead flow. It's important to understand how to collaborate with both teams:

#### BDR's

1. Get yourself familiar with the [outbound responsibilities](/handbook/marketing/sales-development/#outbound-workflow) of the BDR team and their way of working
1. Set up time with your aligned BDR and discuss expectations before starting to work together. Discuss how the BDR can help you succeed and understand how you can help the BDR to succeed.
1. Schedule a weekly or bi-weekly cadence with your BDR to strategize outbound efforts for your territory. During this meeting discuss:
    - Which accounts to go after and why. Select X number of accounts that match with what BDR's are expected to go after per week
    - Strategy to go into these accounts. Which persona's to target and which messaging to use. Discuss an approach before reaching out
    - What has been uncovered about the accounts during the outbound efforts
    - What are the next steps we're going to take based on the gathered information?
    - Results: How many IQM's booked last week / last 2 weeks or what kind of golden information has been uncovered?
1. First Order reps and BDR's are both going outbound into accounts. Make sure it's always visible to both parties who work which accounts. This is [the report](https://www.google.com/url?q=https://gitlab.my.salesforce.com/00O4M000004aiUw?dbw%3D1&sa=D&source=docs&ust=1651508616369703&usg=AOvVaw3BUuFQ4ju9byXYL_MoRsow) BDR's use to track the accounts they actively work on. For First Order we currently track this in a spreadsheet you can create yourself
1. Make sure both parties always check historical outbound efforts done in an account to prevent spamming outreach before reaching out
1. Understand that the way of working from the BDR organization is different from the First Order cadence but both align on call heavy outreach. BDR's have different outreach sequences in place than the First Order team but both heavily focus on calls
1. Consistency is key. Make sure you meet with your BDR and discuss results, progress strategy every week or bi-weekly. From there set the next steps.

### SDR's

1. Get yourself familiar with the [inbound responsibilities](/handbook/marketing/sales-development/#bdr-and-sdr-inbound-workflow--process) of the SDR team and their way of working
1. FO AEs are not meant to be working leads. This is why it is critical to be aware of incoming leads your SDRs are receiving for your territory and work effectively and together to drive conversations with leads
1. The SDR team works round-robin which means you will work with all the SDR's in your region. It's recommended to set up a coffee chat with all of them so you know which SDR's you're going to collaborate with
1. SDR's don't have visibility into accounts that are important to you. That's why it's recommended to create visibility into the leads that are coming in for your own territory.
1. If there is an incoming lead that is part of a high priority account chatter the assigned SDR on Salesforce to pick up the lead with high priority. You can ask the SDR Manager of your region to share a report that shows all incoming leads per Quarter and add filters to the report so it is set for only your territory. Team members or FO Manager can help with this

### Channel

Working with local partners can speed up your sales cycles, increase the overall ARR of your opportunity and help you tackle language barriers.

#### **The process of doing outbound initiatives with Partners**

1. Familiarize yourself with partners in your territory by searching on GitLab Partner Locator or by speaking to the Channel Manager(s) in your Region.
1. Set up calls with channel partners to understand their business, areas of expertise and how they work with GitLab.
1. Select 2-3 of channel partners per quarter you want to actively work with and arrange bi monthly meetings to strategize on prospect accounts.
    1. To begin, select partners you have already engaged until you are able to better determine which partners are best suited for what service.
    1. You can always consult your Channel manager to advise you on which partners are most active in your segment or are actively working on GitLab initiatives.
1. Prepare a list of prospect accounts you want to outbound (ideally Rank 1 or 1,5 accounts) and share with your preferred partners to see how they can help with prospecting. Partners may have worked with top tier accounts in the past and can provide warm introductions or they can help us with prospecting as some have their own GitLab dedicated BDR teams.
    1. Work together with your channel manager to help partners arrange webinars, workshops etc.
    1. Promote partners webinars by creating [Outreach Sequences](https://app1a.outreach.io/sequences/7941) to share with prospects.
    1. If you don't have any contacts on SFDC that you can invite, use a LinkedIn Sequence to invite fresh prospects to webinars.

#### **Working on opportunities with Partners**

1. Familiarize yourself with the GitLab [Partner Program Discount Details](https://docs.google.com/document/d/1lMQHlSMEJQCH1HJnr-MdeVozZ9HJI0oVPmfbPWbJkyw/edit)
1. If a Channel Manager assigns a Deal Registration to your name, ask them to introduce you to the partner, if you don't already have a relationship with them.
1. Set up a short call with the Partner who registered the opportunity to find out details about the opportunity (use case,pain points, timeline etc). This will help you complete the Command Plan.
1. For opportunities where you introduce a partner as a reseller to the prospect, a co-sell discount will apply. All partners can resell opportunities and they can often do this in the local currency and with more flexible payment terms which is something to consider if your prospect brings up these objections.

### **Important Links**

1. [Details on what our channel program looks like](https://partners.gitlab.com/English/)
1. [GitLab Partner Locator](https://partners.gitlab.com/English/directory/)
1. [Program Discount Details](https://docs.google.com/document/d/1lMQHlSMEJQCH1HJnr-MdeVozZ9HJI0oVPmfbPWbJkyw/edit)
1. [Channel Sales HB Page](https://docs.google.com/document/d/18xqRRCkIXlR7r4BvBQnK9n9zE70q-KPga-lVHhVw4n4/edit)

### Alliances

The Alliances team can assist with connecting you to the Alliance Partner sales and technical counterparts to accelerate conversations in prospect accounts.

1. Get yourself familiar with the [Alliances](https://gitlab-com.gitlab.io/alliances/alliances-internal/) team, what they do and how they can help
1. Select a list of your top 10 accounts where you know they are using one of our Alliances Partners
1. Schedule time with the Alliances Manager in your region and bring up that you'd like to be introduced to the Partner representative from the 10 selected accounts. To get in contact with the right Alliances Manager post a new message to the #cloud-aws or #cloud-gcp Slack channel with a brief description of the request. The alliance team member(s) managing the partnership will follow-up with next steps
1. The Alliances Manager is responsible for bringing you in contact with the dedicated customer teams from the Partner (AWS, GCP etc) and set up the meetings
1. Leverage Alliances help you to break into new accounts where there is already a warm relationship with the Alliances Partner who can help to warm introduce you to the right people in the company
1. Make sure you understand what the benefit for the Alliances Partner is to introduce you. Always make sure you understand how we can help them and the customer and align your GitLab proposal to this.

### MM-Named/ Territory

### CS

## How First Order Measures Success

## First Order Logistics

### Rules of Engagement Between MMKAFO and MM-Territory

### MMKAFO to Named Handoff Motion

### Definition of what counts as a logo

## Frequently Asked Questions (FAQ)

1. Which departments does the FO team work most closely with and who are the main contacts?
1. Which internal meetings and slack channels are important to attend/follow?
1. What accounts can MM FO work (FO vs. Territory) and what counts as a new logo?
1. How many opportunities are at least expected to be created each month?
1. What does the handoff process post sale look like?
1. Who is responsible to response to incoming leads?
1. Which leads can be worked by the FO AE?
1. What accounts should be worked by the BDR team?
1. What if a client purchases seats online after talking to the AE?
1. How do I create a quote?
1. Where can I find sales material like customer deck, case studies etc.?
1. Why do we record calls?
1. What's important to know about accurate forcasting?
(Red/Green, close date convention)
1. What is the most efficient way of prospecting? What tools are being used to find potential clients?
1. What are good call notes / next steps?
1. How does GitLab handle discount requests? What is the guidline?
