---
title: "Highspot at GitLab"
description: "GitLab uses Highspot as its Sales Asset Management System. This page shares more about how Highspot is used at GitLab."
---

## Highspot at GitLab

Highspot is a sales enablement tool we use to gather, categorize, and share content within GitLab and externally to our customers. It brings together native content and guidance, training and coaching, and engagement intelligence – all supported by actionable analytics. GitLab uses Highspot as a sales portal to:

1. **Provide a single repository** in which GitLab's go-to-market (GTM) team members can find all of the resources they need.
1. **Enable more efficient discovery** of new resources and content.
1. **Drive consistency in GitLab collateral** including the branding and messaging across assets.
1. **Attribute revenue to GitLab content** to discover ROI and enable a tighter feedback loop between Sales and Marketing.

To learn more about Highspot's features, check out this [Highspot in Action video](https://drive.google.com/file/d/1SL27EzQUKiHSUN_QHxVlIXUrRJivhFNq/view?usp=sharing).

### Why Highspot?

Because of the pace of business and rapid growth of the GitLab team, efficiently organizing and distributing content are key pain points for the GitLab GTM organization.

Upon surveying members of the Field team, we found that 92% of the Field organization felt that finding the resources they needed to do their jobs was moderate-difficult ([source](https://docs.google.com/presentation/d/186Lo_e4kpUeYEbXlYEEK_Kvo1A0Ixjvcofs4MJ8AIM0/edit#slide=id.gb405fa4b55_2_25)). Furthermore, we found that 85% of the organization only finds the resources they are looking for some of the time ([source](https://docs.google.com/presentation/d/186Lo_e4kpUeYEbXlYEEK_Kvo1A0Ixjvcofs4MJ8AIM0/edit#slide=id.gb405fa4b55_2_43)). Lastly, we found that Enterprise SAEs spend an average of two hours per week simply searching for Sales content, which equates to 200 hours per week across the entire Enterprise team that could be used for revenue-generating activities instead ([source](https://docs.google.com/presentation/d/186Lo_e4kpUeYEbXlYEEK_Kvo1A0Ixjvcofs4MJ8AIM0/edit#slide=id.gc0a7571506_0_5)).

GitLab ultimately chose to onboard Highspot as a sales asset management system to increase the efficiency of marketing spend, improve sales productivity and drive more visibility around content adoption and performance.

### Communicating with the Highspot Team

Highspot is managed by the [Field Enablement organization](/handbook/sales/field-operations/field-enablement/), specifically, the [Field Communications & Content](/handbook/sales/field-communications) team. The team leverages a contract agency, [Arnic Business Solutions](https://arnicbizsolutions.com/), to help manage the day-to-day administration of our Highspot instance.

There are two primary Slack channels to communicate with platform DRIs and other content owners / contributors about Highspot at GitLab:

1. #highspot-help-center: Public channel for team members to ask questions and get updates regarding Highspot.
1. #highspot-content-owners: Public channel for content owners to ask questions and collaborate on ongoing upkeep and growth of Highspot instance.

### Submitting Highspot Requests

The Highspot team creates GitLab Issue Templates within the Enablement Project for common requests:

1. Looking for access to Highspot? Follow the typical [Access Request process](/handbook/it/end-user-services/onboarding-access-requests/access-requests/#individual-or-bulk-access-request) to submit your request. Tech stack provisioners to review and approve your request can be found [here](https://gitlab.com/gitlab-com/www-gitlab-com/-/blob/master/data/tech_stack.yml).
1. Need to complete Highspot role-based onboarding? Following the instructions within [this template](https://gitlab.com/gitlab-com/sales-team/field-operations/enablement/-/issues/new?issuable_template=Highspot-Role-Onboarding).

### Key definitions

1. **Spots** - Spots are similar to an asset folder. We use spots to provide quick access to specific content for a certain group or purpose. Spots are the basic building blocks of Highspot. User access to content is determined at the Spot level. See [GitLab Spots](/handbook/sales/field-communications/gitlab-highspot/#gitlab-spots) for a full list of Spots.
1. **SmartPage** - SmartPages are similar to landing pages. Content Owners can create SmartPages to display curated content and provide instructions and CTAs for field members.
1. **Lists & List Groups** - Lists work as filters, and make it easier to find the content you need. Lists can then be collected under list groups for further organization.
1. **Role: Field User** - Field users, or Contributors, have the ability to pitch items to prospects and customers, view pitch performance analytics, and submit content to Highspot Spot Owners for reivew and publishing. This is the access level that most GitLab GTM team members will have.
1. **Role: Content Owners** - Content owners, or Publishers, have the ability to add and manage content, design and build SmartPages, and create and manage lists and Spots. Content Owners are responsible for the management of content in Highspot in one or more spots. They can also make high-level changes to the search structure as needed. Note that all content owners will need to complete the [Content Contributor Training](/handbook/sales/field-communications/gitlab-highspot/#highspot-trainings) prior to being provisioned access to contribute to a spot.
1. **Role: Spot Owner** - Spot Owners are the Directly Responsible Individual (DRI) for a Spot, and oversee content governance and usage performance for the Spot and its users. Note that all spot owners will need to complete the [Content Contributor Training](/handbook/sales/field-communications/gitlab-highspot/#highspot-trainings) prior to being provisioned access to contribute to a spot.
   1. The key difference between Owners/Co-Owners and Editors is that Owners/Co-Owners can delete a spot while Editors cannot.
1. **Role: Analyst** - Analysts have the ability to create reports within the Analytics section of Highspot and view reports in the Analytics Spot. All Field Managers and above have Analyst permissions so they can view team-level reporting.
1. **Contribution Status: Locked** - Only Spot Editors (i.e. Content Owners) can contribute content to these spots. All can view.
1. **Contribution Status: Open - Review Required** – GitLab team members can contribute to these spots but review and approval will be required from a designated content reviewer before the content is viewable by all users.
1. **Contribution Status: Open** - GitLab team members can contribute content to these spots without the need for review.
1. **Internal & External Content** - All content in Highspot will be marked as either internal or external:
   1. **Internal** - This content is for internal consumption/enablement only. Under NO circumstances should this content be shared with external audiences - customers, prospects, partners, etc. You should also not download this content onto your local device. (You can always bookmark content to your personal spot to revisit later.) All items marked as internal cannot be pitched (the pitch function is disabled).
   1. **External** - This content has been reviewed and approved for distribution to external audiences in a small forum (customer/partner call, etc.). You should *always* consult GitLab Legal before distributing content to a large audience (ex. conference or GitLab event), regardless of its distinction in Highspot. All items marked as external can be pitched to prospects and customers.

### GitLab Spots

| Spot Title | Description |  Viewable By | Contribution Status |
| ------ | ------ | ------ | ------ |
| **Global Ecosystem** | Partner marketing material to share within our Global Ecosystem, including channel,  alliances, and internal GitLab team members. | All internal team members | Locked |
| **Competitive Intelligence** | All internal competitive matters; to be used for self-education about our competitors. | All internal team members | Locked |
| **Customer Success** | CS Operations, Gainsight, Professional Services, Solutions Architects, Technical Account Management. | All internal team members | Locked |
| **Customer Advocacy** | Customer case studies, video testimonials, quotes, peer reviews, and accolades from G2, Gartner, and Forrester. | All internal team members | Locked |
| **Customer Outreach** | Resources and insights to support customer collaboration, including case studies, industry research, personas, value drivers, analyst reports, marketing campaigns, and events. | All internal team members | Locked |
| **Field Contributed Content** | Collateral that Field team members have created for customers and prospects – examples of "what good looks like." | All internal team members | Open - Review Required |
| **Field Strategy and Enablement** | Training, onboarding, organization-wide changes or large projects. | All internal team members | Locked |
| **GitLab Duo (AI)** | Resources to understand our developing AI strategy and effectively communicate with prospects and customers. |  All internal team members | Locked |
| **Solution Selling** | What to know, what to say, what to show, what to do across our primary [GitLab Solutions](https://about.gitlab.com/solutions/#by-solution) |   All internal team members | Locked |
| **Company Pitch Templates** | Curated messages and content you can pitch from Highspot or directly within associated Gmail or Outreach accounts. |  All internal team members | Locked |
| **Reporting (Analytics)** | Sample analytics reports that Analysts can view and modify to help answer key business questions. | Analysts in GitLab | Locked |
| **Highspot User Guide** | This spot features quick tutorials, tips & tricks, analytics reports and more. |  All internal team members | Locked |
| **Personal Spot** | Each team member with a Highspot account will have their own personal spot that they can use to upload content of their own. Naming convention is `[Your Account First Name] Spot`. | Account holder only | Open |

### Availability and Access Requests

Teams with access to Highspot include:

1. Sales
1. Customer Success Management
1. Renewals
1. Professional Services
1. Partner
1. Revenue Strategy, Operations & Enablement (RSOE)
1. Sales Development
1. Strategic Marketing (Product Marketing, Customer Reference, Analyst Relations, Competitive Intelligence)
1. Field Marketing
1. Developer Relations
1. Corporate Communications

Non-active users, such as team members who have left the company, will be removed from Highspot on a regular basis in order to open seats within the tool.

Access to the tool is provisioned via SSO in Okta. To access Highspot, please navigate through the Highspot tile in your Okta dashboard. If you do not have access via your Okta dashboard, please submit an [Access Request](/handbook/it/end-user-services/onboarding-access-requests/access-requests/#individual-or-bulk-access-request). Please take special note of the available [Highspot trainings](/handbook/sales/field-communications/gitlab-highspot/#highspot-trainings) and plan to complete one or both depending on your scope of access in the platform.

### Highspot Trainings

There are two training courses for Highspot available in the GitLab Level Up platform. These courses can also be found in the [Highspot User Guide Spot](https://gitlab.highspot.com/spots/61a55821bfc73fc1b19395f1#evt7szob8u) for later reference:

1. [Highspot User Training](https://university.gitlab.com/learn/course/highspot-user/main/highspot-user-training?client=internal-team-members) - Foundational knowledge that all Highspot users should possess to get the most out of the platform. This includes a brief tour of the tool, how to search and discover content, how to share content for buyer engagement and how to leverage Highspot for personal organization and efficiency. All new Field team members should complete this course as a part of the [Sales Quick Start](/handbook/sales/onboarding/) training program in onboarding. Non-Field team members who gain access to Highspot via an [access request](/handbook/sales/field-communications/gitlab-highspot/#availability-and-access-requests) will be highly encouraged to complete this training upon being provisioned access.
1. [Highspot Content Contributor Training](https://university.gitlab.com/learn/course/highspot-content-contributor-training/main/highspot-content-contributor-training) - All Content Owners and Content Contributors in Highspot are required to complete this training prior to being provisioned edit access to any spot. This ensures that all contributors are trained to uphold GitLab's Highspot governance best-practices to support the best end user experience.

## Guidance for Field Team

### Finding Content | Searching and Browsing in Highspot

Highspot provides powerful ways to browse and filter content and helps you pinpoint the most effective content for any given situation.

#### Browse Tag Lists

To quickly explore a spot, you can click on a tag list in the left nav pane. The main area will show only the items tagged within that list. For example, in the screenshot below, the **eBook** tag list shows all items that match that asset type found in the **Customer-Facing Content** spot.

![Screenshot_AddBookmark](/handbook/sales/field-communications/gitlab-highspot/images/Example_BrowseTagLists2.png)

#### Filter Tag Lists

You can also use Filter mode to narrow down all items in a spot to just the content you need, much like filtering for products in an e-commerce application. To enter **Filter** mode, click the funnel icon in the left nav pane.

![Screenshot_AddBookmark](/handbook/sales/field-communications/gitlab-highspot/images/Example_FilterTagLIsts.png)

You'll see lists with checkboxes for narrowing down the results. In the filtered view of the **Solution Selling** spot, pictured below, you can filter results based on Asset Type and Buyer Persona, for example. You can also use your own activity to filter results. In this case, if you've copied or viewed an asset, you can click Copied and Viewed under Your Activity.

![Screenshot_AddBookmark](/handbook/sales/field-communications/gitlab-highspot/images/Example_ListsAndCheckboxes.png)

#### Spot Sort

Another way to navigate a spot is by using Sort under the spot title:

![Screenshot_AddBookmark](/handbook/sales/field-communications/gitlab-highspot/images/Example_SpotSort.png)

Here is an overview of each sort:

- **Popularity:** Item determined by the following types of activities: Views, Pitches, Shares, Downloads, Bookmarks, Remixes, and Copies. Shows each item only once, grouped by:
  - **Trending:** Popular items for the last 2 weeks
  - **Most Popular:** Most popular items for all time
  - **By Popularity:** Remaining items, sorted from the most to the least popular
- **Rating:** Items sorted by rating, starting with highest rated. Users can rate items and optionally leave reviews.
- **Your Activity Date:** Items sorted by your last activity. Activity includes any interaction with the items, such as bookmarking, downloading, and reviewing.
- **Date Added:** Items sorted by the date they were added to Highspot.
- **Alphabetical:** Items sorted alphabetically, from A-Z.

#### Search for Content

One of the quickest and easiest ways to find content in Highspot is through search. You can run a quick search across the entire site by entering your query and clicking return. When you type in a search term, individual items will appear at the top of the list. Different types of items in the search results are divided by lines. You can use the icons to quickly identify results by type: a target for Spot, a headshot outline for person, three heads for Group, etc.

![Screenshot_AddBookmark](/handbook/sales/field-communications/gitlab-highspot/images/Example_SearchforContent.png)

You'll see the Search results page, pictured below:

![Screenshot_AddBookmark](/handbook/sales/field-communications/gitlab-highspot/images/Example_SearchResultsPage.png)

You can scroll through the search results and use the left nav to filter down the results.

Learn more about browsing and searching in the Highspot Help Center:

- [Browse and Filter Spots](https://help.highspot.com/hc/en-us/articles/214982023-Browse-and-filter-spots)
- [Search for Content](https://help.highspot.com/hc/en-us/articles/213579426-Search-for-content)
- [Advanced search](https://help.highspot.com/hc/en-us/articles/216378503-Advanced-Search)

**Complete This:** Complete the [Highspot User Training in Level Up](https://university.gitlab.com/learn/course/highspot-user/main/highspot-user-training?client=internal-team-members) to learn more about searching and discovering content in Highspot.

### Pitching | Effectively Engage Buyers

#### What is Pitching?

Pitching allows you to easily and flexibly share content with your customers and prospects. Pitch it live, email it from Highspot, or create a custom link and send it through Gmail, LinkedIn, and more.

#### Why Pitch?

Pitching through Highspot improves conversion rates and helps you more effectively engage buyers. It gives you the ability to customize, personalize, and send content from Highspot through virtually any channel and receive real-time, actionable notifications when prospects or customers interact with your content. These analytics help sales and marketing teams understand what works best to drive buyer engagement so they can better optimize their sales processes and sales content.

#### How to Add a Custom Signature to Email Pitches

Adding a custom email signature to your Highspot profile will give your email Pitches a consistent look and feel for recipients.

- **To add your email signature, follow these steps:**
  - Log into the Highspot web App
  - Click on your profile picture in the top right corner
  - Click the Settings option from the drop down menu
  - Under USER SETTINGS in the left hand menu, select Pitches
  - Copy paste your Gmail signature into the box, or manually enter your name, job title, logo, or any information you typically include
  - Check the box for "Set as default signature"
  - Click Save Changes

Once these steps are complete, you will see your custom signature included under the Signature section of your Highspot email Pitches.

**Complete This:** Complete the [Highspot User Training in Level Up](https://university.gitlab.com/learn/course/highspot-user/main/highspot-user-training?client=internal-team-members) to learn more about ways to share Highspot content with customers, prospects and partners.

### Pitching Types & Use Cases

![Screenshot_AddBookmark](/handbook/sales/field-communications/gitlab-highspot/images/Example_PitchExamples.png)

#### Email Pitch

- **When to use:** When you would like to generate a new email and understand exactly who is looking at what.

- **Email Pitch Settings:** When preparing to send an email pitch, you can control the following activities:
  - Set expiration on pitch
  - Set passcode on pitch
  - Allow content to be downloaded
    - Download as PDF
    - Download original
  - Allow content to be shared by recipient
  - Send notification when there is activity by recipient

- **Email Pitch Data Considerations:** Depending how you have configured the settings of your email pitch, you can view the following activities:
  - Email address(es) of who opened the email pitch
  - Email address(es) of who viewed the email pitch
  - Duration of time spent viewing the email pitch
  - Detail of which pitch slides or pages were viewed
  - If email pitch was downloaded
  - If pitch was shared by recipient through share function

- **CS/Gainsight considerations:** By relating a pitch to a Salesforce record, the activity will be logged in Salesforce and carried through in Gainsight (same as it does today).

**Learn more:** [Send an Email Pitch](https://help.highspot.com/hc/en-us/articles/213580306-Send-an-Email-Pitch-from-Highspot)

#### Link Pitch

- **When to use:** When you want to package up content to share via LinkedIn, a text message, an existing email thread, a QR code (good for industry conferences), etc., and don't need to know exactly who looked at it. (Note: You will still be able to see the number of views.)

- **Link Pitch Settings:** When preparing to send a link pitch, you can control the following activities:
  - Set expiration on pitch
  - Set passcode on pitch
  - Allow content to be downloaded
    - Download as PDF
    - Download original
  - Allow content to be shared by recipient
  - Send notification when there is activity by recipient

- **Link Pitch Data Considerations:** Depending how you have configured the settings of your link pitch, you can view the following activities:
  - Duration of time spent viewing the link pitch
  - Detail of which pitch slides or pages were viewed
  - If link pitch was downloaded
  - If link pitch was shared by recipient through share function
- **Reminder:** You won't be able to know exactly who looked at the link pitch.

- **Gainsight considerations:** Send a pitch link from within Gainsight or Gmail to automatically log activity in Gainsight.

**Learn more:** [Send a Link Pitch](https://help.highspot.com/hc/en-us/articles/213580286-Send-a-Link-Pitch)

#### Gmail Pitch

- **When to use:** If you have an existing email thread going and want to share content inline. And/or if you just don't feel like going into the Highspot web app.

![Screenshot_AddBookmark](/handbook/sales/field-communications/gitlab-highspot/images/Example_PitchDirectlyFromGmail.png)

- **Gmail Pitch Settings:** When preparing to send a pitch directly through Gmail, you can control the following activities:
  - Set expiration on pitch
  - Set passcode on pitch
  - Allow content to be downloaded
    - Download as PDF
    - Download original
  - Allow content to be shared by recipient
  - Send notification when there is activity by recipient

- **Gmail Pitch Data Considerations:** Depending how you have configured the settings of your Gmail pitch, you can view the following activities:
  - Email address of who opened the Gmail pitch
  - Email address of who viewed the Gmail pitch
  - Duration of time spent viewing the Gmail pitch
  - Detail of which pitch slides or pages were viewed
  - If Gmail pitch was downloaded
  - If Gmail pitch was shared by recipient through share function

- **Gainsight considerations:** Can use both Highspot and Gainsight Gmail extensions to track this email activity in Gainsight (same as you do today).

**Learn more:** Check out [this quick demo video](https://view-su2.highspot.com/viewer/61a6a2a5bef36eca8212baab) and [download the Chrome extension](https://chrome.google.com/webstore/detail/highspot-for-gmail/lmidgenjjlmhobbdgooficpanecechol) to begin using this awesome feature.

#### Outreach Pitch

- **When to use:** If you want to pitch a piece of content or a pre-created pitch template to multiple contacts at once. You can send a Highspot pitch two ways in Outreach:
   1. Direct mail
   1. Within a new / existing sequence

- **Outreach Pitch Settings:** When preparing to send a pitch directly through Outreach, you can control the following activities:
  - Set expiration on pitch
  - Set passcode on pitch
  - Allow content to be downloaded
    - Download as PDF
    - Download original
  - Allow content to be shared by recipient
  - Send notification when there is activity by recipient

- **Outreach Pitch Data Considerations:** Analytics on pitches sent via Outreach depend on *how* the pitch was sent:
  - **For pitches sent via direct mail in Outreach:** A pitch record is created immediately in Highspot, and analytics on the pitch can be viewed immediately in the `Engagement` tab:
    - Duration of time spent viewing the Outreach pitch
    - Detail of which pitch slides or pages were viewed
    - If an Outreach pitch was downloaded
    - If an Outreach pitch was shared by recipient through share function
    - Note: Highspot currently does NOT pull in email addresses of recipients for pitches sent via direct mail. This data will need to be pulled / cross-referenced from Outreach.
  - **For pitches sent via a sequence in Outreach:** A pitch record is not created until a recipient engages with a piece of content in the pitch. For example, if you send a sequence to 100 recipients but only 20 click on the invite link in your pitch, 20 pitches will be created in Highspot at the time of engagement and analytics can be viewed in the `Engagement` tab. Each pitch and the associated analytics are unique to one recipient / email address.
    - Email address of who opened the Outreach pitch
    - Email address of who viewed the Outreach pitch
    - Duration of time spent viewing the Outreach pitch
    - Detail of which pitch slides or pages were viewed
    - If an Outreach pitch was downloaded
    - If an Outreach pitch was shared by recipient through share function

**Learn more:** Check out [this quick demo video](https://gitlab.highspot.com/items/64b1c228139060dabfd1e504) to begin using this awesome feature.

#### Live Pitch

- **When to use:** If you want to understand how long you spend on each slide/piece of content during a client conversation. Also, if you want to automatically log the activity/touchpoint on a SFDC opportunity. (Opportunity must be linked in Highspot.)

- **Live Pitch lets you present content 3 different ways while talking to a prospect or customer:**
  - Slide Cast: Present content securely via the browser, without using a screen sharing app. Does not support sharing web links or videos.
  - Screen Share: Present content and live demos via your preferred screen sharing app.
  - In Person: Present content and live demos via a camera attached to your computer.

- **Live Pitch Data Considerations:** you can view the following activities:
  - Live pitch participant list
  - Duration of time spent viewing the pitch
  - Detail of which pitch slides or pages were viewed

**Learn more:** [Use Live Pitch to Present Content](https://help.highspot.com/hc/en-us/articles/213580266-Use-Live-Pitch-to-Present-Content)

### Integrating Pitching with Your Existing Workflows

**SFDC Integration**

- Make sure to [link your Salesforce and Highspot accounts](https://help.highspot.com/hc/en-us/articles/214982803-Relate-Pitches-to-Salesforce), and then your pitches can be related to a lead, contact, opportunity or account in your CRM, logging the email as well as the following engagement in the ongoing email exchange.
- Note: This also helps us tie ROI back to content, so that Sales and Marketing can understand what content is driving revenue for the team and place more focus on these value-added areas.

**Pitch Styles**

- Pitch Styles determine how your content will display when shared with an external contact. Pitch Styles are available on all pitch types.
- **When to use `Simple Content View` Pitch Style**: This is the default pitch style on all pitch types and will display content in a simple thumbnail view in the pitch and a webpage view upon clicking.
- **When to use `Content Portal` Pitch Style:** If you want to create a more official, branded "landing page" to serve up more than 3+ pieces of content to customers or prospects. Example: Create a content repository for a champion that they can refer back to through a deal cycle.
- Learn more: [Create a Pitch Style](https://help.highspot.com/hc/en-us/articles/360010866653-Create-a-Pitch-Style)

**Pitch Templates**

- **When to use:** If you/your team has an email that you send often. Example: Meeting request / follow-up, "thank you" email, renewal notification, prospecting, etc.
- The Highspot admins will work with content owners to create pitch templates where relevant, but we encourage you to create your own. Pitch templates that you create will only be visible and usable by you. If you have a pitch template that you think others could benefit from, we encourage you to uplevel it and make it available for all Highspot users to leverage. Please contact the Highspot Admins in #highspot-help-center to do this.
- Learn more: [Create a Pitch Template](https://help.highspot.com/hc/en-us/articles/360048380134-Use-Pitch-Templates-and-Pitch-Styles-to-Customize-Pitches#h_01EZAZFVEEMHPZ4NWS71ZYYGD0)

**Pitch Analytics**

- After you've sent a pitch to a prospect or customer, you can view how they've interacted with the content.
- The default tracking for pitches is currently on for all users, except for regions/teams where privacy policies require a different treatment (ex. EMEA).
- Highspot pitch analytics currently track:
  - When the email is opened if it's an email pitch from Highspot.
  - When the link in the email is clicked.
  - How long the recipient looks at the content as well as each slide.
  - When content is downloaded.
  - If content is shared through the share button, including which email it was sent to.
- At the Group level, Highspot can:
  - Ask recipients for consent to track. If the recipient opts-out, we don't track anything. If they opt-in, all data listed above is tracked, except email opens.
  - Disable pitch tracking.
- Learn more: [View Pitch Activity](https://help.highspot.com/hc/en-us/articles/216042403-View-pitch-activity-)

### How to create Pitches using existing Pitch Style and Pitch Template combos

*Note:* For more information on the differences betweeen Pitch Styles and Pitch Templates, refer to the previous section or the following link: [Pitch Templates vs Pitch Styles](https://help.highspot.com/hc/en-us/articles/360048380134-Pitch-Templates-vs-Pitch-Styles)

The following steps are used to create Pitches using specific Pitch Style and Pitch Templates:

- Select **New Pitch**:
![Pitch_template_step1](/handbook/sales/field-communications/gitlab-highspot/images/Pitch_template_step1.png)
- Select **Link Pitch**:
![Pitch_template_step2](/handbook/sales/field-communications/gitlab-highspot/images/Pitch_template_step2.png)
- Select the **Pitch Template** - choose "Browse all templates" and select the appropriate *Template*:
![Pitch_template_step3](/handbook/sales/field-communications/gitlab-highspot/images/Pitch_template_step3.png)
- Select the **Pitch Style** - choose "Browse all templates" and select the appropriate *Style*:
![Pitch_template_step4](/handbook/sales/field-communications/gitlab-highspot/images/Pitch_template_step4.png)

### Editing Content in Highspot

To prepare for a pitch, you can customize content for the customer you are corresponding with.

There are two ways you can customize content inside of Highspot: **Remix** and **Edit in Google Drive**.

**Remix Content**

- Remix is a quick way to rearrange decks and documents. You can also combine decks and documents, mixing and matching different slides or pages.
- When to use: You want to create a collection of content (ex. Slides, PDF/eBook pages/videos/etc.) but do not need to edit any of the content (i.e. you do not need to edit content on a slide or in a doc)
- Learn more: [Remix Content](https://help.highspot.com/hc/en-us/articles/214983703-Remix-content)

**Edit in Google Drive**

- You can edit Google items  - Google Docs, Sheets, and Slide - directly from within Highspot.
- When to use: You want to edit/add/remove content on slides or in a doc. You will save a copy to your personal spot to customize and pitch from there.
- Note: You must have connected your Google Drive account with Highspot in order to use this feature and many others in Highspot.
- Learn more: [Edit in Google Drive](https://help.highspot.com/hc/en-us/articles/115002515023-Edit-in-Google-Drive)

## FAQs

**Who has access to Highspot?**

At this time, the entire GitLab GTM organization, which includes the global Field team, Sales Dev (SDR/BDR) and Strategic Marketing.

**How do I get access to Highspot?**

All members of GitLab's GTM organization have access to the tool via their Okta dashboard. For a full list of teams with Highspot access, see the [Availability section](/handbook/sales/field-communications/gitlab-highspot/#availability) above. If you are on one of these teams and still do not have Highspot access via Okta, please open an [access request](/handbook/it/end-user-services/onboarding-access-requests/access-requests/#how-do-i-choose-which-template-to-use).

**If I have a recommendation for a piece of content that should be in Highspot for all to access, how do I contribute?**

Contributing to Highspot is easy, and we encourage all team members to contribute resources that you think the entire GTM org or specific teams could benefit from. This could be anything from a Marketing resource you found that isn't already in Highspot or a presentation/document you created or found that would be helpful for team members to reference as an example of "what good looks like." If it's helpful for the team, we want to include it in Highspot!

To submit content, navigate to the Highspot homepage and click on the `Contribute Content to Highspot` button. From there, you'll see [these instructions](https://gitlab.highspot.com/spots/61a55821bfc73fc1b19395f1?list=61e8a12843d672fdfa27e199) that will guide you through how to submit a piece / pieces of content in less than one minute! Please follow the instructions for [adding a piece of content from Google Drive](/handbook/sales/field-communications/gitlab-highspot/#links-from-google-drive) or [adding a piece of content via a URL](/handbook/sales/field-communications/gitlab-highspot/#embedding-links) below when contributing content.

![Screenshot_ContributeContent](/handbook/sales/field-communications/gitlab-highspot/images/Example_ContributeContent.png)

**Who can upload content to Highspot?**

Each spot has a handful of designated "Content Owners" who are DRIs in their respective areas. Only these team members can upload content into that particular spot. The reasoning for this is to keep our Highspot database "clean" – i.e. maintain content uploading best practices, tagging, etc. Anyone can submit a piece of content to be added to Highspot in less than 30 seconds by [following this process](https://gitlab.highspot.com/spots/61a55821bfc73fc1b19395f1?list=61e8a12843d672fdfa27e199).

**Can all team members upload content into Highspot?**

There is one spot in which all team members can upload content in Highspot that all users can access: the Sales Contributed Spot (for Sales, Channel, Alliances and Operations-related submissions). Content submitted to this spot requires review before it is visible to all users. Each team member can upload content to their Personal Spot without the need for review. Keep in mind that content uploaded to your personal spot will *only* be viewable by that user.

**How do I request to become a content owner?**

Please request access from the owner of the spot where you would like to gain access. Note that all content contributors will need to complete the [Content Contributor Training](/handbook/sales/field-communications/gitlab-highspot/#highspot-trainings) prior to being provisioned access to contribute to a spot.

**How do I determine the owner(s) of a spot?**

You can find the spot owner in the top right-hand corner of a spot and/or at the bottom of the spot overview page. To get in touch with the spot owner, we recommend [reaching out on Slack](/handbook/sales/field-communications/gitlab-highspot/#communicating-with-the-highspot-team).

**What's the best way to save a piece of content that I want to come back to later?**

You can do this by selecting `Bookmark` on the piece of content and [bookmarking it](https://help.highspot.com/hc/en-us/articles/213579506-Manage-Your-Spot) into your Personal Spot.

**Can content be in only one Spot?**

No - content can be added to multiple spots. Content owners can do this by uploading a piece of content into one spot and bookmarking it to additional spots. Highspot users can also bookmark any piece of content in Highspot to their personal spots.

**Can partners or other external audiences access Highspot?**

Not at this time. GitLab's Highspot instance is only accessible by internal team members via SSO. External audiences can only see external content that is pitched to them via Highspot.

We are exploring the option of a Highspot instance for GitLab partners and will share more details when available.

**Can I find industry- or segment-specific content in Highspot?**

Yes! You can quickly find industry- or segment-specific content by using Highspot's tag lists, which allow you to filter search results as well as content found within individual Spots. When you enter a keyword in the Highspot search field and hit return, all available filter lists will appear in the left-side navigation pane. Simply scroll down to the Industry or Market Segment tag list and click on the desired Industry (e.g., banking, retail, technology) or Market Segment (e.g., Enterprise, SMB) to find all related content. When browsing through a specific Spot (e.g. the "Competitive Intelligence" Spot), simply click into the Spot and then select the appropriate filter list that appears in the left-side navigation pane. For more information about browsing and filtering content, check out the [Highspot Help Center](https://help.highspot.com/hc/en-us/articles/214982023-Browse-and-filter-spots).

**How can I find content that is trending or popular among GitLab's field team?**

You can quickly find trending/popular content by using the Sort functionality found within each Spot. When you visit a specific Spot - e.g., the ["Customer-Facing Content"](https://gitlab.highspot.com/spots/615dd7c2506d3fc490ad78cd) Spot - simply click into the "Content" view and use the sorting options (found under the Spot title) to arrange your display by popularity. Content will then be grouped by trending (popular items for the last two weeks) and most popular (most popular for all time). For more information about sorting and browsing Spots, check out the [Highspot Help Center](https://help.highspot.com/hc/en-us/articles/214982023-Browse-and-filter-spots).

**How does search work in Highspot?**

Highspot's search algorithm is designed to get users in contact with the right content in a quick and effective way. Highspot identifies items that match your search term - looking in many places to detect a match, including the title, description, the content of the item, the name of the Spot it is in, the name of any tag lists it is in, a word spoken in the transcription (if it is audio or video), a word that appears in an image or in a snapshot of the video - and then ranks them.

**Can I download content found in Highspot?**

Generally, no. To help us maintain GitLab's [SAFE framework](/handbook/legal/safe-framework/) and cultivate Highspot as a single source of truth, most content found in Highspot is not available for download. Please reach out to the Highspot admins in #highspot-help-center if you have any questions about a specific piece of content.

**Can teams have an area where they can post content specific to their team?**

Yes! How we accomplish this very much depends on individual use cases, how relevant the content is to other audiences, etc. If you'd like to explore having an area/avenue where you can curate content specific to your team, please reach out to the Highspot admins in #highspot-help-center to set up time to discuss.

**Do we have automation in place to automatically pull in new blog posts, eBooks, slide decks, YouTube videos, etc.**

Not at this time. All content must be manually added to Highspot via designated content owners. This is intentional in order to maintain the quality of content and tagging in Highspot. If you find that a helpful piece of content is not included in Highspot, please follow the [instructions on the Highspot homepage](https://gitlab.highspot.com/spots/61a55821bfc73fc1b19395f1?list=61e8a12843d672fdfa27e199) to submit a piece of content – it takes 30 seconds or less!

**Is it possible to see the speaker notes when viewing a Google Slide?**

This is not a Highspot capability at this time due to limitations with Google's API. The Highspot team is aware that this is a needed feature and are hoping to offer it soon. In addition to speaker notes, there are other limitations to Google Slides in Highspot that include supporting GIFs or slide animations as well as skipped slides. This means that animations will not display and skipped slides will show by default in Highspot or when sharing with a customer. Please take this into consideration when building slide content for Highspot.

**How does Highspot differ from the Handbook?**

The Handbook is still our SSOT at GitLab. If you're a content creator and wanting to document information, processes, etc., you should still use the GitLab Handbook as the place to do this. The added benefit is that you can then add a link to that Handbook page within Highspot and add it to the appropriate Spot/lists so that the Handbook page is more easily discoverable by the Field team. A great way to think of Highspot is like a search engine across the documents/resources that the Field uses often.

**What is the difference between Highspot and Thought Industries (LevelUp)?**

Thought Industries (LevelUp) is the main hub for all training content, courses, etc. Think of Highspot like a search engine put across all of the tools and platforms we use - Google Drive, YouTube, Handbook, etc. So, we might upload a link to a training course or a video recording that's housed in another location so that it's more discoverable and served up with related content within Highspot.

**What are the differing goals of Highspot and PathFactory?**

Similar to PathFactory, Highspot is a tool that can point customers to a set of relevant assets. In Highspot, users can create Pitch Templates with Pitch Styles (sometimes called Digital Sales Rooms) that curate a series of content into a customized experience for customers. Once sent, users can update DSRs for their customers and prospects for a customized, personalized experience. In general, the high-level goals for the two platforms are:

1. **Highspot:** To connect with customers 1:1 as part of a campaign, initiative, event, general outreach, other CTA. Can support lead gen/outreach, but primarily used once a lead has become an SAO.
1. **PathFactory:** To increase consumption/engagement with GitLab content in order to move prospects through the marketing funnel.

**Can Highspot users send PathFactory content to customers?**

Yes. PathFactory tracks are a type of asset that can be shared using Highspot. Content owners can "upload" (point to) PathFactory tracks within Highspot, and send those tracks to customers and prospects via a Highspot Pitch activity.

**Can I use Highspot to mass-send a pitch to multiple customers and prospects?**

Not from within Highspot. The Highspot pitch function and analytics are currently designed for a 1:1 or 1:few experience. The tool is optimized to provide tracking and insights into what customers are opening and viewing (i.e. what content they value) through the 1:1 motion.

If you would like to send Highspot content or a pitch template to a mass audience, consider leveraging the [Outreach integration](/handbook/sales/field-communications/gitlab-highspot/#outreach-pitch).

**Is Highspot a tool for Marketing automation and email nurture?**
Highspot is not a replacement for marketing automation or email nurture tools such as Marketo. All email pitches are sent by a member of the Field team, who can then view insights.

## Guidance for Highspot Content Owners

### Adding/Managing Content in Highspot

Please see the short support videos below:

1. [Highspot Overview](https://help.highspot.com/hc/en-us/articles/360023649654-Publisher-overview-videos-#h_01EVQ9CVNRV3XD5AQB4YCT7BMZ)
1. [Create and manage spots](https://help.highspot.com/hc/en-us/articles/360023649654-Publisher-overview-videos-#h_01EVQ9MFSEZBPR8EMXV3X8K3PQ)
   - Written article: [Create a spot](https://help.highspot.com/hc/en-us/articles/360044198974-Create-a-Spot)
   - Written article: [Add links to a spot](https://help.highspot.com/hc/en-us/articles/214983663-Add-Links-to-a-Spot)
1. [Create and organize lists](https://help.highspot.com/hc/en-us/articles/360023649654-Publisher-overview-videos-#h_01EVQ9N2KA9Z1YZW6RNEN7Q9GD)
   - Written article: [Create lists and list groups](https://help.highspot.com/hc/en-us/articles/213579766-Create-lists-and-list-groups)
1. [Organize content in Highspot](https://help.highspot.com/hc/en-us/articles/360023649654-Publisher-overview-videos-#h_01EVQ9NFW02E4G86R5YKTBHCBT)
1. [Bookmark content](https://help.highspot.com/hc/en-us/articles/360023649654-Publisher-overview-videos-#h_01EVQ9P1DHESF6JSP8QDTBXBKK)

[See more articles about spots and content.](https://help.highspot.com/hc/en-us/categories/4409233846939-Spots-Content)

### GitLab Highspot Best Practices for Content Owners

#### Uploading Content 101

[Watch this video](https://youtu.be/0q4jaPkYYKQ) for a ~5 minute demo on how to upload content into Highspot. See the guidance below for more detailed instructions and considerations.

When uploading content to Highspot, it is best practice to fill in as many of the Properties as possible. Some Properties may be auto-populated, such as Title, Description, and Expiration Date. You can edit any of these fields.

Please note: Highspot Lists are not auto-populated. It is best practice to check the box for EVERY relevant List item, including Market Segment, Region, and Role, as well as Asset Type, Use Case, and more. This is an important step in the upload process because Highspot uses these Lists to filter content in the Browse menu, as well as within SmartPages that are organized based on these Properties. The more Lists you check, the more your content becomes discoverable.

#### Links from Google Drive

Highspot offers the ability to link files directly from GitLab's Google Drive. **When adding a piece of content from Google Drive, you should *always* add the file directly from Drive versus add the link** – i.e. select the + button --> Add Files --> From Cloud Services (Google Drive) vs. + --> Add Link. This will allow Highspot to keep that piece of content up-to-date as changes are made to the Google Drive file.

![Screenshot_LinkVSFile](/handbook/sales/field-communications/gitlab-highspot/images/Example_AddFiles_vs_AddLink.png)

![Screenshot_AddFromDrive](/handbook/sales/field-communications/gitlab-highspot/images/Example_AddFromDrive.png)

In addition, when adding files directly from Drive, ALWAYS select the `Automatically update content from Google Drive` option to maintain version control.

![Screenshot_DriveAutoUpdate](/handbook/sales/field-communications/gitlab-highspot/images/Example_AutoUpdate.png)

#### Google Slide Considerations

Due to a limitation in the Google Slides --> Highspot handoff, the following Google Slides features are not supported when displaying in Highspot:

1. Skipped slides
1. Slide animations
1. Gifs

Please note that you should **NOT** include skipped slides in presentations loaded to Highspot as a best practice to avoid unwanted content displaying to internal Field reps or external customers.

#### Embedding Links

When adding a link in Highspot, you will have the option to add an embed code to the content. **You should always aim to use the embed code for links when possible.**

The format for the embed code is: `<iframe src="https://URL HERE"></iframe>`

Using the embed code will allow Highspot users to view the webpage content directly in Highspot instead of having to click out of the tool, which drives more efficiency and a more seamless user experience. Furthermore, if that link is marked as external and a Highspot user wants to pitch it out to a customer or prospect using Highspot, we will only be able to track engagement analytics on an embedded link, as a non-embedded link will cause the customer to land natively on the URL page where we cannot gather analytics.

**For external YouTube links, you will need to use the embed URL provided by YouTube** within the embed code vs. the standard url. To do this, navigate to the YouTube video --> click `Share` underneath the video --> click `Embed` --> copy the url that is a part of the embed code shown.

**EXCEPTIONS FOR EMBEDDING**

*The following exceptions should be made for embedding links. Do not select `Use embed code` when adding these types of links.*

1. PathFactory - In order to allow PathFactory to gather the necessary analytics, external audiences will need to access the link that takes them directly to the asset in PathFactory.
1. External - Some external links (ex. industry articles) will not allow embedding. You can test this by selecting `Use embed code` and then clicking on the item to check. You will see a broken link message if that link is unable to be embedded.
1. Private YouTube Unfiltered - Links for videos set to private will not embed.

![Screenshot_DriveAutoUpdate](/handbook/sales/field-communications/gitlab-highspot/images/Example_EmbedCode.png)

#### Internal vs. External Content

**Only mark a resource as external if you are absolutely certain it follows the [SAFE Guidelines](/handbook/legal/safe-framework/).** Under NO circumstances should anything marked as `External` contain material non-public information including financial/performance metrics, non-approved customer logos, etc. Also ensure external content follows our [Image/Logo Guidelines](/handbook/marketing/digital-experience/image-guidelines/) and [Trademark Guidelines](/handbook/legal/trademarks-training-materials/).

As a good best-practice, items marked as `External` should only include decks that have been signed off by Marketing and Legal as fit for external use (ex. DevOps Platform deck) or resources that focus on the GitLab product.

For any internal Google Drive resources, you should also select the option to `Prevent users from downloading` as GitLab team members should not keep copies of these documents on their local devices.

If you are unsure about whether a piece of content is fit to be external, please contact GitLab Legal in the #legal channel.

![Screenshot_DriveAutoUpdate](/handbook/sales/field-communications/gitlab-highspot/images/Example_InternalContentPermissions.png)

#### Content expiration 101

Highspot includes the ability to "schedule" content. This allows you to set an expiration date for content. **We should set an expiration date on almost ALL pieces of content**, as it provides an opportunity to review that content on a regular basis and ensure that it is still relevant, the lists are still accurate, etc. If we don't set content to expire, we run the risk of letting outdated/inaccurate content exist on Highspot, compromising the efficacy of the resources.

The only exception to this would be links or files that you know will not change. (Which is unlikely, even URLs for handbook pages can change.)

The recommendation is to set a piece of content to expire one year from the upload date. Note that Highspot will automatically assign an expiration date of one year out when uploading content.

When a piece of content does expire, it will not be deleted. Instead, it will be moved into an Archived folder. All spot owners will receive a notification and can easily reset the content expiration date with the click of a button.

![Screenshot_ScheduleContent](/handbook/sales/field-communications/gitlab-highspot/images/Example_ScheduleContent.png)

#### Validation Rules

There are three validation rules set in GitLab's Highspot instance. Each piece of content must include:

1. An expiration date - A built-in checkpoint to maintain the quality of content in Highspot (see [Content expiration 101](/handbook/sales/field-communications/gitlab-highspot/#content-expiration-101) for more details)
1. A description - Whether one sentence or a full paragraph, a description will help make content more discoverable by users when searching for key words
1. At least one list - Content should be tagged to at least one list (but preferably more) to help increase discoverability

If one of these validation rules is broken, you will see a `Validates Policy` flag. Upon clicking on the flag, a message will appear with more details on which validation rule has been broken. Content owners can easily filter down to content that is in violation of the validation rules by using the `Flags` list in the spot and filtering down by `Violates Policy`.

A piece of content that has this flag will still be visible in Highspot for users to see. The flag is more of a visual cue to help content owners maintain Highspot best-practices.

![Screenshot_ViolatesPolicyFlag](/handbook/sales/field-communications/gitlab-highspot/images/Example_ViolatesPolicyFlag.png)

![Screenshot_ValidationRuleMessage](/handbook/sales/field-communications/gitlab-highspot/images/Example_ValidationRuleMessage.png)

#### Including content in more than one spot

Some content might fit in more than one spot. When this happens, you should bookmark content into an additional spot(s). **Avoid uploading the same piece of content multiple times, as this will make version control difficult.**

It is likely that this scenario will happen most often with the Customer-Facing Content spot, as content that fits under Marketing could also fit under Customer-Facing Content. Always default to adding the content within the primary spot first and then bookmark into Customer-Facing Content. In this scenario, you'd add the link/file to `Marketing` and then bookmark to `Customer-Facing Content`.

![Screenshot_AddBookmark](/handbook/sales/field-communications/gitlab-highspot/images/Example_AddBookmark.png)

#### Designing and building SmartPages

SmartPages make it easier for Content Owners to design and build sales enablement content and guidance. Highspot offers a series of SmartPage templates to get you started, including what are called Homepages and Sales Plays. Homepages are designed to direct users to relevant content, and are generally used as Spot overviews and directories.

Plays are designed to track internal and external engagement, and come with an analytics feature called a Scorecard. When creating a SmartPage for a marketing campaign or sales initiative, you will generally want to use a Sales Play template.

Learn more about designing and building [SmartPages](https://help.highspot.com/hc/en-us/articles/360003228554-Build-a-SmartPage-in-the-Page-Designer) and [Sales Plays](https://help.highspot.com/hc/en-us/articles/360053638814-Create-a-Sales-Play) in the Highspot Help Center.

#### Creating pitch templates

Highspot offers what they call pitch templates, which are email templates that can be created by GitLab and sent to prospects and customers with pre-written messages and pre-selected content attached. These templates include built-in tracking and analytics capabilities, and are intended for 1-to-1 or 1-to-few communications.

Once a pitch template is created, currently anyone with access to the Company Pitch Template Spot can access that template, customize it as/if they see fit, send the template to a prospect or customer, and view all tracked activities.

The Highspot Help Center provides instructions on how to create pitch templates, which you can read [here](https://help.highspot.com/hc/en-us/articles/214982823-Create-a-Pitch-Template). In addition, follow these steps to help keep GitLab's pitch templates organized and consistent:

- Create new pitch templates in the Company Pitch Templates Spot. Users can bookmark templates to their own Spot, and Spot Owners can bookmark or filter pitch templates in SmartPages to quickly surface these items.
  - If you do not already have Editor access to the Company Pitch Templates Spot, you will not be able to add a new template. You can gain access by creating an Issue using [this Template](https://gitlab.com/gitlab-com/sales-team/field-operations/enablement/-/issues/new?issuable_template=highspot-spot-permissions-request).
- Add a descriptive title and description. These fields are internal to Highspot and should help users know when/how/why to use the template. Titles should be consistent, such as when adding a sequence of templates.
- Add a message using text and dynamic fields (i.e. Customer name, Company), which will auto-fill for the user when pitching. Users can edit the message when pitching. This will not affect the template. However, the user's edits will show clearly in their own Pitches Spot, as well as in SFDC.
- Attach an item. All pitch templates must include at least one piece of content from within Highspot. If no content is selected when creating the pitch template, users must add an item when pitching.
- Tag all relevant lists within the pitch template properties. Lists are how users filter content on Highspot. Assigning the Use Case, Role, Market Segment, and Industry, at a minimum, will support a segment and role-based user experience of Highspot.
- Remember: Users can relate a pitch template to a lead, contact, opportunity, or account in SFDC using the Relate and Send To fields within the Send Email Pitch window.
- Remember: Users can enter a custom email signature in Highspot, which will auto-display when pitching.

### Highspot for GitLab Duo Content

As of 2023-07-17, the [GitLab Duo (AI) spot](https://gitlab.highspot.com/spots/64b14e7cc4b08381c0408bb4?list=all&overview=true) was added to Highspot to help reps easily discover internal and external resources needed to understand our developing AI strategy and effectively communicate our position with prospects and customers.

Moving forward, **all AI-related content – internal and external – should be added to the GitLab Duo (AI) spot.** Stakeholders have been given edit access to this spot so they can add content. If you are a Highspot content contributor adding content to this spot, please review and follow the below guidelines to ensure we maintain an efficient user experience in this spot. If you need access to add content to this spot, please reach out in #highspot-content-owners.

1. Review the [guidance for uploading content above](/handbook/sales/field-communications/gitlab-highspot/#gitlab-highspot-best-practices-for-content-owners) to ensure you are adding content in accordance with our best-practices.
1. If it makes sense in a secondary spot (i.e. Customer Outreach, Customer Success, Field Strategy & Enablement, etc.) [bookmark](/handbook/sales/field-communications/gitlab-highspot/#including-content-in-more-than-one-spot) the content into another spot once added in the AI spot.
1. Apply at LEAST one of the eight lists (tags) available in the AI spot.
1. New content will appear in the "Revenue-Focused" (owned by PMM) and "Techincal Resources" (owned by Dev Rel) sections automatically based on the lists applied. No action is needed from teams owning these sections.
1. To ensure the most relevant resources are served up on the homepage, featured content in "What to Know" section (owned by PMM), "Key Messaging" (owned by PMM) and "Competitive Resources" (owned by Competitive Intelligence) will have to be added manually by owners by editing the overview page for the spot.
1. To add content to the spot homepage, navigate to the three dots in the righthand corner when on the spot homepage.
1. Select "view overview for spot".
1. Navigate to the three dots in the righthand corner and select "edit".
1. Any changes you make here will be reflected on the spot homepage. Review [Highspot's SmartPage help articles](https://help.highspot.com/hc/en-us/sections/360007945533-Design-Build-SmartPages-) for more information.

### Highspot Video training for Field Marketing

In addition to the training links above, a video training for Field Marketing can be found [here](https://gitlab.highspot.com/items/6531ac81f2cb7f5067cc03b6?lfrm=shp.0).
