---
title: "Partner FAQ - Selling with GitLab"
---

<link rel="stylesheet" type="text/css" href="/stylesheets/biztech.css" />

This page documents frequently asked questions from our partner community on how to collaborate with GitLab throughout the sales process. Please contact us at `partnersupport@gitlab.com` if you have any questions or would like to see another question/answer documented on this page.

## Deal Registration

<details>
<summary markdown="span">
When should I submit a Deal Registration? What opportunities am I able to register?
</summary>

GitLab has a [Partner Sourced Deal Registration](/handbook/sales/field-operations/channel-operations/#partner-sourced-deal-registration) (DR) program for (i) Resale, (ii) MSP, and (iii) Referral opportunities. You should submit a Partner Sourced DR for an opportunity where you are **sourcing net-new business for GitLab**, which can apply to opportunities for new logo, co-term add-on/upsell, or add-on/upsell as part of a renewal. Note, there can only be one Partner Sourced DR approved for an opportunity, as only one partner can source a deal. You should not submit a Partner Sourced DR if you did not source the opportunity, and you will generally receive Co-Sell discounts for these deals. Partner Sourced and Co-Sell opportunities are discussed further in the [Partner handbook](/handbook/resellers/channel-working-with-gitlab/#definitions-and-qualifications).

GitLab also has a [Service Attach DR](/handbook/sales/field-operations/channel-operations/#service-attach-opportunities) program which applies to opportunities where partners are selling their own professional services into a customer environment at the time of a GitLab product sale.

</details>

<details>
<summary markdown="span">
I am unable to log into the Partner Portal to submit a Deal Registration (DR). How can I get access and submit a DR?
</summary>

If you have a Partner Portal account but are unable to login, please [select "Forgot Password"](https://partners.gitlab.com/English/) to reset your password. If you do not have a Partner Portal account, please [select "Request Portal Access"](https://partners.gitlab.com/English/) to set up an account. Please contact `partnersupport@gitlab.com` for assistance ​​if you have followed the directions but are still having issues.

Note, to submit a Deal Registration, you must first be an authorized GitLab partner as well as have completed the [required training](/handbook/resellers/channel-working-with-gitlab/#training--certification-requirements-for-transactions-deal-registrations-nfrs-and-letters-of-authorization-loas) in order to be granted access to submit a DR.

</details>

<details>
<summary markdown="span">
What does it mean when the status of a Deal Registration is "Returned"?
</summary>

The Channel Account Manager (CAM) assigned to the Deal Registration (DR) has reviewed and sent it back to the resale partner for additional information/context. Once the resale partner reviews and responds to the CAM's feedback, the CAM will be notified to review and action the updated DR.

</details>

## Sales Process

### Partner Discounts and Incentives

<details>
<summary markdown="span">
Where can I find information on GitLab's partner discounts, incentives, and rebate programs?
</summary>

Please review the [GitLab Program Discounts and Incentive Guide](https://partners.gitlab.com/prm/English/s/assets?collectionId=49440) in the GitLab Partner Portal which contains information on our partner discounts, incentives, rebate programs and more. You can also refer to the [Partner handbook](/handbook/resellers/channel-working-with-gitlab/#definitions-and-qualifications) for an overview.

</details>

<details>
<summary markdown="span">
What discount do I receive on GitLab products and services?
</summary>

Please refer to our [GitLab Partner Price List](https://partners.gitlab.com/prm/English/s/assets?collectionId=49439) which includes the current pricing for all of our products and services along with our discount guidelines in the [GitLab Program Discounts and Incentive Guide](https://partners.gitlab.com/prm/English/s/assets?collectionId=49440).

</details>

<details>
<summary markdown="span">
When do I receive Partner Sourced vs Co-Sell discounts?
</summary>

If the opportunity is for new or add-on/upsell business:

- **sourced** by the partner (including adding licenses as part of a renewal opportunity), the partner should submit a Partner Sourced Deal Registration (DR) for the opportunity. If the DR is approved, GitLab will provide Partner Sourced discounts for the new or add-on/upsell portion of the deal.
- **not sourced** by the partner, the partner will generally receive co-sell discounts.

If the opportunity is a flat renewal, please refer to the [Partner Operations handbook](/handbook/sales/field-operations/channel-operations/#incumbency-renewals) for rules on partner incumbency.

Please refer to the [GitLab Program Discounts Incentive Guide](https://partners.gitlab.com/prm/English/s/assets?collectionId=49439) for more information regarding our partner program discounts.

</details>

### General Quoting Process

<details>
<summary markdown="span">
Do I transact via distribution or directly with GitLab?
</summary>

Open Partners located in regions/countries:

- **with** Authorized GitLab Distributors are required to purchase GitLab via those distributors.
- **without** Authorized GitLab Distributors may purchase directly from GitLab

Select Partners may choose to transact directly with GitLab (excluding certain regions) or via the region's authorized distributor(s).

Refer to the [Partner Operations handbook](/handbook/sales/field-operations/channel-operations/#distributor-requirements-and-coverage-by-geo-and-market) for more information on distribution coverage, requirements, and contact information.

</details>

<details>
<summary markdown="span">
How do I determine which distributor covers my region?
</summary>

Please refer to the [Partner Operations handbook](/handbook/sales/field-operations/channel-operations/#distributor-requirements-and-coverage-by-geo-and-market) for details on distribution coverage, requirements, and contact information.

</details>

<details>
<summary markdown="span">
How can I request a GitLab quote for my customer?
</summary>

- Open partners with an Authorized Distributor in region should [contact their distributor](/handbook/sales/field-operations/channel-operations/#distributor-requirements-and-coverage-by-geo-and-market).
- Select partners that transact directly with GitLab and/or Open partners without an Authorized Distributor in region should contact the GitLab sales representative for the customer account. Please contact your Channel Account Manager or `partnersupport@gitlab.com` if you are unsure of which GitLab sales representative to contact for your quote request

</details>

<details>
<summary markdown="span">
Can we include different product tiers (premium and ultimate), deployment types (SaaS and Self-Managed), and/or term lengths (e.g., 12 and 24 months) on the same quote?
</summary>

No, we cannot mix product tiers, deployment types, and/or term lengths on the same quote. Please refer to the [Deal Desk handbook](/handbook/sales/field-operations/sales-operations/deal-desk/#quoting-different-product-tiers-deployment-types-and-term-lengths-on-the-same-quote) for more information.

Please note that Education Services are required for certain deals in order to improve product adoption and minimize security risks.

</details>

<details>
<summary markdown="span">
Our customer has an offline/air-gapped environment, what must be done to ensure they receive a license they are able to use post-sale?
</summary>

Please let the GitLab Sales team know your customer has an offline/air-gapped environment when requesting a quote so they are able to request necessary approvals for the applicable license during the quoting process.

</details>

### Renewal Quotes

<details>
<summary markdown="span">
My customer's renewal quote includes true-up seats. What are true-ups and why is the customer charged for these seats at renewal?
</summary>

The customer purchased a specific number of seats in their original subscription. If the customer adds more users to their GitLab instance than the number they are licensed for during the subscription period, payment for the additional/overage users is required at time of renewal.

Note, "Users over subscription ([Self-Managed](https://docs.gitlab.com/ee/subscriptions/self_managed/#users-over-subscription)) / "Seats owed" ([SaaS](https://docs.gitlab.com/ee/subscriptions/gitlab_com/#seats-owed)) in the customer's admin dashboard represent the number of overage users the customer incurred during the subscription term. Please refer the customer to these guides for how to locate their admin dashboard for [Self-Managed](https://docs.gitlab.com/ee/subscriptions/self_managed/#view-your-subscription) and [SaaS](https://docs.gitlab.com/ee/subscriptions/gitlab_com/#view-your-gitlab-saas-subscription) subscriptions.

</details>

<details>
<summary markdown="span">
How can my customer find their admin usage dashboard to take a screenshot to facilitate their upcoming renewal?
</summary>

Please refer the customer to these guides on how to locate their admin dashboard for [Self Managed](https://docs.gitlab.com/ee/subscriptions/self_managed/#view-your-subscription) and [SaaS](https://docs.gitlab.com/ee/subscriptions/gitlab_com/#view-your-gitlab-saas-subscription) subscriptions.

</details>

<details>
<summary markdown="span">
Our customer has blocked/deactivated/removed users from their subscription. Will these users count towards billable users/seats currently in use at renewal? How will these users be reflected/charged?
</summary>

Deactivated, blocked, and removed users don't count as "Billable Users (Self-Managed) / "Seats currently in use" (SaaS) in the current subscription. However, they may count toward overages in the subscribed seat count which will be charged as true-ups at renewal. Refer to [Self-Managed](https://docs.gitlab.com/ee/subscriptions/self_managed/#billable-users) and [SaaS](https://docs.gitlab.com/ee/subscriptions/gitlab_com/#remove-users-from-your-subscription) subscription documentation for more information.

</details>

<details>
<summary markdown="span">
My customer would like to renew their subscription, but reduce their total license count. What is the minimum quantity required for renewal?
</summary>

The minimum quantity required to be renewed is the customers "Billable users" (Self-Managed) or "Seats currently in use" (SaaS) in order to have an active instance post renewal. If the customer wants to renew fewer users than those currently active, they will need to remove the excess users from their instance. Refer to the following guides for details on where a customer can view their usage and/or instructions on how to block, deactivate, or remove users: [Self-Managed](https://docs.gitlab.com/ee/subscriptions/self_managed/#view-user-totals), [SaaS](https://docs.gitlab.com/ee/subscriptions/gitlab_com/#view-your-gitlab-saas-subscription).

</details>

<details>
<summary markdown="span">
My customer worked with a different reseller for their previous order. Are you able to transfer incumbency (i.e., incumbent partner discounts) to my organization for the customer's renewal?
</summary>

Yes, if the customer provides formal communication through email to confirm they would like to work with you for this renewal (i.e., the new reseller), we are able to transfer incumbency discounts. Refer to the [Partner Operations handbook](/handbook/sales/field-operations/channel-operations/#incumbency-renewals) for further details.

</details>

<details>
<summary markdown="span">
If my customer wants to add seats to their instance before their renewal, does the add-on need to be processed before I can request a renewal quote for the entire subscription?
</summary>

Yes, for the customer's overall license count to be accurate during the renewal, add-on licenses need to be fully processed before GitLab can generate a renewal quote. Refer to the [Deal Desk handbook](/handbook/sales/field-operations/sales-operations/deal-desk/#transacting-a-separate-add-on-opportunity-prior-to-renewal) for further guidance.

</details>

<details>
<summary markdown="span">
My customer is concerned they won't be able to renew their instance before their grace period expires and they lose access. Can a temp license extension be granted to have additional time to process the renewal?
</summary>

On a case-by-case basis, your GitLab sales representative can request a temporary license extension in order to prevent loss of access to a subscription. Please contact your sales team for more information.

</details>

### Puchase Orders (POs)

<details>
<summary markdown="span">
Does GitLab have an Order Requirements Checklist that details the PO requirements for order acceptance and booking?
</summary>

Please refer to the [Sales Order Processing handbook](/handbook/sales/field-operations/order-processing/#submit-an-opportunity-for-booking) for opportunity booking requirements.

</details>

<details>
<summary markdown="span">
Can I submit a signed GitLab quote/order form instead of submitting a PO to purchase a subscription?
</summary>

A signed GitLab quote/order form is acceptable in place of a PO as long as the details meet our opportunity booking requirements. Please ensure a signature, full name, title and date are all listed on the GitLab quote/order form.

</details>

<details>
<summary markdown="span">
How do I ensure my PO submission will count toward GitLab's current fiscal quarter?
</summary>

Please refer to the guidelines listed in the [Sales Order Processing handbook](/handbook/sales/field-operations/order-processing/#end-of-quarter-bookings) regarding end-of-quarter bookings.

</details>

<details>
<summary markdown="span">
I submitted a renewal PO in advance of the renewal date, when will the PO be booked?
</summary>

[New business, add-on](/handbook/sales/field-operations/order-processing/#new-businessadd-on-opportunities), and [renewal](/handbook/sales/field-operations/order-processing/#renewal-opportunities) orders are processed no more than 15 days prior to an opportunity's close date. Note, the start date for renewals is the last day of the customers current subscription term.

</details>

<details>
<summary markdown="span">
What is GitLab's ECCN?
</summary>

You can find our ECCN in our [Trade Compliance handbook](/handbook/legal/trade-compliance/#how-do-trade-control-laws-apply-to-gitlab-software).

</details>

## Post-Sale

<details>
<summary markdown="span">
When can we expect the invoice for an order?
</summary>

Invoices are sent [24 - 48 hours after the opportunity closes](/handbook/finance/accounting/finance-ops/billing-ops/#standard-operating-process).

</details>

<details>
<summary markdown="span">
Our customer purchased the wrong deployment type (SaaS vs. Self-Managed). Can I switch deployment type post-sale?
</summary>

Yes, this change can generally be made by processing a new zero dollar order to facilitate the switch. Please contact the sales representative you worked with on the opportunity so that they may facilitate next steps.

</details>

<details>
<summary markdown="span">
Our customer notified us that their new license does not work as they have an offline or air-gapped environment. How can we request an updated license?
</summary>

Please contact the sales representative you worked with on the opportunity to request an updated license. Note, the sales representative will need to request and receive executive approvals before our support team can process the request.

</details>

<details>
<summary markdown="span">
How can we obtain proof of delivery (POD) for our recent Self-Managed / SaaS order?
</summary>

The partner contact that receives the GitLab invoice will also receive a copy of the customer purchase confirmation email (i.e., copy of the Self-Managed license activation or SaaS notification email sent to the customer). Please connect with this contact to obtain the POD.

**Note**, on a two-tier deal, the distributor is invoiced by GitLab and thus the distributor receives the POD. Please connect with the distributor to obtain the POD if you have purchased through distribution.

</details>

<details>
<summary markdown="span">
My customer is asking that the purchase confirmation email with license/activation code be resent to the same end user contact that was listed on the PO/Quote. How can we request that the purchase confirmation email be resent?
</summary>

The partner that received the GitLab invoice (i.e., Distributor for two-tier deal, Reseller for one-tier deal) needs to [submit the support ticket](https://support.gitlab.com/hc/en-us/requests/new) with the GitLab invoice attached to request the purchase confirmation email be resent to the same end user contact.

</details>

<details>
<summary markdown="span">
My customer did not receive the purchase confirmation email with license/activation code due to the PO/Quote listing the wrong end user contact. How can we request that the purchase confirmation email be sent to the new/updated end user contact?
</summary>

The partner that received the GitLab invoice (i.e., Distributor for two-tier deal, Reseller for one-tier deal) needs to [submit the support ticket](https://support.gitlab.com/hc/en-us/requests/new) with the GitLab invoice attached to request the purchase confirmation email be sent to a new end user contact.

**Important to note**, the GitLab Sales Rep cannot change the end user contact post-sale on behalf of the partner or customer. The request to change the end user contact must either be submitted by the (i) partner that received the GitLab invoice as outlined above or (ii) customer contact listed on the final GitLab quote (i.e., the person that received the license).

</details>

<details>
<summary markdown="span">
The customer received an error stating they are out of Compute Minutes so their instance has stopped working. How can I quickly resolve this?
</summary>

The customer must add Compute Minutes via the same procurement path as the original order (i.e., if they purchased the original subscription through a partner, they must purchase the additional minutes through the same partner). Please take the following steps:

1. Work with your GitLab Sales Rep to obtain a quote for additional Compute Minutes.
2. Request that the GitLab Sales Rep submit an internal support ticket to provide additional Compute Minutes so the customer can get back online while the quote and order process is being completed.

For additional information, the Support team's process can be found [here](/handbook/support/license-and-renewals/workflows/saas/compute_minutes/#process-for-authorising-additional-compute-minutes-for-customers-as-an-act-of-goodwill).

</details>
