---
title: "GitLab Sales FAQ - Selling with Partners"
---

<link rel="stylesheet" type="text/css" href="/stylesheets/biztech.css" />

This page documents frequently asked questions from our GitLab Sellers on how to collaborate with partners throughout the sales process. Please contact us at `#partner-programs-ops` in slack or `@Partner Operations` in SFDC chatter if you have any questions or would like to see another question/answer documented on this page.

## Deal Registration

<details>
<summary markdown="span">
When should my partner submit a Deal Registration? What opportunities are they able to register?
</summary>

GitLab has a [Partner Sourced Deal Registration](/handbook/sales/field-operations/channel-operations/#partner-sourced-deal-registration) (DR) program for Resale, MSP, and Referral opportunities. The partner should submit a Partner Sourced DR for an opportunity where they are **bringing net-new business to GitLab**, which can apply to opportunities for new logo, co-term add-on/upsell, or add-on/upsell as part of a renewal. Note, we can only approve one Partner Sourced DR for an opportunity, as only one partner can source a deal. Partners should not submit a Partner Sourced DR if they did not source the opportunity, and will generally receive Co-Sell discounts for these deals. Please refer to GitLab's [Internal Incentive Guide](https://docs.google.com/document/d/1qiT_2EsnL20c4w0hyZ_CGaJQIzj8CSCsHERoR80cwws/edit#heading=h.9e3o7yaxw8mu) for more information on partner program discounts.

GitLab also has a [Service Attach DR](/handbook/sales/field-operations/channel-operations/#service-attach-opportunities) program which applies to opportunities where partners are selling their own professional services into a customer environment at the time of a GitLab product sale.

</details>

<details>
<summary markdown="span">
My partner is unable to log into the Partner Portal to submit a Deal Registration (DR). How can they get access to submit a DR?
</summary>

If the partner contact has a Partner Portal account but is unable to login, they can [select "Forgot Password"](https://partners.gitlab.com/English/) to reset their password. If they do not have a Partner Portal account, they can [select "Request Portal Access"](https://partners.gitlab.com/English/) to set up an account. Please have the partner contact `partnersupport@gitlab.com` for assistance ​​if they have followed the directions but are still having issues.

Note, to submit a Deal Registration, the partner must first be an authorized GitLab partner as well as have completed the [required training](/handbook/resellers/channel-working-with-gitlab/#training--certification-requirements-for-transactions-deal-registrations-nfrs-and-letters-of-authorization-loas) in order to be granted access to submit a DR.

</details>

<details>
<summary markdown="span">
I am working with a partner on an opportunity but their Deal Registration (DR) has expired. Can the DR be extended?
</summary>

Yes, the expired DR can be [extended](/handbook/sales/field-operations/channel-operations/#rules-of-engagement-for-partner-sourced-deal-registration) for 30 days by the Channel Account Manager. Please chatter the Channel Account Manager to request that they extend the DR. If you need an extension longer than 30 days, please chatter `@Partner Operations` and provide the new date the registration should expire.

</details>

<details>
<summary markdown="span">
What does it mean when the status of a Deal Registration (DR) is "Returned"?
</summary>

The Channel Account Manager (CAM) assigned to the DR has reviewed and sent it back to the resale partner for additional information/context. Once the resale partner reviews and responds to the CAM's feedback, the CAM will be notified to review and action the updated DR.

</details>

## SFDC Opportunity

<details>
<summary markdown="span">
Where can I find Deal Registration (DR) information on an opportunity?
</summary>

DR information can be found in two areas on the opportunity:

- "Registrations" section in the related list quick links section at the top of the opportunity. This section contains all DRs attached to an opportunity, including approved, expired, rejected, and pending Partner Sourced DRs as well as Service Attach DRs.

![Opp DR Top Section](/handbook/sales/field-operations/channel-operations/images/opp_top_section.png "Deal Registration Opp")

- "Partner Sourced Deal Registration" section in the body of the opportunity which contains the approved Partner Sourced DR.

![DR Section](/handbook/sales/field-operations/channel-operations/images/dr_section.png "Deal Registration Section in Opp")

</details>

<details>
<summary markdown="span">
Where can I find information on the partner we quoted on an opportunity?
</summary>

Please refer to the "Primary Quote Partner Details" section of the opportunity which displays the partner information from the Primary Quote.

![Primary Quote Section](/handbook/sales/field-operations/channel-operations/images/quote_section.png "Primary Quote Section")

</details>

<details>
<summary markdown="span">
What causes `Sales Qualified Source` (SQS) to be "Partner Generated" on an opportunity?
</summary>

SQS on the opportunity will be "Partner Generated" if (i) there is an approved Partner Sourced Deal Registration or the Initial Source is Partner Qualified Lead. Refer to the [Partner Operations handbook](/handbook/sales/field-operations/channel-operations/#sfdc-opportunity-source-field-values-for-channel) for further details.

</details>

## Sales Process

### Partner Discounts and Incentives

<details>
<summary markdown="span">
Where can I find information on GitLab's partner discounts, incentives, and rebate programs?
</summary>

Please refer to the [Internal Incentive Guide](https://docs.google.com/document/d/1qiT_2EsnL20c4w0hyZ_CGaJQIzj8CSCsHERoR80cwws/edit#heading=h.9e3o7yaxw8mu) which contains information on our partner discounts, incentives, rebate programs and more.

</details>

<details>
<summary markdown="span">
How do we discount our products and/or services for partners (Distributor, Reseller, MSP)?
</summary>

Please refer to the [Internal Incentive Guide](https://docs.google.com/document/d/1qiT_2EsnL20c4w0hyZ_CGaJQIzj8CSCsHERoR80cwws/edit#heading=h.9e3o7yaxw8mu) to obtain partner program discounts for our products and services.

</details>

<details>
<summary markdown="span">
When should I provide Partner Sourced vs Co-Sell partner discounts?
</summary>

If the opportunity is for new or add-on/upsell business:

- **sourced** by the partner (including adding licenses as part of a renewal opportunity), the partner should submit a Partner Sourced Deal Registration (DR) for the opportunity. The GitLab CAM and ASM will approve the DR and then you can provide Partner Sourced discounts to the DR partner for the new or add-on portion of the deal.
- **not sourced** by the partner, the partner will generally receive co-sell discounts.

If the opportunity is a flat renewal, refer to the [Partner Operations handbook](/handbook/sales/field-operations/channel-operations/#incumbency-renewals) for rules on partner incumbency.

Refer to the [Internal Incentive Guide](https://docs.google.com/document/d/1qiT_2EsnL20c4w0hyZ_CGaJQIzj8CSCsHERoR80cwws/edit#heading=h.9e3o7yaxw8mu) for information regarding our partner program discounts for your quote.

</details>

<details>
<summary markdown="span">
How do partner discounts impact my compensation?
</summary>

Please refer to GitLab's [channel neutral compensation policy](/handbook/sales/field-operations/channel-operations/#channel-neutral). Please contact the Sales Compensation team if you have any questions on a specific opportunity after reviewing the policy.

</details>

### Quoting

<details>
<summary markdown="span">
What are my options in quoting/selling via partners?
</summary>

- **Reseller** - GitLab quotes (i.e., sells to) the reseller, and reseller quotes the end customer. This is commonly referred to as a one-tier or reseller-direct deal
- **Distributor** - GitLab quotes (i.e., sells to) the distributor, distributor quotes the reseller, and reseller quotes the end customer. This is commonly referred to as a two-tier distribution deal
- **MSP** - GitLab quotes the MSP partner. The MSP partner purchases, holds title to, and manages the licenses that are used by their end customer, the MSP End User

</details>

<details>
<summary markdown="span">
What are the benefits of quoting via a distributor rather than reseller-direct?
</summary>

Please refer to the [Partner Operations handbook](/handbook/sales/field-operations/channel-operations/#why-does-gitlab-leverage-distribution) for details on the benefits of leveraging distribution.

</details>

<details>
<summary markdown="span">
When should I quote via a distributor rather than directly through a reseller?
</summary>

Please refer to the [Partner Operations handbook](/handbook/sales/field-operations/channel-operations/#distributor-requirements-and-coverage-by-geo-and-market) for details on distributor requirements and coverage by Geo and Market.

</details>

<details>
<summary markdown="span">
How do I create a reseller-direct, distributor, or MSP quote?
</summary>

Please refer to the [Partner Operations handbook](/handbook/sales/field-operations/channel-operations/#partner-quoting-overview-and-resources) for an overview of the partner quoting process and links to key resources including step-by-step quoting guides.

</details>

<details>
<summary markdown="span">
Where do I send the quote when I have a reseller-direct or two-tier distribution opportunity?
</summary>

The quote needs to be sent to the partner, not the customer. Specifically, if your quote is:

- reseller-direct, send the quote to your reseller contact only (ensure you do not copy the customer)
- via distribution, send the quote to your distributor contact only (ensure you do not copy the reseller or the customer). Please refer to the [Partner Operations handbook](/handbook/sales/field-operations/channel-operations/#distributor-requirements-and-coverage-by-geo-and-market) for distribution contact information

</details>

<details>
<summary markdown="span">
My partner does not have, and/or has provided new or updated, Billing Account (i.e., `Invoice Owner`) and billing account Contact (i.e., `Invoice Owner Contact`) information. How do I add this information to the partner's account so that I can generate a quote?
</summary>

Please refer to the [Partner Operations handbook](/handbook/sales/field-operations/channel-operations/#billing-account-and-billing-account-contact-on-partner-account-record) for details on how to add or update billing information on the Partner Account record.

</details>

<details>
<summary markdown="span">
How do I find the `Invoice Owner` and `Invoice Owner Contact` for my partner quote?
</summary>

The `Invoice Owner` and `Invoice Owner Contact` on a partner quote represent the partner's Billing Account and billing account Contact records, respectively. Please refer to the [Partner Operations handbook](/handbook/sales/field-operations/channel-operations/#how-to-find-partner-billing-records-in-sfdc-and-use-for-quoting) for details on how to find these records in SFDC and use them for quoting.

</details>

<details>
<summary markdown="span">
A prospect/unauthorized reseller is requesting a quote from GitLab. Are we able to provide them a quote either directly or indirectly via distribution?
</summary>

We are not able to quote an unauthorized reseller. Please encourage the reseller to [sign up as a partner](https://partners.gitlab.com/English/register_email.aspx) so you can provide a GitLab quote. If this is not possible, the opportunity owner and/or Channel Account Manager (CAM) can create a legal case on the opportunity to request a one-time authorization for the partner to transact with GitLab. If the request is reviewed and approved, Legal will work with the opportunity owner, CAM, and Sales Support to take the necessary steps to provide a one-time authorization.

</details>

<details>
<summary markdown="span">
I am unable to quote a partner as their `Partner Status` is "Prospect"? Why does this partner account have "Prospect" status and how do we update them to Authorized/Active?
</summary>

The partner account is in ["Prospect" status](/handbook/sales/field-operations/channel-operations/#standard-channel-practices) because they have not yet signed our partner agreement and/or completed their required sales training. Please contact the Channel Account Manager that owns the partner account in SFDC to request that they work with the partner to get them authorized.

</details>

<details>
<summary markdown="span">
The partner informed me that the customer has an air-gapped or offline environment and thus requires a legacy/offline license key. What adjustments are needed on the quote to ensure we provide the correct license key post-sale?
</summary>

Please follow the instructions in the [Cloud Licensing guide](https://docs.google.com/presentation/d/1gbdHGCLTc0yis0VFyBBZkriMomNo8audr0u8XXTY2iI/edit#slide=id.g137e73c15b5_0_298) to request approval for a legacy/offline at the time of quoting.

</details>

<details>
<summary markdown="span">
The partner requested non-standard payment terms for this opportunity. How can I apply non-standard payment terms on a quote?
</summary>

Please refer to the [Deal Desk handbook](/handbook/sales/field-operations/sales-operations/deal-desk/#new-subscription-quote) and [approval matrix](https://docs.google.com/document/d/1-CH-uH_zr0qaVaV1QbmVZ1rF669DsaUeq9w-q1QiKPE/edit#heading=h.ebvtllqqeve9) for details on applying non-standard payment terms.

</details>

<details>
<summary markdown="span">
The partner has asked for multiple versions of the quote with different configurations. How can I duplicate the quote so I can change certain details on each to present multiple versions to the partner?
</summary>

Please refer to the [Deal Desk handbook](/handbook/sales/field-operations/sales-operations/deal-desk/#how-to-clone-an-existing-quote) for details on how to clone a quote.

</details>

<details>
<summary markdown="span">
The partner requested an update to their quote, but I already submitted for approval so the record is now locked. Can I recall approvals to make an update?
</summary>

Yes, please refer to the [Deal Desk Handbook](/handbook/sales/field-operations/sales-operations/deal-desk/#recall-a-quote-from-approvals) for guidance on recalling a quote from approvals.

</details>

<details>
<summary markdown="span">
I understand we [cannot change route to market](/handbook/sales/field-operations/sales-operations/deal-desk/#a--add-on-quote-creation) through an amendment quote (e.g., change from one partner to another on a reseller-direct deal). However, can we amend a subscription to add licenses via a different reseller when the active subscription was sold through distribution (i.e., two-tier deal)?
</summary>

Yes, our contract/subscription record is with the distributor on a two-tier deal, not the reseller. If the customer, distributor, and account team need to change the reseller for a co-term add-on on a two-tier deal, GitLab is able to accommodate the change.

</details>

<details>
<summary markdown="span">
The customer would like to work with a different reseller for their renewal. Are we able to quote the new reseller at the incumbent partner discount?
</summary>

Yes, if the customer provides formal communication through email to confirm they would like to work with the new reseller for their renewal, we are able to transfer incumbency discounts. Refer to the [Partner Operations handbook](/handbook/sales/field-operations/channel-operations/#incumbency-renewals) for further details.

</details>

<details>
<summary markdown="span">
The partner requested to add seats to their customer's instance before the renewal. Does the add-on need to be processed before we can create a renewal quote for the entire subscription?
</summary>

Yes, for the customer's overall license count to be accurate during the renewal, add-on licenses need to be fully processed before GitLab can generate a renewal quote. Please refer to the [Deal Desk handbook](/handbook/sales/field-operations/sales-operations/deal-desk/#transacting-a-separate-add-on-opportunity-prior-to-renewal) for further guidance.

</details>

<details>
<summary markdown="span">
The partner is concerned their customer may not be able to renew their instance before their grace period expires and they lose access. Can a temp license extension be granted to have additional time to process the renewal?
</summary>

Yes, you can [submit an internal support ticket](https://support-super-form-gitlab-com-support-support-op-651f22e90ce6d7.gitlab.io/) to request a temp license to prevent the customer from losing access while the renewal is processed.

</details>

### Purchase Orders (POs)

<details>
<summary markdown="span">
What are the requirements to submit a partner opportunity for booking?
</summary>

Please refer to the [Sales Order Processing handbook](/handbook/sales/field-operations/order-processing/#submit-an-opportunity-for-booking) for partner opportunity booking requirements.

</details>

<details>
<summary markdown="span">
I received a PO from the partner but the quote is now expired. How do I extend the expiration date of the existing quote?
</summary>

Please refer to the [Deal Desk handbook](/handbook/sales/field-operations/sales-operations/deal-desk/#how-to-extend-a-quote-expiration-date) for guidance on extending the expiration date of an existing quote.

</details>

<details>
<summary markdown="span">
I am expecting a PO from the partner on the last day of the quarter. How do I ensure my PO/opportunity submission will count toward GitLab's current fiscal quarter?
</summary>

Please refer to the guidelines listed in the [Sales Order Processing handbook](/handbook/sales/field-operations/order-processing/#end-of-quarter-bookings) regarding end-of-quarter bookings.

</details>

<details>
<summary markdown="span">
My partner asked for GitLab's ECCN. Where can I find this information?
</summary>

You can find our ECCN in our [Trade Compliance handbook](/handbook/legal/trade-compliance/#how-do-trade-control-laws-apply-to-gitlab-software).

</details>

## Post-Sale

<details>
<summary markdown="span">
When can the partner expect the invoice for a closed won order?
</summary>

Invoices are sent [24 - 48 hours after the opportunity closes](/handbook/finance/accounting/finance-ops/billing-ops/#standard-operating-process).

</details>

<details>
<summary markdown="span">
The partner contacted me requesting the GitLab invoice and/or customer purchase confirmation proof of delivery (POD) for a closed-won order. Who from the partner receives the GitLab invoice and/or POD post-sale?
</summary>

The `Invoice Owner Contact` from the Primary Quote receives the GitLab invoice, while the `Sold To Work Email` of the `Invoice Owner` receives the POD (i.e., copy of the customer provisioning email from fulfillment). Note, these two contacts should be aligned on your quote, as the `Invoice Owner Contact` (i.e., billing account Contact) should be created from and thus match the details of the `Invoice Owner` (i.e., Billing Account). Please refer to the [Partner Operations handbook](/handbook/sales/field-operations/channel-operations/#how-to-find-partner-billing-records-in-sfdc-and-use-for-quoting) for details on partner billing records and how they apply to quoting a partner deal.

**Note**, on a two-tier deal, the distributor is invoiced by GitLab and thus the distributor receives the POD. Please connect the reseller with the distributor to obtain the POD if the reseller purchased through distribution.

</details>

<details>
<summary markdown="span">
The partner requested that the purchase confirmation email with license/activation code be resent to the same end user contact that was listed on the PO/Quote. How can we resend the purchase confirmation email?
</summary>

This can be actioned by either the GitLab Sales Rep or the partner:

- The GitLab Sales Rep can [submit an internal support ticket](https://support-super-form-gitlab-com-support-support-op-651f22e90ce6d7.gitlab.io/) to request that the support team send the purchase confirmation email to the same end user contact.
- The partner that received the GitLab invoice (i.e., Distributor for two-tier deal, Reseller for one-tier deal) can [submit a support ticket](https://support.gitlab.com/hc/en-us/requests/new) with the GitLab invoice attached to request the purchase confirmation email be resent to the same end user contact.

</details>

<details>
<summary markdown="span">
The partner contacted me saying their customer did not receive the purchase confirmation email with license/activation code due to the PO/Quote listing the wrong end user contact. How can we send the purchase confirmation email to a different end user contact?
</summary>

The partner that received the GitLab invoice (i.e., Distributor for two-tier deal, Reseller for one-tier deal) needs to [submit a support ticket](https://support.gitlab.com/hc/en-us/requests/new) with the GitLab invoice attached to request the purchase confirmation email be sent to a new end user contact.

**Important to note**, the GitLab Sales Rep cannot change the end user contact post-sale on behalf of the partner or customer. The request to change the end user contact must either be submitted by the (i) partner that received our invoice as outlined above or (ii) customer contact listed as `Sold To Contact` on our final quote (i.e., the person that received the license).

</details>

<details>
<summary markdown="span">
The partner notified us that the customer is unable to use their GitLab Self-Managed activation code as they have an offline or air-gapped environment. How can we provide a legacy or offline license post-sale?
</summary>

Request approval from your VP via SFDC chatter to provide an offline or legacy license key for a closed-won opportunity. If/when VP approval is granted, [submit an internal support ticket](https://support-super-form-gitlab-com-support-support-op-651f22e90ce6d7.gitlab.io/) to request an updated license be issued to the customer.

</details>

<details>
<summary markdown="span">
The customer received an error stating they are out of Compute Minutes so their instance has stopped working. How can I quickly resolve this?
</summary>

The customer must add Compute Minutes via the same procurement path as the original order (i.e., if they purchased the original subscription through a partner, they must purchase the additional minutes through the same partner). Please take the following steps:

1. Initiate the procurement process. For channel deals, GitLab Sales to provide the partner a quote for additional Compute Minutes. For AWS/GCP deals, GitLab Sales to generate a private offer to the customer for additional Compute Minutes
2. GitLab Sales to submit an internal support ticket to request that the support team add minutes to the customer's instance to get the customer back online while the GitLab procurement cycle is completed. To submit an internal support ticket, use the `Other> Other License & Renewals Related Issue request type`, and provide as much information as possible in the request to help drive quick review and approval (e.g., customer is locked out and required to wait on our procurement cycle since they purchase via partner, needs additional minutes to get back online)

**Important to Note**, The Support Team will not keep track nor remove any compute minutes, therefore GitLab Sales should request a modest amount of minutes to cover the time period necessary while waiting for the sale to process.

</details>
