---
title: "Customer Satisfaction Surveys"
description: "A deep dive into these surveys, how they are defined, and actioned."
---

## **What are customer satisfaction surveys?**

Customer Satisfaction surveys are a qualitative metric to gain a deeper understanding of the customer sentiment along the customer lifecycle. **Customer Satisfaction score**, or **CSAT,** is a transactional attribute to understand how a specific action, product, or experience in the customer lifecycle has gone.

**Note**: Any type of question or questions can be a customer satisfaction survey. There are **no standards for questions or metrics**. It is entirely based on what the company is trying to learn about the customer from a question.

**Examples of customer satisfaction surveys in GitLab:**

* [**User Satisfaction (USAT)**](/handbook/product/ux/performance-indicators/usat/)**:** Administered by the UX Research team via Rally UXR & Qualtrics to a representative sample of paid end users of GitLab, these surveys focus on measuring satisfaction with GitLab the product on a quarterly basis.
* **Customer Satisfaction CSAT**: This biannual survey, owned by Customer Success, measures the satisfaction level in both the product and engagement with our teams.
* **Service CSAT:** Administered by the Customer Success team via Gainsight to a larger audience, these surveys assess customer satisfaction with GitLab's overall support, service levels, and customer experience. These tend to be transactional, focused on the most immediate interaction with our team.

All teams are working collaboratively to streamline the survey process, improve data collection efficiency, and ensure that we have a comprehensive understanding of customer feedback. [OKR](https://gitlab.com/gitlab-com/gitlab-OKRs/-/work_items/9025).

## **What are the outcomes of these surveys?**

**For our customers** \- These surveys provide a direct channel to voice their feedback on their needs and expectations of GitLab, and how we can improve their overall customer experience expectations.

**For GitLab** \- These surveys provide insights into the opportunities to improve on our product and service delivery experiences, deepen customer relationships, and reduce churn and boost brand loyalty.

**Note**: GitLab is establishing a cross-functional initiative to enhance customer experience by integrating efforts across product development, marketing, sales, customer success, and support teams. This comprehensive program will provide transparency into strategic initiatives and key milestones, enabling customers to benefit from an optimized experience throughout their journey with GitLab.

## **Active GitLab Customer Satisfaction Surveys**

* [All-Customer CSAT Survey (Customer Success)](/handbook/sales/field-operations/customer-success-operations/cs-ops-programs/all-customer-csat-cs/)
* Post-Scale Engagement CSAT Survey
* Digital SMB [Case Closure Survey](/handbook/sales/commercial/global_digital_smb/#email-to-case) CSAT Survey
* [USAT Survey (UX Research)](/handbook/product/ux/performance-indicators/usat/)

### **What are the differences between the All-Customer CSAT and USAT surveys?**

| Question | All-Customer CSAT | USAT |
| :---- | :---- | :---- |
| What are the objectives? | Obtain a CSAT score, with data available and accessible to all of GitLab, that represents a customer sentiment at GitLab. | Track scores for the USAT by comparing them over time and identify themes within the open ended questions. |
| Who are the target sample? | Paid GitLab.com and Self-Managed customers with Admin or Owner roles. | Paid GitLab.com and Self-Managed end users and have been using GitLab for at least 60 days. |
| What roles do we contact? |  |  |
| How often are individuals in the target sample contacted? | Surveys are sent 2 times a year (in Q2 and Q4). Customers are contacted for both surveys via a survey email. | Surveys are sent 4 times a year. End users who have been contacted within the past 12 months do not receive a survey email. |
| How many and what kinds of questions are included? | 6 questions (See [internal slide deck](https://docs.google.com/presentation/d/12cHM8t7LAo2uXm0VIeFm6tZWK04ENBHykJHcNbesj58/edit#slide=id.g29649bd3f05_0_44)) for list of questions. | 4 questions (See [internal slide deck](https://docs.google.com/presentation/d/1zLtH5lc3GNx8dtzn8Q4y-fwXWyrccbdd0J263BEKkAE/edit#slide=id.g29649bd3f05_0_44)) for list of questions. |

## **Customer Engagement**

### **Who do we contact?**

Surveys sent directly to primary users on paid Premium and Ultimate accounts to measure satisfaction of a service, product, interaction or experience with GitLab. Each account will receive a CSAT survey no more than twice in a year. We hope to receive from as many accounts at GitLab as possible, rather than a representative sample of accounts. This enables us to inform all account teams of their portfolio’s customer satisfaction.

In order to target leaders and decision-makers on accounts, three types of users will receive an invitation to a survey:

* [GitLab admin contacts](/handbook/sales/field-operations/customer-success-operations/cs-ops-programs/#gitlab-admin-contacts)
* Sold-To Billing Contact (if no GitLab Admin exists)
* [GitLab.com Owner](https://docs.gitlab.com/ee/user/permissions.html) role

### **Who is not contacted?**

* Identified Billing or Procurement personas configured as Owners or GitLab Admins on accounts
* Guest, Reporter, Developer or Maintainer roles on accounts
* Users that have been contacted by other related surveys within the past eight weeks, such as the [USAT](/handbook/product/ux/performance-indicators/#regular-performance-indicators) survey administered by the UX Research Team.

## **Viewing CSAT Survey Results**

Each satisfaction survey is owned by different teams. Please see the linked pages above for links to dashboards.

## **Deprecated Surveys**

### **Net Promoter Score Survey (NPS)**

Net Promoter Score is a [standardized](https://en.wikipedia.org/wiki/Net_promoter_score) numerical value from 1 to 10\. It is NOT a determination of customer health. It is NOT a method of pinpointing specific product issues.

Customers received NPS surveys at multiple points in their lifecycle from 2021 to 2024\. These are stopped as of May 1, 2024\. Their results and data can be accessed [by request](https://gitlab.com/gitlab-com/sales-team/field-operations/customer-success-operations/-/issues/new) to the CSSO team. Additionally, you may request historical data for the following NPS surveys:

* Post-Onboarding NPS/CSAT
* Pre-Renewal NPS
* Post-Renewal NPS/CSAT

---

| Page Metadata |  |
| :---- | :---- |
| Last Updated | Oct 29, 2024 |
| Next Update | May 1, 2025 |
| Owner | Sarah Schuster |
| Sponsor | Brittney Sinq |
