---
title: "Renewals Operations Team"
description: "The Renewals Operations Team handbook page covers our mission, strategies, responsibilities, and processes."
---
<link rel="stylesheet" type="text/css" href="/stylesheets/biztech.css" />

## Vision

The Renewal Operations team is responsible for building, maintaining and optimizing the operational framework that supports GitLab Account Teams to effectively manage customer Renewals in an effort to increase Net Revenue Retention. The Renewal Operations team enables and supports Account Teams to:

- Ensure a consistent, seamless and positive Customer Renewal experience
- Identify and manage churn and contraction risk effectively
- Accurately forecast churn and contraction with a high degree of confidence
- Analyze drivers of Churn and Contraction and provide strategic recommendations to mitigate risk
- Ensure an exceptional level of data quality within tools and systems
- Identify, build and iterate process improvements to improve account management effectiveness

Find more information about how we drive the above initiatives on the [Renewals Managers - What we Do](/handbook/customer-success/renewals-managers/what/) page

Below is a breakdown of the 4-part [Renewal Operations Strategy](https://docs.google.com/document/d/1W63d98cMVXfMvqAey8vbd2JRlfOWHLK-Yu23hhZQGTI/edit#heading=h.xion0u9mlv5c).

- **Measure**
    1. Create continuous workflow that accurately measures and analyzes the main areas of churn and contraction
    1. Define Renewal Metrics to assist in forecasting based on Usage, Engagement, and [Predictive Models](https://internal.gitlab.com/handbook/sales/propensity_models/)
- **Improve Workflows**
    1. Identify and focus on areas of improvement in the customer lifecycle to prevent further churn and contraction and iterate on scalable solutions
- **Mitigate Risk - Customer Segmentation**
    1. Create a scalable risk management system, to allow Account Teams to monitor, investigate, and intervene on upcoming opportunities at risk.
    1. Establish an Early Warning System (EWS) to segment customers based on Customer Health and Growth metrics.
- **Growth & Engagement**
    1. Iterate through automated & manual engagement strategies and campaigns based on segmentation. Work with Renewals, Product, Digital CS, CSM, Sales Ops, and Sales Enablement to provide creative time & cost saving solutions.

## Meet the Team

| Person | Role |
| ------ | ------ |
| [John Budreski](https://gitlab.com/jbudreski ) | [Senior Manager, CS Strategy & Operations](/job-families/sales/renewal-operations-analyst/#manager-renewal-operations-requirements) |
| [Heather Kacmarski](https://gitlab.com/hkacmarski) | [Customer Success Operations Analyst](/job-families/sales/renewal-operations-analyst/) |
| [Laura Simmons](https://gitlab.com/simmons-laura) | [Customer Success Operations Analyst](/job-families/sales/renewal-operations-analyst/) |

## Get in Touch

Head over to [#renewal-ops](https://join.slack.com/share/enQtNDQwMzIxMzIzNzQ2Mi1lOGJlNmU2NDg5YzM5YzZlZDc0ZmI2YTM2NzQyZmU2OTM1NWMzMjY0NTFhN2QzMTYxMDI3NGZhNmVlNTY2ZmVm) on Slack to get in touch with us. We use this channel for general Renewal Operations support, and key system status updates. We attempt to avoid direct messages where possible as it discourages collaboration.

## Who We Work With

Renewal Operations supports the Renewals, Success and Sales Teams: Directors & Area Sales Managers, Renewals Managers, Account Executives, Strategic Account Executives and collaborates with Customer Success Operations, Sales Operations and Sales Strategy.

[**Renewals Team**](/handbook/customer-success/renewals-managers/home/) is Renewal Operations' direct focus, our primary customers are Renewals leaders; the insights, strategies, and actionable campaigns are built to assist the Renewal Managers and Account Executives with the renewal process.  Renewals Operations provides intelligent insights for the large amount of upcoming renewals managed by Account Teams to allow a more focused approach.

**Customer Success Operations** helps organize and collect pertinent product usage, and  customer health data that the Renewal Operations Team uses to identify insights and engagement strategies. For example, creating automated one-to-many campaigns in Gainsight to support product adoption.

**Sales Operations** supports Renewal Operations by maintaining our systems that process the renewals and opportunity management. As we progress, it can also improve risk management and forecasting.

## How We Work

The Renewal Operations team primary focus is to support the Global Renewals team through a number of channels and activities. For guidance on when and how to engage Renewal Operations see below:

### Renewal Manager Account & Opportunity Management

To reach out to Renewal Operations within Salesforce, follow the process to request internal support outlined [here](/handbook/sales/field-operations/requesting-internal-support/)

Renewal Operations can assist with:

- Territory Assignment Questions or Corrections ([for a Territory Change Request please follow the instructions here](/handbook/sales/field-operations/gtm-resources/rules-of-engagement/#territory-ownership-renewals-managers))
- Renewal Manager Opportunity Assignment
- Renewal Ownership (Tier) Re-assignment
- [Renewal Forecast](/handbook/customer-success/renewals-managers/what/#forecasting) field updates
- [Closed Details](/handbook/customer-success/renewals-managers/what/#analytics) updates
- Renewal Forecast guidance
- Complex Opportunity management guidance
- Renewal Manager Opportunity Split
- Merged Opportunities
- Churn Exception Review for Renewals Managers

### Quoting, Approvals and Bookings

For questions on Quoting, Approvals, Opportunity Booking or Opportunity data quality refer to the [Sales Order Processing Handbook Page](/handbook/sales/field-operations/order-processing/) or reach out to [Deal Desk via an Internal Support Request](/handbook/sales/field-operations/requesting-internal-support/)

### Compensation

For Compensation related questions please reach out to Sales Comp via the [internal support request](/handbook/sales/field-operations/requesting-internal-support/). Renewal Operations does not approve Churn exception requests, to request a Churn exception [please follow the process outlined here.](/handbook/customer-success/renewals-managers/how/#churn-exceptions).

## Renewal Operations Process Cadences

### Weekly

- Renewal Forecast Template Update
- [Forecast Data Quality Review](https://gitlab.com/gitlab-com/sales-team/field-operations/customer-success-operations/-/wikis/Renewal-Operations-Process-Documentation/Renewal-Forecast-Data-Quality)
- [Loss/Downgrade Reason Review](https://gitlab.com/gitlab-com/sales-team/field-operations/customer-success-operations/-/wikis/Renewal-Operations-Process-Documentation/Closed-Lost-Reason-Audit)
- [Renewal Opportunity - Customer Subscription Reconciliation](https://gitlab.com/gitlab-com/sales-team/field-operations/customer-success-operations/-/wikis/Renewal-Operations-Process-Documentation/Debook-Rebook-Reconciliation)

### Monthly

- Top Churn & Contraction Opportunity Review
- Debook-Rebook Renewal Reconciliation
- Churn Exception Review
- SMB Churn & Contraction Readout
- MM Churn & Contraction Readout
- Customer Success Forum

## Renewal Operations Projects

Renewal Operations uses issues and issue boards to track our projects and tasks. If your expertise can assist in any of our projects or if you simply want to share an idea you believe could assist the Renewals process, please open an issue and add the ~CS RenewalOps label anywhere within the GitLab repo.

See the [Renewal Operations issue board](https://gitlab.com/groups/gitlab-com/-/boards/3126050?scope=all&label_name[]=RenewalOps) to track progress.

## Projects

Create Issues in the [CS Operations project](https://gitlab.com/gitlab-com/sales-team/field-operations/customer-success-operations) using the RenewalOpsRequest Issue template.

### Labels

Labels to use when creating new Issues or MRs for Renewal Ops:

- CS RenewalOps - Catch all label to designate Renewal Operations involvement in the Issue. Use this label to bring an Issue to the Renewal Ops teams attention.
- ROPS::In_Process - Renewal Ops actively working Issue
- ROPS::Monitoring - Renewal Ops is a stakeholder but not the DRI for the Issue and is tracking progress
- ROPS::Priority - Renewal Ops has made this Issue a top priority to resolve ASAP
- ROPS::Blocked - Renewal Ops unable to resolve Issue due to technical or business limitation
- ROPS::Backlog - Renewal Ops has deprioritized this Issue and will be addressed at a later time
- ROPS::Completed - Renewal Ops resolved the Issue and is now Closed

## Contact Us

Send any questions to the slack channel [#renewal-ops](https://gitlab.slack.com/archives/C028Q2F3002)
