---
title: "Go-to-Market (GTM) Enablement motion"
description: "The GTM Enablement function is designed to ensure that new products, SKUs, and offers are supported effectively and efficiently as they launch to field teams and ultimately go to market. This framework outlines the processes and standards necessary for successful GTM enablement launches, aligning and integrating closely with both the New Product Introduction (NPI) process and the Field Enablement team."
---

This page defines the GTM Enablement motion and how it aligns to current processes here at GitLab. The GTM Enablement function is designed to ensure that new products, SKUs, and offers are supported effectively and efficiently as they launch to field teams and ultimately go to market. This framework outlines the processes and standards necessary for successful GTM enablement launches, aligning and integrating closely with both the New Product Introduction (NPI) process and the Field Enablement team.

This framework standardizes the approach to GTM enablement across different product launches and offerings and reconciles related frameworks, including:

* [New Product Introduction (NPI) Process Criteria](/handbook/product/product-processes/product-launch/)
* [Field Enablement High-Complexity to Low-Complexity GTM framework](https://gitlab.com/gitlab-com/sales-team/field-operations/enablement/-/issues/1500)
* [Field Communications Tier 1-5 model](/handbook/sales/field-communications/#field-communications-playbook)
* Product Marketing Tier 1-3 model
* GTM Revenue Play criteria

## Roles & responsibilities across GTM motion

[**The New Product Introduction (NPI) SteerCo**](/handbook/product/product-processes/product-launch/#step-2-meet-with-the-npi-steerco-and-get-alignment-on-the-launch-plan)**:** Assesses and approves the launch of the NPI process based on business cases presented by DRIs. These business cases must address product functionality, target market, value proposition, and financial opportunity. Once the SteerCo decides to proceed, they commit to a scope & launch timeframe (Step 4 in NPI Process: Planning Phase).

* **The NPI DRI** drives the feature or service strategy and is the primary business owner. This is the person requesting a new product, service, or SKU. The person is responsible for delivering the initial business plan, and ensuring that the launch meets business goals.
* **The NPI Program Manager** coordinates and directs the multiple parallel work streams required by the NPI process. In some cases, the DRI and the Program Manager may be the same person.

**GTM Enablement:** Generally, GTM Enablement leads the land and adopt strategy for net-new product and initiative launches at GitLab. This function works closely with the [Field Communications](/handbook/sales/field-communications/#field-communications-playbook) team to land initiatives in the field. This team is responsible for creating effective, timely, and easily consumable communications with the Field team (Sales, Customer Success, Channel, Alliances, Revenue Strategy, Operations & Enablement).

**Key initiative areas are limited to:**

* New product introductions
* New major SKU launches
* GTM Revenue Plays & Sprints
* Sales Offers
* Major Feature GAs & Product Updates
* CRO Annual Fiscal Year Launch

For this reason, GTM Enablement is one input into the NPI process. They provide guidance to the NPI SteerCo leads on what enablement considerations should be addressed when considering a launch timeline, including: potential enablement requirements, risks, and impact to field & partner teams. They also raise requirements from downstream workstreams as the main liaison between the field and launch teams. For launches that do not require the NPI process, GTM Enablement supports according to a tiered structure of effort.

[**Field Enablement:**](/handbook/sales/field-operations/field-enablement/#key-programs) Focuses on the "Reinforce & Sustain" motion, cascading information and training to field sales and customer success teams around new launches and initiatives to ensure long-term adoption, sustainment, and integration of new products and initiatives. For more information about the Field Enablement team, visit the [team handbook page](/handbook/sales/field-operations/field-enablement/).

## GTM Enablement coordination goals

View [list of cross-functional stakeholders](https://docs.google.com/spreadsheets/d/1hmph_k2uY9JokVV_M4tch01dyKSvqwvx1NanWDrey70/edit?gid=0#gid=0) with which this function collaborates. The GTM Enablement function adopts the sames goals as the New Product Introduction team in orchestrating downstream:

* **Empower teams:** Provide teams with a way to identify when & how we need to fix problems or adjust course.  
* **Include all relevant expertise:** Teams participate in decisions that need to incorporate their requirements. We create more robust & efficient solutions by leveraging teams’ expertise.
* **Provide clarity and certainty:** We document decisions, and communicate them widely and as early as possible. We lock down decisions at various points in the process so that teams have a shared understanding and can move forward.
* **Introduce process without being overly prescriptive:** Provide process to address coordination gaps. Balance this with empowering individual team members with expertise to make decisions.

## GTM Enablement Briefing Requirements

To launch the GTM Enablement process, a requester should fill out the [intake form](https://gitlab.com/gitlab-com/sales-team/field-operations/enablement/-/blob/master/.gitlab/issue_templates/gtm-field-enablement-intake.md) to determine level of effort and support.

### The GTM Enablement DRI must be able to understand the following

1. **Anticipated Impact to the field:** How much does this change for them, how many does this affect, relevancy to segments and partners, level of attention needed, and time needed from the field to reach the desired outcome. Additionally, what is the actual projected impact (revenue, strategic importance, and geographic relevance) so we can understand the scope and level of behavior change needed.
2. **Level of leadership buy-in**: The requester should provide a list of leaders who have reviewed and signed off on the project
3. **Timeline confidence:** The requester should present dates that have already been confirmed by initiative leads as non-MNPI and with high confidence
4. **Related materials & cadences:** Project issue or epic, Key project milestones, Draft Program tracker, Plan for recurring async updates

**Based on this information, the GTM Enablement DRI will assign a Support Tier:** The GTM Enablement DRI will determine level of support that will be provided and anticipated outcome. Timelines associated with each Tier cannot be adjusted; instead the outcome will need to change to reflect the available timeline.

### Downstream teams, in turn, should raise

1. Any internal factors (Field quiet periods, month/quarter/year end financial close, etc.) that create timing requirements
2. Any bandwidth constraints or gaps in support

### For reference, in order to launch the NPI process, the NPI DRI must communicate

1. **What** we’re launching: product features & functionality, service entitlements, or something else
2. **Why** we’re launching: value proposition, strategic value, and scale of financial opportunity (understand that finance will not have built detailed models, but some financial justification must exist)
3. **Who** we’re targeting: Ideal Customer Profile (ICP) and target market
4. **When** we need to launch: any internal (e.g. [Field blackout periods](/handbook/sales/field-communications/), month/quarter/year end financial close, quiet periods, etc.) or external factors that create timing requirements
5. **That we’re able to launch:** product development is sufficiently far along that it makes sense to start the process, and GTM teams have sufficient bandwidth to do the work in the required timeframe

## GTM Enablement Operating Rhythm Overview

* Phase 1: Briefing & planning
* Phase 2: Project execution & launch
* Phase 3: Feedback & initial results

### **Phase 1: Briefing & planning**

1. GTM DRI briefed and determines tiered support based on initiative and field impact
2. Builds workback plan in collaboration with workstream leads for confirmation (NPI, PMM, and/or Sales Strategy)
3. Identifies cross-functional working group and aligns to open cadences set by initiative DRI (NPI, PMM, Sales Strategy)
4. Provides clear briefing to downstream teams for input and collaboration. Surfaces concerns or requirements back to upstream teams.
5. Downstream teams inform their leadership and plan their reinforce & sustain motions by audience and desired impact

### **Phase 2: Project execution & launch**

1. GTM DRI orchestrates launch and drives process
2. Maintains close coordination on decisions & steps that affect others
3. Delivers updates on progress & results to stakeholder groups upstream and downstream
4. FE DRIs collaborate on reinforcement & cascades. Raise concerns and create open feedback loop with downstream teams.

### **Phase 3: Feedback & initial results**

1. GTM DRI delivers wrap-up & final results reporting
2. GTM DRI creates retro with FE teams. Participates in retros upstream & raises feedback from downstream
3. FE DRIs reinforce & sustain motions begin

## **Integration with the NPI & Field Enablement teams, activities, and processes**

In this process, GTM Enablement is integrated as main liaison to field enablement for land & adopt motion.

## **NPI Planning:**

1. Based on the process within the [New Product Introduction (NPI) Handbook page](/handbook/product/product-processes/product-launch/). The NPI Program Manager communicates the plan & organizes logistics with the wider working group. This includes two key meetings:
   * Stakeholder kickoff (process-focused): Meeting with all NPI stakeholders to launch the process: share overview of timeline, milestones, what success looks like, expected challenges.
   * Product review (product-focused): Product Manager to present overview to all stakeholder teams. This is a deeper dive than stakeholder kickoff, and more focused on the product. GTM teams use this information for additional due diligence & clarity, and as an input to start developing their own strategies and roadmaps. (e.g. Deal Desk may have questions around usage boundaries, approval processes for non-standard steps, etc.)
   * These meetings are a chance for the various stakeholders and Subject Matter Experts (SMEs) in the organization to raise risks/issues sooner rather than later. The SMEs may ask questions that can’t be answered yet; that’s an opportunity for further discussion later in the project. For stakeholders this is a chance to understand what will be expected of them in the coming weeks/months.
2. NPI Program Manager completes GTM Enablement intake issue to begin the briefing process. The intake issue reflects the briefing requirements outlined in the NPI process alongside GTM Enablement requirements. Enablement DRI schedules a briefing session depending on the contents of the issue.
3. GTM Enablement DRI is briefed and determines tiered support based on initiative and field impact. Provides initial feedback or considerations to NPI lead that may affect timeline or impact.
4. GTM Enablement DRI and Product/Product Marketing Lead align on approach & launch timeline as well as MNPI restrictions. (NPI’s might be [limited access](/handbook/communication/confidentiality-levels/#limited-access) in which case, details would not be open to all team members only those that need-to-know).

### **GTM Briefing & Planning:**

1. GTM Enablement lead participates in topical deep dives, and builds a workback plan in collaboration with NPI workstream leads for confirmation. They also identify the downstream cross-functional working group that needs to be informed.
2. GTM Enablement DRI aligns to open cadences set by initiative DRI and workstream leads (NPI lead, PMM lead, Sales Strategy, FE leads)
3. GTM Enablement lead schedules and provides a briefing to FE leads once any MNPI restrictions are lifted.
4. FE leads inform their leadership and plan their reinforce & sustain motions by audience and desired impact.
   1. This action reflects the NPI process approach where workstream leads are empowered to deliver and manage their work accordingly. A framework will be provided that allows flexibility for these SMEs to determine the best path for reinforcement & sustainment.
   2. FE leads and the GTM FE DRI check-in async or in established team cadences to ensure that work is on track against the defined timeline. The GTM FE DRI should partner with teams to facilitate decision making and problem solving where needed. NPI projects can be highly complex and the teams will need to discuss challenges regularly.
5. The GTM FE DRI will surface challenges covered with FE leads to the NPI team for consideration, action, or as part of the retrospective process.

### **GTM Execution and Launch:**

1. GTM FE DRI orchestrates the launch and drives process, using packaged enablement templates defined by cross-functional teams and collaborating closely with Field Enablement to ensure a seamless transition.
2. Similar to NPI process: Both workstreams maintain close coordination on decisions & steps that affect others
3. GTM FE DRI Delivers updates on progress & results to stakeholder groups upstream and downstream
4. FE DRIs collaborate on reinforcement & cascades. Raise concerns and create open feedback loop with downstream teams.

### **Post-Launch Evaluation:**

1. GTM Enablement delivers closed-loop reporting on all enablement activities and engagement aligned to the GTM Enablement Framework.
2. GTM Enablement participates in [retrospectives](/handbook/engineering/management/group-retrospectives/) upstream and downstream (merging where possible) with various working groups and engages in feedback loops to assess the launch's success and identify areas for improvement, ensuring continuous enhancement of the NPI and enablement processes.  
3. Field Enablement reinforce & sustain motions begin.
