---
title: "Using Gainsight within Sales"
description: "The key aspects of how Sales uses Gainsight to drive success for customers."
---

*For an overview of Gainsight, and information about how to login, please refer to the [Gainsight Overview Page](/handbook/sales/gainsight/).*

### Gainsight in Salesforce

There are a few different ways to access Gainsight. The first is to access Gainsight through Okta. The second and third options require you to login to SalesForce. Once logged into Salesforce, navigate to the Account or Opportunity page, and scroll down to the Gainsight widget.  The Customer 360 page will be the default view and is customized to show high-level account data and navigational tabs specific to Account Planning. The other option, is to select the + sign on the blue navigation bar in Salesforce, and choose Gainsight NXT from the dropdown menu. Many reps prefer this view since you can see more of the entire account plan in a single pane.

### Creating an Account Plan

1. From the Gainsight widget, use the top navigation bar to select the **Success Plan tab**.
1. In the right corner select **New Success Plan**.
1. Name your success plan indicating Land or Expand and year(s).
1. The **Type** will be Account Planning.
1. Add a due date. The account renewal date is a good place to start, although this will evolve as the plan evolves.
1. Add a template to the Account Plan by using the ellipsis menu located in the gray bar on the right side of the page. The [Land Plan](/handbook/sales/account-planning/#land-account-plans) and [Expand Plan](/handbook/sales/account-planning/#expand-account-plans) templates will provide a guided action items and next steps.
1. To learn about other plan types (Opportunity Plan, Command Plan, Success Plan), review [this page](/handbook/sales/account-planning/#what-is-the-difference-between-an-account-plan-and-a-success-plan).

### Locating an Existing Account Plan

1. From the Gainsight widget, use the top navigation bar to select the **Success Plan tab**.
1. In the gray bar towards the top of the widget, use the **More Plans arrow** to view the existing plans.

### Account Plan Info

1. The default view of an Account Plan will be the Plan Info section.
1. Plan Info is comprised of the Customer Profile, Execution Plan and Go-To-Market Plan.
1. Add or edit content to the Plan Info by using the pencil icon located to the right of each text box.
1. For further detail on the methodology behind the individual components, [click here](/handbook/sales/account-planning/#account-profile).

#### The Customer Profile

This section of the account plan serves to capture any relevant customer information.

| Field Name         | Field Description                                                                                                                                                                                                                                         |
|--------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| Name               | Pulled from Salesforce                                                                                                                                                                                                                                    |
| Account Rank       | Pulled from Salesforce                                                                                                                                                                                                                                    |
| Account Rank Notes | Link a GoogleDoc, or add any context detailing why the account was ranked the way it was. We should be starting with Rank 1 Accounts.                                                                                                                     |
| Business Overview  | High level overview of the organization, and any pertinent information that someone would need to know about the organization. This can include information such as key products and services, key customer business priorities, or financial challenges. |
| Industry Trends    | Is there anything going on in the customer's industry? New technology or changes that impact the customer's org?                                                                                                                                          |

#### The Account Snapshot

This section of the account plan serves to capture relevant information about the customer and their engagement with GitLab.

| Field Name                      | Field Description                                                                                                                                                                                                            |
|---------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| Account Summary and History     | Relevant information about what is currently going on in the account, and anything pertinent that could impact the account. For example, organization has a new CTO or the organization is deciding on a new cloud strategy. |
| Current Entitled Solutions      | Information on current subscriptions, adoption rates, and product usage data if it is available.                                                                                                                             |
| IT/ Digital Strategy            | Where is the customer in their digital transformation journey? What is their strategy for the next 3, 6, 12 months?                                                                                                          |
| Strategic Partnerships          | Information about partners engaged with the customer (e.g. their cloud provider) and partners involved in this account.                                                                                                      |
| Goals/ Strategies/ Objectives   | Information about the customer's pain, and desired positive business outcomes.                                                                                                                                               |
| Customer High Level Initiatives | What is the customer working on? Do they have any key initiatives we should be aware of?                                                                                                                                     |

#### Go-to-Market Plan

This section of the account plan serves to capture relevant information about our plan to drive success for the customer.

| Field Name                                    | Field Description                                                                                                                                                                                                                        |
|-----------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| Overall Account Plan Goals (6, 12, 18 months) | What is your vision for the customer for the next 6 months? What about 12, and 18 months? Has the customer shared their vision/ strategy for the next year with you?                                                                     |
| GitLab Initiatives                            | Information about any relevant internal initiatives that could impact the customer. For example are there impending pricing changes, or incentives around GitLab Ultimate?                                                               |
| Threats/ Risks                                | Are you aware of any threats to your customer's business, to the health of their GitLab adoption, or your plans to expand within the account? For example, are they downsizing? Is Microsoft making a strong play for their CI business? |
| Action Plan                                   | Based on your vision for the next 6, 12, and 18 months, how do you plan to get there? Have you considered the role of yourself, the SDR, the SA, and the CSM?                                                                            |

### Relationship and Influence Mapping

1. From the Gainsight widget, use the top navigaion bar to select the **Contacts tab**.
1. Use the drag and drop function to add contacts to the map or use the Add Person button located to the right of the widget.
1. Add further detail (Influence, GitLab Role, Manager) to the contact card by double clicking in the card or using the ellipsis menu.
1. Check out [this article](https://support.gainsight.com/gainsight_nxt/07360/User_Guides/Build_People_Maps) from Gainsight on building maps as well as [this enablement](/handbook/sales/account-planning/#relationship-and-influence-mapping) page.

### Whitespace Mapping

This activity is best done as a team, Solutions Architects and Customer Success Managers can help ensure this section reflects the team's understanding of the opportunities within the account.

1. In Gainsight, there are two different sections for whitespace mapping. Whitespace (Use Case) and Whitespace (Use Case Visual).
      - **Whitespace (Use Case):** This is where you will enter the data. It will flow back into Salesforce but cannot be edited in Salesforce at this time.
      - **Whitespace (Use Case Visual):** After data has been entered, use this tab to see a visual representation of the data.  There are multiple views from which to choose.
1. Reference this [Whitespace Mapping page](/handbook/sales/account-planning/#white-space-mapping) for further detail on the methodology.

For each use case, seek to understand if the customer is using a competing technology aligned to each of the use cases (there is a picklist in Gainsight), if there is an appetite for replacement (green indicates there is an appetite for change), and when that contract ends.

### Company Intelligence

Company Intelligence allows users to stay up-to-date on their key customers and prospects and can be located in the Company Intelligence tab. Company Intelligence is also available via notification. To turn on notifications follow these steps:

1. Using the bell icon in the top right corner of Gainsight, select the gear icon.
1. Select the Events drop down menue
1. Next to Company Intelligence, select your notification preferences. Currently the only option is Slack and the updates will arrive via the Gainsight Sally app.
   - Bonus: Once opted in to Slack notifications [you can request additional real time updates](https://support.gainsight.com/SFDC_Edition/Sally_AI_Bot/User_Guides/Sally_-_the_Gainsight_bot_Overview). Go to slack and send a direct message to "Gainsight Sally." Ask for a summary of an Account you own.

- [Setting up notifications](https://support.gainsight.com/Gainsight_NXT/Company_Intelligence/FAQs/Company_Intelligence_FAQs).
- [Company Intelligence FAQs](https://support.gainsight.com/Gainsight_NXT/Company_Intelligence/FAQs/Company_Intelligence_FAQs).
- [Company Intelligence, The long version](https://support.gainsight.com/gainsight_nxt/Company_Intelligence/About/Company_Intelligence_Overview_Old).

*Note: Only 5,000 Accounts can be tracked at a time. To request an account be added to tracking, please submit an issue in the [Sales Ops project](https://gitlab.com/gitlab-com/sales-team/field-operations/sales-operations/-/issues) and select the General Request template.*

### Sponsor Tracking

1. From the Gainsight widget, use the top navigation bar to select the **Sponsor Tracking** tab.
1. Click **+Sponsor** to choose a contact from the list or add a new contact by using the search feature.
1. In the action column, click the link and enter the LinkedIn URL to start tracking.
1. Private, Premium LinkedIn profiles can't be tracked at this time (May 2021).
      - Profile with special characters cannot be tracked unless a request is submitted to Gainsight Customer Support.
1. For more detail on how Sponsor Tracking works, please [read this article](https://support.gainsight.com/SFDC_Edition/View_More_Categories/Sponsor_Tracking/User_Guides/How_to_Use_Sponsor_Tracking#Changes_in_Tracked_Contacts) from Gainsight.

### Available Courses

- [Account Planning in Gainsight: The Account Snapshot](https://gitlab.edcast.com/pathways/ECL-5c4a6b55-f0cc-4a15-b445-6b46b2824a1f)
- [Account Planning in Gainsight: Relationship/ Influence Mapping](https://gitlab.edcast.com/insights/ECL-6f45dc9d-d9f8-4d9c-be2d-3a13f6bbe148)
- [Account Planning in Gainsight: Whitespace Mapping](https://gitlab.edcast.com/insights/ECL-15299b51-9d03-4a43-ac47-1a8ffd544c2d)
- [Account Planning in Gainsight: The Action Plan](https://gitlab.edcast.com/insights/ECL-972e933a-3768-4f4a-8784-ed1ba62dbf2d#)

### Video Enablement

- [Gainsight Kickoff and Demo](https://www.youtube.com/watch?v=Xhor2IIsCQQ)
- [How a Gainsight Rep Uses Gainsight](https://youtu.be/lnEkbLnxs-8)
- [Getting Started with Gainsight](https://www.loom.com/embed/3bc8692532e94a37ba693c14e36d1d8a)
- [Completing the Account Snapshot in Gainsight](https://www.loom.com/embed/09f6d86b58f042da860185fe947814c9)
- [Whitespace Mapping with Gainsight](https://www.loom.com/embed/1da3c252c8f34e74a145cf964e4fb29e)
- [Whitespace Mapping Visuals with Gainsight](https://www.loom.com/embed/3463bbf34da64343821df1b0c7f302eb)
- [Relationship and Influence Mapping with Gainsight](https://www.loom.com/embed/1d5cfe4374bc40d2b2dddd0dee43a387)
- [Relationship and Influene Multi-Maps with Gainsight](https://www.loom.com/embed/3e04070f7f9a47babb5b5cb6a3838741)
- [Creating the Action Plan with Gainsight](https://www.loom.com/embed/6ce45c18843743b88ec7554863792266)
