---
title: Inside Sales Department
description: >-
  The Inside Sales department is part of the GitLab Sales function who partners with the sales and customer success teams to deliver maximum value to GitLab customers throughout their journey with GitLab.
---

The Inside Sales department is part of the [GitLab Sales](/handbook/sales/) function who partners with the sales and customer success teams to deliver maximum value to GitLab customers throughout their journey with GitLab.

The Enterprise Inside Sales team can be reached in [Slack channel](https://gitlab.slack.com/archives/C01P39947ND) (internal only).

The Public Sector Inside Sales team can be reached in [Slack channel](https://gitlab.slack.com/archives/CNAMWG9N3) (internal only).

## Mission Statement

To deliver value to all customers by managing customer accounts and working closely with GitLab account teams and partners on renewals and growth initiatives.

The mission of the Inside Sales department is to create valuable experiences for our customers and partners, and assist internal sales teams with renewal management, quoting, and paper process. We do it by:

- Taking a consultative approach to customer and partner management
- Generating growth net ARR from renewals
- Maintaining a high on-time renewal rate

## Enterprise ISR Goals & Behaviors (FY23)

| Goals              | Behaviors              |
| ------------------ | ---------------------- |
| **1. Manage & grow renewals with < or equal to $50k in ARR Basis** | Collaborate closely with SAEs, ASMs, and regional sales teams to build account plans to retain, grow, and upgrade customers. Work with customers and partners to get 90-120 days ahead of all renewals. Conduct Renewal health checks to review current usage and potential for growth or upgrades. Support customers and partners with license procurement and fulfillment. |
| **2. Drive nARR with upgrades and add-ons for growth opportunities with <$50k in ARR Basis** |  Support SAEs and the field sales team with strategic growth including add-on and upgrade opportunities, assist with account planning, discovery, qualification, quoting & paper process, internal approvals, partner management, as well as licensing and fulfillment |
| **3. Maintain & improve renewal rate** | Work closely with SAEs, ASMs, CAMs, and CSMs to ensure on-time renewals. Work closely with channel partners, deal desk, internal teams and develop a process to stay 90 - 180 days ahead of all renewals |

## ISR Alignment

After completing onboarding, Inside Sales Representatives are assigned a territory by *region* or a defined set of *Account Territories*. Current Enterprise ISR territory assignments can be found in the [Territories Mapping File - SSoT](https://docs.google.com/spreadsheets/d/1gElhORjqraKDMQnWzApPelyP_vVa24tAOA85vb5f3Uc/edit#gid=1765694827).

### ISR Account Alignment

Once an ISR has been added to the Territories Mapping File, their name will **automatically** be populated in the `Proposed ISR` field on all Accounts associated with ther respective `Sales Territory`.

It's expected for the Inside Sales Team to follow the [Account Ownership Rules of Engagement](/handbook/sales/field-operations/gtm-resources/rules-of-engagement/). The section linked above provides step by step clarity on how to follow the ROE.

### ISR Opportunity Alignment

The `ISR` field will be **automatically** populated on an opportunity based on the `Proposed ISR` field from the opportunity's associated Account.

- **Open Opportunities**: the `ISR` field will reflect whatever information is populated in the associated Account's `Proposed ISR` field (including blanks).  `ISR` will remain a fluid field until the opportunity is moved to a closed stage, meaning if the `Proposed ISR` is changed, any associated open opportunity will be updated to reflect that change in the `ISR` field.
- **Closed Opportunities**: the `ISR` field will not change after an opportunity has been moved to a closed stage (Won, Lost, Duplicate) and will reflect whoever the `Proposed ISR` was at the time of closure.
- **ISR Override**: In the event that the `ISR` field on the opportunity should not be the same as the `Proposed ISR` on the Account, the ISR Management team has the ability to override the `ISR` field by checking the `ISR Override` box on the opportunity and updating the `ISR` field accordingly.  This removes the `ISR` from any automation.
  - **Note**: In scenarios where the override is no longer needed, the ISR Manager simply needs to uncheck the `ISR Override` checkbox and the auotmation will run as intended (for open opportunities only).

**Note**: The `ISR` field will be populated on **all opportunities** where the associated `Proposed ISR` field is also populated. This does not guarantee compensation credit. Please see your comp plan for details to determine what qualifies.

It's expected for the Inside Sales Team to follow the [Opportunity Ownership Rules of Engagement](/handbook/sales/field-operations/gtm-resources/rules-of-engagement/). The section linked above provides step by step clarity on how to follow the ROE.

## Enterprise ISR FY23 FAQ

**What changes for ISRs in FY23?**
In FY23, ISRs will have a narrowed focus and will be responsible for managing renewals and growth exclusively. The primary focus for Enterprise ISRs will be individual renewals with < $50k ARR Basis as well as add-ons and growth associated with those < $50k renewals.

In addition to renewing and growing < $50k renewals, the ISRs will be measured on renewal rate for the area(s) they support. SAEs and ASMs should be the primary point-of-contact for renewals > $50k in ARR basis as well as all first order or new business initiatives.

**How does GitLab define ARR Basis?**
ARR Basis or "Renewal Amount" means the prior period of ARR between GitLab and a Customer or GitLab and an eligible Partner.

ARR Basis is automatically recalculated after every subscription change.

**How does GitLab define Renewal Rate?**
"Renewal Rate" means the amount of successfully renewed ARR divided by the total Available to Renew (ATR) for a given period. This does not include growth opportunities.

**If I am a SAE or ASM will I retire quota for ARR generated by my aligned Inside Sales Rep?**
Yes. ARR generated from ISR-managed renewals will roll up to the SAE and ASMs. It is important for ISRs, SAEs, and ASMs to collaborate closely on the renewal pipeline, pipeline management, and forecasting.

**What if a SAE wants to be involved or manage renewals < $50k because they see potential for significant growth?**
In this case, ISRs and SAEs should collaborate and document who owns next steps using the Next Steps fields in the opportunity. The "ISR Priority" field should also be updated from "Tier 1 - Actively Managed by ISR" to "Tier 2 - Co-managed by SAE & ISR."

By default, all <$50k renewals will be marked as "Tier 1 - Actively Managed by ISR" unless this is manually updated by the account team.

**What are ISRs no longer compensated for?**

- First Order
- ARR for Renewals with > $50k ARR Basis
- Connected-New

**What about quoting and paper process for first order deals and strategic (>$50k renewals)?**
In FY23, SAEs and ASMs will be responsible for quoting and paper process related to First Order. ISRs are expected to collaborate and can help in case of emergency, but are not able to retire quota for assisting with renewals >$50k.

**Who should serve as the primary backup when SAEs are out of office?**
ASMs with ISRs available to support with renewals and growth.

**Will ISRs retire ARR quota by growing renewals over the <$50k ARR threshold?**
Yes. And once the value crosses over the $50k threshold, SAEs should be looped in to coordinate and drive the opportunity to close alongside the ISR and ASM.

**What should an ISR do if they identify signficiant growth potential from a sub $50k renewal?**
Loop in the SAE and ASMs and other account team resources (SAs and CSMs). These growth oppotunities should be a collaborative effort between the ISR, SAE, and ASM.

**How should ISRs work with Solution Architects?**
[Engaging Solution Architects](/handbook/solutions-architects/processes/#engaging-an-sa-during-the-sales-cycle) is ultimately the responsibility of the SAE (or ASM). ISRs should work closely with SAEs to ensure the SA qualification criteria is uncovered and there is strategic growth or upgrade potential.

## Getting Started as a New Hire

1. Get to know your team. Prepare to introduce yourself on the first team call and schedule coffee chats to get to know your teammates around the globe.
2. Review the [quote configuration process](/handbook/sales/field-operations/order-processing/#quote-configuration) in the Field Operations handbook.
3. Review the handbook pages linked in the "Resources" section below.
4. If you are new to GitLab, complete your [onboarding issue](/handbook/people-group/general-onboarding/#completing-onboarding-issue). If you are an internal transfer, complete your [career mobility issue](/handbook/people-group/promotions-transfers/#career-mobility-issue) and [access change request issue](/handbook/it/end-user-services/onboarding-access-requests/access-requests/#access-change-request). These will need to be completed and closed out before regions or territories can be assigned.
5. Get to know your [regional deal desk team](/handbook/sales/field-operations/sales-operations/deal-desk/#deal-desk---a-global-presence). Schedule coffee chats, attend the Deal Desk office hours, or both!

   Once you have been assigned a territory:

6. Schedule and lead a recurring call with the Regional Director(s) and Area Sales Manager(s) to review regional priorities (bi-weekly cadence suggested). Work with RDs and ASMs to make sure you are invited to the appropriate team calls, slack channels, etc.
7. Schedule time to introduce yourself and educate supported SAEs or AEs on your role and responsibilities. Develop a working cadence and document how you plan to communicate and stay aligned on priorities.
8. Ensure that you are added to regional sales team calls.
9. Ensure you are added (as an optional attendee) to all relevant SAE and CSM calls or opportunity reviews.
10. Review and document Current- and Next-FQ Renewals and Opportunities that you will "actively manage" as the ISR. Tag all "actively managed" opportunities following the process outlined in the "Actively Managed Opportunity" section below.
11. Review your regional alignment on the [Sales Territories](/handbook/sales/territories/) page.
12. Create a renewals report that includes quote start and end dates.

## ISR Account and Opportunity Management

### The ISR Required 5

It's Monday morning. You have just opened your laptop. You've got 2 renewal health check calls, an Ultimate Upgrade call, 10 customer touchpoints to execute, and 2 quotes to do. You know this because your tasks and next steps are clear and up to date.

Your first call is a Renewal Health Check. You have already put a deck together and you double-check your next steps and opportunity history to make sure you haven't missed anything. Turns out the customer mentioned other business units could benefit from using GitLab on a previous call and promised you that they would track down the best people to get in touch with. You were reminded of this because it was in your next steps. You remind the customer and get names and contact information and a new add-on opportunity to qualify.

Next up, you need to send out those two quotes. You create the quotes, send them to the customer, and update your next steps to remind you to follow-up with the customer in 2 days' time.

Next up is the Ultimate Upgrade. You get on the call. You recap the last conversation and take the customer through the reasons why Ultimate is ideal for them. You know security is important because they've mentioned it to you a few times on calls now as per your call notes. They like what they see, but the price seems a bit high. But you've already thought about that and go through the ROI of using Ultimate. You end the call agreeing to send over a quote and confirm that you will have a check-in in a week's time. You update your task and next steps in line with the check-in call date, you update the opportunity history and paste your raw notes from the call into your activity log.

Now it's time to work through the remaining tasks in your task list. You navigate to the Salesforce.com homepage and realize that you need to prepare and build a deck for an add-on call with a new customer business unit tomorrow. You create the deck in the customers branding. You add in info that you gathered previously. It's 100 potential Premium users, so you add in the questions you'll ask in your command plan. You update the task and next step to remind yourself to update the opportunity once the call is finished.

Finally, you have time to clear your inbox and catch up on Slack messages!

| Required Component | Detail                 | Why                   |
| ------------------ | ---------------------- | --------------------- |
| **Tier all of your opportunities** | [Requirements - ISR Prioritization & Opportunity Tiering](/handbook/sales/insidesales/#isr-prioritization--opportunity-tiering) | Helps to identify opportunity ownership and streamline account team collaboration |
| **Create & maintain an opportunity task for all opportunities** | [Requirements - Opportunity Task Management](/handbook/sales/insidesales/#opportunity-task-management) | Creates efficiencies in customer outreach and helps you ensure that you are ahead of all opportunities |
| **Keep your next steps up to date** | The `Next Step` and `Next Steps Owner` fields must be up to date at all times | Understanding the next step and who owns it is critical to delivering a good customer experience and closing deals |
| **Keep a log of your customer-facing activities** | Keep a running log of all customer-facing activities using the `Next Steps History` field. | As an ISR, you have a high volume of activites and opportunities to keep track of. Maintaining a log of activities will help you work through opportunities and context-switching more effectively. |

### ISR Opportunity Tiering

This process helps to better organize, track, and report on the different types of opportunities that are being managed by the Enterprise Inside Sales team. Enterprise Inside Sales Reps are required to select the appropriate `ISR Priority` tier for each opportunity that they are working in Salesforce. The `ISR Priority` tier is a data point that can be found in the Opportunity object in Salesforce and should be maintained until the opportunity is closed out.

#### Tier 1 = Actively managed by ISR

An "actively managed" opportunity is any opportunity or renewal which has been delegated by a SAE or AE to be directly managed by an ISR.

ISR Requirements:

- Copy the account leader on all customer-facing communications
- Create & maintain an open Opportunity Task on all open opportunities assigned in Salesforce
- Ensure the *Next Step* field is up-to-date with the context as well as who owns the next step (if it is not the ISR)
- Ensure proper logging of ALL activities in Salesforce

#### Tier 2 = Co-managed by SAE and ISR

A "co-managed" opportunity is an opportunity that SAEs & ISRs collaborate on and work together with customers to close.

ISR Requirements:

- Copy the account leader on all customer-facing communications
- Create & maintain an open Opportunity Task on all open opportunities assigned in Salesforce
- Ensure the *Next Step* field is up-to-date with the context as well as who owns the next step (if it is not the ISR)
- Ensure proper logging of ALL activities in Salesforce

#### Tier 3 = SAE-managed

"SAE-managed" opportunities are managed entirely by the SAE including customer-facing activities, quoting, internal approvals and paper process.

ISR Requirements:

- Backup / Emergency support on paper process, quoting, approvals, and customer-facing activity on an as-needed basis
- If an ISR is looped in to support a SAE-managed opportunity, the ISR should update the *ISR Priority* field and move it to the appropriate tier.

#### Tier 4 = Low touch

"Low touch" opportunities require no customer-facing activities from the inside sales rep to close. Or Opportunities in which the ISR is responsible for only internal processes like quote generation, internal approvals, deal facilitation, processing, or license management.

ISR Requirements:

- Copy the account leader on all customer-facing communications
- Create & maintain an open Opportunity Task on all open opportunities assigned
- Ensure the *Next Step* field is up-to-date with the context as well as who owns the next step (if it is not the ISR)
- Ensure that all customer-facing activities and communications are logged in Salesforce

### Opportunity Task Management

In addition to being tagged on every opportunity in region, ISRs should maintain an `Opportunity Task` for each open opportunity that they are assigned. For Public Sector ISRs, there should be an open task for all assigned opportunities. Enterprise ISRs are required to have an opportunity task for all assigned opportunities in Tiers 1, 2, and 4. These tasks help ISRs stay on task and should be maintained and updated regularly as opportunities progress through the sales cycle.

### ISR Note Taking

GitLab is an organization that is built on contribution and collaboration. These values are not only critical for building a great product, they are critical for building a world class sales team. Each member of the Inside Sales team is expected to document detailed notes in SFDC on accounts and conversations they participate in or currently own. With GitLab being a remote company, it is even more important to create and maintain a culture of great note taking and ensure the notes are captured in our systems.

ISRs are expected to understand and follow the note taking process outlined in the Commercial Sales Handbook:

- [Why do we take notes on accounts?](/handbook/sales/commercial/enablement/#why-do-we-take-notes-on-accounts)
- [Different Sections of notes to include](/handbook/sales/commercial/enablement/#different-sections-of-notes-to-include)
- [Characteristics of Next Steps](/handbook/sales/commercial/enablement/#characteristics-of-next-steps)

### Holdover Account / Opportunity Process

In the event of a territory or alignment change, Inside Sales Representatives will be allowed to holdover up to five (5) accounts / opportunities. The holdover opportunities will be transitioned to be managed by the new team member and quota credit will be determined by `Close Date`.

As it relates to retirement of quota, we will refer to the Closed Won date as well as the payout schedule below:

- *If holdover opportunity `closes in month 1 of the quarter` = 75% credit to current ISR, 25% credit to new ISR*
- *If holdover opportunity `closes in month 2 of the quarter` = 50% credit to current ISR, 50% credit to new ISR*
- *If holdover opportunity `closes in month 3 of the quarter` = 25% credit to current ISR, 75% credit to new ISR*

**In order to qualify, the opportunity must:**

   1. Be a renewal or opportunity currently delegated to or being managed by an Inside Sales Representative
   2. Close within the current Fiscal Quarter
   3. Be approved as a holdover by Inside Sales Management (via Salesforce Chatter)

### Inside Sales Resources

#### Team Resources

| Link | Team  | Purpose           |
| ----- | ----- | ---------------- |
| [Enterprise ISR Team Slack Channel](https://gitlab.slack.com/archives/C01P39947ND) | Enterprise | Team slack channel for internal team communications and requests |
| [Public Sector ISR Team Slack Channel](https://gitlab.slack.com/archives/CNAMWG9N3) | PubSec | Team slack channel for internal team communications and requests |
| [GitLab Sales Territories](/handbook/sales/territories/) | All | Handbook page that outlines regional alignment for SAEs and ISRs |
| [FY22 Sales Compensation Plan](/handbook/finance/sales-comp-plan/#fy22-sales-compensation-plan) | All | Outline of the FY22 inside sales commission plan |
| [Sales Commissions](/handbook/sales/commissions/) | All | Handbook page that includes process and policies related to GitLab commissions |

#### ISR Processes

| Link | Type  | Purpose           |
| ----- | ----- | ---------------- |
| [Quote Configuration](/handbook/sales/field-operations/order-processing/#quote-configuration) | Field Operations | Go-to resource for building quotes via the Field Operations team |
| [Order Processing](/handbook/sales/field-operations/order-processing/) | Field Operations | Go-to resource for deal processing and facilitation |
| [Deal Desk Handbook](/handbook/sales/field-operations/sales-operations/deal-desk/) | Field Operations | Handbook page for GitLab Deal Desk and associated processes |
| [Renewals Process Guide](/handbook/sales/sales-renewal-process/) | Field Operations | Handbook page outlining renewal process and policies |
| [Customer Renewal Tracking](/handbook/customer-success/csm/renewals/) | Technical Account Management |  Resource that outlines process for managing renewals as a part of the larger account team (with SAEs, CSMs, Customer Success) |
| [ISR Renewal Management](https://drive.google.com/drive/u/0/search?q=%22Renewal%20Oppty%20Management%22) | Shared doc | A shared document outlining the renewal management process for ISRs |
| [Community Education / EDU Program](/handbook/marketing/developer-relations/community-programs/education-program/) | Developer Relations | Resource that outlines The GitLab for Education Program which provides GitLab for free to students and faculty at educational institutions around the globe |

#### ISR Manager Resources

| Link | Type  | Purpose           |
| ----- | ----- | ---------------- |
| [Territory Change Request](https://docs.google.com/document/d/1UaKPTQePAU1RxtGSVb-BujdKiPVoepevrRh8q5bvbBg/edit#bookmark=id.aces298pv2vw) | Sales Operations | This process is used by sales operations, ISR management, and regional sales directors to update ISR alignment|
| [ISR Overrides](https://gitlab.com/-/ide/project/gitlab-com/www-gitlab-com/edit/master/-/sites/handbook/source/handbook/sales/insidesales/index.html.md#isr-opportunity-alignment) | ISR Manager Process | This process allows the ISR Management team to override any automation associated with the population of the `ISR field` on an opportunity.  This should be used in scenarios where an ISR is working an opportunity that is not aligned with one of their territories. |
