---
title: "Enterprise Area Sales Manager Handbook"
description: "Successful management includes onboarding, reviewing Command Plans, opportunity coaching, strategic coaching, career development and performance management"
---

## Overview

Welcome to the Enterprise Area Sales Manager Handbook. You can use the [Enterprise Area Sales Manager Playbook](https://docs.google.com/presentation/d/1HmzgSsau959CSZxEOoXCHdFS9h6a0vvvtDMVsFX57yo/edit?usp=sharing) for a 1-page view of what's on this page. It includes key activities an Enterprise Area Sales Manager leads as they manage their team and area. Think of it as a guide (not hard and fast mandates) to help you manage your business and optimize results.

The below detail offers additional guidance on how responsibilities and activities are managed, and has been sourced from experienced GitLab Enterprise ASMs and leaders. When thinking about 'what good looks like' in this department, refer to your [job family](/job-families), the [field competencies](/handbook/sales/training/field-functional-competencies/), our [manager and leadership competencies](/handbook/people-group/competencies/#manager-and-leadership-competencies), and our [GitLab values](/handbook/values/).

## Quick links

- [**Enterprise Sales handbook page**](/handbook/sales/playbook/#overview): This page is the home base for Enterprise Sales and includes links to our content hub (Highspot), training hub, slack channels, tools, strategy and planning resources. It also includes all resources for our Enterprise Accounts Executives (AEs), including major and strategic roles, like the Enterprise Account Executive playbook.
- [**Enterprise Sales update ticker**](https://docs.google.com/document/d/18SfdalBZDQyhnN0X7LwCRQmSfv3iiK59JPuj85f6Zkc/edit): This is updated weekly based on focus areas and key topics for the week. Bookmark it and consistently point your team back to it.
- [**Sales handbook page**](/handbook/sales/#welcome-to-the-sales-team-homepage): This page has general sales guidance applicable to all roles and segments, including deal and order processing information, customer reference resources, executive sponsorship, and more.
- [**Enterprise Area Sales Manager playbook**](https://docs.google.com/presentation/d/1HmzgSsau959CSZxEOoXCHdFS9h6a0vvvtDMVsFX57yo/edit?usp=sharing): A 1-pager guide showing the typical operating rhythm that area sales managers use to run their business, manage their teams, and get results. It also includes key reports and dashboards to help you.
- [**Enterprise Account Executive onboarding journey**](/handbook/sales/onboarding/#learning-journeys): An at-a-glance view of your team member's first 90 days, and the milestones they should reach during this time.

## Strategic sales planning

Strategic sales planning is a key activity every Area Sales Manager (ASM) leads for their team - validating that **sales team members**:

- Are focused on the accounts and opportunities that have the highest potential,
- Are aware of the things that may impact their plan positively or negatively, rooted in strong data analysis
- Are collaborating effectively with their deal team and internal business partners like field marketing, deal desk, channel, partners & alliances
- And have enough pipeline to reach their goals and quotas.

### Territory assignments and GTM planning

This happens annually. In preparation, you'll look at how those accounts are distributed across your team and validate our goal of having a fairly equitable distribution across your Account Executives (AEs). You'll recommend territory assignments and quotas and identifying resource requirements to meet and exceed financial targets.

#### Territory planning is a key part of strategic planning

AEs create a new or updated territory plan based on their assignments annually; the detail of this plan will vary depending on if they are Major or Strategic Account Executives. They present these plans in Territory Plan Presentations hosted by ASMs or VPs, which usually occur twice per year in Q1 and Q3. [View the territory planning handbook page and toolkit.](https://internal.gitlab.com/handbook/sales/territory-planning/)

**Every Account Executive in Enterprise Sales should have a territory plan for how they're approaching their patch**, and every ASM should have visibility into it so they can help each AE validate and update their approach. This plan is a high-level, strategic and collaborative plan for targeting the right customers and implementing goals for income and consistent sales growth over time. It includes planning for pipeline generation, partner/channel engagements, and field marketing activities. It's usually followed by the creation of in-depth account plans for prioritized accounts.

While this type of strategic planning is a material up-front time investment, it's incredibly helpful for an AE in better understanding their territory and is much easier to update and iterate on over time.

#### Account planning

Following a territory plan, a AE has identified and prioritized the accounts they are going to focus on to reach their goals. For their top accounts, each AE should prioritze the ones they're going to create account plans for and agree with their ASM on the level of detail required. Account planning should occur quarterly, if not more frequently.

High-level account plans are often shared using a [strategic account plan template](https://docs.google.com/presentation/d/1AcwkYebTZ9mPfGsKlzd5IvppB_cc8to9z_yUvievSL4/edit?usp=sharing), and can be stored alongside territory plans. Detail and month to month maintenance usually occurs in Gainsight in collaboration with Customer Success Managers (CSMs) for expand accounts that have a CSM assigned. CS team members and AEs can build joint success plans in [Gainsight and use it to view customer product usage and health scoring](/handbook/customer-success/product-usage-data/using-product-usage-data-in-gainsight/#quick-links).

## Reviews and consults

### Quarterly Business Reviews (QBRs)

[QBRs](/handbook/sales/qbrs/#best-practices-for-rdsasmssalsaes) happen during the first two weeks of each quarter for the previous quarter. Preparation usually starts about two weeks before that. QBR decks are stored in our [Google Drive (GitLab internal only)](https://drive.google.com/drive/u/0/folders/1QAWFYxT2-NzWpOUodepbl0O6zfsMxJGL).

### Account reviews

Initially, ASMs and CSM Managers may want or need to partner on scheduling and facilitating these reviews, but regular account reviews should eventually become part of an account team's normal operating rhythm. See [Coaching Account Planning for ASMs](/handbook/sales/account-planning/coaching/) for additional guidance.

Accounts reviews are conducted quarterly (or more frequently as needed) at various points in the quarter, usually over a 2-week period. The extended account team (AEs, SA, CSM, SDR) is encouraged to participate and contribute.

Customer Success participation is critical to ensure alignment between the account plan and the customer success plan (see [What is the Difference Between an Account Plan and a Success Plan?](/handbook/sales/account-planning/#what-is-the-difference-between-an-account-plan-and-a-success-plan)).

#### Partner Reviews

Partner reviews are used to make sure the partner plan is aligned with regional sales goals and objectives and covers questions like:

- Do we have the right set of partners to support the business?
- Where and what type of additional partners are needed and why?
- How do we drive even more alignment and collaboration between key partners and GitLab account teams?

ASMs either host or participate in these depending on who owns the activity (this looks different in different regions and sectors). It's a best practice have either a bi-weekly or monthly connect with your regional Channel & Alliances team, and support it with a plan of how you'd like to collaborate.

#### Opportunity Reviews

[Opportunity consults](/handbook/sales/command-of-the-message/opportunity-consults/) are deal reviews that focus on helping a sales team member maximize the likelihood of winning and securing the customer's business. They are based on a joint inspection of the "health" of the opportunity's [Command Plan](/handbook/sales/command-of-the-message/command-plan/) and a 2-way dialogue to identify and commit to specific actions that aim to increase the likelihood of success.

**Using the Command Plan in an opportunity consult.** Every key opportunity, especially for key accounts, should have a command plan associated with it. This gives the business visibility into the opportunity, how it's developing, and highlights where they can support and coach the AE on progressing it forward. Our command plan reviews follow the Command of the Message Sales Methodology, and incorproate MEDDPPICC.

**Identifying opportunities for a consult.** During monthly forecast calls and weekly 1x1s, the ASM and each AE identify which opportunities would benefit from an opportunity consult and work together to get those scheduled. When possible, the entire account team (AE, SA, CSM, and SDR) participates in these reviews.

**Run consults every week.** ASMs should be conducting multiple opportunity consults every week (though not necessarily with the same AEs). Sometimes these reviews follow the standard opportunity consult format. Other times, these reviews are working sessions that include the ASM working with the AE and/or account team to collaboratively complete the Command Plan for a given opportunity. And other times, the ASM may choose to hone in on one or a few specific areas of the opportunity (this may especially be the case for follow up opportunity reviews).

Some ASMs also choose to conduct opportunity consults with a group to incorporate peer review and feedback (either during regularly scheduled team meetings or as separate meetings). Consider the below framework and iterate as you deem appropriate:

- Invite AEs to volunteer in advance to do a group consult and present their Command - Plan for a key deal to the rest of the team
- Schedule a 30-45 minute meeting once you have a volunteer
  - ASM to decide whether team participation is mandatory or optional (consider starting as optional but strongly encouraged until the value is proven)
- During the meeting, the volunteer AE presents his or her Command Plan for one key opportunity and then receives questions, input, and feedback from the team
- If successful, consider creating a recurring meeting series (1-2x per month)

#### Forecasting and pipeline reviews

**Find Clari and Salesforce resources for these reviews in the [Enterprise Area Sales Manager Playbook](https://docs.google.com/presentation/d/1HmzgSsau959CSZxEOoXCHdFS9h6a0vvvtDMVsFX57yo/edit?usp=sharing).** The following forecast & pipeline review cadence is recommended:

1. Month 1 of a quarter: current fiscal quarter (CFQ)
1. Month 2 of a quarter: next fiscal quarter (Current Quarter + 1)
1. Month 3 of a quarter: two fiscal quarters out (Current Quarter + 2)

Quarterly Business Reviews (QBRs) provide a great opportunity to conduct Month 1 CFQ forecast & pipeline reviews, so you likely don't need a separate review. At the end of Month 1, the ASM should encourage AEs to clear out pipeline opportunities from the CFQ forecast. Entering Month 2, all CFQ opportunities should be in either Best Case or Commit. If they are not, the forecasted close date should be pushed out.

Month 2 and Month 3 forecast & pipeline reviews are typically scheduled for 2 hours. Ideally, the Month 2 review takes place ~30 days after the QBRs, and Month 3 reviews are scheduled about ~30 days after that (but not in the last 7-10 days of the quarter). See the Out-Quarter Forecasting and Pipeline Reviews section below for additional guidance.

**In-Quarter Forecasting:** Every week, ASMs must review the team's Commit & Best Case opportunities and submit their forecast. ASMs should work with their teams to ensure that the Single Source of Truth (SSOT) for Best Case and Commit deals is in Salesforce.

**Out-Quarter Forecasting and Pipeline Reviews:** As outlined above, out-quarter reviews typically take place in Month 2 and 3 of the quarter. Each AE has 15-20 minutes to cover the following topics:

1. Forecast
    - Summary of Stage 3+ opportunities by stage
    - Churn risks
    - Call out specific opportunities only if you want to discuss (e.g. highlight a risk, ask for help, etc.)
1. Pipeline
    - Where are you against pipeline coverage targets?
    - Plans to close gaps, highlight risks
    - Actions with partners and SDRs
1. Prioritized Actions

#### Best practices for forecasting and pipeline reviews

We have detailed guidance on Sales Forecasting, Opportunity Management, and using our tools to review on the [internal handbook page](https://internal.gitlab.com/handbook/sales/sales-forecasting/).  Guide AEs to [the Clari cheat sheet](https://docs.google.com/presentation/d/1ZvQzFrmmqsJPUIk_FxfTy5X0G59IIWDve0Rfmfw1Wec/edit#slide=id.g133719dda83_2_102) and #sales-support Slack channel for additional support.

- **AEs should be empowered to be the CEO of their own territory and manage their business accordingly.** ASMs will need to manage the agenda to ensure the team doesn't get bogged down in too much detail and encourage AEs to focus on the bigger picture. More specifically, even the best AEs will miss their quarterly quota from time to time. What's important is that the AE and ASM are aware of the risk in advance and that there is sufficient pipeline in other quarters to make up for a down quarter.
- **It's not a performance review.** ASMs should also continuously reinforce that the dashboards, heat map, and other resources listed below are for the AE's benefit (not management tools) and to help them effectively manage their business.
- **3.5x is the rule of thumb for pipeline.** A general rule of thumb is that a AE has 3.5x their target in pipeline (view the [Prospecting handbook page](/handbook/sales/prospecting/#build-your-strategy) for in-depth guidance). During strategic planning they should identify this number and then work backwards to determine the value they need to deliver every quarter and every month.

## Coaching team members

[Coaching and mentoring](/handbook/leadership/coaching/) happens throughout the development of your team member, as well as during business as usual activities like territory planning, account planning, sales calls, prospecting and pipeline reviews, opportunity reviews, and the list goes on and on.

Follow [Performance Management best practices](/handbook/sales/field-manager-development/#performance-management-and-giving-feedback), and leverage [GitLab's Field Functional Competencies](/handbook/sales/training/field-functional-competencies/) to reinforce the critical skills and behaviors that will lead to desired outcomes/results.

ASMs should focus on providing coaching and mentoring in a collaborative and proactive way. Examples include but are not limited to:

- Reinforce [effective discovery](/handbook/sales/playbook/discovery/) best practices
- Maintain proper focus on customer value ([Command of the Message](/handbook/sales/command-of-the-message/)) and avoid technical rabbit holes
- Identify when and how to position GitLab's holistic differentiators to the right people at the right time
- Help newer AEs understand the context behind industry terms/concepts like application refactoring, microservices, Kubernetes, and more
- Improve the quality of [Command Plans](/handbook/sales/command-of-the-message/command-plan/)

ASMs routinely participate in sales calls with their new AEs or with AEs working on extremely complex, strategic, or high-impact deals including:

- Helping with meeting prep (see [Develop a Pre-Call Plan](/handbook/sales/playbook/discovery/#develop-a-pre-call-plan))
- Participating on the call
- Debriefing immediately after the call

### Team assessment

Last but not least, ASMs also assess their teams annually following the [Performance / Growth Matrix](/handbook/people-group/talent-assessment/).

## Onboarding new team members

All team members go through an onboarding journey by segment and role. [View the AE onboarding journey here.](/handbook/sales/onboarding/#learning-journeys). In it, AEs are assigned the following activities:

- Standard GitLab onboarding issue (1-2 weeks): AEs should complete all 'red dot' tasks in their onboarding issue, bookmark and organize key resources, and learn about the GitLab product they're going to be selling
- Customer Ready Shadow Program: Shadowing can start as soon as they take the 20-minute training in their onboarding issue.
- Sales Quickstart (async pre-work and 1 week of ): This time should be spread across their first two weeks. This covers general sales methodology, DevOps landscape, MEDDPPICC, our portfolio of products, and our customers, personas, and their pain points.
- Role-based pathway (4 hours per month for first 90 days): This pathway is divided into bite-sized training they should complete during their first 90 days and guides them around key activities they should be familiar with as a AE. Things like territory planning, pipeline generation, effective discovery.

ASMs should work with new AEs to develop and monitor progress against their 30/60/90 day plan, set clear performance expectations, and provide regular feedback during the onboarding process.

### Key activities for managers during team onboarding

- Support your ramping AE. ASMs should encourage new AEs to complete "red dot" tasks in their general GitLab onboarding issue, bookmark and organize key resources, complete their role-speific onboarding, and prioritize peer-to-peer shadowing of customers calls.
- Connect the dots. Encourage your new hires to speak up or ask for help when and if they need it. Pair them with an onboarding buddy to support their first 90 days, and point them to the right resource and team when they're not sure where to find something.
- Actively support their shadow time with peers. 100% of our new hires recommend customer call shadowing as a key way to onboard fast. Learn about the program, help them prioritize participation, and foster a culture of shadowing within your team.
- Get familiar with their onboarding journey. Every AE is required to complete role-specific training - this is the content that the majority of AEs need to know to do their everyday jobs. Without it, AEs generally don't know where to find what they need or who to go to for what.

## Recruiting top talent

Always be recruiting! As outlined in the [Winning Top Talent](/handbook/sales/field-manager-development/#winning-top-talent) portion of the GitLab Field Manager Development Program, the importance of effective recruiting to GitLab's continued growth and success cannot be understated. ASMs should meet regularly with your Talent Acquisition Recruiter (exact cadence will vary based on hiring needs) and should also be comfortable and confident in selling the amazing opportunity here at GitLab.

**Key Resources**

- Success Profile
- Interview Guide
- Networking tools
- "Why GitLab" Summary

### Career development and mobility for your team

[Career development](/handbook/people-group/learning-and-development/career-development/) is the lifelong process of managing learning, work, leisure and transitions to move toward a personally determined and evolving preferred future. As a manager you should:

- Take time with team members to discuss their career aspirations
- Listen and provide feedback, ideas and contacts
- Make choices to support their development.

Start by encouraging them to create an [Individual Growth Plan](/handbook/people-group/learning-and-development/career-development/#individual-growth-plan) and then go over it together.

## Manager development program

Manager effectiveness is important to GitLab's continued ability to attract, develop, and retain key talent and deliver scalable, efficient growth. In response, the Corporate L&D, People, and Field Enablement teams collaborated to launch programs to equip managers with a foundational set of skills & practices for effectively managing remote teams across GitLab's field organization.

**Manager Challenge:** [The Manager Challenge](/handbook/people-group/learning-and-development/manager-challenge/) addresses your specific needs to understand the qualities of a good leader and to master practical leadership styles that empower you to become a confident people leader. Effective leadership is grounded in your understanding of powerful interpersonal skills that inspire performance, communication, team member retention, and motivation to achieve results.

**Field Manager Development Program:** Managers participate in a series of quarterly training & reinforcement exercises throughout each fiscal year. While there will be formal training elements, a large focus will be on social learning (learning from others) and practical, real-world application to convert knowledge to action. Learn more on the [Field Manager Development Program handbook page](/handbook/sales/field-manager-development/).
