---
title: Negotiate to Close
description: >-
  A sales negotiation is a strategic discussion (or series of discussions)
  between buyer and seller that ideally leads to a deal being closed. The main
  goal of the negotiation process is to reach an agreement that's acceptable to
  everyone.
---

## Overview

A sales negotiation is a strategic discussion (or series of discussions) between buyer and seller that ideally leads to a deal being closed. The main goal of the negotiation process is to reach an agreement that's acceptable to everyone. Successful negotiation outcomes often start with the sales professional having and demonstrating the right mindset -- one focused on a building a long-term partnership whereby both parties (buyer and seller) benefit more by working together than if the partnership did not exist.

In his book [*Closing Time*](https://www.amazon.com/Closing-immutable-Sales-Negotiation-Hubsher/dp/0981789005), Ron Hubsher highlights the 7 immutable laws of sales negotiation:

1. You must be the buyer's first choice
1. Know the financial benefit your solution creates
1. Anticipate getting squeezed on price
1. Be proactive on budget and remove decision-making obstacles in advance
1. Expand the pie with a set of non-monetary trade-ups
1. Never give without getting
1. Know your walk-away price and conditions

## When do negotiations start?

Preparing for a negotiation starts as early as your first conversation, and successful negotiation outcomes begin with embracing a value-based sales methodology like [Command of the Message](/handbook/sales/command-of-the-message/) from the very onset of the sales process.

## 5 1/2 tips for how to approach price-lock negotiations at GitLab

In this video, VP of Enterprise Sales - Mike Pyle, gives tips for how to approach price-lock negotiations at GitLab while protecting the value of our product during these negotiations. The key to doing this well is consistently and proactively having this conversation. This guidance is useful no matter the size of your prospect or customer. Watch below or go directly to GitLab Unfiltered to view: [5 1/2 Tips for Getting Ahead of Price-lock Negotiations (YouTube, 10 minutes)](https://www.youtube.com/watch?v=mzGc1bXESzI).
<!-- blank line -->
<figure class="video_container"><iframe src="https://www.youtube.com/embed/mzGc1bXESzI"></iframe></figure>In addition to these tips, the below critical sales skills will also help you achieve a successful negotiation:

## Uncover customer needs

Conduct effective, ongoing discovery to:

- Obtain a deep understanding of the customer's current state (see [Sales Discovery and Qualification Questions](/handbook/sales/qualification-questions/))
- Identify the Positive Business Outcomes they want or need to achieve (and why), and
- Co-create a shared vision for the Required Capabilities to get from the current state to the desired future state

## Articulate value and differentiation

Don't start a negotiation if you are not the buyer's first choice. With a thorough understanding of your customer's needs, be sure to:

- Effectively articulate how GitLab will address the customer's requirements (leverage [these core resources](https://internal.gitlab.com/handbook/sales/command-of-the-message/#resources-core-content)) (internal only)
- Successfully connect the dots between technical metrics and the business value that GitLab delivers (see [Demystifying the Metrics Conversation](/handbook/sales/command-of-the-message/metrics/)), and
- Share relevant [proof points](/handbook/sales/command-of-the-message/proof-points/) that highlight how and why GitLab can deliver against the customer's requirements better than any other option(s) available

## Closing

The [Command Plan](/handbook/sales/command-of-the-message/command-plan/) provides a framework to maximize your likelihood of winning and securing the customer's business for a defined purchase initiative. Before even attempting to move to Close, be sure you have compelling answers to every component of the [Opportunity Overview](/handbook/sales/command-of-the-message/command-plan/#opportunity-overview) section of the Command Plan.

While there are [numerous closing techniques](https://spotio.com/blog/sales-closing-techniques/) out there, the LinkedIn Learning course referenced below recommends four common closing techniques (these need not be mutually exclusive):

1. **The Summary Close** - reiterating all the key benefits of your offer as they relate to the customer's prioritized requirements before you ask for the order
1. **The Balance Sheet Close** - collaboratively making a list of pros and cons to help the customer feel more comfortable with the decision to move forward (note: be sure you are confident that the pros significantly outweigh the cons!)
1. **The Needs Close** - methodically go through the list of all of the customer's requirements to explicitly show how you are addressing their needs and will help them achieve their desired results
1. **The Assumptive Close** - gently nudging the customer to move forward in a non-manipulative way when it seems clear that your solution meets all of the customer's requirements (most effective when you have an established and trusted relationship with the buyer)

## Recommended resources

- [*Closing Time*](https://www.amazon.com/Closing-immutable-Sales-Negotiation-Hubsher/dp/0981789005) by Ron Hubsher
- LinkedIn Learning course: [Sales: Closing Strategies](https://www.linkedin.com/learning/sales-closing-strategies/) (38 minutes)
- LinkedIn Learning course: [Sales Negotiation](https://www.linkedin.com/learning/sales-negotiation/) (58 minutes)
- [Finding Success With Procurement](https://podcasts.apple.com/us/podcast/34-finding-success-with-procurement-w-tim-caito/id991362894?i=1000494550388) (podcast, 22 minutes)
- [*Never Split the Difference: Negotiating As If Your Life Depended On It*](https://www.amazon.com/Never-Split-Difference-Negotiating-Depended/dp/0062407805/) by Chris Voss
