---
title: "Effective Discovery"
description: "Effective discovery is critical to thoroughly understanding customer needs and establishes the foundation for being able to effectively articulate GitLab's value and differentiation in a compelling, customer-centric way"
---

## Overview

Effective discovery is critical to thoroughly understanding customer needs and establishes the foundation for being able to effectively articulate GitLab's value and differentiation in a compelling, customer-centric way. Effective discovery will help you attach to your customers' biggest problems, gain access to higher-level business stakeholders, and serve as a trusted advisor to your customers. This, in turn, will help you build and maintain a healthy and predictable pipeline, to meet and exceed your sales goals while helping your customers achieve their business objectives. After reviewing the below information, GitLab field team members are encouraged to take the interactive [Effective Discovery course](https://gitlab.edcast.com/insights/ECL-c0a6e34d-a997-4200-b0d9-65e3305e3761) in GitLab Learn.

![discovery-components-visual](/handbook/sales/playbook/discovery/discovery-components-visual.png)

## Qualification

The first phase of any discovery process is to determine whether or not you should spend time on a particular opportunity pursuit. A good guide for this phase is codified in the [Criteria for Sales Accepted Opportunity (SAO)](/handbook/sales/field-operations/gtm-resources/) and includes confirmation of **Authority**, **Initiative**, **Fit**, and **Timing**.

Ideally, effective qualification also includes identification of the prospect's:

- Cloud strategy
- Preferred cloud partner(s)
- Future growth potential ([Landed Addressable Market (LAM)](/handbook/sales/sales-term-glossary/)), and
- Preference for [SaaS or Self-Managed](https://about.gitlab.com/features/)

## Understand Value Points

The second phase of discovery uses an iterative insight/question loop, often across multiple meetings or conversations, to uncover the prospect's underlying challenges and motivations, with the ultimate goal of constructing a highly relevant and differentiated value message that ties the GitLab solution to the prospect's business needs.

### Preparation

Ensure you are ready for each discussion. The level of preparation for each discovery conversation will vary, so use your best judgment for how deep you go and be sure to leverage the information that has already been collected during Prospecting and Qualification. The key point is to be prepared and to not just wing it. Consider the below recommendations.

<!-- blank line -->
<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/Jk6n4MrJ3J8" frameborder="0" allowfullscreen="true"> </iframe>
</figure>
<!-- blank line -->

#### Research the Prospect

Researching your prospect may include but is not limited to:

- Annual reports and/or financial statements
- Account activity/engagement history in Salesforce
- Recent news or press releases
- Research your contact(s) on LinkedIn, Twitter, and/or other social media platforms
- Insights gleaned from partners that already have relationships with the account

<!-- blank line -->
<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/fdc5U02wHkc" frameborder="0" allowfullscreen="true"> </iframe>
</figure>
<!-- blank line -->

#### Understand the Persona

Different roles within the prospect's organization will inherently care about and be motivated by different things. Leverage the below resources to understand the challenges and motivations of the persona you are engaging.

- [Buyer personas](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/roles-personas/buyer-persona/)
- [User personas](/handbook/product/personas/#user-personas)

<!-- blank line -->
<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/qWlzcGewi_U" frameborder="0" allowfullscreen="true"> </iframe>
</figure>
<!-- blank line -->

#### Develop a Pre-Call Plan

As outlined in the [Pre-Call Plan](https://docs.google.com/document/d/1yjyfvMoDvayZca5hXiIwSHYc9T1M3mTc7ocqzjhqOf8/edit?usp=sharing) job aid, be sure to consider the below questions.

- What is your desired outcome for this conversation or meeting? What do you think the prospect's desired outcome is?
- What information do you need to gather to achieve your objective(s)? What discovery questions will you ask, how, and in what sequence? As outlined above, this iterative insight/question loop will often span across multiple meetings or conversations.
  - Start with [Customer Strategy-based discovery questions](/handbook/sales/qualification-questions/#customer-strategy) to seek to understand your prospect's goals, objectives, and initiatives
  - Next, ask open-ended [Customer Needs-based discovery questions](/handbook/sales/qualification-questions/#customer-needs) in pursuit of understanding your prospect's desired outcomes, current situation and environment and level of satisfaction, and motivations (including personal needs)
- As you develop and prioritize your discovery questions, what types of questions will you ask that reinforce [GitLab's differentiators](/handbook/sales/command-of-the-message/#gitlab-differentiators)?
  - For a deeper dive, re-review the Defensible Differentiators content and sample questions in the GitLab Value Framework doc (see top asset highlighted in the [Resources: Core Content](https://internal.gitlab.com/handbook/sales/command-of-the-message/#resources-core-content) (internal only) section of the Command of the Message Internal Handbook page)
- What agenda will provide the structure needed to help you achieve your meeting or call objectives? Assuming you achieve your objective(s), what are possible next steps you may recommend? How will you close the call or meeting to progress the opportunity further?
- What are some potentially relevant success stories (e.g. same industry, geo, anticipated pain points, etc.) and other proof points (e.g. favorable analyst report) that you may want to reference or highlight to build interest and credibility?
- What questions or objections do you anticipate the prospect may have? If those indeed come up, are you ready to respond?

### Seek to Understand

#### Approach With Curiosity

Approach discovery conversations with a curiosity-led mindset and a desire to better understand the customer's challenges as well as the *implications* of those challenges.

- How big is the problem?
- How does this impact higher-level goals and objectives?
- How does this challenge impact the person(s) with whom you are talking?
- Who else in the organization does this challenge impact and how?

#### TED

Leverage the TED questioning model (see below) to get the prospect to open up and provide more context and detail about their challenges.

- T: **Tell** me more about...
- E: Can you please **explain** the impact of...?
- D: Will you please **describe** how others are affected by...?

<!-- blank line -->
<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/VOu0q2NvH_s" frameborder="0" allowfullscreen="true"> </iframe>
</figure>
<!-- blank line -->

#### Five Whys

Use the [Five Whys](/handbook/customer-success/csm/success-plans/questions-techniques/#five-whys) technique to identify the root cause(s) and understand the "So what?" Check out the short video below and read the [Why Salespeople Should Ask The Same Question 5 Times In A Row](https://blog.hubspot.com/sales/the-five-whys-sales-strategy) blog to learn more.

<!-- blank line -->
<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/c2jSn5AdBYY" frameborder="0" allowfullscreen="true"> </iframe>
</figure>
<!-- blank line -->

#### Active Listening

Commit to [active and effective listening](/handbook/communication/#effective-listening). Watch the video, listen to the podcasts, and check out the [Why Your Active Listening Skills Are Crucial to Hitting Your Number](https://www.forcemanagement.com/seller-blog/why-your-active-listening-skills-are-crucial-to-hitting-your-number) blog.

<!-- blank line -->
<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/5pJHlI6C_zU" frameborder="0" allowfullscreen="true"> </iframe>
</figure>
<!-- blank line -->

#### Master Command of the Message

[Command of the Message](/handbook/sales/command-of-the-message) is a proven, value-based sales messaging methodology from Force Management that allows GitLab sales team members to effectively uncover customer needs and articulate value and differentiation. Leverage the below resources to ensure you are confident in the methodology and the GitLab-tailored sales resources created to help you be successful and delight your customers.

- [Command of the Message Handbook page](/handbook/sales/command-of-the-message)
- [Command of the Message e-learning module](https://gitlab.edcast.com/insights/ECL-20f0f2ac-0d50-4384-b473-63cc6d3bb48d) (90 minutes) (GitLab internal with protected IP from Force Management)

## Identify the Buying Process

The final phase of discovery identifies the roadmap, along with potential roadblocks, for getting a deal closed as well as key stakeholders who must be involved. Discovery will continue throughout the sales process as you and your account team continue to gain a deeper understanding of all elements of [MEDDPPICC](/handbook/sales/meddppicc/) to increase the likelihood of earning the customer's business.

- Leverage [Customer Decision-based discovery questions](/handbook/sales/qualification-questions/#customer-decision) to gain a better understanding of the [Decision Process](/handbook/sales/meddppicc/#decision-process), [Decision Criteria](/handbook/sales/meddppicc/#decision-criteria), [Paper Process](/handbook/sales/meddppicc/#paper-process), and more
- Check out the full [MEDDPPICC](/handbook/sales/meddppicc/) Handbook page
- Complete the [MEDDPPICC e-learning module](https://gitlab.edcast.com/insights/ECL-315a08a3-c8e2-48e1-9d4e-b43a6afd440b) (60 minutes, GitLab internal)

<!-- blank line -->
<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/BJXQIKmGOcw" frameborder="0" allowfullscreen="true"> </iframe>
</figure>
<!-- blank line -->

## Avoid These Discovery Pitfalls

## Lack of Preparation

See the [above section](/handbook/sales/playbook/discovery/#preparation) for tips to avoid what may be the most common discovery pitfall.

<!-- blank line -->
<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/7nSImEMagAQ" frameborder="0" allowfullscreen="true"> </iframe>
</figure>
<!-- blank line -->

## Happy Ears

Resist the urge to prematurely talk about or begin to position GitLab until you have a thorough understanding of the customer's challenges, the implications of those challenges, how big the problem is, the urgency of the problem, who cares about the problem and why, and more (see below).

<!-- blank line -->
<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/EGJlmGxpOv0" frameborder="0" allowfullscreen="true"> </iframe>
</figure>
<!-- blank line -->

## Not Attaching to the Biggest Problem

You must have a solid understanding of the prospect's key business drivers, strategic business initiatives, and associated objectives and goals to be able to serve as a trusted advisor. These will almost assuredly relate to one or more [Customer Value Drivers](/handbook/sales/command-of-the-message/#customer-value-drivers). Use [Customer Strategy-based discovery questions](/handbook/sales/qualification-questions/#customer-strategy) followed by [Customer Needs-based discovery questions](/handbook/sales/qualification-questions/#customer-needs) to identify how GitLab can have a positive impact on your buyer's business issues.

<!-- blank line -->
<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/1ZJ6S0fwYMw" frameborder="0" allowfullscreen="true"> </iframe>
</figure>
<!-- blank line -->

<!-- blank line -->
<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/F3QMlgTdVhQ" frameborder="0" allowfullscreen="true"> </iframe>
</figure>
<!-- blank line -->

## Failing to Identify the Negative Consequences of Doing Nothing

Watch the short videos below to learn more about the importance of seeking to understand, and helping your prospect understand, the negative implications of their current state. As a salesperson, you must understand the difference between the prospect's *current state* and the *future state that GitLab can help deliver* and effectively articulate that difference in a way that compels them to take action.

<!-- blank line -->
<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/DTxFqjLbvtI" frameborder="0" allowfullscreen="true"> </iframe>
</figure>
<!-- blank line -->

<!-- blank line -->
<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/KYLBUPJYkzA" frameborder="0" allowfullscreen="true"> </iframe>
</figure>
<!-- blank line -->

## Lack of Multi-Threading

Sales multi-threading refers to the concept of engaging and developing relationships with multiple stakeholders who are involved in your customer's decision-making process. According to CEB Global, the average B2B deal has 5.8 decision-makers, and that number typically increases along with the size and complexity of the contract. Even if your primary contact has significant authority in the organization, that may be insufficient if the rest of the buying group is not on board with the decision. Therefore, the more connections you have from the buying side, the better your chances of getting a deal closed. To learn more, check out the below articles/blogs and podcast.

- [What is Multi-threading Sales and Why Do You Need to Start Doing It?](https://web.archive.org/web/20221204062800/https://www.dealsinsight.com/what-is-multi-threading-sales-and-why-do-you-need-to-start-doing-it/)
- [The Tactical Guide to Multi-Threading Sales](https://www.saleshacker.com/multi-threading-sales/)

<!-- blank line -->
<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/tlp8LMsLhsg" frameborder="0" allowfullscreen="true"> </iframe>
</figure>
<!-- blank line -->

## Supplemental Resources

**Overall Discovery**

- [Executing Great Discovery](https://www.spreaker.com/episode/33-executing-great-discovery-w-brian-walsh--51904801) podcast (31 minutes)
- [Discovery is a Process](https://youtu.be/7icHj3UdSVw) featuring Matt Petrovick (GitLab Strategic Account Executive) (2.5 minutes)
- [Matt Petrovick's Favorite Discovery Call](https://youtu.be/3jxBPQxCwEo) (3 minutes)
- [Matt Petrovick's Most Memorable Discovery Call](https://youtu.be/Zngf1HzNuEo) (2 minutes)

**Preparation**

- [Be Match Ready!](https://youtu.be/teAWL9YUy30) featuring Peter Davies (GitLab Strategic Account Executive) (2 minutes)

**Active Listening**

- [Improve Your Active Listening Skills](https://www.spreaker.com/episode/improve-your-active-listening-skills-w-patrick-mcloughlin--51904758) podcast (15 minutes)
- [Why Are You Talking?](https://www.spreaker.com/episode/why-are-you-talking-w-john-kaplan--51904754) podcast (9 minutes)
- [Use the Customer's Words and Stop Talking](https://youtu.be/lV_DGNB_bcQ) featuring Peter Davies (GitLab Strategic Account Executive) (0.5 minutes)

**Attaching to the Biggest Problem**

- [How to Enable Reps to Sell Higher](https://www.spreaker.com/episode/how-to-enable-reps-to-sell-higher-w-brian-walsh--51904779) podcast (27 minutes)

**Identifying the Negative Consequences of Doing Nothing**

- [Standing in the Moment of Pain](https://youtu.be/zDh2GwVaK8A) (1 minute)

**Multi-Threading**

- [Navigating the Decision Process with Multiple Buyers](https://www.spreaker.com/episode/navigating-the-decision-process-with-multiple-buyers-w-john-kaplan--51904731) podcast (11.5 minutes)
- [Multi-threading with Application Security](https://youtu.be/9FTpDK-q11o) featuring Matt Petrovick (GitLab Strategic Account Executive) (1 minute)
