---
title: "Sales Prospecting"
description: "Prospecting is the process of initiating and developing new business by searching for potential customers, clients, or buyers for your products or services"
---

## What is prospecting at GitLab?

All AEs are expected to have good pipeline generation coverage (3.5x) regardless of their role or types of accounts. The more you can integrate good pipe gen habits into your everyday activities, the easier it will be to have a strong pipeline throughout the year and with less maintenance. [Watch the latest on prospecting best practices from recent AEs on Highspot.](https://gitlab.highspot.com/items/63f4e733519f3a9436b95c65) In this video, severals AEs across AMER and EMEA talk about what helped them achieve their goals in prospecting and offer tips you can apply to your strategy right away, in addition to what's here on this page.

**Prospecting has come a long way from cold calling:** In Enterprise Sales, prospecting is strategic, thoughtful, helpful, and almost always a **warm** connection.

*What is warm?* Warm is when you know there's a good reason why you need to reach out to your prospect, it's for their benefit that you're getting in touch, and you know why they're likely to need your solution now.

**You own your pipeline.** For enterprise account executives (AEs), prospecting should be a part of your regular sales activities. This means blocking dedicated time on your calendar to plan, strategize with your team, and reach out to your top prospects every single week. After all, if you don't have a pipeline, you don't have a business. And as the CEO of your territory or area, you need to dedicate time to your future business as much as your current business to reach your target.

**It takes a team effort to achieve results.** The AE owns the customer relationship, but all team members can and should participate in strategy, planning, and execution. AEs should work closely with their sales development reps (SDRs), channel account manager, and also sync with their Field Marketing team member.

**Team is external, too.** Think about the technology partners that can help you scale your approach. Engage with these partners, identify the right entry point, and present GitLab jointly with the partner to your customer. Exercise the muscle of engaging early and working with partners to identify new customers.

**Here are a few things to keep in mind about Prospecting at GitLab:**

1. **Good prospecting feels like a conversation.** Cookie-cutter copy blocks, technical jargon, and generic language don't get results. Custom, tailored, and specific messages do. This takes a lot more work, but the ROI is worth it and you should factor additional time to plan, strategize, and write into your approach. A lot of the tools included in this toolkit are designed to help you do this efficiently.

2. **You need to earn the attention of your customer or prospect. It's not guaranteed.** If you don't know why they should be talking to you over anyone else in the world - then you need to refine both your message and your target list.  After all, they do not owe you a response or a message back, it is earned. A great way to earn the attention of your prospect is to know more about their strategic technology initiatives or partnerships. It shows you've done your research and elevates your conversation to alignment with something the business has prioritized and budgeted for.

3. **You're the expert on GitLab, they're the expert on their business.** You know what they say about assumptions? It's important to keep in mind that no one knows your customer's business better than they do. It's your job to keep them in the loop on what solutions we offer that could help them be more effective now or down the line - but don't assume it's what's best for them. In every prospecting call or message, it should be clear that you're offering to advise them, not tell them what's best for them.

## Build your strategy

**Start from [your territory plan](/handbook/sales/territory-planning/#overview).** This exercise should be your source of information on where you're prioritizing your time and what activities you and your team think will be most effective. It's also where you've set your **pipeline generation target.**

*How to determine your target?* A general rule of thumb is to plan to create 3.5x your target in pipeline and then work backwards to determine what value you need to deliver every quarter and every month. As you measure your success, you'll learn whether that's too high or too low based on how you implement your strategy and the results you deliver.

Working backwards from your target, you'll be able to calculate how many accounts and opportunities you need to be successful. When looking at your target list, make sure you have a mix of those who are likely to buy now and those who may take a year or longer. Strategic partnerships take time so you need to diversify both your list and your outreach.

Work with your [Sales Development team member](/handbook/marketing/sales-development/#working-with-sales) to:

- Get input on your territory plan and how that maps to their activities.
- Review activity and engagement in [6Sense](/handbook/marketing/marketing-operations/6sense/).
- Develop your approach and identify the right messaging.

**Use data to support your assumptions:**

- **Account data:** Target accounts that have new leadership, show recent Merger & Acquisition activity, or have contacts who are posting relevant content on social media. Reach out to GitLab advocates and champions when they transition to new target accounts.
- **Engagement data:** Target prospects that have recently engaged with GitLab marketing activity or website content multiple times.
- **Intent data:** Target accounts that have demonstrated interest in a competitor and relevant industry trends.

**Next, plan your approach and sequence with your team.** Have regular pipeline generation reviews and meetings (whether async or live) with your sales development team members and wider team to get input and advice on your approach.

## Collaborating on your strategy

Work with your Sales Development team member to:

- Decide which format of approach is best (email, linkedin, phone), and what your cadence will be:
- Customize the [Prospecting Sequences for AEs](https://docs.google.com/document/d/1ksEGBsDVjQGkSeq8ESKf9Jdy-N7wREq_stnLutJBPTo/edit#heading=h.ufep756p4z4j) template or create your own.
- Organize the [qualifying questions](/handbook/sales/qualification-questions/) and [customer use cases](/handbook/marketing/use-cases/) that might be relevant.
- **Practice your elevator pitch.** Both you and your SD teammate need to practice your pitches together to make sure you're aligned on what you want the customer or prospect to hear. Really work on your tone of voice. You know you're ready if you can easily tweak it based on who you're talking to and what's relevant to them.

**Work with partners:** Work with your Channel Account Manager (CAM), talk to your peers, or use the [Partner Directory](https://partners.gitlab.com/English/directory/) to identify if there is a partner that supports specific accounts and can provide insight into target contacts or stakeholders.

**Work with Field Marketing:** Learn what [events are currently scheduled in your region](/handbook/marketing/field-marketing/#whats-currently-scheduled-in-my-region) and view the name of your aligned field marketer.

View the below YouTube video hosted on GitLab Unfiltered to see how AEs typically work with their sales development team member to get results. Remember that to view these, you have to switch your YouTube account to the GitLab Unfiltered account first. [View instructions for this on the YouTube handbook page here.](/handbook/marketing/marketing-operations/youtube/#unable-to-view-a-video-on-youtube)

<!-- blank line -->
<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/hnUUThsr9Us" frameborder="0" allowfullscreen="true"> </iframe>
</figure>
<!-- blank line -->

## Put your strategy into action

**Use the [Pipeline Generation Toolkit for Enterprise AEs](https://docs.google.com/presentation/d/1Uo1_Ly_nRhgRwoesja3vHM0K9e-dwdRSZdTyCbVYAhI/edit?usp=sharing) to get started on prospecting.**

Remember to triple-check your messages before you send them to prospects and customers. Getting details about them and their company wrong is cited in the [State of Sales 2021 report](https://business.linkedin.com/sales-solutions/b2b-sales-strategy-guides/the-state-of-sales-2021-report) as one of the top deal-breakers in the eyes of buyers.

### Outbound Wednesday

Teams at GitLab find success when they dedicate time to prospecting and customer-centric activity. Whether you're meeting with a prospect, a partner, or with growth customers, setting up an Outbound day to focus on bringing customer's value can boost your results and let your team members know not to schedule or pre-book internal meetings during your dedicated customer time.

#### **AMER's Outbound Wednesday Initiative**

- Mission: In alignment with the GitLab Value of Iteration, we want to give time back to the customer-facing teams, AEs, SAs, BDRs, TAMs / CSMs, ISRs, and Channel Account Managers, to allow for customer focus and partner-facing time. In addition, we feel it will allow for more significant customer and partner collaboration.

- Why it matters: We recognize that there is an abundance of internal meetings and requests. To help foster more customer centricity, we have developed the concept of "Outbound Wednesdays."

- What it is: Use your best efforts not to pre-book internal meetings on a Wednesday. If on a Wednesday, feel free to schedule a same-day meeting to collaborate with the critical stakeholders on customer activities.

- Beliefs:
  - Block out Wednesdays for Outbound activity
  - Dedicate 20%+ of your week to meeting face-to-face with customers
  - Prioritize live syncs with customers and make it easy for them to do it
  - Drive activities and resources to help you have more customer meetings
  - Be available to show customer-centricity as ONE team

**Exceptions:**
Outbound Wednesdays are not a mandate; however, a recommendation for our Americas Enterprise teams to use their best efforts only to pre-book customer and partner meetings. For managers, this would include customers, partners, and recruiting. They can still happen if we need to have same-day internal discussions on a Wednesday. There will be the time in people's calendars for same-day meetings.

The goal is to avoid scheduling such meetings in advance. By doing this together as a "ONE AMER ENT Team", we will find that it will help to provide an environment where customer-centric collaboration can more easily happen. By striving to reduce internal meetings on Wednesdays, we should be [taking the initiative to operate asynchronously with team members whenever possible](/handbook/values/#bias-towards-asynchronous-communication). We can follow up with an internal discussion on subsequent days where synchronous collaboration is needed to clarify any misunderstandings.

Read [the overview in Google Drive and contribute.](https://docs.google.com/document/d/1x2lKXh1hYs5gx0MPYrHjHayFTFALBFREhSFR81yKiUY/edit)

## Keep your pipeline healthy

Generally, surprises - whether in the form of sudden, major deals or sudden, major losses - are a bad thing. We have to strive to create predictable results. At first, this seems like trying to predict the vast unknown. But if you have a strong strategy in place for your pipeline, you'll be able to see exactly how your year will turn out well before it happens. This means better, more reliable forecasts and less stress for you on whether you'll meet that target.

**Validate, validate, validate.** Effective qualification is just the first step. As you invest in a prospect, it's important to continuously validate the opportunity throughout the sales cycle and make sure it can deliver results for you and that we are the effective solution for the prospect.

**Use data to validate your opportunities.** If you're making big bets because you 'hope' a prospect will change their mind it's a sign that you need to go back to the validation process:

- What evidence do you have that this deal is 'real'?
- What data tells you it will happen this quarter or next?
- What is not being talked about is usually a sign something is not going as planned. For example, do you know their paper process inside and out? Do you know the potential people on their team that could derail the deal later?

Meet with your team and get their help and feedback on validating what's in your pipeline and hold regular meeting cadences with them to walk through your top prospects.

**Keep your opps squeaky clean:** Pay attention to how long something has been sitting in a specific stage, and close it out when the time is right. For a tech company, the average strategic deal *takes 6 months to a year* to close. While it's normal for an opportunity to sit, holding it prevents another team (or other resources) from helping it progress.

Holding hurts our prospective customers because while they're sitting there, they aren't getting any real value from us (and likely to get more value from a competitor). It's for their benefit that we push deals along or move them to close.

---

## Resources

- [Sales discovery and qualifying questions handbook page](/handbook/sales/qualification-questions/)
- [Effective discovery handbook page](/handbook/sales/playbook/discovery/)
- [Most common customer use cases handbook page](/handbook/marketing/use-cases/)

### Training

- [Pipeline Generation at GitLab](https://gitlab.edcast.com/pathways/pipeline-generation-at-gitlab) (GitLab Learn - EdCast, 35 minutes)
- [Effective discovery course](https://gitlab.edcast.com/insights/ECL-c0a6e34d-a997-4200-b0d9-65e3305e3761) (GitLab Learn - EdCast, 40 minutes)
- [Demystifying the metrics conversation](/handbook/sales/command-of-the-message/metrics/#embrace-your-role-as-the-trusted-advisor) (Nico Ochoa video, 10 minutes)
- [Pipeline Generation - Leading with Insights](https://www.youtube.com/watch?v=fNiGq5uOxgo) (GitLab Unfiltered, Nov 2019, 10 minutes)

### Support

- [Field Marketing events and support](/handbook/marketing/field-marketing/#types-of-programs-field-marketing-runs)
- [Compete support](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/competitive-intelligence/#account-specific-support) and [Competition Slack channel](https://gitlab.slack.com/archives/C1BBL1V3K)
- [Executive sponsorship program](/handbook/sales/field-operations/gtm-resources/#executive-sponsorship-program)
- [Nominate account for ABM marketing support](/handbook/marketing/account-based-marketing/)

**Partner support:** [#channel-sales Slack channel](https://gitlab.slack.com/archives/CT9KKE5RR) is a great place to get help from a Channel Account Manager that can share partner contacts with you

- Find a partner in the [GitLab Partner Directory](https://partners.gitlab.com/English/directory/)
- Register a deal [with our technology partners](/handbook/resellers/#deal-registration-instructions)

### Tools

The toolkit above will be your main resource and contains things like a sequencing template for you to copy and modify for your own pipeline generation activities. It also includes the resources below which we've described here for easier access. To explore additional tools available, check out [our tech stack page.](/handbook/business-technology/tech-stack)

**[Outreach.io](https://university.outreach.io/prospecting-specialist-badge)** is a tool used to automate emails in the form of sequences. Users can track open rates, click through rates, response rates for various templates and update sequences based on these metrics. Outreach.io also helps to track sales activities such as calls. All emails/calls/tasks that are made through Outreach.io are automatically logged in Salesforce with a corresponding disposition. See below for a list of current call dispositions, what they mean and scenarios on when to use each of them. All AEs can request access to Outreach.io by submitting an [Access Request](https://gitlab.com/gitlab-com/team-member-epics/access-requests/-/issues/new?issuable_template=Individual_Bulk_Access_Request) (if you do not already have access).

**[LinkedIn Sales Navigator](https://www.linkedin.com/business/sales/blog/sales-navigator/what-is-linkedin-sales-navigator)** is one of the main prospecting tools we use at GitLab. It features a powerful set of search capabilities, improved visibility into extended networks, and personalized algorithms to help you reach the right decision maker. All AEs have access to LSN. [Click to go to the EdCast training.](https://gitlab.edcast.com/insights/learning-linkedin-sales) And view additional videos and tutorials on [the handbook page](/handbook/sales/training/social-selling/).

**[6Sense](/handbook/marketing/marketing-operations/6sense/)** is used by Sales Development who can show you relevant data related to your target prospects. It has a wealth of intent and propensity to buy data that is married with account engagement indicators to create a holistic intent mapping for each account.

**[Conversica](/handbook/marketing/marketing-operations/conversica/)** is a conversational AI tool that helps enterprise marketing, sales, customer success, and finance teams attract, acquire and grow customers at scale across the customer revenue lifecycle. The AI Assistant works by engaging the prospect in a human-like conversation over email in an effort to further qualify the prospect.

**[Salesforce Inbox](https://www.salesforce.com/sales/engagement-platform/)** is a productivity tool to integrate Salesforce with emails. You may need to request access. View the [Associating emails to Salesforce handbook](/handbook/sales/prospect-engagement-best-practices/) page for more information on how to use Salesforce to track outreach.
