---
title: "Sales Discovery and Qualification Questions"
description: "An effective questioning strategy is critical to engaging customers in dialogue to truly understand their needs, build credibility and trust, and qualify the opportunity"
---

An [effective questioning strategy](https://docs.google.com/presentation/d/1caRLqSGNhFAQ9KuRVBaxI9cExOvBQBC4hd36uVfWFvs/edit?usp=sharing) is critical to engaging customers in dialogue that will help you truly understand their needs, build credibility and trust, and qualify the opportunity. Furthermore, effective discovery and needs analysis will be instrumental to your developing a tailored, compelling, customer-centric solution that will increase your chances to win the business and advance the buying decision.

Target buyer personas include CIO, CTO, VP of Application Development, Product Owner, and App Developer/DevOps Engineer.

## **CUSTOMER STRATEGY**

### Goal

- So that we may best understand your organization's needs and how we can help, what are your long-term goals for modernizing your application development practices to deliver increased value to the business?
- What are you trying to achieve and why are these goals important?
- What is  your strategy for increasing the frequency of app deployments? If you were able to do this, what would the impact be to the business?
- How will you measure success for each of your goals?
- What is your cloud strategy?

### Objectives

- With an understanding of your long-term goals, what are your key objectives for the next 6-12 months?
- What challenges are you experiencing with modernizing your application development practices?
- If you could address or improve one or a just a few things in your current DevOps stack implementation and execution, what would that be and why?
- What has prevented the move to <x> so far?
- What are the implications if these problems were to continue to persist?
- As you look into the future, what other challenges or obstacles do you anticipate encountering? What are you doing today to prepare for those challenges?
- What else is holding your team back from being even more successful?

### Initiatives

- On what prioritized initiatives are you and your team currently focused?
- What initiatives are currently being planned or under consideration?
- Where is this interest/initiative coming from and what is the scope? (note: higher priority initiatives are often more likely to close and close more quickly)
  - Is it a company-wide or business unit-wide initiative? Or other?
- Do you have cloud-native initiatives? If so, what solutions are you exploring (i.e., Kubernetes)?

## **CUSTOMER NEEDS**

### Desired Outcomes

- What are the requirements you have for this project? What does success look like?
- How will success be measured?

### Current Situation

- What can you tell me about your current situation?
- What led you to look at GitLab? (if applicable)
- What is your role and what do you do? (ideal roles: Infrastructure/Cloud/Enterprise Architects, Dev Ops, System Admin/Engineer, IT Managers/Directors, Release Engineer, VP Engineering)
- How would you describe what your group does?
- How large is your group? (goal: find out who will use GitLab and how large the opportunity could be)
- How would you describe the projects on which your dev teams are currently working?
- If you were to rate how modern your organization's application development practices are on a scale of 1 to 5 (1 being not very modern at all, 5 being best-in-class modern), what would your rating be and why? What would it take to move the rating up?
- What tools are you currently using in your DevOps stack (or application development toolchain)?
  - What are you using for issue & bug tracking?
  - What are you using for CI?
  - What are you using for code review?
  - What tool(s) do you leverage for application deployment?
  - How would you describe your organization's current and future plans for adoption of the following:
    - Containers
    - VMs
    - Microservices
    - Kubernetes
    - What tools do you use for project management?
- What platforms/clouds are you deploying to?  (AWS/GCP/Azure/VMWare/Openshift/other)
  - If AWS are you deploying to EC2, ECS, EKS, Fargate, or Lambda
  - If GCP are you deploying to GCE, GKE, App Engine, or Cloud Run
  - If Azure are you deploying to VMs, AKS, Functions
- How would you describe your maturity level/progress with continuous integration and continuous delivery Is this something your group and company want to improve upon?
- How are you using GitLab CE right now? (note: if applicable--check <https://version.gitlab.com/> to identify if their company is on CE)
- Are other groups using Git? If no, why not and what Version Control System(s) are they using? If yes, what are they using?
- How is security testing currently done in your organization?
- What is the current process for finding vulnerabilities around Static Application Security Testing, Dependency Scanning, and/or License Compliance?
- What is the financial impact on your organization/teams budget with other test and review tools?
- For additional customer use case-based discovery questions, please reference the following:
  - [Version Control and Collaboration (VC&C)](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/version-control-collaboration/#discovery-questions)
  - [Continuous Integration (CI)](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/ci/#discovery-questions)
  - [DevSecOps](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/devsecops/#discovery-questions)
  - [Agile Planning and Management](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/agile/#discovery-questions)
  - [Continuous Delivery (CD)](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/cd/#discovery-questions)
  - [GitOps](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/gitops/#discovery-questions)

### Level of Satisfaction

- How is your current application development & delivery tool stack working overall?
- What is working well?
- If you could change anything about it, what would that be and why?
- What elements are presenting the most challenges today? Why are those challenges proving to be so pesky?
- What are the underlying root causes for the issues you and the team are experiencing?
- What else do you need to be successful?

### Personal Needs

- What's most important to *you* in accomplishing this objective(s)?
- What makes you personally so committed to the success of the project?
- What will it mean to you personally when the project is successful?
- What are the implications to you personally if it is not successful?
- What concerns you most?
- What is most important to you as it relates to your relationship with your supplier/partner?
- How do you prefer to work with your suppliers?
- What have you heard about and what are your perceptions of GitLab?
- Do you have any prior experience with GitLab? How did you find out about us?

## **CUSTOMER DECISION**

### Decision Process

- How would you describe the decision-making process at your organization?
- How many individuals or teams are involved in the decision making process?
- What executive or senior level sponsorship is required?
- Does each team/group purchase their own solutions or is there a department who does this? If a centralized department, what is that group's name?
- How does high availability rank within your needs and what you are trying to accomplish?

### Decision Criteria

- What criteria will be used in making a decision?

### Budget and Timeline

- When are you looking to implement? What is driving that timeline and is there any flexibility in the timeline?
- To what extent is there a compelling event (or series of events) that are influencing/impacting the timeline? What else can you tell me about that?
- What budget and resources have been allocated to this project?

### Competitors

- Are you considering other Git-based offerings? If so, who?
- What other suppliers/vendors/solutions are you considering and/or evaluating?
- How is GitLab viewed in comparison to the other suppliers?

### Time to Value

- Tell me about the most important things that need to be done to make the rollout successful.
- Describe to me where you think there may be opportunities to accelerate your time-to-value?
- How much time could we save your teams by having a GitLab expert architect and deploy GitLab for you?
- How would the business benefit from the ability to quickly and easily migrate teams?
- Describe how your developer productivity would be impacted by education around best practices for using GitLab, git or GitLab CI/CD
- How does your team manage the risk associated with adding a new tool or platform?

## **QUESTIONS FOR SELLING GITLAB PREMIUM AND ULTIMATE**

The key to identifying more GitLab Premium and GitLab Ultimate opportunities is to *truly embrace a consultative mindset with your prospect and customer engagements*. More specifically:

- **First, ensure you have an intimate understanding of the customer challenges and use cases that each version helps our customers address**
  - See the [Why Premium?](https://about.gitlab.com/pricing/premium/) page
  - See the [Why Ultimate?](https://about.gitlab.com/pricing/ultimate/) page
- And more importantly, ask effective, open-ended discovery questions and actively listen to your customer's responses to determine if and how the capabilities of these versions map to the required capabilities they need to deliver desired outcomes for their organization.

### Discovery Questions for GitLab Premium

#### Overview

[GitLab Premium](https://about.gitlab.com/pricing/premium/) helps organizations increase operational efficiencies and deliver better products faster. With GitLab Premium, organizations may scale their DevOps delivery supporting high availability, geographic replication, progressive deployment, advanced configuration, and consistent standards. Are these capabilities important to your customer? Consider asking the below questions to find out.

#### Enterprise level Support

- What is the impact of outages and downtime with your SDLC toolchain?
  - If the impact is large, position [Priority Support](https://about.gitlab.com/support/#priority-support) as a required capability
- How important is priority support to your organization?
  - Standard support: Next business day support (response within 24 hours 24x5)
  - Priority support: 4 hour response time for regular business support and 24x7 uptime support with a guaranteed 30 minute response time (best choice for minimizing outages and downtime
- How confident are you in your team's ability to roll out GitLab? What would be the impact if you had expert help to assist in guiding, planning, and shaping your deployment and implementation?
  - Position how [Customer Success Manager](https://about.gitlab.com/services/customer-success-management/) access can help to mitigate deployment risk, accelerate time to value, and optimize ROI and TCO
- How do you normally handle software upgrades? Would it be helpful to have GitLab support to help you through the process to ensure there aren't any surprises?
  - If yes, position GitLab's *Upgrade Assistance*

#### Achieve High Availability and Disaster Recovery

- What is your organization's HA (High Availability) strategy? Do you have one? Why / why not?
  - If HA support is needed, position Premium's HA support via our [Reference Architectures](https://docs.gitlab.com/ee/administration/reference_architectures/); note: Free offers HA capabilities with self-support vs. expert GitLab support
- How does your organization handle [Disaster Recovery](https://docs.gitlab.com/ee/administration/geo/disaster_recovery/index.html)?
  - GitLab's Disaster Recovery feature, only available in Premium and Ultimate SKUs, handles fail-over to another data center within minutes
- Are your development teams centrally located in generally the same vicinity or are they distributed across the world? If distributed, how do you ensure that latency between geographically dispersed developers is minimized?
  - If this is important to the customer, discuss with your SA whether or not [Geographic Replication](https://about.gitlab.com/solutions/geo/) is a required capability

#### Developer Productivity

- How important is it for you to maximize the productivity of your development teams?
- If you could change one thing to make your developers more productive, what would it be and why?
- If you were able to analyze graphs and reports to understand team, project, and group productivity to uncover patterns and best practices, how would that improve overall productivity?
  - If this is of interest, position [Productivity Analytics](https://docs.gitlab.com/ee/user/analytics/productivity_analytics.html)
- How does your organization currently track and manage code reviews and feedback?
  - GitLab Premium includes built-in [merge request reviews](https://docs.gitlab.com/ee/user/discussions/index.html#merge-request-reviews)
- How important is having consistent and standard practices to boost overall developer productivity?
  - [Group and file templates](https://docs.gitlab.com/ee/user/group/#group-file-templates) allow you to share a set of templates for common file types with every project in a group
- What is your organization doing to simplify and streamline system logon processes for developers? Do you currently use or have plans to use SmartCard authentication?
  - If yes, highlight Premium's [Smart Card Authentication](https://docs.gitlab.com/ee/administration/auth/smartcard.html) capabilities

#### Streamline Project Planning

- How do you currently handle project planning with your existing software development toolchain?
- If you could change one thing to streamline your project planning efforts, what would it be and why?
- How would your organization benefit from simplified management and visualization of work assignment and tracking?
- If streamlining project planning is important, consider positioning how the following capabilities can help your customer (see the [Why GitLab Premium? page](https://about.gitlab.com/pricing/premium/) for value descriptions of each of these features)
  - [Group Backlog management](https://docs.gitlab.com/ee/user/project/issue_board.html#multiple-issue-boards) - Simplify tracking, scoping and planning future work with group level backlog management on multiple issue boards
  - [Group Milestone Boards/Lists](https://docs.gitlab.com/ee/user/project/issue_board.html#multiple-issue-boards) - Visualize future work to be delivered in future releases/milestones
  - [Assignee Boards/Lists](https://docs.gitlab.com/ee/user/project/issue_board.html) - Streamline assignment of work to team members in a graphical assignment board
  - [Group Issue Boards](https://docs.gitlab.com/ee/user/project/issue_board.html#multiple-issue-boards) - Visually manage programs (groups) with multiple issue boards where work can be dynamically assigned and tracked
  - [Issue Analytics](https://docs.gitlab.com/ee/user/group/issues_analytics/index.html) - Establish consistent and standard practices

#### Deploy with Confidence

- How do you keep teams aligned and working on the right things at the right times?
  - [Epics](https://docs.gitlab.com/ee/user/group/epics/) - Organize, plan, and prioritize business ideas and initiatives
  - [Roadmaps](https://docs.gitlab.com/ee/user/group/roadmap/) - Visualize the flow of business initiatives across time in order to plan when future features will ship

- How many tools do you have to use to understand current status? How long does that take? How does that affect your teams?
  - If this line of questioning reveals challenges in lack of visibility across the DevOps toolchain, position GitLab Premium's [Operations Dashboard](https://docs.gitlab.com/ee/user/operations_dashboard/index.html#doc-nav) which provides a holistic view of the overall health of an organization's operations
- How would you assess your level of confidence in how your organization currently manages software deploys? Are there any risks you wish you could mitigate? If so, what are they and why? GitLab Premium offers a multitude of capabilities to allow organizations to deploy with confidence including the below (see the [Why GitLab Premium? page](https://about.gitlab.com/pricing/premium/) for value descriptions of each of these features)
  - [Multi Project Pipelines](https://docs.gitlab.com/ee/ci/pipelines/downstream_pipelines.html#multi-project-pipelines) - Link CI pipelines from multiple projects to deliver integrated solutions
  - [Protected Environments](https://docs.gitlab.com/ee/ci/environments/protected_environments.html) - Establish controls and limit the access to change specific environments

#### Manage Development

- How do you currently track and manage code reviews and feedback?
- Describe your current workflow between SCM to CI. When your pipeline fails, what's the process to remediate?
- If you could collaborate at the point of change, how would that affect your productivity?
- When is your next release? How at risk are you for missing that release? At what point does this escalate to higher management?
- How do you currently manage auditing and compliance with your existing software development toolchain?
- How easy or difficult is it for you to pull together audit evidence and proof points across multiple tools? How could you benefit from a faster process?
- How do you collect the data for security and compliance on a regular basis? When you have a breach, what are the implications and who has to get involved? What type of information is required? How long does it take for your teams to provide audit evidence?
- GitLab Premium includes several enhancements that help with auditing and compliance including the below (see the [Why GitLab Premium? page](https://about.gitlab.com/pricing/premium/) for value descriptions of each of these features)
  - [Audit Logs](https://docs.gitlab.com/ee/administration/audit_events.html) - Review changes by user and track access
  - [Auditor users](https://docs.gitlab.com/ee/administration/auditor_users.html) - Read-only access to all projects, groups, and other resources on the GitLab instance
  - [Merge Request Reviews](https://docs.gitlab.com/ee/user/discussions/index.html#merge-request-reviews) - Draft multiple comments in a merge request code review and review/resolve comments together
  - [Verified Committer](https://docs.gitlab.com/ee/user/project/repository/push_rules.html#enabling-push-rules) - Ensure only authorized and verified team members are allowed to commit to the project
  - [Require Signed Commits](https://docs.gitlab.com/ee/user/project/repository/push_rules.html#enabling-push-rules) - Enforce policy to require signed commits from contributors

### Discovery Questions for GitLab Ultimate

#### Overview

[GitLab Ultimate](https://about.gitlab.com/pricing/ultimate/) helps organizations increase operational efficiencies, deliver better products faster, and reduce security and compliance risk. This product tier is ideal for projects with executive visibility and strategic organizational usage and helps enterprises transform IT by optimizing and accelerating delivery while managing priorities, security, risk, and compliance. Ultimate helps organizations achieve advanced DevOps maturity. Are these capabilities important to your customer? Consider asking the below questions to find out.

#### Security

- To what degree is cybersecurity a critical concern for you and your organization?
- How would you characterize the actions your organization is taking to ensure all applications are secure?
- What challenges have or do you run into as it relates to securing all applications?
- GitLab Ultimate weaves security into the pipeline to provide early and actionable feedback to the development team and includes the following security features:
  - [Static Application Security Testing (SAST)](https://docs.gitlab.com/ee/user/application_security/sast/) - Evaluates the static code, checking for potential security issues
  - [Dynamic Application Security Testing (DAST)](https://docs.gitlab.com/ee/user/application_security/dast/) - Analyzes the review application to identify potential security issues
  - [Dependency Scanning](https://docs.gitlab.com/ee/user/application_security/dependency_scanning/) - Evaluates the third-party dependencies to identify potential security issues
  - [Container Scanning](https://docs.gitlab.com/ee/user/application_security/container_scanning/) - Analyzes Docker images and checks for potential security issues
  - [Security Dashboard](https://docs.gitlab.com/ee/user/application_security/security_dashboard/#project-security-dashboard) - Visualize the latest security status for each project and across projects
  - [Security Metrics and Trends (future)](https://gitlab.com/gitlab-org/gitlab-ee/issues/6954) - Metrics and historical data about how many vulnerabilities have been spotted, addressed, solved, and how much time was spent for the complete cycle

#### Compliance

- How important is license compliance to your organization so that you can  track project dependencies for their licenses and approve or deny specific licenses?
- GitLab Ultimate offers the following compliance features:
  - License Compliance - Identify the presence of new software licenses included in your project. Approve or deny the inclusion of a specific license
  - [Compliance Templates](https://docs.gitlab.com/ee/user/project/working_with_projects.html#enterprise-templates) - Templates to streamline audit management with specific regulatory standards. Currently, HIPAA is available. SOX & SOC2 are in the near term roadmap.

#### Project Insights

- How would it affect your organization's efficiencies to gain insights into things that matter for your projects (e.g. triage hygiene, issues created/closed per a given period, average time for merge requests to be merged, etc.)?
  - If this is of interest, position [Project Insights](https://docs.gitlab.com/ee/user/project/insights/)

#### Portfolio Management

- What does your organization do today to track software development and delivery projects from start to finish?
- How easy or difficult is it to provide senior leadership with end to end visibility of these projects?
- How would it affect productivity if everyone involved in critical projects had a common view of portfolio planning, tracking, and execution in one tool?
- GitLab Ultimate delivers robust portfolio management that enables this end-to-end insight and visibility to help your organization focus on delivering business value. Highlighted features include:
  - [Multi Level Epics](https://docs.gitlab.com/ee/user/group/epics/) - Organize, plan, and prioritize business ideas and initiatives
  - [VSM Workflow Analytics (future)](https://gitlab.com/gitlab-org/gitlab-ee/issues/7269) - Visualize the end to end value stream to identify and resolve bottlenecks
  - [Risk Management (future)](https://gitlab.com/gitlab-org/gitlab-ee/issues/3978) - Manage risk of epics not being completed on time
  - [What-If Scenario Planning (future)](https://gitlab.com/gitlab-org/gitlab-ee/issues/3979) - Visualize potential impact in the overall portfolio if you were to make a change
  - [Roadmap Capacity Planning (future)](https://gitlab.com/gitlab-org/gitlab-ee/issues/6777) - Visualize if future work is feasible from an effort perspective

#### Other

- Guest users - Guest users don't count towards the license count

## **ADDITIONAL QUESTIONS IF…**

### Prospect Signed Up For a Free Trial (goal: ensure a successful trial)

- How would you and your organization describe a successful trial?
- What are the most important criteria in your evaluation?
- How many users are you interested in deploying on GitLab?
- Are you evaluating any other tools?
- What is your timeframe for making a decision?
- Are you looking to bring one division of your company on to EE?
- If only a group, what is preventing you from bringing on the entire company at this time?

### Competing/Selling Against GitHub and GitHub Actions

- Review the battle card and discovery questions [here](https://about.gitlab.com/competition/github/)

### Competing/Selling Against Microsoft Azure DevOps

- Review the battle card and discovery questions [here](https://about.gitlab.com/blog/2020/07/09/integrating-azure-devops-scm-and-gitlab/)

### Competing/Selling against BitBucket

- Review the battle card and discovery questions [here](https://about.gitlab.com/blog/2016/01/27/comparing-terms-gitlab-github-bitbucket/)

### Customer is Using Jira

- How would you describe the current implementation of Jira within your organization?
- What are some of the challenges you have with Jira (if any)?

### Post Sale Account Development

Goal: Understand why they bought and use nuggets to further expand the sale and help with other sales

- How is the adoption of GitLab going?
- What are you liking about GitLab EE?
- What are you not liking or have questions about?
- How has GitLab helped your group? What are their use cases?
  - Improve code quality?
  - Speed up code releases?
- How many projects do they have?
- Is there anything you or your team would like to see within GitLab?
- Are you seeing any challenges with not having other groups using GitLab as well?
- Are there other groups that you think would benefit using GitLab?
- If yes, how would you suggest getting in contact with them?
- How many of the provisioned licenses are being used?
- If low adoption, Is there anything I can do to help you?
- If high adoption of licenses, Ask what their growth plans are and when they feel they will need to increase their seats?
- Would you be willing to be a reference customer for GitLab? If so, how has GitLab helped you and your organization?
