---
title: "Communicating with the Field"
description: "Guide to communicating with and within the GitLab Field team using both Slack and email"
---

This page is meant to serve as a guide to communicating with and within the Field using both Slack and email. Read below to find an outline of all Google Groups and Slack channels related to Sales and Customer Success.

In order to drive clarity on this page, it is important to note the difference in definitions between:

1. Sales: Refers to team members in the Enterprise and Commercial Sales teams.
1. CS: Refers to team members in the groups that make up the Customer Success organization.
1. Field: Refers to ALL members of the GTM team – Sales, CS, Marketing (SDRs), Professional Services.

## Google Groups

The parent google group of the sales team is sales-all. Several child groups fall within the parent group.

| Group Name | Group Level/Access | Description |
| ------ | ------ | ------ |
| sales-all | organization | Includes all members of the sales and CS teams as well as stakeholders across the business |
| sales-leaders | leadership | Regional directors and above (ASM and above for COM) |
| cs-leaders | leadership | VP Customer Success direct reports |
| field-managers | leadership | ASMs and above *or* equivalents on the CS/Channel/Alliance/SDR side who are people managers |
| sales-ent-managers | leadership | ASMs and above on the Enterprise team |
| sales-com-managers | leadership | ASMs and above on the Commercial team |
| sales-cs-managers | leadership | Managers and above on the Customer Success team |
| sales-commercial | segment | Members of the commercial sales team |
| sales-ent | segment | Members of the enterprise sales team |
| sales-emea | team | Members of the ENT EMEA sales team |
| sales-apac | team | Members of the ENT APAC sales team |
| sales-east | team | Members of the ENT AMER east sales team |
| sales-west | team | Members of the ENT AMER west sales team |
| sales-pubsec | team | Members of the ENT pubsec sales team |
| sales-cs | segment | Members of the customer success team |
| partners_all_hands | segment | Members of the Partner team |
| rsoe-team | segment | Members of the Revenue Strategy, Operations and Enablement (RSOE) team |
| sales-ops | team | Members of the sales operations team |
| field-enablement | team | Members of the field enablement team |

To confirm if you are in a particular Google Group, see the [Google Workspace Group Membership Reports.](/handbook/it/end-user-services/#automated-group-membership-reports-for-managers) To gain access to new Google Groups, please [fill out an access request (AR) form.](/handbook/it/end-user-services/onboarding-access-requests/access-requests/)

## Slack Channels and Groups

The primary Slack channels for the field are:

- #field-fyi: Official field announcements channel. Restricted permission levels to help streamline important updates. (Find more information [here](/handbook/sales/sales-google-groups/field-fyi-channel).)
- #sales: The general channel for WW Sales open to posts from all team members.
- #sales-support: The general channel to ask for sales support from Field Operations.
- #customer-success: The general channel to interact with & within Customer Success.

All field team members should star 🌟 and follow these four channels for important updates about the business. There are multiple team channels in the field organization, outlined below. Please follow the channels relevant to your role. To gain access to private channels, please [fill out an access request (AR) form.](/handbook/it/end-user-services/onboarding-access-requests/access-requests/)

### Slack Groups

Slack Groups are groups of members in a workspace who often need to be notified at once. The Field organization has multiple Slack Groups that effectively allow a group of people to be cc'd on a Slack communication. Please note that Slack groups send a push notification to all members and should be used sparingly, in accordance with the [guidelines around @here mentions in the Handbook](/handbook/communication/#be-respectful-of-others-time).

Only use Slack Groups if:

1. The content of the message is hyper-relevant to ALL members of the group
1. The content of the message is time-sensitive and/or needs immediate action
1. The content of the message has significant impact to the business and/or team

| Group Name | Group Members/Description |
| ------ | ------ |
| sales_leaders | Regional directors and above (ASM and above for COM) |
| cs_leaders | VP Customer Success direct reports |
| field_managers | ASMs and above *or* equivalents on the CS/Channel/Alliance/SDR side who are people managers |
| sales_ent_managers | ASMs and above on the Enterprise team |
| sales_com_managers | ASMs and above on the Commercial team |
| sales_cs_managers | Managers and above on the Customer Success team |

### Field Slack Channels

The below channels are specific to the field organization.

**Organization-Wide/Management**

| Channel Name | Channel Access (Private/Public) | Description |
| ------ | ------ | ------ |
| #sales | public | General channel for WW Sales, open to posts from all team members |
| #field-fyi | public (read-only) | Official field announcements channel |
| #cro | public | CRO (Chief Revenue Officer) announcements and communication |
| #sales-vp | public | Used for scheduling requests, etc. related to all field VPs |
| #field-managers | private | Confidential (people and/or comp-related) communication with Field (Sales, CS, SDR) managers - ASMs or equivalent and above |

**Sales**

| Channel Name | Channel Access (Private/Public) | Description |
| ------ | ------ | ------ |
| #apac_field_team | public | Team channel for APAC sales team |
| #eastsales | public | Team channel for ENT U.S. East sales team |
| #westsales | public | Team channel for ENT U.S. West sales team |
| #mid-atlantic-sales | public | Team channel for ENT U.S. Mid Atlantic sales team |
| #emea-sals |  public | Team channel for ENT EMEA sales team |
| #public-sector-sales |  private | Team channel for Public Sector sales team |
| #emea_mid-market_sales | public | Team channel for EMEA Mid-Market sales team |
| #commercial_global_all | private | Team channel for global Commercial sales team |

**Customer Success**
Consistent with company guidance to use [public channels](/handbook/communication/#use-public-channels), there are instances where private channels are preferred. As we want to ensure an [inclusive environment](/handbook/values/#diversity-inclusion), the feedback from some of the team is that private channels are sometimes preferred as there is a perception of being judged (i.e., imposter syndrome). The recommendation is to use public channels as it:

- Allows for broader collaboration (i.e., SA/CSM/PS, Product, Marketing, Sales) on solutions, recommendations, and best practices
- Provides ability for broader learning for things such as customer challenges, enablement needs, product documentation improvements, etc.
- Enables the ability to harvest the information for content (i.e., CSM solutions, adoption content for digital journey, product documentation)
The recommendation is to use public channels even while it may sometimes feel uncomforable as we [want to embrace this](/handbook/values/#embracing-uncomfortable-ideas-and-conversations).

| Channel Name | Channel Access (Private/Public) | Description |
| ------ | ------ | ------ |
| #customer-success | public | Used to interact with & within Customer Success |
| #cs-questions | public | Questions from customers and prospects to the Customer Success team about using GitLab and best practices |
| #demo-systems | public | Open discussion and questions about demo systems that aren't appropriate for issues |
| #professional-services |  public | Used to [communicate with the Professional Services team](/handbook/customer-success/professional-services-engineering/working-with/#slack) |

**Field Operations**

| Channel Name | Channel Access (Private/Public) | Description |
| ------ | ------ | ------ |
| #sales-support | public | Support for general sales-related questions, requests, and updates |
| #field-enablement-team | public | Used for communication between GitLab sales and CS team members and the field enablement team |

**Channels and Alliances**

| Channel Name | Channel Access (Private/Public) | Description |
| ------ | ------ | ------ |
| #cloud-aws or #cloud-gcp | public | Questions regarding alliance partners |
| #channel-sales | public | Topics related to channel sales |
| #partner-programs-ops | public | Topics related to partner programs and operations |
| #channel-marketing | public | Topics related to channel marketing |
| #channel-services | public | Topics related to channel services |
| #channel-accred-mvp | public | Communication about the channel partner accreditation program |

### Helpful Company Slack Channels

The below channels are owned by teams outside of the field organization but might be helpful for field team members to follow given the nature of their roles.

| Channel Name | Channel Access (Private/Public) | Description |
| ------ | ------ | ------ |
| #company-fyi | public (read-only) | Official company announcements channel |
| #company-fyi-private | private (read-only) | Official & confidential company announcements channel |
| #whats-happening-at-gitlab | public | Team-wide communication and announcements (reminders, events, project updates, etc.) |
| #ceo | public | Questions and requests for Sid |
| #competition | public | Used to share competitive insight/information from the market in real time and to ask the competitive intelligence team questions about how they might handle certain situations |
| #support_ops-announcements | public (read-only) | Sharing updates on Support-related changes  |
| #legal | public | General legal questions that are not confidential or seeking legal advice |
| #marketing | public | General marketing team channel |
| #sdr-global | public | Used to ask questions and provide useful information related to XDRs |
| #sales_dev_fyi | public (read-only) | The official SDR announcements channel |
| #content-updates | public | The latest GitLab-published content you can share with prospects on social media |
| #newswire | public | News mentions and industry news related to GitLab |
| #diversity_inclusion_and_belonging | public | Get updates and receive feedback on all things related to Diversity, Inclusion & Belonging  |
| #eba-team | public | Communicate with the EA team; schedule time with the CEO and CRO |
