---
title: "Deal Closure"
description: "GitLab sales process for deal closure"
---

You have obtained the verbal commit from the economic buyer and it's now time to close the opportunity and get the deal signature.  You will need to reapply **[MEDDPPICC](/handbook/sales/meddppicc/)** throughout this phase to accomplish the following tasks and close the deal:

1. Create a Mutual Close Plan
1. Create a Deal Package
1. Conduct Negotiations
1. Create a Final Quote
1. Acquire Signature

## 1. Create a Mutual Close Plan

A mutual close plan is a visual timeline of all the necessary tasks, individuals, and deadlines necessary to get the deal through closure and into deployment. A mutual close plan must have mutual outcome. It is created with your champions, advocates, and economic buyers. It will highlight gaps on both sides of the table so that they can be addressed and advance the deal to closure and deployment. Additionally, it allows you to coordinate/facilitate closure of the deal through your guidance of the process. Here is a [example/template](https://docs.google.com/presentation/d/1noScuDwweIX_rBSqvPqaTR5ag4GbD9e8WqE5x7_OqJ4/edit#slide=id.g80210dcfb3_7_222) you can download to complete with your champion, economic buyer, SA, and CSM.

<!-- blank line -->
<figure class="video_container">
<iframe src="https://docs.google.com/presentation/d/e/2PACX-1vR1m7yf5Db9zE-dt9papH28yHBM3XH-Tm3iCHYgySiNlK97RSZJ0RUXah29zZpnuhYf4wxq8B9iK6gl/embed?start=false&loop=false&delayms=3000" frameborder="0" width="960" height="569" allowfullscreen="true" mozallowfullscreen="true" webkitallowfullscreen="true"></iframe>
</figure>
<!-- blank line -->

### 1.1 Rediscovery

Rediscovery involves additional engagements to capture and re-verify the business drivers of the opportunity. You will use deeper open-ended questions to gather the following information:

1. Redocument Business Drivers
1. Paper Process - Increase your knowledge of the customer's procurement/vendor management process. You will need to understand if they have been through the purchase process before or not.
    - Use open-ended questions to determine if they have been through procurement before
    - Use multiple choice questions if they have not
1. Capture pricing information - This requires additional discovery and analysis to capture the following information:
    - Is the purchase a budgeted line item or discretionary spending?
    - How much are they allowed to spend?
    - What is the time horizon for this initiative to be implemented?
    - What are the logistical needs for project deployment
    - How fast do they need to move on this project?

## 2. Create a Deal Package

A deal package is an additional component of the customer deck you used earlier. The deal package must include everything the customer needs for a complete solution for long term use while also taking into account budget information you captured earlier. The deal package within the customer deck should include the following components:

- Business Case Proposal
- Mutual Close Plan
- Master Software Agreement
- Preliminary Pricing Proposal by tier based on the POV developed by the SA
- Execution and Tracking of Mutual Close Plan

## 3. Negotiations

**Rule to Remember: *You should only discount when real budget constraints are the hold up to the purchase.***

**Negotiations are defined as a discussion aimed at reaching a mutually beneficial agreement.** At this point in deal closure, the economic buyer has received the deal package. You have conducted a number of engagements with the economic buyer, the technical champion, and advocates to create a package that provides a definitive solution to their business problems while also being priced in the appropriate product tier necessary for the customer to be successful. Yet, they want a discount.

**Rule to Remember: *If they push back, you probably missed something during your discovery process.***

When this happens..you need to conduct additional discovery to work around the customer push back.

### 3.1 Ask Why?

1. Find out why they suddenly want to negotiate even though they were included in the deal proposal at all phases. **Ask why?** - Understand why they are asking for something. Confirm in the customer's words that they see the value of GitLab. Determine what has changed and why the business goal you solved for may no longer be their priority. Remind them of why they are here.
1. Determine if they are asking because they are trained to ask for concessions or if it truly is a money issue.
1. Understand who you're negotiating with because if it's a Procurement or Purchasing department instead of the economic buyer, remember that 70% of the time Procurement always asks for discounts with no understanding of the solution. Procurement's job is to get as low a price as possible. In these instances, work with your champion to get a feel for the pricing based on justification and ROI. Also, test your champion again on the decision/paper process to get through the hurdles of pricing. Engage with Champion and Vendor Management POCs..who can cut business up..Need champions to help remove business level barriers.. Finding money, vendor barriers.
1. Barter.. What are we getting in return? If GitLab doesn't approve a discount, what will happen? Ask the customer what the risk is of not doing this? The client has to make judgment on the risk. Negotiations should rarely go beyond the discount matrix because of the work done to align the business requirements with GitLab capabilities and service tiers. You can guide the customer to start smaller on a lower tier and/or with fewer users and expand usage over a longer period of time (generally 3 years plus). Utilize the following [**Deal Approval Matrix**](https://docs.google.com/document/d/1-CH-uH_zr0qaVaV1QbmVZ1rF669DsaUeq9w-q1QiKPE/edit?ts=5d6ea430#heading=h.ag75fqu12pf0) to understand your flexibility when negotiating.

Additionally, during the negotiation phase you should also be working with the Customer Success Team to plan a smooth transition for the customer. Below are the three tasks/deliverables that need to be captured and executed prior to closing the deal.

### 3.2 Customer Success Planning

#### 3.2.1 Capture Customer Success Criteria

**The Solution Architect (SA) Documents Success Criteria**  This can be accomplished by [facilitating a discovery workshop](https://docs.google.com/presentation/d/1NtURhF4TH3mYqhjaDiwDbhq5m5y2GMfOv8BtxOtp2w0/edit#slide=id.g8920d2a269_0_609) asking questions about what a successful rollout plan looks like, the expectations around user experience during a transition period, and how to educate the customer's end-users. This process will help clarify whether [positioning professional services](/handbook/customer-success/professional-services-engineering/positioning/) is appropriate at this stage during the customer buying journey.

This activity should produce a document that clearly articulates what done looks like and when done is successful. The document should be signed by an accountable individual from both parties and verbally discussed.

#### 3.2.2 Create Customer Success Plan

**The SA and CSM work with the customer to create a [Customer Success Plan](/handbook/customer-success/csm/success-plans/).**  A Success Plan is an interactive map to align the purchase (including renewals!) reasons to customer outcomes, develop joint accountabilities, measure progress and evolve as customers' needs change. Put another way, it's the way the customer can see and know that they're obtaining significantly more value than the cost of a product or service. Click on the link above to follow the steps to create a Customer Success Plan.

## 4. Final Quote Creation

Once negotiations are concluded and a final price point per user and terms are established, a final quote and Master Service Agreement (MSA) needs to be created to submit for signature.

- Quote
- Master Service Agreement (MSA)

This step can be looked at as an extension of the negotiation process and the time horizon for final quote approval, and MSA review can vary greatly between the Commercial Sales and Enterprise Sales based on the customer's purchasing processes.

### 4.1 Create a New Quote

A quote is created in Salesforce. [Create a New Quote](/handbook/marketing/developer-relations/community-programs/community-program-applications/#step-3-create-a-new-quote). Generally once you submit a quote it will be sent to the customer's legal team to redline and review.

EMEA specific Quote Creation Considerations:

1. EU based companies must have a VAT reference number.
2. EMEA must always ask the new or existing customer for the VAT reference number and re-enter it into the quote
3. The company's correct legal entity name must be manually entered into the quote versus the automated or assumed name that may auto-populate.

### 4.2 Master Service Agreement

A **[Master Service Agreement](https://about.gitlab.com/terms/#subscription)** (or **MSA**) is a contract reached between parties in which the parties agree to most of the terms that will govern future transactions or future agreements. Generally, Sales works with Legal to redline the document with the customer's legal representation. Once the redlining is completed, the deal is then ready to move to signature.

## 5. SIGNATURE

The final stage is signature. By this time the due diligence, negotiations, and revisions have been done and it's now time to have the deal signed by the economic buyer. The following components are submitted as a package:

- Customer Deck with Mutual Close Plan
- Clean Quote
- Clean version of the MSA

## 6. Next Steps

1. Update the opportunity in Salesforce as Closed/Won or Lost
2. AE/SAE coordinates a [Welcome Call](https://gitlab.com/gitlab-com/account-management/templates/customer-collaboration-project-template/-/issues/24) to introduce the CSM to the customer stakeholders.

Congratulations! You are now ready to move the deal to the [Retain and Expand](/handbook/sales/sales-operating-procedures/retain-and-expand/) phase.
