---
title: Engage & Educate the Customer
description: GitLab sales process for engaging and educating the customer
---

Your goal as a sales representative is to build 2.5 -3x your annual **[ARR](/handbook/sales/sales-term-glossary/)** quota. The ability to achieve this goal is based on your ability to create **Moments That Matter** (MTM), interactions with a customer that make a positive emotional impact about the value you and your product bring to their organization. The ability to **Engage and Educate the Customer** is fundamental to creating positive Moments That Matter.

In this Sales Standard Operating Procedures page, the four phases of the sales cycle are:

1. **Engage & Educate**
1. **Facilitate the Opportunity**
1. **Deal Closure**, and
1. **Retention and Expansion**

## Step 1: Analyze your territory

In order to accomplish this you must understand your territory. Think of your territory as your book of business, patch, or market segment. Most often your territory or book of business will be a mix of net new and renewal accounts. Companies operate in many different business verticals. The steps to understanding your territory are questions you need to answer such as:

1. How much are they using GitLab?
1. How do they buy software? (Routes to Market)

### How much GitLab are customers using?

Create a visual diagram of your territory similar to [this example on slide 5](https://docs.google.com/presentation/d/1XPhv3zqtR-q5sKgDx1HhnNkaQUSIVTO0pXj2wPdjafs/edit#slide=id.g7656291cd4_0_750).

1. Visually list each organization you currently do business with or want to do business with.
1. Breakdown each organization into departments, divisions, or branches. This breakdown depends on the business vertical.
1. Color code in green each of the departments, division, or branches that is currently utilizing GitLab
1. Color code yellow, the department, divisions, or branches that DevOps focused that are currently evaluating or testing GitLab.
1. Color code in red the departments, divisions or branches within each organization that perform DevOps but are currently not using GitLab

From this diagram you can determine what accounts **need a point of entry developed**. From the diagram, you will notice that within some organizations, there are departments/divisions who are early adopters and users of GitLab. Your goal is to leverage the early adopters success to leverage engagements with other low touch opportunities or net new opportunities.

### Strategic goal

Your strategic goal is to incrementally turn the red and yellow divisions within an organization into green GitLab users. Eventually the entirety of the organization will be green GitLab users. The question here is how do you ripen the fruit faster for harvest? By understanding how your customers buy.

## Step 2: Understand how your customers buy

Customers often buy software in multiple ways, but your ability to understand how they acquire technology will help you be more focused on the most common routes your customers use. The most common are direct purchase, through channel, and programs.

Determine your customers common routes to market and best strategies for territory engagement.

1. Create a list of your territory's three most [common business verticals](https://docs.google.com/presentation/d/1XPhv3zqtR-q5sKgDx1HhnNkaQUSIVTO0pXj2wPdjafs/edit#slide=id.g7656291cd4_0_740).
1. Discuss the most common routes to market for each business vertical.

Work with your extended team to analyze your territory and build your strategy. Your team may consist of a variety of the following:

- SDR
- ISR
- SA
- CSM
- Reseller Channel Mgr
- SI Channel Manager
- OEM/Cloud Channel Manager
- Field Marketing

### Strategic planning

1. Utilize the Google Doc Template that can be found <b>[here](https://docs.google.com/document/d/161XUH3WQ2G4oCycsoGhWprUGTu4BSJKKcM5gOnozri8/edit?usp=sharing)</b> (please make a copy, do not edit the original)
1. Choose one business vertical and create a list of the objectives and tactics to engage and grow within that business vertical

## Step 3: Select engagement activities

Your Routes to Market/Territory Plan will help you determine which GitLab resources to use to gain a point of entry into prospective opportunities. Use the list below with your team to determine the best activities to make contact with an opportunity representative.

- **Marketing**
  - What external events attract my customers?
  - What internal events might apply?
    - **External:**
      - Trade Shows
    - **Internal (Growth or Land and Expand):**
      - Lunch and Learns
      - Workshops
    - **Networking**
      - Meetups
    - **[Marketing Campaigns](https://about.gitlab.com/resources/)**
- **Division Programs**
  - Are there specific company initiatives that might provide an entry point?
    - The goal is to pick off individual programs within company divisions to build momentum towards capturing your market
- **Cloud Provider Partnerships**
  - Are they using the Cloud? - Which ones?
    - Partner with those that your customer uses as a way to leverage an entry point.
    - Work with our Channel Team to get to the right contacts with the right value proposition
    - You have to sell the Cloud provider on what's in it for them:
      - GitLab accelerates Cloud Adoption - drives usage growth
- **System Integrator (SI) Partnerships**
  - Do they do their own IT support or hire it out? - Which ones?
    - Work with the Channel Team to get to the right contacts.
    - Use this as a way to "create an internal champion"
      - If they are currently not a GitLab partner, make them one
      - Sell them on "thought leadership, speed to delivery, revenue stream."
- **Resellers**
  - Do they buy direct or through resellers? - Which ones?
    - Work with the Channel Team to get to the right contacts.
    - Use this as a way to "be a force multiplier" (there is only one of you)
      - If they are currently not a GitLab partner, make them one
      - They typically rep a lot of products, so make it easy for them to give the GitLab Story
        - Give them your latest briefing deck, walk them through the talking points.
      - Sell them on "thought leadership, speed to delivery, revenue stream."
- **Original Equipment Manufacturers** (OEM)
  - Are there other software technologies they currently use that might integrate with GitLab to provide **an entry point?**
    - Work with the OEM Team or the customer to get to the right contacts.
      - You will have to sell them on the benefits of working with us.
        - "thought leadership, speed to delivery, revenue stream."
    - This can be both an entry point but also a growth strategy.
- **Industry Memberships**
  - Do the executive and management staff belong to any industry groups? - Which ones?
    - Not just the obvious ones (Tech or DevOps) but their own industry Groups (Healthcare, Manufacturing, Transportation, Financial, etc.)
    - Meet with our Marketing Team for advice
      - Use this as a way to gain credibility and for networking.

## Step 4. Meeting preparation and execution

At this point, the selected engagement activities should have generated a significant number of leads. It's now time to sift through those leads and determine which may become opportunities. This requires an initial qualifying meeting and the quality the preparation you take for that meeting can mean the difference in having a deal or losing a deal. The steps that necessary to prepare and execute a successful meeting are:

1. <b>[Determine your Buyer Persona](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/)</b> - a buyer persona is a fictional representation of your key buyers. This helps you pre-identify obstacles, objections, initiatives, and metrics that are important to your buyer. This step will give you an edge in understanding your customers better than your competition. There are typically 5 buyer personas you may encounter.
    - Technology Leader
    - Business Application Leader
    - Security Leaders
    - COO/CXO Leader
    - Financial Leader
1. **Reference Buyer Process Maps** (BPMs) - are maps of mental pathways buyers' travel to make decisions. BPMs will guide selling activity based on where the buyer is in their process. Your goals in this step is differentiation, reduction in resistance, avoid wasting cycles, and facilitate better meetings and create **Moments that Matter**. See a breakdown of the <b>[Buyer Process Map](https://docs.google.com/presentation/d/181vsu60-UYk1890BJjemfjZ3GIQhYrPrsNAh4xN3-wM/edit#slide=id.p25)</b> stage and the common buyer actions that indicate what stages of the buyer process the prospect is in.
1. **Research the Buyer** - includes a number of sub-tasks necessary to get additional insight into the buyer.
    1. Reference **SFDC** to see if the lead is a current customer or prospect. Review their digital body language such as recent activities and past contact.
    1. Reference **LinkedIn** and cross reference the contact's profile to relevant buyer personas and look for overlaps.
    1. Reference the **company's website** and absorb basics related to strategic goals, industry, business model, their buyer, etc.
    1. Develop **Pre-Call Planning Questions** to better determine what discovery questions. The pre-call planning questions will cause you as the seller to further validate and reference the buyer persona you will engage with.
    1. Develop a **Persona Based Call Plan** to ensure that you gather more pertinent information from the buyer. It will help identify information gaps, set specific objectives, and ultimately increase your buyer's confidence in you.
1. Utilize <b>[MEDDPPICC](/handbook/sales/meddppicc/)</b> to create Discovery questions to gather the information necessary to qualify the opportunity. MEDDPPICC is a qualification framework that will help you determine if the opportunity is worth your time, effort, and company resources. It will help you to more quickly determine what stage the buyer falls in the sales process. The framework will also expose problems and clarify next steps. It will help make you more efficient and focused sales representatives by making it easier to sort the good deals from no deals, and quick deals from long term deals. The foundation of MEDDPPICC is based on asking good discovery questions.
1. Ask effective, open-ended **[Discovery Questions](/handbook/sales/qualification-questions/)** to identify existing customer needs, problems, pain points, goals etc. The **[GitLab CxO Digital Transformation Discovery Guide](https://drive.google.com/a/gitlab.com/open?id=1balLINV-vnd6-6TYzF3SIIJKrBPUQofVSDgQ5llC2Do)** is a helpful resource with sample discovery questions for senior economic buyers.
1. **Prepare a Meeting Agenda** to identify how the buyer wants will match what you will cover. Leverage this [Pre-Call Plan](https://docs.google.com/document/d/1yjyfvMoDvayZca5hXiIwSHYc9T1M3mTc7ocqzjhqOf8/copy) document to prepare for this and subsequent customer calls/meetings. In addition, consider sending your proposed agenda to the buyer in advance of the meeting to ensure alignment. For each agenda item, include some questions from the BPM, prepare statements, industry case studies. Research 1-3 items in the Objectives and Obstacles section of the personas. Finalize your meeting objectives in order to show the buyer you are prepared, listening, and empathic. Structure the meeting so that the prospect is relaxed and is comfortable going deep with their problems and needs.
1. Utilize a **[Command Plan](/handbook/sales/command-of-the-message/command-plan/)** to track the progress of a deal. The Command Plan an iterative document within Salesforce that gives you and your team macro and micro level visibility into an opportunity. It is designed to align and guide you through the necessary [MEDDPPICC](/handbook/sales/meddppicc/) process to quickly capture the information necessary to properly qualify an opportunity. Here is a sample [Command Plan](https://docs.google.com/spreadsheets/d/16m5_w4NiNSXfJFt9576IktNUp6uTCOKxaLBtoyR0lrA/edit#gid=299910663).

**Reminder**: A [Command Plan](/handbook/sales/command-of-the-message/command-plan/) is not a one and done document. Nor will you gather all the necessary information in one meeting, so be prepared to work through pieces of the document over a series of meetings. Taking this time up front will help you better evaluate the deal by asking deeper trap-setting questions that will help you gather more insightful data about your customer.

As a rule of thumb, here is the cadence for updating your [Command Plans](/handbook/sales/command-of-the-message/command-plan/).

- Command Plan: Opportunity Overview - Real Time
- Command Plan: MEDDPPICC Data - Real Time
- Command Plan: Close Plan - Real Time

## Step 5. Qualify the opportunity

Once you have conducted the initial qualifying meeting. You and your team should review all the data gathered in the [Command Plan](/handbook/sales/command-of-the-message/command-plan/). This includes a review of the research conducted, the discovery questions asked, how much [MEDDPPICC](/handbook/sales/meddppicc/) data was captured in the Command Plan, and what gaps you still have outstanding to capture. Depending on the level of data captured, the lead can then be evaluated according to the below listed criteria to recategorize from a lead to a <b>[Sales Accepted Opportunity](/handbook/sales/field-operations/gtm-resources/)</b>:

- **Authority (Is the prospect a person with decision- making authority?)**
  - The prospect being met is directly involved in a project or team related to the potential purchase of GitLab within this buying group, either as an evaluator, decision maker, technical buyer, or *influencer.
- **Initiative (Is it a Small Box sale or is this a Top 2 priority?)**
  - A Small Box opportunity is one where the buyer buys the smallest solution necessary that will solve the very specific problem they know they need to solve immediately. (**This criteria is specific to Commercial Sales**)
  - A Top 2 Priority is an initiative the company is working on has been identified and GitLab can potentially help the initiative. Identified by either a business problem (i.e too many tools), strategic direction or modernization interest (impetus to change).
- **Fit (How well does the lead align with the GitLab product? )**
  - Current DevOps or software development lifecycle tools (from conversation or credible data source)
  - Expected entry point use case (e.g. SCM or CI)
  - Potential seats of the first opportunity (if this is a new account or buying group)
- **Timing (How Soon Will They Buy?)**
  - After the initial qualifying meeting with the account leader/executive, there must be a next step that is set to occur within a *60 day timeframe*. (If next step isn't within a 60 day timeframe, the opportunity remains in stage 0).

Once the lead has been evaluated according to the above criteria, it can be designated as a qualified opportunity. An OPPORTUNITY can be created in Salesforce a) when converting a LEAD to CONTACT; b) from a CONTACT. **All opportunities** should be created with a Stage = 0-Pending Acceptance regardless of how you create the OPPORTUNITY. Once the initial setup is complete, the [OPPORTUNITY Stage](/handbook/sales/field-operations/gtm-resources/) can be updated within Salesforce.

## Step 6. Pipeline management and forecasting

Your goal is to close deals and the best way to do that is to track where your sales stands within your sales framework as well as where the deal stands within the **buyer's journey**. This is done through pipeline management and forecasting.

### Pipeline Management

**Pipeline Management** is typically done in **Salesforce**, and forecasting is done in **Clari**. The common pipeline stages within Salesforce are the following:

- 0 - Pending Acceptance
- 1 - Discovery
- 2 - Scoping
- 3 - Technical Evaluation
- 4 - Proposal
- 5 - Negotiating
- 6 - Awaiting Signature
- 7 - Closed Won
- 8 - Lost

Below are **DAILY TASKS** you'll need to perform within Salesforce.

1. Accurately document each stage of the sales cycle using the list above. This requires you to assess each opportunity based on what tasks have taken place. If you have gathered data and the deal meets the criteria in step 5, the deal can then be designated as 0 - Pending Acceptance.
    - When you have scheduled a follow up meeting to interview and obtain in depth [MEDDPPICC](/handbook/sales/meddppicc/) data the opportunity should be designated as stage 1 - Discovery.
    - **Pipeline Hygiene: Generally review your accounts DAILY, but depending on the size of your book of business, it should be at least once per week.**
    - Identify prospects who have been in your sales pipeline longer than your average sales cycle.
    - Before you completely give up on a prospect, send them a sales breakup email
1. Use a repeatable framework for pipeline management is:
    1. Connect via email, phone, or zoom meeting.
    1. Use discovery questions to assess the buyer's interest level using the [Buyer's Process Map](https://docs.google.com/presentation/d/181vsu60-UYk1890BJjemfjZ3GIQhYrPrsNAh4xN3-wM/edit#slide=id.p25)
    1. Document the interaction in Salesforce
    1. Set Appointment if possible
    1. Send followup documentation to further educate the customer
1. Keep your pipeline leads high by flowing using a standard followup process
    1. Conduct engagement activities on a **Regular Basis** as outlined in Step 3: Select Engagment Activities.
    1. Set a response time to respond to inbound leads
    1. Set a number of touches per lead spread out over one month
    1. Set a number and a variety of email, phone, and social media touches a lead receives
    1. Every touch a lead receives should include new information or resources from the **[Use Case GTM Bill of Material Priorities](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/)** matrix.

### Forecasting

**Forecasting** in simple terms is determining if you will hit your sales numbers at a given point in time. Clari is the tool to help you track your sales projections. Clari delivers insights by pulling data from all your engagements (phone calls, emails, calendar, social media, and news) and fuses that data so that you can better estimate the timing and likelihood of closing. Clari is also a good tool to quickly understand your **sales gap to quota** and help you focus on your deals from best case to worst case.

Below are the **WEEKLY TASK** you'll need to perform within Clari. Navigate to the **Net ARR** tab within Clari.

1. Renewal Loss Best Case
    - **Click "Net ARR", then Click "Renewal Loss Best Case".** This field should reflect the value of non-renewals during the current quarter with a LOWER probability (or Best Case) but a HIGHER value than Renewal Loss Commit.
1. Renewal Loss Commit
    - **Click "Net ARR", then Click "Renewal Loss Commit".** This field should reflect the value of non-renewals during the current quarter with a HIGHER probability (or Commit) but a LOWER value than Renewal Loss Best Case.
1. Gross ARR Best Case
    - **Click "NetIACV", then Click "Gross ARR BEST CASE ".** This field should have the value for your Gross ARR Best Case minus your Renewal Loss Best Case.
1. Gross ARR COMMIT
    - **Click "Net ARR", then Click "Gross ARR Commit".** This field should have the value for your Gross ARR Commit minus your Renewal Loss Commit.
1. NET 50/50
    - **Click "Net ARR", then Click "Net 50/50".** This field should have the value for what you believe will be the actual forecast for your team. If you consider the Commit as the floor and Best Case as the ceiling, then the 50-50 is what is the most likely outcome.

For in-depth training on Clari go to the **[Clari for Salespeople Instructional Videos](/handbook/sales/forecasting/)**.

Now you are ready to move into the next phase of the sales cycle, **[Facilitating the Opportunity](/handbook/sales/sales-operating-procedures/facilitate-the-opportunity/)**.
