---
title: "Retain and Expand"
description: "GitLab sales process to retain customers and expand GitLab's footprint and value to the customer"
---

Once the account is won it is time for the AE/SAE/CSM/PSE to work together to ensure [Customer Success](/handbook/customer-success/). This requires [Account Engagement](/handbook/customer-success/csm/engagement/) by all parties.  The components of this are:

- Customer Onboarding
- Customer Implementation
- Customer Account Management
- Customer Account Expansion

In the retention and expansion phase, the roles and responsibilities of the CSM/PSE/AE/SAE run parallel and it is very important that all roles work together to help the customer be successful. Retention and expansion is typically the purview of the CSM regarding most project management and technical aspects of customer success, but it's important for the AE/SAE to conduct ongoing sales engagement activities with the account in order to provide dependable touch points for customer support. This Standard Operating Procedure (SOP) will layout the steps, tasks, and deliverables necessary by all parties below related to account management.

- Strategic Account Executive ([Enterprise](/job-families/sales/enterprise-account-executive/)) or Account Executive ([SMB](/handbook/sales/commercial/#smb-account-executives) or [Mid Market](/handbook/sales/commercial/#mid-market-account-executive))
- [Customer Success Manager](/handbook/customer-success/csm/#what-is-a-customer-success-manager-csm)
- [Solutions Architect](/handbook/solutions-architects/)
- [Professional Services](/handbook/customer-success/professional-services-engineering/)

## 1.Customer Onboarding

**[Customer onboarding](/handbook/customer-success/csm/onboarding/)** is a term typically used to describe the process users go through, from the start of their journey to become a customer and beyond. Within GitLab, customer onboarding encompases an the SAE/AE conducting an official introduction and account management transition to CSM and PSE to customer stakeholders via a Welcome Call.  Additionally, the CSM will begin to re-validate an understanding of the customer's use case, technology stack. The tasks that need to be accomplished are below:

1. Professional Services Implementation kick-off. CSM manages the kick-off and implementation plan catered to the customer.

- [Professional Services](/handbook/customer-success/professional-services-engineering/sales-enablement/) helps your customer accelerate their DevOps Transformation by delivering services to improve operational efficiency, accelerate time to market and reduce risk through GitLab product adoption. We accomplish these by offering categories of services to help ensure the initial GitLab rollout goes smoothly so the end users can get value as fast as possible. It is important for a ISR/SAE to understand the services that certain types of customers typically engage in and how to position those services when building out a success plan. Utilize the [Positioning Professional Services](/handbook/customer-success/professional-services-engineering/positioning/) handbook page to understand all the services available to customers and how to market to them.

1. Solution Architect transitions customer meta-record and technical profile to PSE or CSM.
1. Account Executive transitions customer meta-record and business profile to CSM
1. Define transition process for customers. Plans should not end at signature but from their goal and work backwards
    - SAE/AE updates [Command Plan](/handbook/sales/command-of-the-message/command-plan/)
    - CSM builds the [Success Plan](/handbook/customer-success/csm/success-plans/)
1. CSM creates and execute onboarding and implementation plans
1. Customer Implementation

## 2.Implementation

**Implementation** is focused on ensuring the customer has the right infrastructure to support GitLab solution operations. For self-managed customers, this could include setting up on-premises equipment and/or cloud infrastructure. For customers leveraging GitLab.com, this includes integration of the GitLab cloud service with the customers environment (e.g., SAML SSO integration). This is considered complete when production infrastructure is ready for use.

### 2.1 Success Planning

There are two types of [success plans](/handbook/customer-success/csm/success-plans/) in Gainsight. The first is the **ROI Success Plan** described above. The second type is the **Stage Adoption Success Plan**. This success plan is an internal document allowing the CSM to track progress and goals on driving stage adoption within an account.

The **Return on Investment (ROI) Success Plan** is a customer facing interactive map created by a CSM to align the purchase (or renewal!) reasons to customer outcomes, develop joint accountabilities, measure progress and evolve as customers' needs change. Put another way, it's the way the customer can see and know that they're attaining significantly more value than the cost of a product or service. Success Planning focuses on helping customers achieve their desired objectives and recognizes that the purchase transaction is just the beginning of the customer's journey with GitLab. This includes outlining a vision to customers that combines the GitLab road map with the customer road map.

- CSM responsibilities include a full use-case, stakeholder, technology stack, and opportunity discovery with the account customer.  The information gathered for the customer's success plan is housed in **[GainSight](/handbook/customer-success/csm/gainsight/)**, which is embedded as an additional link within Salesforce.
- CSM coordinates and educates customer and positions them for GitLab Certification with GitLab 101.

### 2.2 Stage Adoption

The objective is to support our customer's utilization of the GitLab solution to address the customer's original purchase intent (i.e., product stage(s) and capabilities, licenses). [Stage Adoption](/handbook/customer-success/csm/stage-adoption/) is complete when the following questions can be answered:

- Have 80% of the licenses from the original purchases are activated?
- Is the customer successfully adopting the capabilities or stages from their original purchase intent?
- Will these be measured according to product analytics (if available) or through agreement with the customer.

As part of our customer journey, we highly value the customer's initial experience and measure time-to-value. This is done according to [Key Performance Indicators (KPIs)](/handbook/customer-success/customer-success-vision/#measurement-and-kpis) Specifically, we will measure the time in calendar days from the initial transaction to:

- **Engagement**: Represents our time to engage the customer. Completion defined when the CSM has their first meeting with the customer.
- **Onboarding**: Completion is defined when all the onboarding tasks are done.
- **Infrastructure Ready**: Completion is defined as either 1) production implementation is complete for on-premises installations 2) GitLab.com is integrated into a customer's environment or 3) Cloud and on-premises environments ready for a hybrid deployment
- **First Value**: Represents a small subset of users are using the product in a Production environment. This is achieved when a customer activates 10% of their licenses.
- **Outcome Achieved**: Represents delivery to original purchase intent. We want to capture the delivery of outcomes against their original purchase intent. New and changed goals will continue to be tracked with the engagement, but not included in this milestone.

## 3. Customer Account Management (Retention)

Customer service is an important aspect of the customer journey. The reason this is so important is that most of your revenue from an account will come from renewals and license growth. To do this, a consistent customer buying experience must be provided through exceptional customer service and account management activities. Within GitLab this is done by keeping track of how the account is progressing, understanding the issues and requests that are important to the account, navigating delivery of key milestones (onboarding, EBR, renewal), and escalating and responding to account risks quickly. Below are the main tasks that need to be conducted for effective Customer Account Management.

### 3.1 Ongoing Customer Engagement

It is important that both the SAE/AE and CSM conduct ongoing customer touchpoints and engagements. The following are tasks that fall under the purview of ongoing customer engagement:

- SAE/CSM continually re-verify and documents customer's positive business outcomes and connects the GitLab solution with their pain.
  - [Success Plans](/handbook/customer-success/csm/success-plans/) for CSMs in GainSight
  - [Command Plan](/handbook/sales/command-of-the-message/command-plan/) for SAEs in Salesforce
- CSM develops a clear process for responding to problems that support escalations (collaborating with Sales, Support, Product, and Engineering, CSMs). Host escalation calls and manage the customer from an escalated state back to a normal state. SAE supports the CSM.
- SAE/AE/CSM continually meets with customers to capture problems, adjust the plan, reinforce confidence, and identify new opportunities to resell.
- SAE/AE remains present on how the customer is achieving their positive business outcomes.

### 3.2  Customer Account Maintenance Tasks

#### 3.2.1 Daily Activities (SAE/AE)

Below are the activities that should be documented by the SAE/AE in real-time.

- Update Salesforce to capture next steps, dates in order to maintain a current status and log major events on the account.
- Update the Command Plan Opportunity Overview to ensure the account/opportunity assumptions are current and accurate.
- Update the [MEDDPPICC](/handbook/sales/meddppicc/) section of the [Command Plan](/handbook/sales/command-of-the-message/command-plan/) to ensure pretentant data is up-to-date and accurate
- Update the Close Plan and Close Date to ensure you're forecasting accurately

#### 3.2.3 Weekly Account Maintenance Activities (SAE/AE)

Below are the **WEEKLY TASK** you'll need to perform within Clari.

- **Clari-Forecast Values (Net New)** - Document regional news, success stories, closed, won, and organizational issues
- **Clari-Forecast Value (Renewal)** - Document and discuss field marketing details with your patch.

For in-depth training on Clari go to the [Clari for Salespeople Instructional Videos](/handbook/sales/forecasting/).

### 3.3 Conduct Executive Business Reviews (CSMs)

An [Executive Business Review (EBR)](/handbook/customer-success/csm/ebr/) is a strategic meeting with stakeholders from both GitLab and the customer. Together with the SAE/AE, a CSM is responsible for scheduling and conducting EBRs and working with their customers to achieve the primary objectives and desired business outcomes. The CSM will own the content creation, and together the SAE/AE and CSM will determine the flow of the review based on best practices and insight into the customer relationship.

CSMs should hold EBRs with each of their customers at least once per year. Larger ARR accounts or those with more strategic initiatives may benefit from or even require a quarterly cadence, a decision to be made by the CSM, SAE/AE, and Sales/CS leadership.

The CSM will coordinate with SALSA to determine who will invite the stakeholders to ensure we get the right people into the room, build the [EBR deck](https://docs.google.com/presentation/d/1FfHBVMsY2a3cteylz7Alq-K43OmBPLylBoVdIccsO8g/edit), and tell a story around the presentation that is solution and value focused.

## 4. Customer Account Expansion

### 4.1 CSM Customer Account Expansion Activities

Below are some of the top processes to be performed by CSM Managers on a recurring cadence. The overall goal is to ensure the CSM Manager has a strong grasp on their team's group of customers through various data points (health, Support tickets, Onboarding objects, renewals, etc.). Resources such as Dashboards and videos are included for easy reference.

- Conduct regular [Health Checks](/handbook/customer-success/csm/health-score-triage/) with customers.
- Conduct [Renewal Review Meeting](/handbook/customer-success/csm/renewals/#renewal-review-meeting) with SAE/AE. A key part of the customer relationship lifecycle is the renewal phase. CSMs must proactively track the renewal dates of their customers and align with their Strategic Account Manager (SAE) to ensure that a customer renewal takes place.
**At the beginning of each month** a CSM should review their list of accounts in Salesforce and note the renewal dates for their accounts. If a renewal date is within six months the CSM should schedule two "Renewal Review" meetings with the appropriate SAE and Solutions Architect (SA). The first "Renewal Review" meeting should be scheduled five months out from the renewal date and the second should be scheduled three months out from the renewal date.
- Conduct **SAE/SA/CSM** meetings to review forecasting, pipeline, and identify new sales opportunities.
- Develop **Net Promoter Score** NPS/ CSAT twice per year to rate general customer satisfaction (after closed cases).

### 4.2 CSM Review Checklist

For CSM Managers, here is a short checklist to assist in the review:

- [Account assignment](/handbook/customer-success/csm/csm-manager/#account-assignment): Accounts have been reviewed and are assigned or are in review
- [Customer Onboarding](/handbook/customer-success/csm/csm-manager/#onboarding-object-review): Customers in the Onboarding phase have been reviewed and onboarding status and notes are complete
- [Success Plans](/handbook/customer-success/csm/csm-manager/#success-plan-review): Customers have a Success Plan, it is being communicated with the customer, and the CSM is using it as the guiding document
- [Triage and Health](/handbook/customer-success/csm/csm-manager/#triage-and-health-review): Health for all CSM-assigned accounts have been updated within the last month, and any accounts in Triage are being evaluated
- [Renewal Review](/handbook/customer-success/csm/csm-manager/#renewal-review): Upcoming customer renewals have been reviewed — the CSM has updated customer health and communicated with the SAE and SA for the upcoming renewal

### 4.3 SAE/AE Customer Account Expansion Activities

Once renewal opportunities are identified at the monthly renewal meeting, the SAE/AE should conduct in-depth engagements with the customer with a baseline from the account/product tier purchased at the original deal closure.

#### 4.3.1 Discovery Call Meetings

#### Use the Command Plan within Salesforce to capture the following information for the renewal opportunity

- Engage regularly with the CTO to re-validate top priorities
- Review the 18-24 month plan and align the plan as necessary to the customer's priorities
- Capture the primary team/division's success with the product so far
- Capture from the organization what other toolchains they are using, what outcomes they seek, and metrics for success with their timelines
- Capture their budget projections for future expansion

#### 4.3.2 Account Expansion Strategy

Meet with the CSM/SA to review the information captured from your discovery meeting and align it with the data the CSM has captured in the Success Plan. Use the data and questions below to determine a tailored expansion strategy.

- Does the GitLab product make an impact on the customer's vision? Does it solve their problem(s)?
- How does the product impact change over the long term?
- How does the product impact the budget allocation or will it be discretionary spending? How will this impact their decision to expand? Do we need to reduce friction on cost versus features?
- Does the original POV scale beyond the original group and solves problems for the larger organization?  Do we need a new POV that aligns better with the customer's priorities?

These questions should be answered as a team with the SAE/AE,CSM, and SA pulling together data to make an informed decision about the account expansion strategy that aligns best with the customer's top long term priorities.

#### 4.3.3. Customer Deck Renewal Deal Package

As you did in the Factiliate the Opportunity and Deal Closure, you will need an updated customer deck.  This consists of an overall deal package to engage the economic buyer with a package that aligns high level business priorities with GitLabs Value Drivers. The focus of the renewal customer package is to make them more forward thinking by investing earlier and having a full toolbox as they grow.

The customer deck should be created with the idea that your champion can present it to the economic buyer. To do this you will need to work side-by-side with your advocates, champions, CSM, and SA to update the customer deck and provide the following components to an economic buyer:

1. Current state of GitLab usage
2. Case study that aligns with the customer's top priorities
3. Justification
    - Includes a market thesis on where the market is currently and what they'll gain over time by investing now versus waiting. If they buy at a higher tier they'll have specific features as needed but also gain single application capability when they need it.
4. Preliminary pricing proposal that aligns with the value GitLab is delivering while taking into consideration the customer's budget or financial constraints
