---
title: "Sales Training"
description: "GitLab's sales learning framework and sales training resources"
---

## GitLab Sales Learning Framework

GitLab field team members are expected to be knowledgeable and proficient across a variety of topics, skills, behaviors, and processes. For ease of consumption, sales training resources are organized in 6 categories below. If you are looking for more immediate access to resources to support your selling efforts, please check out the [Sales Resources](https://gitlab.highspot.com/spots/615dd7e3911d70c4887812a7) page.

For the latest Field Enablement Spotlight videos and training resources please see the [Field Enablement Spotlight: Continuous Education at GitLab](https://gitlab.highspot.com/items/6480e56aff37cbf397ac752f?lfrm=srp.2) page on Highspot.

## GitLab Target Audiences

Successful field team members must have an intimate understanding of ideal customer profiles, customer environments where opportunities for GitLab are most ripe, targeted buyer personas, industry-relevant insights, and more.

| **Topic** | **Resource(s)** |
| ------ | ------ |
| What is GitLab's ideal customer profile? |- [Handbook page](/handbook/marketing/account-based-marketing/) <br>- [GitLab Account Based Marketing and Ideal Customer Profile](https://youtu.be/6TbtGiS9Eak) (Mar 2020, 34 minutes) (internal only) |
| What business problems does GitLab help customers solve? | - Check out the value drivers and other materials on the GitLab [Command of the Message page](/handbook/sales/command-of-the-message/) |
| What are target buyer personas and their pain points? | - [GitLab Buyer Personas](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/roles-personas/buyer-persona/) <br> - [Interview with an IT Agility Director](/handbook/sales/it-agility-director-interview/) <br> - Learn more about [Enterprise IT roles & key pain points](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/enterprise-it-roles/) |
| What are target user personas and their pain points? | - [Handbook page](/handbook/product/personas/#list-of-user-personas) |

## Industry Topics & Trends

To serve as trusted advisors to customers and partners, GitLab field team members must be able to competently and confidently engage with customers on topics like the Software Development Life Cycle (SDLC), Source Code Management (SCM) / Version Control & Collaboration, open source & open core, DevOps, Continuous Integration & Continuous Delivery (CI/CD), containers, Kubernetes, and more.

| **Topic** | **Resource(s)** |
| ------ | ------ |
| What is DevOps? | - [DevOps Explained](https://about.gitlab.com/topics/devops/) (20 minutes) <br> - [Video](https://www.youtube.com/watch?v=_I94-tJlovg) (Dec 2013, 7 minutes) <br> - [Stages of the DevOps Lifecycle](https://about.gitlab.com/stages-devops-lifecycle/) <br> - [DevOps terms: 10 essential concepts, explained](https://enterprisersproject.com/article/2019/8/devops-terms-10-essential-concepts) |
| What is the software development life cycle and how is software developed and deployed? | - [GitLab's public website on the SDLC](https://about.gitlab.com/stages-devops-lifecycle/) <br> - [What is the Software Development Lifecycle (SDLC)?](https://www.youtube.com/watch?v=Ancdhr3t2sE) (July 2018, 11 minutes) <br> - [Software Development Lifecycle (SDLC) in 9 minutes!](https://www.youtube.com/watch?v=i-QyW8D3ei0) (Jan 2016, 9 minutes) <br> - [How is software made using GitLab?](https://www.youtube.com/watch?v=UuX-GnYWNwo&feature=youtu.be) (Nov 2019, 23 minutes)|
| What is Git? | - [Git Tutorials](https://www.youtube.com/playlist?list=PLu-nSsOS6FRIg52MWrd7C_qSnQp3ZoHwW) |
| What is cloud-native? | - [GitLab website](https://about.gitlab.com/topics/cloud-native/) <br> - [Video on Cloud-Native Transformation](https://www.youtube.com/watch?v=WsIM034RnAc) (Mar 2019, 29 minutes) |
| What is SCM? | - [Video](https://drive.google.com/file/d/13YIChJtWWTI2ekfM3ClSi0DMZRFpaQ9b/view) (June 2019, 29 minutes) |
| What is CI and CD? | - [GitLab Continuous Integration (CI) & Continuous Delivery (CD)](https://about.gitlab.com/solutions/continuous-integration/) <br> - [Modernize Your CI/CD eBook](https://learn.gitlab.com/c/modernize-your-ci-cd) <br> - [Click here](https://gitlab.edcast.com/pathways/continuous-integration-customer-use-case/cards/5691968) to enroll in the Continuous Integration learning path (Aug 2020) |
| What is DevSecOps? <br> What is "shift left?" | - [Security & Governance Enablement Update](https://youtu.be/O3osCCcZbt4) (Oct 2022, 30 minutes) <br> - [DevSecOps Campaign Refresh](https://youtu.be/6eE0K2NXNw8) (Oct 2021, 30 minutes) <br> - [DevSecOps with GitLab](https://about.gitlab.com/solutions/dev-sec-ops/) <br> - [2019 Global Developer Report: DevSecOps](https://learn.gitlab.com/devsecops/2019-global-develope) <br> - [Speed up secure software delivery with DevSecOps](https://about.gitlab.com/blog/2019/04/30/speed-secure-software-delivery-devsecops/) (Apr 2019) <br> - [Click here](https://gitlab.edcast.com/pathways/devsecops-customer-use-case/cards/1472168) to enroll in the DevSecOps learning path. (Aug 2020) |
| What is Auto DevOps? | - [Auto DevOps](https://about.gitlab.com/stages-devops-lifecycle/auto-devops/) |
| What is GitOps and Infrastructure as Code? | - [Why GitOps should be the workflow of choice](https://about.gitlab.com/blog/2020/04/17/why-gitops-should-be-workflow-of-choice/) (Apr 2020) <br> - [Optimize GitOps workflow with version control from GitLab](https://about.gitlab.com/blog/2019/10/28/optimize-gitops-workflow/) (Oct 2019) |
| What is open source? |- Check out [this post](https://opensource.com/resources/what-open-source) on opensource.com |
| What is open core? |- [What to consider with an open source business model](https://about.gitlab.com/blog/2019/07/05/thoughts-on-open-source/) (Jul 2019) |
| What are microservices? | - [Video: What are microservices?](https://www.youtube.com/watch?v=petnTitp6CQ) (Jan 2019, 19 minutes) <br> - [What are microservices?](https://about.gitlab.com/topics/microservices/) |
| What is serverless? | - [What is Serverless?](https://www.youtube.com/watch?v=GBOroGozm5w) (Jan 2019, 18 minutes) |
| What are containers? | - [What are containers and why do you need them?](https://www.cio.com/article/2924995/what-are-containers-and-why-do-you-need-them.html) (Jun 2017) <br> - [What are containers?](https://www.youtube.com/watch?v=wuhxSLapDe0) (Mar 2018, 9 minutes) |
| What is Kubernetes? | - [What is Kubernetes?](https://www.youtube.com/watch?v=ALW6VBviSgQ) (Jun 2018, 12 minutes) <br> - [The Evolution of the Kubernetes Landscape](https://www.youtube.com/watch?v=5OLkPK4MRVQ) (Nov 2019, 30 minutes) <br> - [First Steps to Becoming Certified Kubernetes App Developer](https://www.oreilly.com/library/view/certified-kubernetes-application/9780136677628/) (30-60 minutes) <br> - [Kubernetes API Fundamentals](https://www.oreilly.com/library/view/kubernetes-fundamentals/9781492032144/) (30 minutes) |
| What is complete DevOps? | - [The entire DevOps lifecycle in one application](https://about.gitlab.com/stages-devops-lifecycle/) |
| What is concurrent DevOps? | - [Video](https://www.youtube.com/watch?v=bDTYHGEIeM0) (Apr 2019, 24.5 minutes) <br> - GitLab Concurrent DevOps white paper ([internal link](https://gitlab.com/gitlab-com/www-gitlab-com/-/blob/master/source/resources/downloads/gitlab-concurrent-devops-whitepaper.pdf)) ([gated link](https://about.gitlab.com/resources/whitepaper-concurrent-devops/)) |
| How do I keep up to date with industry trends? | - Review and subscribe to the following blogs: [Hacker News](https://news.ycombinator.com/), [Martin Fowler](https://martinfowler.com/), and [New Stack](https://thenewstack.io/) |

## Why GitLab?

GitLab field team members must be able to clearly articulate a compelling, differentiated, value-driven message to customers, prospects, and partners.

| **Topic** | **Resource(s)** |
| ------ | ------ |
| What is GitLab? | - [GitLab Explainer Video](https://www.youtube.com/watch?v=-_CDU6NFw7U) (Oct 2020, 1.5 minutes) <br> - [GitLab infomercial](https://youtu.be/gzYTZhJlHoI) featuring David Astor (Feb 2020, 5.5 minutes) |
| GitLab is THE DevOps Platform | - [The DevOps Platform customer deck (Enterprise)](https://docs.google.com/presentation/d/1vtFnh8DU6ZZzASTHg83UrhM6LJWqo5lq9mJDAY2ILpw/edit?usp=sharing) (internal only)<br> - [The DevOps Platform Customer Deck e-learning course](https://gitlab.edcast.com/insights/ECL-be96cce1-0d72-48e5-a744-f4f1260e8533) (30 minutes)<br> - [DevOps Platform Message House](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/devops-platform/message-house/) |
| Key value drivers and differentiators | - Review the [Command of the Message](/handbook/sales/command-of-the-message/) page <br> - [Operational Efficiencies](https://youtu.be/8z1ek4Qwnqw) (May 2020, 32 minutes) <br> - [End to End Visibility & Insights](https://youtu.be/cduwGbXOScY) (Apr 2020, 31 minutes) <br> - Understand the [3 types of differentiators: Unique, Comparative, and Holistic](https://www.forcemanagement.com/seller-blog/articulating-differentiation-5-ways-to-trap-the-competition)|
| Positioning GitLab | - [FY24-Q2 Revenue Play: GitLab AI](https://youtu.be/BCfuWuUodQQ) (May 2023, 30 minutes) <br> - [Winning with Value Stream Assesments](https://youtu.be/Bl4f87W-S0Y) (Mar 2023, 30 minutes) <br> - [FY24-Q1 Revenue Play - Achieving Efficiencies via Toolchain Consolidation](https://youtu.be/Hii30ErvqE8) (Mar 2023, 25 minutes) <br> - [FY23-Q4 Product Spotlight: Winning with Ultimate](https://youtu.be/z2jLBwUcrDg) (Dec 2022, 30 minutes) <br> - [Strategic Selling & ROI](https://youtu.be/lkUOd-lzU8I) (Nov 2022, 30 minutes)  <br> - [Solution Selling](https://youtu.be/VrECy8sWDJc) (Mar 2022, 25 minutes)  <br> - GitLab customer deck ([presentation](https://docs.google.com/presentation/d/1SHSmrEs0vE08iqse9ZhEfOQF1UWiAfpWodIE6_fFFLg/edit?usp=sharing)) <br> - GitLab customer deck [video](https://youtu.be/UdaOZ9vvgXM) (Dec 2019, 28 minutes) <br> - GitLab Sales Kickoff 2020: Articulating and Selling the GitLab Vision & Customer Journey ([slides](https://drive.google.com/open?id=14kO1iTqSwuvV-7CDHThslUv8_QP_EnaZg4yG-1romZc)) ([video](https://www.youtube.com/watch?v=DtL38mgpycE)) (Feb 2020, 37.5 minutes) <br> - [GitLab value prop messaging](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/messaging/#gitlab-value-proposition) <br> - [Pitch deck](/handbook/customer-success/professional-services-engineering/positioning/#pitch-deck) <br> - [Delivering the GitLab pitch deck](https://drive.google.com/open?id=1vRgU1o-o4kcOblQCxNi3h6xrN7KQZY1H) (Apr 2019, 14 minutes) <br> - [Removing Software Bottlenecks](https://www.youtube.com/watch?v=RT-fKTFevEY) (Mar 2019, 30 minutes) <br> - [Forrester Total Economic Impact Report](https://youtu.be/J_6QgemCz2E) (July 2020, 60 minutes) <br> - [Demystifying the Metrics Conversation](https://youtu.be/dbB6gzNYsG8) (Aug 2020, 30 minutes) |
| What customer ROI models are available? | - [Forrester TEI Enablement (Study + Estimator)](https://youtu.be/PBAjRh8_Vsk) (Dec 2022, 30 minutes) <br> - [The New Simple ROI Calculator](https://youtu.be/cOW1C-penoY) (July 2022, 24 minutes) <br> - Check out the resources on [this page](/handbook/sales/command-of-the-message/metrics/#economic-metrics) |
| GitLab culture | - [GitLab Culture](/handbook/company/culture/) <br> - [GitLab Values](/handbook/values/) <br> - [This is GitLab video](https://www.youtube.com/watch?v=Mkw1-Uc7V1k) (Feb 2018, 3.5 minutes) <br> - [Everyone Can Contribute video](https://www.youtube.com/watch?v=V2Z1h_2gLNU) (May 2019, 3.5 minutes) |
| GitLab subscription model | - [How GitLab.com Subscriptions Work](https://www.youtube.com/watch?v=W-ZYi4H4XMM) (Jun 2019, 29 minutes) |
| GitLab vision | - Review [GitLab's Direction](https://about.gitlab.com/direction/#single-application) |
| Follow GitLab | - Review and subscribe to the [GitLab blog](https://about.gitlab.com/blog/) |

## Competition

To maximize opportunities, GitLab field team members must demonstrate the knowledge and ability to beat out various competitors.

| **Topic** | **Resource(s)** |
| ------ | ------ |
| Who are GitLab's competitors? | - [GitLab Comparison Page](https://about.gitlab.com/why-gitlab/) |
| What is Competitive Intelligence? | - Check out the [Handbook page](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/competitive-intelligence/) |
| Microsoft Azure DevOps | - [Competing against Microsoft for Plan - Azure Boards](https://youtu.be/IRC6CFUfO-Y) (Jun 2021, 30 minutes) <br>- [Q2 FY22 Microsoft Competitive Update](https://youtu.be/TtisyWQ9rE8) (Jun 2021, 30 minutes) <br> - [Q3 FY21 Microsoft Competitive Update](https://youtu.be/fOeLdLwAgOI) (Sep 2020, 27 minutes) <br> - [Proactively Competing Against Microsoft](https://docs.google.com/presentation/d/1WUdzaNn-tgm3Pa1W3JQyGjcR9JOR2a0rLUTA7zRNIt8/edit?usp=sharing) presentation (SKO 2020, internal only) <br> - [Proactively Competing Against Microsoft](https://www.youtube.com/watch?v=Ds_U8iiUOz8) private video (Feb 2020, 58 minutes) |
| GitHub | - [Winning Against Github](https://youtu.be/FKtbXfHMVBA) (Jan 2023, 30 Minutes) <br> - [GitHub Tiers & Support](https://youtu.be/HY1bffR8Kfc) (May 2020, 30 Minutes) <br> - [GitHub Competitive Update](https://youtu.be/1iMBhe0wUdI) (Apr 2020, 26 minutes) |
| Jenkins | - [Proactively Competing Against Jenkins](https://drive.google.com/open?id=1IvftLfaQyKn5-n1GLgCZokOoLU-FFzQ8LfJ9cf0FVeg) presentation (SKO 2020, internal only) <br> - [Competing Against Jenkins and CloudBees](https://youtu.be/a95DQqRTOHw) (Sep 2019, 25 minutes) <br> - [Jenkins: Competitive Overview](https://www.youtube.com/watch?v=_HJMtp-fcHc) (Feb 2019, 31 minutes) <br> - [Jenkins: Overcoming Objections](https://www.youtube.com/watch?v=qrENxT9iPvE) (Mar 2019, 26 minutes) <br> - [GitLab vs Jenkins, where is GitLab weaker?](https://www.youtube.com/watch?v=3Wr3O6mY5VE) (Feb 2019, 25.5 minutes) |
| Where may one find additional competitive insights? | - [How GitLab Competes with Snyk](https://youtu.be/SzAbgQGQ8Wg) (Oct 2022, 30 minutes) <br> - [Q1 FY22 Competitive Update](https://youtu.be/WzxQjr94mOM) (Feb 2021, 30 minutes) <br> - [GitLab's Competitive Intelligence Resources Page](https://about.gitlab.com/devops-tools/) is the single source of truth for competitive sales resources organized by competitor <br> - [Compete page overview and launch to sales](https://www.youtube.com/watch?v=S_z_hgf3ASc&feature=youtu.be) (June 2020, 27 minutes)  |

## GitLab Portfolio

GitLab field team members must understand how various elements of the GitLab portfolio (offering tiers, SDLC phases, services, training, etc.) solve customer challenges.

| **Topic** | **Resource(s)** |
| ------ | ------ |
| What is GitLab's product strategy?  | - [GitLab Dedicated](https://gitlab.highspot.com/items/6478cd2f94e64c47fe04e6f5)  (Jun 2023, 30 minutes) <br> - [Automated Software Delivery (AutoSD) Integrated Campaign](https://youtu.be/Eq-DdOGkAlk) (Aug 2022, 21 minutes) <br> - [Positioning & Selling GitLab.com](https://youtu.be/mCqC6btgQBc) (June 2022, 26 minutes) <br> - [15.0 Release](https://youtu.be/gGMJZo40CjE) (May 2022, 18 minutes) <br> - [GitLab acquires Opstrace](https://youtu.be/l1HWrdUJdjs) (Dec 2021, 20 minutes) <br> - [Breaking Changes in 14.0 - AMA with Product & Customer Success](https://youtu.be/k-wvJtL_NeM) (Jun 2021, 30 minutes) <br> - [Positioning Verify & Product Vision](https://youtu.be/zKmD4i80tdg) (Mar 2021, 30 minutes) <br> - [GitLab Direction](https://about.gitlab.com/direction/) <br> - [Advantages of a single application](/handbook/product/categories/gitlab-the-product/single-application/) <br> - GitLab Sales Kickoff 2021 Product Keynote: A Winning Product for Peak Performance ([slides](https://docs.google.com/presentation/d/1NunKRuZBnDcZi0k_N5-NQBvdy5X5ZaV4a1Qf7w126qs/edit?usp=sharing)) ([video](https://gitlab.edcast.com/insights/ECL-a4010292-8e12-435f-a971-b3a6f3a121c7)) (Feb 2021, 88 minutes) |
| What are GitLab's product tiers? | - [GitLab Tiers](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/tiers/) <br> - [Why GitLab Ultimate?](https://about.gitlab.com/pricing/ultimate/) <br> - [Why GitLab Premium?](https://about.gitlab.com/pricing/premium/) <br> - [Feature comparison](https://about.gitlab.com/pricing/feature-comparison/) <br> - [The Journey to Ultimate](https://youtu.be/d3tkGHBFaRM) (Nov 2021, 48 minutes) <br> - [How to upgrade your customer to a higher tier](https://www.youtube.com/watch?v=8ZpU7PZzFyY) (Jul 2019, 26 minutes) <br> - [Discovery Questions for Selling GitLab Ultimate and GitLab Premium](/handbook/sales/qualification-questions/#questions-for-selling-gitlab-premium-and-ultimate) <br> - [Seven Ways GitLab Premium will Accelerate Customer Development](https://www.youtube.com/watch?v=aHUNPmzzusg&feature=youtu.be) (July 2020, 40 minutes) |
| How is GitLab priced? | - [Pricing page](https://about.gitlab.com/pricing/) <br> - [Pricing model](/handbook/company/pricing/) in the Handbook |
| What are the GitLab customer use cases (solutions)? | - Check out the [Customer Use Cases Handbook page](/handbook/marketing/use-cases/) <br> - [Use Case Driven Go To Market (GTM)](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/) |
| Where may I learn about the Version Control & Collaboration use case / solution (formerly Source Code Management (SCM))? | - Check out the [Version Control & Collaboration Handbook page](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/version-control-collaboration/) <br> - [The GitLab Journey & The SCM Use Case](https://www.youtube.com/watch?v=GN891Bqc6QY) (Mar 2020, 27 minutes) |
| Where may I learn about the Continuous Integration (CI) customer use case / solution? | - Check out the [Continuous Integration (CI) Handbook page](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/ci/) <br> - [The GitLab Journey & The CI Use Case](https://www.youtube.com/watch?v=JoeaTYIH5lI) (Mar 2020, 30 minutes) <br> - [Forrester Wave Cloud CI Report: What It Means to GitLab Sales, Customers & Prospects](https://youtu.be/q6YXIvHZuDU) (Oct 2019, 32 minutes) <br> - Complete the Continuous Integration Customer Use Case learning path in [Level Up](https://levelup.gitlab.com/access/saml/login/internal-team-members?returnTo=https://levelup.gitlab.com/learn/course/continuous-integration-customer-use-case) (internal only). <br> - Just want to take the knowledge check quiz? [Click Here](https://forms.gle/SYcjEptqKyfohUHx7) |
| Where may I learn about the DevSecOps customer use case / solution (aka Shift Left Security)? |  - Check out the [DevSecOps Handbook page](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/devsecops/) <br> - Complete the DevSecOps Customer Use Case learning path in [Level Up](https://levelup.gitlab.com/access/saml/login/internal-team-members?returnTo=https://levelup.gitlab.com/learn/course/devsecops-customer-use-case) (internal only) <br> - Just want to take the knowledge check quiz? [Click Here](https://forms.gle/hkta3uDUpki52BGD8) |
| Where may I learn about the DevOps Platform customer use case / solution? | - Check out the [DevOps Platform Handbook page](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/devops-platform/) <br> - [GitLab AutoDevOps Run Click-Through Demo](https://www.youtube.com/watch?v=V_6bR0Kjju8) (Apr 2019, 21 minutes) <br> - Complete the DevOps Platform Customer Use Case learning path in [Level Up](https://levelup.gitlab.com/access/saml/login/internal-team-members?returnTo=https://levelup.gitlab.com/learn/course/devops-platform-customer-use-case) (internal only). |
| Where may I learn about the GitOps customer use case / solution? | - Check out the [GitOps Handbook page](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/gitops/) <br> - Watch [The GitLab Journey & the GitOps Use Case](https://youtu.be/Ap14indu2-w) (July 2020, 30 minutes)  |
| Where may I learn about the Agile Planning customer use case / solution? | - Check out the [Agile Planning website page](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/agile/) (Handbook page coming soon) <br> - [Agile Project & Portfolio Management on GitLab Click-Through Demo](https://www.youtube.com/watch?v=Eo8pFoE6DjU) (Jun 2019, 30 minutes) |
| Are additional customer use cases / solutions being considered and/or developed? | - Yes, check out the [Customer Use Cases Handbook page](/handbook/marketing/use-cases/) for the latest and greatest information |
| What about services? | - [Positioning Professional Services](https://youtu.be/vFr86T4MFCE) (Apr 2023, 29 minutes) <br> - Professional services, available through GitLab or partners, help to optimize your organization's adoption of GitLab, continue to leverage the tools your teams use every day, facilitate your transition to GitLab, and deliver hands-on training to accelerate your team's adoption <br> - [Q1 FY23 Professional Services Update](https://youtu.be/_UUhi2A2Biw) (Mar 2022, 25 minutes) <br> - [GitLab Value Stream Assesments](https://youtu.be/jfM3AG6dBFY) (Feb 2022, 29 minutes) <br> - [Services to Accelerate Customer Adoption](/handbook/customer-success/professional-services-engineering/sales-enablement/) <br> - [How to engage Professional Services to help you sell and scope](/handbook/customer-success/professional-services-engineering/working-with/) <br> - [Professional Services Full Catalog](https://about.gitlab.com/services/catalog/) <br> - [The Value of Professional Services: A CFOs Perspective](https://youtu.be/arF-6BBRAxU) (Aug 2020, 29 minutes) <br> - [Professional Services Offerings & Positioning](https://www.youtube.com/watch?v=_04S2JhVZ5A) (Apr 2020, 29 minutes) <br> - [Selling Services to Accelerate Customer Adoption](https://youtu.be/ngTI5-1cQK4) (Oct 2019, 28 minutes) |
| What about GitLab security? | - [Solution Selling: Compliance](https://youtu.be/sGSZlxGciiE) (Apr 2022, 29 minutes) <br> - [Product Stage Direction - Secure](https://about.gitlab.com/direction/secure/) <br> - From SCM and CI to Security: Paths to Ultimate ([slides](https://docs.google.com/presentation/d/1VTCfKcAZ4NS2xQu8C-fA6pugCdvUbb0MfQhimLiAGak/) from GitLab Sales Kickoff 2020) <br> - [How GitLab Helps Customers Achieve Compliance](https://youtu.be/MRaCKYDXmuI) (May 2020, 26 minutes) <br> - [Forrester Software Composition Analysis (SCA) Wave & Security Q&A](https://www.youtube.com/watch?v=FIfZCg02G3o) (Apr 2019, 30 minutes) <br>- [GitLab SOC2 Security Compliance](/handbook/security/security-assurance/security-compliance/certifications/) |
| What about GitLab testing capabilities? | - [Pipeline Security Direction Handbook pages](/handbook/product/categories/#pipeline-security-group) <br> - [Verify:Pipeline Security Category Vision and Positioning](https://youtu.be/Zisa9Qfh8v8) (Sep 2021, 26 minutes) |
| What are the most common technical questions that GitLab sales team members should be able to answer? | - Check out the [Technical Questions for Sales](/handbook/sales/training/technical-questions-for-sales/) page |
| Where can I learn about GitLab High Availability, Data Resiliency and Performance? | - Check out the [Operational Efficiencies & Flexible Hosting Options with Gitaly Cluster](https://youtu.be/zI1t0IyHayM) video. (Dec 2021, 30 minutes) |
| Where can I learn about GitLab Cloud Licensing? | - Check out the [GitLab Cloud Licensing Update](https://youtu.be/A5IOhI-QPXY) video. (Mar 2022, 30 minutes) |

## Functional and Technical Skills & Processes

To optimize productivity, GitLab field team members must be able to consistently demonstrate the skills and behaviors (including adherence to standard processes and use of tools like Salesforce, Gainsight, and others) that lead to desired outcomes. These functional and technical skills and processes are complementary and in addition to GitLab's [Values](/handbook/people-group/competencies/#values-competencies) and [Remote Working](/handbook/people-group/competencies/#remote-work-competencies) competencies.

| **Topic** | **Resource(s)** |
| ------ | ------ |
| GitLab Sales Plays | - [FY23-Q3 Revenue Play: Winning with Ultimate](https://youtu.be/nBV-_LrTqKQ) (Aug 2022, 17 minutes) <br>- [Sales Play: GitLab Runner & CI](https://youtu.be/dzu7SojmPYo) (Feb 2022, 30 minutes) <br>- [Sales Play: Infrastructure Automation with GitOps](https://youtu.be/aXg3zGg54sg) (May 2021, 30 minutes) <br> - [GitLab Premium to GitLab Ultimate Sales Playbook Launch](https://youtu.be/UY-J-SHcCC8) (Apr 2021, 25 minutes)|
| Qualification Best Practices | - [Figuring out if you truly have an opportunity](https://youtu.be/S2MpIS18noM) (Dec 2020, 25 minutes)|
| What are the critical skills and behaviors needed to succeed in a field role at GitLab? | - [Field Functional Competencies](/handbook/sales/training/field-functional-competencies/) |
| What is social selling? | - [Social Selling Handbook page](/handbook/sales/training/social-selling/)<br>- [Social Selling Basics presentation](https://docs.google.com/presentation/d/1UCRF6PC6al8XxT8E_4rDKkQjkW6WGPA6gybWeuRIg7A/edit?usp=sharing) |
| How do I find out what version of GitLab my customers are using? <br> How do I find organizations in my patch using GitLab CE? | - [Version.GitLab.Com Walk-Through](https://www.youtube.com/watch?v=lBWwlbd1J5k) (Jul 2019, 8.5 minutes) |
| What does a good discovery call look like? | - [Anatomy of a Successful Discovery Call](https://youtu.be/maai4tuDtoM) (Jul 2019, 21 minutes) |
| How do I lead with insights? | - [Working with Analyst Relations](https://youtu.be/cJQkqr5CArg) (Jan 2023, 30 minutes) <br> - [Pipeline Creation - Leading with Insights](https://www.youtube.com/watch?v=fNiGq5uOxgo) (Nov 2019, 10 minutes) |
| How can I successfully engage with Channel / Alliance Partners? | - [FY24-Q1 Channel Program Update](https://youtu.be/oCNI17x9bC4) (Apr 2023, 30 minutes) <br> - [Co-Selling with Oracle Cloud Infrastructure](https://youtu.be/tqjIcVM0PpY) (Mar 2023, 20 minutes) <br> - [CDW & Arctiq - Partner Solution Showcase](https://youtu.be/5XjvEjjfC14) (Feb 2023, 21 minutes) <br> - [VMWare Partnership and Go-to-Market Approaches](https://youtu.be/Hx_QE65GDKA) (Sep 2022, 31 minutes) <br> - [Q3 FY23 Channel Update](https://youtu.be/7H4tJptEJ_Y) (Aug 2022, 30 minutes) <br>- [Alliance Technology Partner Solutions](https://youtu.be/KcytqAzgORM) (June 2022, 24 minutes) <br>- [Q1 FY23 Channel Update](https://youtu.be/pYRwkcYR9Xk) (February 2022, 30 minutes) <br>- [GitLab on IBM Power - Modernization](https://youtu.be/0c0CE3JWz0Q) (January 2022, 30 minutes) <br>- [GitLab & Service Now: Better Together](https://youtu.be/bUl1-mAmMY4) (August 2021, 30 minutes) <br>- [Q3 FY22 Channel Update: Overview of Partner Program & Sales Systems Changes](https://youtu.be/mwSnV5s_CsQ) (August 2021, 30 minutes) <br>- [Q2 FY22 Alliances Update: The Importance of Ecosystem Partners](https://youtu.be/lJfkkPeQtlI) (July 2021, 12 minutes) <br>- [Q2 FY22 Channel Program Update](https://youtu.be/sOx3WSscAF8) (May 2021, 30 minutes) <br>- [Co-selling with AWS](https://youtu.be/dKWjSjkhyE0) (Apr 2021, 30 minutes) <br>- [Co-selling with GCP](https://youtu.be/BOyE0NQxL90) (Mar 2021, 30 minutes) <br>- [GitLab & IBM - Better Together](https://youtu.be/E546ohLj-cQ) (Mar 2021, 30 minutes) <br>- [The GitLab / RedHat Partnership](https://youtu.be/dfjuUQp5Y90) (Jan 2021, 30 minutes) <br> - [Deal Registration Program and Working with Partners](https://youtu.be/8XyM4Z-0XLg) (Dec 2020, 30 minutes) <br> - [Maximizing Value of Partners in a Deal](https://youtu.be/ndrNX8fIIqs) (Nov 2020, 30 minutes) <br> - [Channel Partner Success for GitLab Sellers](https://youtu.be/OeykHQetd7U) (Jul 2020, 30 minutes) |
| How can I accelerate my pipeline with AWS? | - [AWS Alliances: New AWS Marketplace listing and upcoming Credit Promotion](https://youtu.be/JPP58JHObw8) (May 2022, 33 minutes) <br> - [Best Practices for Co-Selling with AWS](https://youtu.be/FXo89JVefoU) (Feb 2022, 25 minutes) <br> - [Accelerating Your Pipeline with AWS for GitLab Sellers](https://youtu.be/iPDPtOUuNls) (Sep 2020, 30 minutes) |
| How do I create a quote using Zuroa CPQ? | - [FY24-Q1 Sales Ops Update - Quote Studio](https://youtu.be/l46EeHRuVWw) (Feb 2023, 28 minutes) <br> - Take the Quote Studio eLearning course on Level Up [here.](https://levelup.gitlab.com/access/saml/login/internal-team-members?returnTo=https://levelup.gitlab.com/learn/course/cpq-x-quote-studio) |
| What is DocuSign and how do I use it? | - [Q2 FY22 Docusign Rollout](https://youtu.be/Dch4zaUQOeg) (May 2021, 18 minutes) |
| How do I forecast at GitLab? | - [Sales Forecasting at GitLab](/handbook/sales/forecasting/) |
| What is Chorus.ai and how do I use it? | - [Chorus Native Zoom Recent Changes](https://gitlab.com/gitlab-com/sales-team/field-operations/sales-operations/uploads/f8469097949b5143b32ac5bd50af6a8e/Chorus_+_Zoom_Native_Integration_FAQ__1_.pdf) <br> - [Zoom Desktop client vs. Browser client when using Chorus](https://docs.google.com/document/d/1zZuf_mFwFVq4z1nXOjPjrMgzD5alO3f1Rr8TVJ3anig/edit?usp=sharing) <br> - [Chorus FAQs: Stop & Start a Recording](https://help.zoominfo.com/s/article/How-to-Stop-Recording-a-Call) <br> - [Chorus.ai](https://www.zoominfo.com/products/chorus) is a leading conversation intelligence platform <br> - [How to find a call in Chorus](https://hello.chorus.ai/listen?guid=10c8460049f842e99477de4e9f2affca) (Jul 2019, 4 minutes) <br> - [How to review a call in Chorus](https://hello.chorus.ai/listen?guid=5fc22bca9ec04141a5245062b7907f09) (Jul 2019, 7 minutes) <br> - [How to comment and share moments in Chorus](https://hello.chorus.ai/listen?guid=199654f39cbd4fc69c00e839ea406930) (Jul 2019, 5 minutes) <br> - [How to gain compliance on recorded calls (primarily for NA)](https://hello.chorus.ai/listen?guid=6d8a5c1bcb364547bb8dc2eed8a5e6a5) (Jul 2019, 6 minutes) |
| Where do I learn about quarterly co-terms? | - [Quarterly Co-Terms May 2020 Update](https://youtu.be/CnLfeDhbzcM) (May 2020, 27 minutes) |
| How do I find customer references? | - [Q1 FY23 Customer References Update](https://youtu.be/X_RpwfJDuxE) (Mar 2022, 17 minutes) <br> - [Reference Edge - Customer Reference Process](https://youtu.be/8Le_Ovglnq8) video (Jan 2020, 25 minutes) |
| Presentation skills | - [How to Avoid Death by PowerPoint](https://www.youtube.com/watch?v=Iwpi1Lm6dFo) (20 minutes) |
| How should I work with the GitLab Legal team? | - [Basics of Legal Subscription Agreements](https://youtu.be/8cmfmqc6iag) (Sep 2022, 27 minutes) <br> - [Sales Guide: Collaborating with GitLab Legal](/handbook/legal/customer-negotiations/) |
| What are sales negotiation and closing best practices at GitLab? | - [Co-Selling Executive Business Reviews](https://youtu.be/1CL5YQeC8Fs) (September 2021, 30 minutes) <br> - [Negotiate to Close](/handbook/sales/negotiate-to-close/) Handbook page <br> - [Closing Best Practices](https://youtu.be/y3iLSsAD24s) (27 minutes, July 2020) <br> - [Deal Structure Best Practices](https://youtu.be/t55rDyNd0wE) (28 minutes, October 2020) |
| Proof of Value for SAs | - [Proof of Value Review](https://docs.google.com/presentation/d/1LpvXLtviKOlDay5p3XtgDsWDW8x8WS8_SF9qT13zkoU/edit#slide=id.g153a2ed090_0_63) |
| Customer Onboarding for Customer Success Managers (CSMs) | - [Customer Onboarding Custom Object Video](https://drive.google.com/file/d/17Y8LpYTaLwIByyd-BKN9e8u80oxaqFtt/view) (Nov 2019, 17 minutes) <br> - [Customer Onboarding Custom Object Deck](https://docs.google.com/presentation/d/1SBQ_FbCsPfycTxdtoracQTAh7WOpGPPAqptXfRiZdvc/edit#slide=id.g29a70c6c35_0_68) <br> - [Customer Onboarding SalesForce Dashboard](https://gitlab.my.salesforce.com/?ec=302&startURL=%2F01Z4M000000skrQ) |
| Gainsight for SAEs | - [Office Hours for Gainsight & Account Planning](https://youtu.be/lnEkbLnxs-8) (May 2021, 25 minutes) <br> - [Gainsight Overview](https://youtu.be/vXwsWB8zAXA) (May 2020, 6.5 minutes) <br> - [Gainsight Overview for Sales](https://youtu.be/mBdVeZJKthw) (Aug 2020, 27 minutes) <br> - [Gainsight View Only Licenses](https://youtu.be/RV205Ms0Mfs) (July 2020, 9 minutes) |
| Gainsight for CSMs | - [Using Gainsight within Customer Success](/handbook/customer-success/csm/gainsight/) Handbook page <br> [Success Plans](/handbook/customer-success/csm/success-plans/) Handbook page <br> - [Gainsight Foundations](https://education.gainsight.com/app/courses/ac66619f-2082-4305-a3cd-714cc242a320) (overview of the Gainsight NXT Platform and a brief demo of key capabilities) (26 minutes) <br> - [Gainsight Reports and Dashboards](https://education.gainsight.com/admin-reports-and-dashboards-horizon-analytics-nxt) (overview of how to leverage dashboards within the tool to make better decisions on managing your accounts) (19 minutes) <br> - [Calls to Action (CTA), Playbooks, and the Cockpit](https://education.gainsight.com/app/courses/1d2c358b-2aa8-4fae-b638-0bb4d0b9d932) (overview of Calls to Action (CTAs) in the Cockpit, the tool to manage customer outreach, as well as playbooks) (23 minutes) <br> - [360 View, Health Scores, and Timeline](https://education.gainsight.com/app/courses/f017fac0-8d28-4703-aaa2-87c865c5a52d) (overview of the 360 feature for research and call prep, Timeline for centralized note-taking, and an overview of health scores and trend insights) (34 minutes) <br> - [Sally Bot in Slack](https://education.gainsight.com/app/courses/471d5899-0af7-414f-a375-146c9ce5317d) (overview of what Sally is and how to use it) (15 minutes) |
| Other | - [Things I Wish I Knew During My First Few Quarters at GitLab](https://youtu.be/3gprWrDTEQM) video (Aug 2019, 25.5 minutes) <br> - Sessions (presentations, videos) from [GitLab Sales Kickoff 2021](https://gitlab.edcast.com/channel/sales-kickoff-sko-2021) <br> - Sessions from [GitLab Sales Kickoff 2020](/handbook/sales/training/sko/#sales-kickoff-2020) |
| Where can I go to learn more? | - Bookmark the [GitLab Sales Handbook](/handbook/sales/) <br> - [Upcoming and past Level Up sales enablement webcasts](/handbook/sales/training/sales-enablement-sessions/) <br> - [Customer Success Skills Exchange GitLab Unfiltered playlist](https://www.youtube.com/playlist?list=PL05JrBw4t0KorkxIFgZGnzzxjZRCGROt_) on YouTube <br> - Check out past [Customer Success meetings](/handbook/customer-success/#customer-success-meetings) where new features from recent product releases are discussed and/or demo'ed  |

## Field Enablement Spotlight Sessions

Live sales enablement sessions are held every Thursday from 12:00-12:30pm ET with the exception of the last two weeks of every quarter. Sessions are recorded and published to [Highspot](https://gitlab.highspot.com/items/6480e56aff37cbf397ac752f?lfrm=srp.2), made available for on-demand playback, and added to the inventory above. [Learn more here](/handbook/sales/training/sales-enablement-sessions/).

## Customer Success Skills Exchange

Live customer success enablement videocasts are held roughly every other Wednesday. Learn more by visiting the [Customer Success Skills Exchange Sessions](/handbook/sales/training/customer-success-skills-exchange/#past-sessions) Handbook page and/or check out the [Customer Success Skills Exchange playlist](https://www.youtube.com/playlist?list=PL05JrBw4t0KorkxIFgZGnzzxjZRCGROt_) on GitLab Unfiltered to watch past sessions at a location and time of your choosing.

## **Additional Notes**

- Learn about GitLab customer training on the [GitLab Training Tracks site](https://about.gitlab.com/learn/)
- Learn about the [weekly GitLab Field Enablement Spotlight series](/handbook/sales/training/sales-enablement-sessions/)
- Learn about the [weekly GitLab SDR Enablement webcast series](/handbook/sales/training/sales-enablement-sessions/)
