---
title: Collaborating with Community Programs
---

## 🌎 Overview

This enablement material is for GitLab team members seeking to collaborate with the Community Programs team in order to identify and assist customers who might benefit from GitLab's community programs.

## 🎯 Learning outcomes

By the conclusion of this session, participants will be able to:

- **Describe** GitLab's community programs and their functions
- **Identify** potential members of the GitLab for Education, GitLab for Open Source, and GitLab for Startups programs
- **Connect** program members with the appropriate resources/processes for those programs
- **Identify** opportunities for collaborating with the Community Programs team to assist GitLab customers
- **Employ** processes and best practices for engaging with the Community Programs team while working with GitLab customers
- **Locate** and **utilize** resources for interacting with the Community Programs team

## 📼 Recording

A [recording of this session](https://youtu.be/B75IPB5L4yI) is available for on-demand playback. Note that this video is private.

## 👋 Introduction

The Community Programs team supports communities that align with GitLab's CREDIT values by executing specific programs that help these communities grow and thrive. Our mission is to help these communities experience GitLab's vision of a world where everyone can contribute. Learn more about [Community Programs in the GitLab handbook](job-families/marketing/community-programs/).

## ❓ What is a community program?

GitLab's community programs aim to put GitLab's most powerful features in the hands of communities who may not otherwise have the means to access to them. Each program is unique in its organization and execution; however, in general, community programs offer GitLab customers benefits like:

- Complimentary subscriptions to GitLab Ultimate
- Direct lines of communication to GitLab team members
- Opportunities to partner with GitLab for presentations and events

Through these programs, we seek to raise awareness of GitLab in specific markets. We do this by partnering with members of these communities to spotlight (via case studies, articles, webcasts, and videos) ways they're using GitLab to achieve success.

## 🔎 Meet the programs

Learn more about GitLab's community programs and their respective DRIs in the [Community Programs handbook pages](/handbook/marketing/developer-relations/community-programs/#meet-the-programs).

## 📃 Rules of engagement

### Account and Opportunity Ownership

See point 13 on the [Go to Market Rules of Engagement Handbook page](/handbook/sales/field-operations/gtm-resources/rules-of-engagement/) for details on handling accounts with a Community Programs-related opportunity.

Please note that even if there is not a sales related opportunity on an account, all accounts must remain in the AE/SAE name. If a Community Programs-related opportunity is incorrectly in the AE/SAE name, please chatter @Sales-Support in SFDC for assistance with changing the owner to the proper Community Programs team member.

### Lead routing

GitLab does not currently have routing in place for leads related to Community Programs. If you are routed a lead that has contacted GitLab about a Community Program, please reply directly to the lead with the appropriate response whenever possible. Consider using one of [Community Programs' email templates](/handbook/marketing/developer-relations/community-programs/community-program-applications/email-and-zendesk-macros/#zendesk-macros-and-email-templates) to structure correspondence. Replying directly provides the optimal experience for the wider community member and the most efficient path for everyone.

Please use the [lead routing workflow](/handbook/marketing/developer-relations/community-programs/#inbound-sales-requests-routing-workflows) to determine the best course of action.

Please do not forward leads or emails from individual program members to Community Programs team members' personal email addresses. With 4,700 license holders (and growing), we are not able to provide efficient and optimal response times from personal email addresses.

## ♻️ Community program application cycle

In Q3FY23, Community Programs launched an automated system which allows wider community members to apply, receive verification, and obtain new or renewed subscriptions directly through a specific portal on `gitlab.customers.com`. After successful verification, applicants will receive a coupon code to use in the Community Self-Checkout Portal.

Below are details on the application process most pertinent to Sales team members. To learn about the application and renewal process in its entirety, please see the [Community Programs Applications Automated Workflow](/handbook/marketing/developer-relations/community-programs/community-programs-workflows/#automated-applications-workflow-overview) handbook page.

### Application

The Community Programs team uses a third party vendor, [SheerID](https://www.sheerid.com/), to host the application forms for its programs. More details are in the [Application](/handbook/marketing/developer-relations/community-programs/community-programs-workflows/#automated-applications-workflow-overview) section of the Community Programs handbook page.

Important points:

- If a community member's educational institution or country is not listed in the SheerID form, they should email education@gitlab.com and let us know.

- If a community member applying to the GitLab for Education Program believes they've been falsely rejected, they should contact SheerID per the instructions in the rejection email.

### Verification

SheerID provides automated verification for applications to the GitLab for Education Program, while the Community Programs Associate Program Manager manually reviews applications for the open source and startups programs. Additional details are in the [Verification](/handbook/marketing/developer-relations/community-programs/community-programs-workflows/#automated-applications-workflow-overview) section of the Community Programs handbook page.

Important points:

- For applications to the education program, the Community Programs team does not require proof of use case nor do we enforce it. The applying entity agrees to our legal terms—use case included—as described in the Education Program Agreement [Purpose section](/handbook/legal/education-agreement/#2-purpose).

- For applications to the open source program, the Community Programs team requires proof of use case at the time of application (new and renewing) in the form of a screenshot. The applying entity agrees to our legal terms—use case included—as described in the Open Source Program Agreement [2.Purpose & Eligibility Section](/handbook/legal/opensource-agreement/#2-purpose--eligibility). If a SAE/AE has concerns regarding potential violation of the use case, please contact our team in the #community-programs channel and provide the SFDC opportunity in question.

- In the case that a community program member no longer meets the program requirements, the Community Programs team works with the sales team to identify a path forward to transition from free to paid.

### Booking

After successful verification, program members receive a coupon code, which members then use in the Community Programs self-checkout portal on CustomerDOT to obtain their subscription license or renew. Additional details are in the [Booking](/handbook/marketing/developer-relations/community-programs/community-program-applications/) section of the Community Programs handbook page.

Add-ons or license-type changes cannot be made on through self-service. Program members need to [email the corresponding program](/handbook/marketing/developer-relations/community-programs/#meet-the-programs) with the request.

### Provisioning

Licenses will be provisioned directly during process via the WebDirect flow.

### Compliance

Sales Support and Billing Ops handle compliance. This phase results in granting the subscription license and notifying the customer of how to access the subscription.

### Renewal

Community program members need to renew their subscriptions annually.

Self-checkout renewal functionality on CustomerDOT launched in 2022-09. Program members use the same form for both new and renewing subscriptions. For renewal instructions please see the programs' respective [marketing pages](/handbook/marketing/developer-relations/community-programs/#meet-the-programs). Additional details on the renewal process are in the [Renewal](/handbook/marketing/developer-relations/community-programs/community-programs-workflows/#automated-applications-workflow-overview) section of the Community Programs handbook page.

Important points:

- For any inbound requests for renewals, direct the community member to the self-service instructions rather than forwarding an email or carbon copying an email to a community program team members' personal GitLab email address. Given the volume of program members, we cannot provide optimal service from our personal email addresses.

- At this time, the Community Programs team does not actively conduct outreach for renewals or manage renewal opportunities in SFDC. If the automatically generated renewal opportunity expires before the community program member reaches out for renewal, the SAE/AE has the option to request that the opportunity be closed-lost. No other action is required.

- Startup subscriptions are valid for one year only. Renewals must be paid after the initial 12-month, zero-dollar subscription license has expired. Special pricing does not exist. The community programs team does not actively route Startups program members to the sales team at this time.

### Support

Details on the Support workflow for Community Programs are in the [Support](/handbook/marketing/developer-relations/community-programs/community-programs-workflows/#automated-applications-workflow-overview) section of the Community Programs handbook page.

Important points:

- Program members do not receive Ultimate support with subscriptions granted through community programs. They are able to open a support ticket via the [GitLab Support Portal](https://about.gitlab.com/support/#issues-with-billing-purchasing-subscriptions-or-licenses) with errors involving the Community Self-checkout Portal on CustomersDOT or any errors relating to their subscription.

- If GitLab for Education applicants are having issues during the application or verification stages, they first contact SheerID as indicated in the [Support table](/handbook/marketing/developer-relations/community-programs/community-programs-workflows/#automated-applications-workflow-overview).

## 🤝 Engaging with the Community Programs team

You can engage with our team asynchronously by:

- Using our Slack channel, `#community-programs`
- Tagging us in account-related conversations on Salesforce
- Using our Slack channel, `#gitlab-for-campuses` for questions regarding the [GitLab for Campuses](/handbook/product/packaging-and-pricing/gitlab-for-campuses/) paid offering.

We are also happy to meet with you for synchronous coffee chats or join you for meetings with customers.
