---
title: "Sales Kickoff Planning"
description: "This page outlines the GitLab Sales Kickoff core team structure and planning process"
---

## Sales Kickoff Core Team

Sales Kickoff is too big to have a single DRI for everything. The Field Enablement leader is ultimately accountable for delivery of a successful, on-budget SKO and will be responsible for the following:

- Overall story arc
- SKO agenda
- CRO leader interlocks & communication
- SKO Ambassador program

See the [SKO 2023 parent epic](https://gitlab.com/groups/gitlab-com/sales-team/sales-kick-off/-/epics/10). Additional SKO responsibilities will be split into 3 sub-teams with category DRIs responsible for specific aspects of SKO as outlined below. The SKO core team will include the following sub-teams, all of which have supporting team members underneath them:

1. **Event Support & Logistics DRI**
    - See the [SKO 2023 Event Support & Logistics epic](https://gitlab.com/groups/gitlab-com/sales-team/sales-kick-off/-/epics/11) for additional details
1. **Content DRI**
    - See the [SKO 2023 Content epic](https://gitlab.com/groups/gitlab-com/sales-team/sales-kick-off/-/epics/13) for additional details
1. **Communications DRI**
    - See the [SKO 2023 Communications epic](https://gitlab.com/groups/gitlab-com/sales-team/sales-kick-off/-/epics/12) for additional details

The SKO core team also includes an executive sponsor (VP, Field Ops) with responsibilities that include:

- Champion and socialize CRO Leaders' POV in SKO planning conversations
- Ensure regular CRO leader check-ins with executives
- Help drive alignment across CRO leadership team
- Secure exec reviews (if/as needed)
- Help prioritize where exec review and approval is needed vs. when and where the team has autonomy to make decisions

## SKO Sub-Team Responsibilities

| Sub-Team | Responsibilities | Key Collaborators |
| ------ | ------ | ------ |
| Event Support & Logistics | - Brand / Design<br>- Budget management<br>- Venue details<br>- Partner Summit logistics<br>- F&B (onsite & offsite)<br>- Registration<br>- Run of show<br>- Event check-in<br>- Signage<br>- Mobile app<br>- Ancillary events (if applicable) | - Brand<br>- Field Enablement<br>- Channel Programs |
| Content | - Mainstage content<br>- Non-mainstage content<br>- Partner Summit content<br>- Awards & Compensation<br>- Production Video<br><br> ** *see additional details in the [Content Sub-Team Deeper Dive](/handbook/sales/training/sko/SKO-planning/#content-sub-team-deeper-dive) section below* | ** *see additional details in the [Content Sub-Team Deeper Dive](/handbook/sales/training/sko/SKO-planning/#content-sub-team-deeper-dive) section below* |
| Communications | - Comms plan<br>- Event copy<br>- Slack channels<br>- Survey planning & execution<br>- Post-event content sharing<br>- Event summary / wrap-up | Events |

### Content Sub-Team Deeper Dive

| Content Type | Responsibilities | Key Collaborators |
| ------ |  ------ | ------ |
| Mainstage | - Keynote content<br>- Customer and/or partner speaker sessions<br>- Motivational speaker | - Events<br>- Corp Comms<br>- Execs|
| Non-mainstage | - Role-based breakouts<br>- Birds of a Feather sessions | - Events<br>- Portfolio Marketing<br>- Field org |
| Partner Summit | - Partner Summit sessions<br>- Partner sponsorships | - Events<br>- Portfolio Marketing<br>- Field Enablement |
| Awards & Compensation | - Tracking final results<br>- Awards<br>- President's Club winners<br>- Comp Overview | - Events<br>- CRO leaders |
| Production Video | - Video for mainstage sessions <br>- Video content production for SKO and Partner Summit, Event recording, and Other | - Events<br>- Digital Production<br>- Field Enablement<br>- Channel |

## Managing SKO Work

Scheduling and logistics are managed in a [Sales Kickoff (SKO) 2023 Agenda & Logistics](https://docs.google.com/spreadsheets/d/1aHNxXv432TdXoMt_BDt39hMH5PDE8si0OErl1fVmrxw/edit#gid=1074572255) Google sheet, while actual work is managed in GitLab.

SKO work within GitLab is managed in epics and issues (see [SKO 2023 meta epic](https://gitlab.com/groups/gitlab-com/sales-team/sales-kick-off/-/epics/10)). Sub-team DRIs are empowered to manage their child epics and issues as they see fit.

The Sales Kickoff (SKO) 2023 Agenda & Logistics Google sheet contains:

1. SKO Mainstage Agenda
1. SKO Breakout Schedule
1. Partner SKO schedule
1. Ancillary Events schedule
1. SKO Planning Timeline
1. Due Dates
1. SKO Planning GitLab Directory (links to the relevant Epics & notes docs for SKO planning for ease of use)

The sub-team DRIs are responsible for maintaining the efficacy of this document unless there is a core team member directly responsible for all of the contents of a tab (i.e. Partner Summit, Ancillary Events, Breakouts).

## SKO Planning Meetings & Cadence

The SKO planning team has one 50-minute planning meeting that includes ALL DRIs and sub-DRIs + team members leading planning and content for keynote sessions.

- SKO Core Team Weekly Meeting
  - Q2: Monthly
  - Q3: Weekly
  - Q4: 2x weekly (consider making one occurrence 25 min)

In addition, the SKO planning team delivers CRO Leader Status Updates in the following cadence:

- Q3 (September 2022): SKO 2022 planning overview, high-level objectives, theme, and draft agenda discussion
- Q3 (October 2022): SKO theme confirmation and messaging hierarchy kickoff (detailed goals & objectives)
- Q4 (Nov-Jan): Bi-weekly progress reviews

## SKO "Call for Content"

In order to drive relentless prioritization based on GitLab Sales Kickoff (SKO) theme/sub-themes/goals, gather content in a timely manner and secure executive consensus early, the SKO Core Team implements a "Call for Content" for SKO breakout sessions. A secondary benefit of this process is that it gives [Field Enablement](/handbook/sales/field-operations/field-enablement/) a strong backlog of well-rounded training and enablement topics for topic submissions not selected or prioritized for SKO (e.g. webcast topics, etc.) in future months/quarters to support continuous education initiatives for the field organization. There are two types of breakout sessions:

1. **Role-Based Breakout Sessions:** Teaching skills and behaviors aligned to specific role(s) within the organization.
   1. Submit a role-based breakout session idea [using this issue template](https://gitlab.com/gitlab-com/sales-team/field-operations/enablement/-/issues/new?issuable_template=SKO-call-for-content-role-based-submission)
1. **"Choose Your Own Adventure" Breakout Sessions:** Allow attendees to step out of the role-based breakout experience and select from a list of breakout topics for the final breakout. These topics can be a deep-dive into a keynote topic (ex. diving into a feature that Product discussed in their keynote) or a broader topic or soft-skill (ex. DIB in Sales, Project Management, etc.).
   1. Request a topic or focus for a "Choose Your Own Adventure" breakout [using this issue template](https://gitlab.com/gitlab-com/sales-team/field-operations/enablement/-/issues/new?issuable_template=SKO-call-for-content-choose-adventure-submission)

Note that we will also use the Call for Content submission form for Mainstage sessions to tease out the learning objectives and outlines, but we will not implement a formal selection process as there is already a prescriptive "formula" for which speakers/teams give keynotes.

### High Level Process

Field Enablement Program Managers send a "Call for Content" for their relevant segment areas (ENT, COMM, Customer Success, Channel & Alliances) and give DRIs/team members 3 weeks to send in submissions. Submissions are then prioritized based on a set list of criteria and relevance to the SKO theme. Any sessions not chosen are put into a backlog for consideration in fast-follow enablement/reinforcement activities following SKO. Please see below for a more detailed overview of the process.

### SKO Breakout "Call for Content" Process

Below are the activities that Field Enablement Managers and Sales Kickoff (SKO) DRI collaborate on as a part of the "Call for Content" for SKO breakout sessions. This process begins no later than three months before SKO.

1. Field Enablement Program Managers to meet with segment VPs and determine on what types of content (topic, format, etc.) to solicit in their Call for Content.
1. Field Enablement Program Managers open their segment's "Call for Content" and socialize it in relevant meetings/Slack channels.
1. Call for Content stays open for 3 weeks.
1. Call for Content submissions for role-based breakout sessions are made via the [SKO Call for Content Submission issue template](https://gitlab.com/gitlab-com/sales-team/field-operations/enablement/-/issues/new?issuable_template=SKO-call-for-content-role-based-submission)
1. Call for Content submissions for "Choose Your Own Adventure" breakout sessions are made via the [SKO Call for Content Submission issue template](https://gitlab.com/gitlab-com/sales-team/field-operations/enablement/-/issues/new?issuable_template=SKO-call-for-content-choose-adventure-submission)
1. Submissions are managed on [this issue board](https://gitlab.com/gitlab-com/sales-team/field-operations/enablement/-/boards/3428335?scope=all&label_name[]=sko%20content%20submission) with the following labels for organization:
   1. Static labels: ~field enablement ~field events ~FE priority::1 ~sko ~sko content submission
   1. Scoped labels: ~sko content::triage, ~sko content::accepted, ~sko content::deferred, ~FE status::triage
1. Once Call for Content closes, Field Enablement Program Managers review the submissions and choose top submissions based on the selection process outlined below.
1. Field Enablement Managers notify DRIs of chosen submissions and begin working with them on next steps to further build out session content.
1. Label for these accepted issues changes to ~sko content::accepted and ~FE status::wip
1. Field Enablement Managers notify DRIs for submissions not chosen. Issues for all submissions that are not chosen (and are viable, i.e. not a partial/irrelevant submission) are moved into the Field Enablement Backlog where they can be considered for upcoming enablement initiatives.
   1. ~sko content::deferred and ~FE status::backlog

### Selection Criteria & Process

Below is are the criteria used to select submissions for SKO breakout sessions.

**Criteria**

1. Content directly supports the [SKO objectives](/handbook/sales/training/sko/#sales-kickoff-sko-overview)
1. Proposed session is interactive and takes advantage of in-person modality
1. High content quality
1. Fresh content (not a rehash of old ideas or topics)
1. Session topic embodies the [GitLab values](/handbook/values/)
1. Content fits well in the landscape of all other topics being chosen (i.e. a blend of technical, functional/soft skill topics)

**Selection Process**

1. All Field Enablement Program Managers and the Field Enablement leader meet in a working session to review submissions for each segment and select the winning submissions based on the criteria.
   1. Note: Doing this in a working session vs. silo will help the team have healthy discussions around relevance and will uncover any areas of overlap.
1. Field Enablement Program Managers review/justify selections with their segment area VPs to ensure alignment.
