---
title: Corporate Security Onboarding 101 Guide
---

👋 Welcome to GitLab! We're glad you're here. The links on this page will help you get your laptop set up and access to the various systems that you will use to collaborate with other team members and start working on projects with your team.

## Need Help?

While it may seen a little bit overwhelming at the start, the Corporate Security Helpdesk team is here to make the process as easy as possible!

We host an *optional* weekly onboarding call every Tuesday (check your calendar) to help new team members with MacBook setup.

Please visit the [Corporate Security Support](/handbook/security/corporate/support) handbook page if you need help. For most questions, simply ask in the `#it_help` Slack channel.

## Laptop Ordering

- [Laptop Procurement for New Team Members](/handbook/security/corporate/services/laptops/onboarding)
- [Macbook Model Eligibility](/handbook/security/corporate/services/laptops/hardware#macbook-model-eligibility)

## Initial Setup

- [Apple macOS Setup](/handbook/security/corporate/systems/macos/setup)
- [Okta User Setup](/handbook/security/corporate/systems/okta/user/setup)
- [Google User Setup](/handbook/security/corporate/systems/google/user/user/setup)
- [Jamf MDM Enrollment](/handbook/security/corporate/systems/jamf/setup)
- [Okta Verify Setup](/handbook/security/corporate/systems/okta/verify/macos)
- [1Password User Setup](/handbook/security/corporate/systems/1password/setup)
- [Laptop VPN for Public Networks](/handbook/security/corporate/systems/vpn/setup)
- [Laptop Application and Software Standards](/handbook/security/corporate/services/laptops/software)
- [Laptop Security Configuration Standards](/handbook/security/corporate/services/laptops/security)
- (Internal) [System Configuration Standards](https://internal.gitlab.com/handbook/it/it-security/system-configuration/)

> **Using Linux?** If you're one of the very few team members using Linux, see the [Linux](/handbook/security/corporate/systems/linux) handbook page to get started.

## Productivity Guides

It is understandable if you're overwhelmed during onboarding. To get started in your first few weeks, simply access the following Okta application tiles to get started.

The links for each application below will take you to the step-by-step instructions. If you have any questions or problems accessing these applications, please reach out to `#it_help` in Slack for 24x5 support. You can also ask your manager, onboarding buddy, or anyone on your team for help.

### Collaboration Apps

- **[G Suite SSO Mail](/handbook/security/corporate/systems/google/mail/setup):** This is your work email account that uses a Gmail interface that you are likely already familiar with. We do not use Microsoft Outlook or Office 365 at GitLab. Please keep in mind that we rarely/never send emails internally and use Slack or GitLab issues to communicate with other team members.

- **[GitLab.com](/handbook/security/corporate/systems/gitlab/com/setup):** This will automatically provision your GitLab.com user account if you do not already have one. We use our own product to run the company day-to-day and you will spend a lot of time working with issues and merge requests. Your onboarding issue is the first issue assigned to you and will give you a feel for what to expect and how to use the [GitLab product](https://about.gitlab.com/features/).

- **[GitLab Internal Handbook](https://internal.gitlab.com):** We have an internal handbook that requires authentication for information that is not suitable for our public handbook. During your onboarding, you'll need to read through  the [confidentiality levels](/handbook/communication/confidentiality-levels/) and [data classification standard](/handbook/security/data-classification-standard/).

- **[Slack SSO](/handbook/security/corporate/systems/slack/setup):** This is where async collaboration happens at GitLab. If you're not familiar with [Slack](https://slack.com/help/categories/360000049043), it is group text messaging on steroids with all of our team members, vendors, and customers, and is similar to Microsoft Teams.

- **[G Suite SSO Drive](/handbook/security/corporate/systems/google/drive/setup)** This is where our meeting notes are stored at (aka agenda docs), spreadsheets, and slide decks. All of these documents are saved in Google Drive that is managed by Corporate Security so data is saved securely in the cloud and not locally on team member laptops. We do not use Microsoft Word, Excel, PowerPoint, or SharePoint at GitLab.

- **[Google Calendar](/handbook/security/corporate/systems/google/calendar/setup)** We use Google Calendar for all meeting invitations and integration with various services including [Paid Time Off](/handbook/people-group/paid-time-off/) events.

- **[Zoom SSO](/handbook/security/corporate/systems/zoom/setup):** You will be invited to several Zoom calls in your first week. Be sure that your microphone, headphones, and camera are configured.

### Employment Apps

As you complete your employment onboarding tasks, you may also need to access these applications.

- **[Workday SSO](/handbook/people-group/workday-guide/):** This is our Human Resources Information Systems (HRIS) where all of your employment and benefits information is managed.

- **[Level Up SSO](/handbook/people-group/learning-and-development/level-up/):** This is our learning management system (LMS) that has professional development and product training courses to learn more about various topics.

- **Will Learning:** Compliance training learning management system (LMS) for some courses

- **[Navan SSO](/handbook/business-technology/enterprise-applications/guides/navan-expense-guide/):** This is our [expense reporting](https://internal.gitlab.com/handbook/finance/expenses/) and travel booking system for most countries.

- [Payroll Provider](https://internal.gitlab.com/handbook/finance/payroll/#legal-entity-payroll-providers)

### Accessing Documents and Files

Each team has one or more Google Drive folders or shared drives that will be shared with you. Please ask your onboarding buddy or manager for a tour of where they create and access documents at.

### Additional Documentation

We have documentation for many of our systems on the [Corporate Security Systems](/handbook/security/corporate/systems) handbook page.

## Getting Help

- [Corporate Security Systems](/handbook/security/corporate/systems)
- [Corporate Security Support](/handbook/security/corporate/support)
- Ask in the `#it_help` Slack channel
