---
title: "Trust & Safety Team Frequently Asked Questions"
---

<link rel="stylesheet" type="text/css" href="/stylesheets/biztech.css" />

## Overview

Below is a list of Frequently Asked Questions.

### Account Reinstatements

{{% details summary="What do I do if my account has been blocked?" %}}

1. ![Account_blocked](../images/Account_blocked.png)
1. You can open an Account Reinstatement request with [GitLab Support](https://support.gitlab.com/hc/en-us/requests/new)
   - Select `GitLab.com (SaaS) user accounts and login issues` and complete the form.
1. Wait for feedback from the support team.
{{% /details %}}

### DMCA Requests

{{% details summary="I received a DMCA request and my Account is Blocked?" %}}

1. If you received a DMCA request for your account,  you can do one of the following.
   - Review the request and determine whether or not you would like to submit a counter notice.
   - If you want to submit a counter notice, visit the `Intellectual property on gitlab.com`page.
   - Alternatively, you can agree to remove the copyright content from your account immediately.
{{% /details %}}

### Trademark Requests

{{% details summary="I received a Trademark request and my Account is Blocked" %}}

1. Should you receive a Trademark take down request, you can do one of the following.
   - Agree to submit proof that you own the rights to use  the reported Trademark.
   - Alternatively, you can agree to speedily remove the trademark content from your account.
{{% /details %}}

### Reported or Blocked Accounts

{{% details summary="My account was reported for abuse, what can I do?" %}}

1. Should your account be blocked, continue to reach out to the GitLab support team to have your account reinstated.
{{% /details %}}

{{% details summary="My account was blocked for no reason" %}}

1. If you notice that your account was blocked, you can;
    - Reach out to GitLab Support to obtain more information on getting the block removed.
{{% /details %}}

{{% details summary="My account was blocked soon after signing up" %}}

1. If your account gets blocked soon after signing up, you can;
   - Reach out to GitLab Support to obtain more information on getting the block removed.
{{% /details %}}

### Security Research

{{% details summary="Can I host Security Research tools?" %}}
Making use of GitLab.com services to deliver malicious executables or as attack infrastructure is prohibited under the [GitLab Website Terms of Use](https://about.gitlab.com/terms/) (**Section 3, "Responsibility of Website Visitors"**).

We do however understand that making such technical details available for research purposes can benefit the wider community, and as such it will be allowed if the content meets the criteria set out on our dedicated`Abuse on gitlab.com` page.
{{% /details %}}

### Security Testing

{{% details summary="Can I perform Security Testing on GitLab.com?" %}}
When researching security issues, especially those which may compromise the privacy of others, you must use only test accounts in order to respect our users' privacy. Any attempt at accessing private information of other users, performing actions that may negatively affect GitLab's users or disrupt GitLab operations will result in the account being blocked.

Security, or any, testing that could cause disruption on GitLab.com or be in violation of our Website Terms of use can be researched freely on your own installation of GitLab. GitLab is an open-core company, with the source code powering gitlab.com available at `https://gitlab.com/gitlab-org/gitlab-foss` and `https://gitlab.com/gitlab-org/gitlab`. You are encouraged to install your own standalone instance for researching vulnerabilities. Screen captures, logs, and videos showing vulnerabilities against your own GitLab installation are encouraged.

Examples of disruptive activity include, but are not limited to:

1. Port scanning
1. Intrusion Attempts
1. Denial of Service Attack

When testing on GitLab.com, your `@wearehackerone.com` address must be associated with the testing gitlab.com user account. If separate accounts are necessary, you can use an alias. This will help us separate testing from other forms of abuse, and help inform the decision of blocking an account. Note that this does not provide immunity, and the [Rules of engagement](https://hackerone.com/gitlab?type=team) must be followed at all times.
{{% /details %}}

### Reporting Abuse

{{% details summary="Someone is spamming my account, what should I do?" %}}

1. If a user account is spamming your`Issues`, `Snippets` or `Merge Requests`, you can;
   1. Report the comment using the **drop down** menu at the top right of the comment,
   1. Then select, `report abuse to gitlab admin` and complete the report.
       - A member of our team will review the report.
{{% /details %}}

{{% details summary="How can I report Abuse?" %}}

1. There are various ways you can report user generated abuse to GitLab.
    1. Use the `Report Abuse` button at the top right of the user profile which you are reporting.
    1. Use the `Report abuse to gitlab admin` dropdown menu on `comments`, `Merge Requests` and issues.
    1. If you would like to submit more detailed information, you can always send an email to abuse@gitlab.com where a member of our team will review your report.
{{% /details %}}

{{% details summary="Someone is using my copyright work, what should I do?" %}}

1. If someone is using your copyright work and do not have sufficient rights to do so, you can;
    1. Submit a complete DMCA notice to dmca@gitlab.com.
    1. You can find the details of the information required on our `Intellectual Property on gitlab.com` page.
{{% /details %}}

{{% details summary="How does GitLab treat Copyright or Trademark requests?" %}}

1. We take the intellectual property rights of others seriously and require that our Users do the same. The Digital Millennium Copyright Act (DMCA) established a process for addressing claims of copyright infringement. If you own a copyright or have authority to act on behalf of a copyright owner and want to report a claim that a third party is infringing that material on or through GitLab's services, please send a notice that meets the minimum requirements of the DMCA, to dmca@gitlab.com, and we will take appropriate action.
1. Disputes regarding namespaces, ownership and trademarks are not governed by DMCA. These disputes must be resolved by the parties involved. GitLab will never act as arbitrators or intermediaries in these disputes and will not take any action without the appropriate legal orders.
{{% /details %}}

### Existing Namespaces

{{% details summary="I want to use an existing namespace, can I claim it?" %}}

1. GitLab.com namespaces are available on a first come, first served basis and cannot be reserved. No brand, company, entity, or persons own the rights to any namespace on GitLab.com and may not claim them based on the trademark. Owning the brand "GreatCompany" does not mean owning the namespace "gitlab.com/GreatCompany". Any dispute regarding namespaces and trademarks must be resolved by the parties involved. GitLab Support will never act as arbitrators or intermediaries in these disputes and will not take any action without the appropriate legal orders.
{{% /details %}}

### Detailed Abuse Reports

{{% details summary="I want to report multiple accounts or types of abuse, how can I do this?" %}}

1. Should you want to report multiple accounts or URLs, it is recommended that you submit this information to abuse@gitlab.com.
    - Make sure that you include the `gitlab.com` URL(s) in your mail and a detailed description of the type of abuse you are reporting.
{{% /details %}}

### Report Abuse button(s)

{{% details summary="What happens when I press the `Report Abuse` button or `Report Abuse dropdown?" %}}

1. Using the `Report Abuse` or `Report Abuse to gitlab admin` button will open up a window where you can directly report a user for activity that is considered abusive or disruptive.
1. A member of our team will review your report and take appropriate action should the activity or content violate our terms of use.
{{% /details %}}

{{% details summary="How do I use the `Report Abuse` form?" %}}

1. The `Report Abuse` form consists out of a text box where you can include information about the type of abuse you are reporting.
1. You can use the report abuse button in different places on gitlab.com, you can either.
1. Report the user account
![Report_user](../images/report_user.png)
1. Report a comment/thread
![Report_Comment](../images/Report_Comment.png)
1. Report an issue
![Report_Issue](../images/Report_Issue.png)
1. Report Merge Request
![Report_MR](../images/Report_MR.png)
1. Email `abuse@gitlab.com`
    - For more detailed reports, you can email `abuse@gitlab.com`
{{% /details %}}

### Using a VPN

{{% details summary="Can I use a VPN to access my account?" %}}

1. Using a VPN is permitted, however using a VPN to access GitLab.com from a trade restricted area, could result in your account being blocked.
{{% /details %}}

### TOR Nodes

{{% details summary="Can I use my account using TOR Exit nodes?" %}}

1. TOR exit nodes are not recommended, as this could result in your account being blocked, or have problems using the platform.
{{% /details %}}
