---
title: "Intellectual property on gitlab.com"
---

<link rel="stylesheet" type="text/css" href="/stylesheets/biztech.css" />

## Overview

### DMCA - Digital Millennium Copyright Act

GitLab takes the intellectual property rights of others seriously and require that our users do the same. The Digital Millennium Copyright Act (DMCA) established a process for addressing claims of copyright infringement. If you own a copyright or have authority to act on behalf of a copyright owner and want to report a claim that a third party is infringing that material on or through GitLab's services, review the `Submitting a DMCA Notice` section further below.

### Trademark Policy

GitLab.com namespaces are available on a first come, first served basis. No one can claim priority rights to any namespace on GitLab.com based on a trademark registration. For example, owning the trademark for "GreatCompany" does not mean the trademark owner will be granted the namespace name "gitlab.com/GreatCompany" if it is already registered.

GitLab is not in a position to investigate, assess or adjudicate complicated trademark disputes between third parties. In these instances, contact the third party that you believe is infringing your rights to resolve the matter, or seek resolution by available legal means. GitLab cannot intervene in such matters without a valid legal order.

GitLab will only review a trademark infringement claim related to a namespace registered to a third party, and may intervene, where both of the below criteria are satisfied:

1. you provide evidence to GitLab's satisfaction that you are holder of a relevant trademark registration, and
1. you provide clear evidence to GitLab's satisfaction showing that unauthorized use is being made of your trademark such that there is an obvious intent to mislead others into believing that the relevant namespace is affiliated with your trademark.

Reports can be submitted to dmca@gitlab.com, and GitLab will review the evidence provided, and if it satisfies the above criteria, GitLab will take any action it deems appropriate.

### Namespace Policy

GitLab.com namespaces are available on a first come, first served basis and cannot be reserved. No brand, company, entity, or persons own the rights to any namespace on GitLab.com and may not claim them based on the trademark. Owning the brand "GreatCompany" does not mean owning the namespace "gitlab.com/GreatCompany". Disputes regarding namespaces and trademarks must be resolved by the parties involved. GitLab will never act as arbitrators or intermediaries in these disputes, and will not take any action without the appropriate legal orders.

### Account and Group Ownership Disputes

GitLab will not act as an arbitrator of Group or Account ownership disputes. Each user and group owner is responsible for ensuring that they are following best practices for data security.

As GitLab subscriptions are generally business-to-business transactions, in the event that a former employee has revoked company access to a paid group, please contact GitLab Support for recovery options.

### Name Squatting Policy

Per the GitLab Terms of Service:

Account name squatting is prohibited by GitLab. Account names on GitLab are administered to users on a first-come, first-serve basis. Accordingly, account names cannot be held or remain inactive for future use.

The GitLab.com Support Team will consider a [namespace](https://docs.gitlab.com/ee/user/group/#namespaces) (user name or group name) to fall under the provisions of this policy when the user has not logged in or otherwise used the namespace for an extended time. For more information, see the `Name Squatting` section further below.

### DMCA

#### Submitting a Notice

{{% details summary="Submitting a DMCA Notice" %}}
If you believe that someone is infringing on your copyright as the copyright owner, you can send a DMCA notice to dmca@gitlab.com.

A DMCA notice is a legal document, therefore GitLab requires you to submit a notice in the following format.

1. A description of the copyrighted work that you claim is being infringed;
1. A description of the material you claim is infringing and that you want removed or access to which you want disabled, and the URL or other location of that material;
1. Your name, title (if acting as an agent), address, telephone number, and email address;
1. The following statement: `"I have a good faith belief that the use of the copyrighted material I am complaining of is not authorized by the copyright owner, its agent, or the law (e.g., as a fair use)"`;
1. The following statement: `"The information in this notice is accurate and, under penalty of perjury, I am the owner, or authorized to act on behalf of the owner, of the copyright or of an exclusive right that is allegedly infringed"`; and
1. An electronic or physical signature of the owner of the copyright or a person authorized to act on the owner's behalf.

After your submission to dmca@gitlab.com, you should receive an automated confirmation of receipt.

#### What happens Next?

- Once your request is received, a member of our Trust and Safety Team will verify and process your notice.
- Notices with missing or inaccurate information cannot be processed. A member of the Trust and Safety team will reach out to you for more information.
- Should we verify that you have submitted the required information, you will receive a confirmation email from our team that your request has been processed.
  - If you have not heard from us, you are welcome to send a follow-up email requesting an update.
- Valid notices will be forwarded to the reported account owner, allowing them to submit a counter notice or remove the content from gitlab.com
- GitLab users, implicated by the notice, have the right to submit a counter-notice. If the counter-notice is deemed valid, we will forward it to you for further action.
- For more information on counter complaints, see the `Responding to a DMCA notice` section on this page.
{{% /details %}}

#### Responding to a DMCA Notice

{{% details summary="Submitting a DMCA Counter Notice" %}}
If it is not possible to come to an agreement with the reporting copyright owner, the content owner may submit a DMCA Counter-Notice to dmca@gitlab.com within ten (10) business days of the date of receiving our notice.
If we receive a valid counter-complaint, we will email a copy of the notice to the copyright owner.

The Counter complaint is a legal document and must comply with the requirements of the DMCA and must include the following:

1. Contact Information: Your name, title (if acting as an agent), physical address, email address, and phone number;
1. Content Identification: A reasonable identification of the material that has been removed or to which access has been restricted;
1. Statement under Perjury: A statement under penalty of perjury that you have `"a good faith belief that the material was removed or disabled as a result of mistake or misidentification of the material to be removed or disabled."`;
1. Consent to Jurisdiction: A statement that you `consent to the jurisdiction of Federal District Court for the judicial district in which your provided address is located, or if your address is outside of the United States, for any judicial district in which GitLab may be found`.
1. Consent to service of process: A statement that you will `accept service of process from the person who provided the original notification or an agent of such person`.
1. Signature: An `electronic` or `physical` signature of the owner of the copyright or a person authorized to act on the owner's behalf.
{{% /details %}}

{{% details sunmmary="Mitigating Copyright Infringement" %}}

- Should you receive a gitlab.com DMCA notice for content that is in your control;
  1. You can respond to the notice by removing the reported content from gitlab.com.
  1. If you believe your content is mistakenly the subject of a DMCA take down request, you have the right to contest the take down request by submitting a counter complaint.
- In the event that we **do not** see that any actions has been taken and no response to the DMCA notice has been received;
  1. The reported content will be made private.
      - Depending on where the content is located, access to the group/project can be restricted.
      - Access to the gitlab.com account is restricted.
{{% /details %}}

#### Trademark Infringement

{{% details summary="Submitting a Trademark Infringement Notice" %}}
To submit a trademark infringement report under the [Trademark Policy](/handbook/security/security-operations/trustandsafety/intellectual-property-on-gitlab-com/#trademark-policy), please provide:

1. Evidence that you are holder of a relevant trademark registration, such as a scanned copy of the trademark registration certificate(s) or screenshot of the registration on the website or database of the applicable national intellectual property office(s).
1. A declaration of the following statement: "By submitting this trademark infringement notice, I state that I have a good-faith belief that the reported use, in the manner that I have complained of, is not authorized by the intellectual property rights owner, its agent or the law; that the information contained in this notice is accurate; and, under penalty of perjury, that I am authorized to act on behalf of the owner of the intellectual property rights at issue".

You can send this information to dmca@gitlab.com, you should receive an automated confirmation of receipt.
{{% /details %}}

#### Name Squatting

{{% details summary="Requesting a dormant namespace" %}}
The GitLab.com Support Team will consider a [namespace](https://docs.gitlab.com/ee/user/group/#namespaces) (user name or group name) to fall under the provisions of this policy when the user has not logged in or otherwise used the namespace for an extended time.

**Specifically:**

User namespaces can be reassigned if both of the following are true:

- The user's last sign in was at least two years ago.
- The user is not the sole owner of any active projects.

Group namespaces can be reassigned if one of the following is true:

- There is no data (no project or project(s) are empty).
- The owner's last sign in was at least two years ago.
- If the namespace contains data, GitLab Support will attempt to contact the owner over a two-week period before reassigning the namespaces. If the namespace contains no data (empty or no projects) and the owner is inactive, the namespace will be released immediately.
- Namespaces associated with unconfirmed accounts over 90 days old are eligible for immediate release. Group namespaces that contain no data and were created more than 6 months ago are likewise eligible for immediate release.

Account and Group ownership disputes should contact **GitLab Support** to see if namespaces are eligible.
{{% /details %}}
