---
title: Solutions Architects Handbook
description: "Solutions Architects (SA) are the trusted advisors to GitLab prospects and customers during the presales motion, demonstrating how the GitLab application and GitLab Professional Services address common and unique business requirements"
---

## Solutions Architecture Mission

**Mission Statement:**

"As a learning organization, we enable our customers to realize value as they achieve outcomes faster and more efficiently and drive GitLab sales through technical and business consultation."

**Elaboration:**

Leveraging our technical and domain-specific expertise, along with strong cross-functional collaboration, Solutions Architects strive to become trusted advisors, fostering a collaborative learning environment with our prospects, customers, partners, and internal teams. Our primary objectives include:

- Crafting impactful value propositions that resonate with prospects, demonstrating the potential for transformative outcomes through GitLab adoption.
- Championing successful adoption of the GitLab platform, ensuring our customers realize maximum value from their investment.
- Cultivating a thriving business partner ecosystem by fostering partner capabilities and co-developing innovative solutions that expand market reach and customer value.

Here's how the SA organization fosters value creation through the lens of a learning organization and DevOps culture:

1. Shared Vision & Value Creation
   - The SA team aligns its goals with the overarching organizational vision of empowering customer success.
   - They prioritize customer value creation, understanding that their success is directly tied to the positive outcomes achieved by their customers.
   - This shared focus encourages collaboration and a sense of collective responsibility towards delivering value.

2. Personal Mastery & DevOps Expertise
   - SAs continually expand their technical, consultative, and domain-specific knowledge, embracing a mindset of lifelong learning.
   - They actively seek out new information, experiment with innovative solutions, deliberately practice, and share insights with their peers, contributing to the team's collective expertise.
   - This emphasis on personal mastery aligns with the DevOps culture of continuous improvement and adapting to evolving technology landscapes.

3. Systems Thinking & Customer-Centric Approach
   - SAs take a holistic view of the customer's challenges, understanding how different parts of their organization and technology stack interact and impact each other.
   - They identify potential bottlenecks or inefficiencies, working collaboratively to design solutions that optimize the entire system for maximum value creation.
   - This systems thinking approach echoes the DevOps philosophy of breaking down silos and promoting cross-functional collaboration to achieve shared goals.
   - SAs also leverage these concepts to improve internal processes at GitLab.

4. Challenging Established Mental Models & Encouraging Innovation of Thought
   - SAs encourage customers to question assumptions and challenge traditional ways of thinking about their processes and technologies.
   - They introduce new perspectives and innovative solutions, helping customers overcome limitations and unlock new opportunities for growth.
   - This focus on challenging existing mental models and fostering innovation reflects the DevOps principle of experimentation and learning from both successes and failures.  SAs also challenge internal assumptions and approaches, looking to continuously improves GitLab's ability to help our customers.

5. Teamwork & Knowledge Sharing
   - The SA team operates as a collaborative unit, sharing knowledge, experiences, and best practices freely.
   - They create a safe space for experimentation and learning, fostering an environment where individuals feel comfortable asking questions, seeking help, and offering insights.
   - This emphasis on teamwork and knowledge sharing reflects the core DevOps values of collaboration and transparency.

6. Building and leveraging continuous feedback loops
   - The SA organization thrives on feedback, both between team members and through instrumentation of our practices.  By leveraging feedback and data, the SA organization makes data driven decisions wherever possible.
   - A culture of feedback reflects the DevOps philosophy of continuous improvement and adapting to evolving technology landscapes.

Conclusion:

By embracing the principles of a learning organization the SA team becomes a powerful catalyst for customer value realization. They not only provide technical expertise but also foster a collaborative and innovative environment where customers are empowered to achieve their goals and maximize the value they derive from GitLab solutions.

## Role & Responsibilities

### Solutions Architects (Field)

Field [Solutions Architects](/job-families/sales/solutions-architect/) (SA) are the trusted advisors to GitLab prospects and customers during the presales motion. We demonstrate how the GitLab platform and GitLab Professional Services address common and unique business requirements. SA's add value to GitLab's customers by providing subject matter expertise and industry experience throughout the sales process and collaborate internally with product.

In addition, SA's identify and propose comprehensive solutions to complex business problems and workflow scenarios after compiling inputs from customer requests during conversations. Desired inputs include pain points, role-based visibility concerns, opportunities for improved efficiencies, current technologies and tools (3rd party to GitLab) and therefore opportunities to improve integrations, corporate initiatives, target outcomes and more. SA's also act as the technical liaison between the sales team and other groups within GitLab, engaging GitLab employees from other teams as needed in order meet the needs of the customer.

Our Field SA's also engage proactively with existing GitLab customer to provide thought-leadership, engage in innovative solutions, collaborate around evangalism activities around unique customer requirements (i.e. meetups and presentations) and continously seek market feedback to improve the GitLab platform.

### Strategic Field Organization

The [Strategic Field Organization](/handbook/solutions-architects/strategic-field-org/) is a team of [Principal Solutions Architects](/job-families/sales/solutions-architect/#principal-solutions-architect-responsibilities) that support global strategic sales opportunities and customers. This team collaborates with the regional account teams to work together on large engagements that require a higher degree of strategic planning, consulting, executive-level technical leadership, and internal GitLab cross-departmental collaboration.

### Ecosystem Solutions Architects

[Ecosystem Solutions Architects](/job-families/sales/solutions-architect/#specialties) are the trusted advisors to our strategic alliances partners, professional services partners, and channel resellers. The focus of this team is to develop relationships and provide technical assistance and leadership to drive joint GTM strategies. This team helps grow and strengthen the partner ecosystem by building new capabilities and growing GitLab revenue together with partners.

In addition to core responsibilities, Solutions Architects may assist in other client-facing activities aligned to Partner and Strategic Marketing such as blogs, videos, webinars, presentations and industry trade show presence.

See the [Solutions Architect role description](/job-families/sales/solutions-architect/) for additional details, and [Engaging an Ecosystem SA](/handbook/solutions-architects/processes/ecosystem/) when you need help with a partner cooperative opportunity.

### Demo Architects

- [Demo Architect Offerings](/handbook/solutions-architects/demo-architect/)

Demo Architects are tasks with maintaining public facing demo content (Workshops/Hands on Labs/ Pre-baked demos) as well as running the systems these events run on. There main goal is to create processes & new tools to help assist & enable Solution Architects when selling to customers.

### SA Managers

- [SA Manager Process](/handbook/solutions-architects/sa-manager/)

The Field and Partner SA Management (referred as SA management going forward) around the globe collaborates around unique requirements, identifies improvements in the go-to-market approaches and focussed on prioritises on strategies to address the market's requirements. The SA management is aligned in the interest of technical matters to address exisiting needs raised by customers and priotise on innovative requirements. The SA management will collaborate with product teams to achieve required outcomes.

## Trusted Advisors

Being a Trusted Advisor is referencing a role/skill that a person takes on when working with customers to solve their business problem.

> **Building Trust (Trusted Advisor)**:
> Connects with key stakeholders on both a personal and professional level and shows up as a credible and reliable champion for customers. Effectively positions GitLab as a partner to the customer rather than just another vendor with a focus on following through on commitments and delivering results.
>
> --<cite> [Solution Focus Field Competency](/handbook/sales/training/field-functional-competencies/#solution-focus)

For more information and development see the "Trusted Advisor Skill Development", [Community of Practice](/handbook/customer-success/initiatives/communities-of-practice/#active-communities-of-practice)

### Key Attributes for Positioning Value

As the DRIs helping position, prepare, and guide a customer's technical evaluation the SA team ensure that GitLab can surface the right points of value to the customer's key stakeholders post technical evaluation.  The following embody GitLab's technical evaluation philosophy and help guide successful technical evaluations.

These offerings are delivered each within a specific context of a particular customer journey.

- **Labs / Workshops**: Closed invite, typically in-person events (or a Zoom meetings) providing an exclusive list of customers (typically 1) access to a lab environment, where SAs provide personalized guidance to the customers as questions arise to help them see the value of what they are not currently paying for.
- **Technical Discovery**: A deep dive into current practices at the company that aid in helping identify pain points specific to where GitLab can help address needs and work towards a better long-term state.
- **Demonstrations**: Built around the work done within the technical discovery. Demonstrations aim to address at least 3 specific pain points identified during discovery while selling the vision of GitLab's DevSecOps platform approach.
- **Guided Trials**: Three goals in 30 days through the usage of a GitLab Trial. This can oftentimes be used to replace the need for the more formal Proof of Value.
- **Proofs of Value**: Technical evaluation with more complexities than a Guided Trial. May last up to 8 weeks.
- **Technical Close Plans**: An internal strategy used to secure a technical win for a given opportunity. It leverages the Command Plan and also details the customer's desired business outcomes, notional architectures of the current and proposed states, key stakeholders, and known risks.

## Changing the Solutions Architects Handbook Content

This is the Solution Architect handbook. If you see any typos, copywriting improvements or content clarifications you'd like to contribute, please create a merge request and ask your managers to merge. Please add the label "SA-HANDBOOK" to your merge request, and post a link to the [solutions-architects](https://gitlab.slack.com/archives/C01788YAY58) slack channel, mentioning @sa_leaders, as a heads up and so we can thank you! Since we have a [bias for action](/handbook/values/#bias-for-action), we trust your judgement.
