---
title: Solutions Architecture Activity Description
description: >-
  Solutions Architects record all customer and prospect activity. This is activity description to guide the accurate capture.

---

Solutions Architects record all customer and prospect activity with accurate activity type to promote **result** and **efficiency**. By consistently and accurately capturing our prospect or customer-facing activity, we can perform analysis for further reporting to establish **efficient** decision making for GitLab's business.

## Customer Activity Type with Troops.ai

When recording prospect/customer activity by SA into `Task` objects within Salesforce based on the Troops.ai `Log a Call` action on an `Opportunity`, one or more than one activity type should be selected to accurately reflect the customer interaction.

This page describes all activity types available for SAs in

- [Enterprise and Commercial](/handbook/solutions-architects/processes/activity-capture/activity-desc/#Description-for-Enterprise-and-Commercial-SA-Activity-Type)
- [Strategic Field](/handbook/solutions-architects/processes/activity-capture/activity-desc/#Description-for-Strategic-Field-SA-Activity)
- [Value Stream Workshop](/handbook/solutions-architects/sa-practices/value-stream-discovery/#value-stream-workshop), and
- [Alliance/Channel](/handbook/solutions-architects/processes/activity-capture/activity-desc/#description-for-alliancechannel-sa-activity)

### Description for Enterprise and Commercial SA Activity Type

Select these types when capturing activities by Enterprise and Commercial SA teams.

- **Customer No Show** - The SA has the opportunity to log an activity for a scheduled client meeting whereby the customer has not attended. In collaboration with the SAE/AE/Channels Manager, the SA should try to understand the underlying reason for the customers absence and record under the [SA] Activity Description.
- **Customer Strategy Plan Review** - Collaborative session between SA and a customer identifying and documenting business stakeholders, high-impact strategic requirements and key technologies, the current state of their technology ecosystem, current and desired capabilities, operational alignment with strategic objectives, and perceived gaps and deficiencies in current capabilities. See [process description](/handbook/solutions-architects/processes/#customer-strategy-planning) for details. When reporting this activity a link to the latest Customer Strategy Plan must be included.
- **Demo** - The SA can record the activity when a planned GitLab product demonstration has been
delivered to the client. In the [SA] Activity Description field in troops, the SA should
also refer to insights around the demonstration purpose and area of product walkthrough. Options could be a full high-level end-to-end GitLab overview, or a specific GitLab stage demonstration, a partial GitLab platform overview or a very specific technical deep dive into the product.
- **Discovery Session** - The SA has the opportunity to record major insights during the initial discovery session with the client. The SA could work with the client in collaboration to understand whether the current environment is restrictive in the project deliverables or whether there is a need to extend the existing platform with our offering. Examples of categorised discovery sessions could be;
  - DevOps discovery discussion
  - Continuous Integration discussion
  - Deployment environment discussion
  - Application front- and back-end discussion
  - Cloud journey and strategy discussion
- **Other** - The SA should utilise this [SA] Activity type to record any activity not listed in the options dropdown and is reserved for all non-anticipated types of SA services. It is imperative when using this activity type to be precise under the [SA] Activity Description field in troops to record the detail of the activity.
- **Post-sales technical account management** - SA uses this type to record technical account management work for accounts that don't qualify for CSM and for collaboration with CSM as part of post sales cadence calls. For growth opportunities to expand the account using the cadence calls, log the activity in other appropriate types.
- **PoV related activity** - It is assumed that the client's indication of a PoV and/or Technical Evaluation would be shared in either a Discovery session or during another [SA] Activity and the PoV related activity would be used by the SA as an activity record pertaining to the preparation, execution and completion of a PoV or a Technical Evaluation. Examples of PoV related activities could be;
  - PoV/Technical Evaluation scoping: The SA has the opportunity to record their activity towards engaging with the client on understanding the requirements and work in collaboration to agree on the type of evaluation [PoV or Technical Evaluation] and on the in-scope success criteria. The client on the other hand has the opportunity to define whether a high- or lite-touch PoV is required. Optionally the client may prefer to decide that a self-managed Technical Evaluation is sufficient and the SA assists ad-hoc.
  - Technical Evaluation cadence: The SA has the opportunity to record their activity with their client specific in relation to the Technical Evaluation. Upon agreeing to a plan, specific requirements and the definition of success, a regular or irregular cadence may be set by the SA with collaboration with the customer.
  - PoV cadence: The SA will often agree to a PoV plan, duration, sign off the in-scope PoV success criteria and work with their client on a regular cadence [weekly, bi-weekly, multi-weekly]. This [SA] Activity is an opportunity to capture the frequency and progress on the PoV. The SA should consider hosting a final cadence session with their client to agree on the sign off of the final completion of the evaluation.
- **Presentation / pitch** - The SA has the opportunity to record their preparation for a presentation to the client as well as the actual delivery. Sometimes a Pitch is requested by our SAEs/AEs due to significant client discussion without a SA, which is completely acceptable. Consideration for this type of [SA] activity are:
  - The SA attended an initial Technical Discovery session with the client and first requirements have been clearly collaborated on with the SA to take initiative to prepare for a presentation.
  - The SA debriefed internally with their SAE/AE/Channels Managers to understand the requirements of a first-time SA connect with the client and the expectation on an initial Presentation / Pitch
- **Ride Along** - This activity type is used when one SA is shadowing another SA to help support the opportunity, provide feedback for the primary solutions architect, and to learn how the primary solutions architect works. Please leverage [the Ride Alongs](/handbook/solutions-architects/sa-practices/ride-alongs/) handbook page to learn more about how Ride Alongs work. Record this activity on Account level. Recording at the account level is required because ride alongs that are inter-segment or inter-region will not have their opportunities available to the riders.
- **Guided Trial** - This activity type is used in case a prospect or existing customer needs support from an SA during their self-evaluation via the GitLab Free trial offering.
- **Security Questionnaire / RFP** - The SA should use this activity type to record actions related to completing security assessments or progressing opportunities through tender processes. Examples of activities that fit into this category are;
  - Security Assessment: Although technically speaking part of the tendering process, Security Assessment generally involve the SA to interact with GitLab governing divisions ensuring accuracy and legal responses. As such, the SA engages with a GitLab division internally to address those Security specific requirements but ahead of the process, the SAs have a responsibility to attempt in the form of a first attempt to the queries.
  - Procurement / Tender process (RFx): The SA is engaged with the client and an indication has been given that their organisation will be undergoing a public tendering process. Tendering processes could be requesting a proposal, quote, information, expressions of interest and generally result in the SA responding to functional and/or non-functional queries of the GitLab platform as part of a request. Often tendering processes are indicated early, shared fairly with the approaches to take it to market and require a formal process involving the SA addressing technicalities required in form of written artefacts.
- **Technical Deep Dive** - SA should record client sessions on in-depth review of technology and GitLab capabilities, and creating the client solutions.
- **Technical Support** - SA conducts the technical support sessions as the account team and with GitLab Support to troubleshoot and address specific technical issues and challenges.
- **Positioned Professional Services** - This activity type should be used when positioned Professional services as part of the [Solution Architects Processes](/handbook/solutions-architects/processes/#positioning-professional-services)
- **Professional Service Support** - SA have a clear understanding of the client's available internal skills and capabilities and assist their clients in ways to become successful in a quicker way when skills gaps are identified. As a result of that, GitLab Professionals Services support adds customer value to mitigate risk and accelerate speed to success. Since the SA owns the initiation of the ProServ division at GitLab for our customers outlined here - and a significant amount of follow up and cadence is expected as a SA service to our regional customers.
- **SA Assistance - Subject Matter** - A [SA] is requested to support another GitLab Team Member with their advanced knowledge and understanding in a certain subject, without owning the particular engagement or opportunity.

- **SA Assistance - Manager** - To be used by [SA] Manager in case of assisting a customer engagement.

### Description for Strategic Field SA Activity

Select these [SA] Activity types when capturing activities by the Strategic Field team but other activity types for Enterprise can also be used.

- **SA Assistance - Strategic Field** - Calls with client's management and executives to review enterprise DevOps strategy and alignment to the overall company initiatives such as digital or cloud transformation.
- **Executive Solution Plan** - Calls with client's management and executives to discuss, strategize and review DevOps solution for organization wide transformation, develop the trusted advisory relationship with industry thought leadership and guide the enterprise for DevOps adoption with best practices.

### Description for Alliance/Channel SA Activity

Select these [SA] Activity types when capturing activities by the Alliance/Channel team but other activity types for Enterprise can also be used.  There is an implied priority with higher value activities listed highest / first to lowest / last.

- **Partner Opportunity** Alliances / Channel - Sales opportunity # aligned work alongside field SA on specific sales opportunities with a partner involvement. This includes being an overlay SME on partner technologies and its joint value proposition with GitLab and/or helping a channel/services partner become successful with joint customers.
- **Partner Assisted Demand Gen** Alliances / Channel - Delivering or developing customer facing webinars, workshops, roadshows and similar activities in collaboration with a partner, focussed on demand generation / lead generation.
- **Partner VSA Enablement** Channel - Activities involving enablement of partners to pitch or execute Value Stream Assessment and similar presales value selling motions.
- **Partner Technical Evangelism** Alliances / Channel - Delivering or developing partner facing (not customer facing) events and evangelism, including partner internal conferences, meetups, webinars, open-invite bootcamps, blogs and customer success stories.
- **Internal Enablement and SME Assistance** Alliances / Channel - GitLab facing internal calls, meetings, webinars for partner promotion and GitLab field team assistance.
- **Partner Solutioning** Alliances / Channel - Solution architecture work for defining and developing partner solutions and integration with GitLab.  For a work done on a specific sales opportunity, consider "Partner Opportunity."
- **Partner Services Attach** Channel - Develop partner services catalog and/or SoW for future services engagements.
- **Partner Enablement** Alliances / Channel - Partner facing calls, meetings, workshops, webinars, including prep work to enable partner Champions on GitLab product and pre-sales.
- **Partner Cadence calls** Alliances / Channel - Cadence calls with partners for partnership building and pre sales activities on customer opportunities and account strategy.

### Description for Value Stream Workshop

**Note:** These options still refer to the old naming of "VSA" but due to ongoing data tracking reasons, we are unable to update the selections. Please be aware of this.

- **VSA Pitch** - This is an initial VSW pitch to the customers/prospects to get their buy in, discuss next steps, send follow ups before the VSW planning meeting
- **VSA Execution** - External customer/prospects calls for VSW planning, VSW workshop, VSW executive presentations.
