---
title: Solutions Architects Onboarding
description: "Onboarding Program for Solutions Architects (SA)."
---

View the [SA Handbook homepage](/handbook/solutions-architects/) for additional SA-related handbook pages.

---

{{% alert title="⚠️" color="warning" %}}
This information is under active development and is not yet final. This page will be updated on an ongoing basis during this phase.
{{% /alert %}}

## Solutions Architects Onboarding Overview

Onboarding for Solutions Architects is meant to provide newly hired Team Members with information to expedite the process of becoming acclimated to GitLab and the SA role. As a crucial part of the Solutions Architecture team, it is imperative that the new Team Member understands the intricacies of how GitLab's products and solutions work and thus be able to articulate specific use cases and efficiently execute demos.

The purpose of this role-specific onboarding program is to provide the newly hired Solutions Architect (SA) with information to expedite the process of becoming acclimated to GitLab and the SA role. As a crucial part of the Solutions Architecture team, it is imperative that as a new SA, you fully understand the intricacies of how GitLab's products and solutions work. This will enable you to articulate GitLab's Go To Market (GTM) Messaging, apply specific use cases, and efficiently execute demos.

![swag](https://gitlab.com/gitlab-com/people-group/peopleops-eng/emails/-/raw/f300f5097b8364158541bc447ad71af2d6fad249/images/swag.png)

—

### Introduction

**Welcome to your GitLab Solutions Architects (SA) Onboarding!**

_We are so excited you're here and look forward to setting you up for [all-remote](/handbook/company/culture/all-remote/guide/) success as your team member journey begins._

Now that you have completed your core GitLab onboarding issue housed in GitLab.com, and Sales Quick Start (SQS) it is time to jump into your [role-based onboarding path](https://docs.google.com/document/d/1BNxW0n9tr-65IEUbARb0zUZj14atIRURVT1BiuGBD0g/edit). This onboarding program will cover Technical Onboarding as it relates to the SA role. An overview of topics and links covered in your role-based learning path can be found in this [role-specific onboarding guide](https://docs.google.com/document/d/1BNxW0n9tr-65IEUbARb0zUZj14atIRURVT1BiuGBD0g/edit). Please make a copy of this document and check off items as you complete them.

This onboarding still adheres to the sentiments of [self directed and continuous learning](/handbook/company/culture/all-remote/self-service/), using the diverse set of high and low touch resources available to all GitLab team members such as videos; handbook pages; blog pieces; Zoom sessions and knowledge assessments, while encouraging [asynchronous communication and workflows](/handbook/company/culture/all-remote/asynchronous/).

### Support and our Single Source of Truth

Since GitLab is a [handbook first](/handbook/company/culture/all-remote/handbook-first-documentation/) organization, the answer to any question you may have particularly throughout your first thirty days should be documented and readily available as this is our [Single Source of Truth (SSoT)](/handbook/values/#single-source-of-truth).

If you are unable to find the information you are looking for, please be sure to reach out to your Manager; Onboarding Buddy; People Connect Team member or the Field Enablement team for support by tagging them in the comments section of this [SA onboarding feedback issue](https://gitlab.com/gitlab-com/sales-team/field-operations/enablement/-/issues/2635). If you need to troubleshoot specific issues with tools, you can add a screenshot of the issue directly in the comment to help them diagnose the problem.

Alternatively once you are active on [Slack](/handbook/communication/chat), which is used solely for informal communication, you will notice that you have been automatically added to a handful of useful support channels such #questions, #cs-questions, #solutions-architects, #it-help, etc.

## Learning Objectives for SA Onboarding

In addition to the SQS learning objectives, your onboarding is intended to fulfill the following learning objectives:

**Module 1: SA at GitLab**

- Understand the SA Mission
- Differentiate the roles and responsibilities within the SA org
- Describe what it means to be a Trusted Advisor
- Recall the GitLab Sales Learning Framework
- Illustrate how to use demo projects in the CS shared demo space
- Acquire certification in GitLab Certified Fundamentals

**Moduel 2: SA Processes**

- Demonstrate understanding of the SA process maps, activity capture, and engagement models per region
- Recall the GitLab Sales Stages
- Identify the SA’s roles within the various sales stages
- Summarize the GitLab Pitch
- Describe what technical discovery is
- List the different approaches and activities to achieve a technical win
- Demonstrate understand of the Value Stream Workshop
- Deliver a Positioning a Value Stream Workshop
- Differentiate between the Technical Close Plan and Mutual Customer Success Plan
- Outline the steps for building a Customer Success Plan
- Acquire certification in GitLab CI/CD Associate

**Module 3: Technical Deep Dive**

- Complete pre-work for Sales Quick Start (SQS)
- Recognize the customer issues prioritization framework
- Demonstrate deep understanding of DevSecOps Adoption
- Acquire certification in GitLab Certified Security Specialist

**Module 4: Demo Engineering**

- Demonstrate ability to utilize the GitLab Sandbox Cloud
- Demonstrate cloud readiness
- Deliver demos on various product features / functions
- Acquire certification in GitLab Certifie Agile Portfolio Management Associate

**Module 5: SA Practices and Selling Excellence**

- Demonstrate understanding of the various SA practices including but is not limited to:
  - Proof of Value (POV)
  - Strategic Solution Selling
  - Selling professional services
  - Technical Close Plan
  - Mutual Customer Success Plan
  - Business Value Consulting
  - Value Stream Discovery
- Describe Reference Architecture
- Install GitLab via Omnibus and via Helm Chart
- Demonstrate understanding of GitLab’s competition by reviewing battlecards
- Recognize second tier competitors
- Demonstrate understanding of Professional Services at GitLab
- Explain how to submit marketing support requests for participating in in-person events

**Module 6: SA Onboarding Conclusion**

- Identify tools and resources available to you
- Recognize the various career paths that you can take in your career as a SA
- Identify helpful enablement resources available to you in the SA Knowledge Mine on Highspot

## Milestones and Onboarding Roadmap

![SA Onboarding Journey Roadmap](/handbook/solutions-architects/SA-Onboarding-Journey-Roadmap.png)

## Expectations for Manager Support during Onboarding

Your manager will be there to support you during your onboarding journey and beyond. Beyond the expectations laid out for your manager in your onboarding issue and role-based onboarding guide, they will be providing you with the following support:

**Month 1**

- Schedule recurring 1:1s
- Provide guidance on who the new hire should schedule coffee chats with during their onboarding journey
- Review and discuss company policies
  - PTO policy
  - Family and Friends first culture
  - CREDIT Values
  - Growth and Development Budget
- Discuss any team specific expectations
- Review organizational structure
- Ensure new hire has access to all role-specific tools and appropriate Slack channels
- Align on a general plan to get customer ready; discuss shadowing opportunities
- Ensure new hire is meeting appropriate milestone and expectations from week to week; engage your new hire in discussions about their learnings and insights from their onboarding
- Identify skills to be mastered and resources available to accomplish learning objectives

**Month 2**

- Check in regularly with your new hire
  - Ask them if they are experiencing any challenges with GitLab’s asynchronous culture
  - Discuss any general concerns
- Encourage new hire to continue building their internal network and provide support by facilitating introductions to key stakeholders, other team members, and cross functional teams as needed
- Share constructive feedback on their recorded demos they were expected to complete as part of their role based onboarding
- Ensure onboarding milestones are met and that new hire is completing required courses and certifications and is shadowing calls
- Align on whether your new hire is on track to be customer ready and how else you can provide support to help them prepare for customer engagement
- Discuss best practices

**Month 3**

- Decide on a regular cadence for 1:1 calls beyond onboarding
- If not already complete, discuss plan for taking over assigned customers / accounts
- Consider shadowing some customer calls and provide feedback as needed
- Confirm that new hire has completed all mandatory and necessary onboarding activities including SQS, role-based learning path and embedded required tasks, and GiLab core certifications
- Discuss how their performance will be formally evaluated in the future

**Beyond 3 Months**

- Provide regular feedback on performance
- Demonstrate curiosity as it relates to your new hire’s career goals and aspirations and support them in their development
- Encourage your new hire to:
  - Build out an individual growth plan
  - Participate in knowledge sharing whether through team Slack channels, presentations, or enablement sessions
  - Participate in TMRGs that are of interest to them

## Expectations for Buddy Support during Onboarding

**Month 1**

- Nurture a welcoming environment for the new hire
- Establish a recurring 1:1 to check in on the new hire’s progress on onboarding activities
- Provide assistance with any barriers or difficulty understanding concepts covered in the onboarding learning path and SQS
- Connect the new hire with members of the broader team to build a network
- Share helpful tips and resources that are beneficial during their onboarding and beyond

**Month 2**

- Ensure new team member is actively engaged in [ride-alongs](/handbook/solutions-architects/sa-practices/ride-alongs/) and offer support as needed
- Align with new hire’s manager on ways you can provide support
- Discuss any feedback, learnings, insights new team member has gathered throughout their onboarding experience
- Ask the new team member is they are experiencing any challenges and provide support accordingly

**Month 3**

- Inform new hire on how you can support them beyond their onboarding journey
- Share guidance around what resources you use in your day to day role as a SA and encourage new team member to bookmark and save these resources for future references

## Graduation from SA Onboarding

In order to be considered as having graduated from your role based onboarding journey, you need to have completed the following:

- Completed Sales Quick Start (SQS) prework on GitLab University
- Attended the SQS workshop and completed all relevant activities
- Completed your role based learning path on GitLab University
- Shadowed calls with other SAs to prep for customer calls
- Attained the following certificates:
  - GitLab Certified Fundamentals
  - GitLab Certified CI/CD Associate
  - GitLab Certified Agile Portfolio Management Associate
  - GitLab Certified Security Specialist
- Created your own script and recorded demos for the following:
  - End to End Ultimate, Security Demo
  - Portfolio Management Demo (including Analytics)
  - GitOps Workflow Demo (Push-based and Pull based)
  - Compliance Premium Demo (Push-based and Pull-based)

## Continuous Enablement

In addition to onboarding enablement, continuous enablement will be available to you via micro-learning, job aids, just-in-time learning, and webinars.

- [Customer Success Skills Exchange](/handbook/sales/training/customer-success-skills-exchange/) is a biweekly webinar for the Customer Success and Solutions Architect teams on various technical topics
- [Field Enablement Spotlight](/content/handbook.gitlab.com/handbook/sales/training/sales-enablement-sessions/#field-enablement-spotlight-sessions) sessions take place weekly and cover topics relevant to the field

In additon to the above resources, you will also have access to [O'Reilly](https://learning.oreilly.com/home/), a learning platform accessible via Okta SSO.

## Feedback

Your feedback on the onboarding process and materials is important to us and we welcome your thoughts and ideas on how we can improve in the future. Please share your feedback in the following issue: [SA Onboarding Feedback Issue](https://gitlab.com/gitlab-com/sales-team/field-operations/enablement/-/issues/2635).

## Updates to Onboarding

The role based onboarding learning path for SAs as well as the SA Onboarding Guide will be reviewed and updated each fiscal year to ensure up to date and accurate information. Please see the [SA Onboarding Feedback Issue](https://gitlab.com/gitlab-com/sales-team/field-operations/enablement/-/issues/2635) for information regarding the next planned refresh.

## Resources and Links

- [SA - New Hire - Onboarding Guide](https://docs.google.com/document/d/1BNxW0n9tr-65IEUbARb0zUZj14atIRURVT1BiuGBD0g/edit)
- [SA Onboarding Learning Path](https://university.gitlab.com/learn/learning-path/solutions-architect-sa-onboarding-journey)
- [#solutions-architects](https://gitlab.enterprise.slack.com/archives/C01788YAY58) Slack Channel
- [SA Onboarding Feedback Issue](https://gitlab.com/gitlab-com/sales-team/field-operations/enablement/-/issues/2635)
- [SA Highspot Page](https://gitlab.highspot.com/spots/6165db692a8a94c7d9e65f94)
