---
title: Customer Success Plan

description: A Customer Success Plan is a customer-facing and mutually agreed roadmap for achieving value through GitLab adoption. This is an outcome of collaboration between GitLab Solution Architecture and the customer with the primary objective of ensuring customers are successful. The process is designed to support shifting from product scoped conversations (focusing on specific features or functions and limited to a specific subset of DevSecOps stages) towards solution (addressing specific pain points) or strategic (shaping business outcomes through holistic organizational process innovation and transformation tied to top strategic initiatives ) scopes. This Success Plan starts in the pre-sales process and is intended to carry through to the post-sales Success Plan. **In some cases, there may be no clear GitLab owner for the post-sales success plan. This should not prevent the creation and customer review of a success plan by the Solutions Architect where required.**  The Customer Success Plan is intended to be dynamic and should therefore be regularly reviewed on an agreed-upon cadence.

---

## What is the Mutual Customer Success Plan

 The [**Mutual Customer Success Plan Template**](https://docs.google.com/presentation/d/1VCzXDiwJAwLu9e_JKTWCFkKbbviUWbtRySyTs75Uldc/edit#slide=id.g2a9229693f5_0_5) is a merging of the [Pre Sales Customer Success Plan](https://docs.google.com/presentation/d/1npyhUebp68YkccLlJP5R_6gmtQjfELpB1mBGWfroVmY/edit#slide=id.g24cd733349c_7_898) and the [Post Sales CSM Customer Success Plan template](https://docs.google.com/presentation/d/1T-Y2WJ-mRqGey7b1YQMTKE3tVbBTnyY3a9HzaOpxPQ4/edit#slide=id.g27c03c31d08_1_500).  It contains the following:

- Customer Background
- Elements from the Technical Close Plan i.e.
  - Customer Business Outcomes
  - Key Business stakeholders
  - Current and Desired State/ Workflows
  - Technical Activities Planned or Completed
  - Technical Evaluation Plan List
- Customer Phased Success plan & Adoption Journey
- Proposed Initiatives and Milestones

Please use the  [**Mutual Customer Success Plan Template**](https://docs.google.com/presentation/d/1VCzXDiwJAwLu9e_JKTWCFkKbbviUWbtRySyTs75Uldc/edit#slide=id.g2a9229693f5_0_5) for all Strategic and Enterprise opporttunities.

Please use the [**Commercial Customer Success Plan Template**](https://docs.google.com/presentation/d/18D2cGJKH5_qIPBwcoy24ORfiBNqw_sKr9VGnOxeqwOc/edit#slide=id.g24cd733349c_7_898) for all High Velocity or Commercial opportunities.

## Why Use a Mutual Customer Success Plan (CSP)

### Primary Objectives

As a follow on to the [Technical Close Plan process](/handbook/solutions-architects/sa-practices/technical-close-plan/), the Technical Close Plan can be converted into, or utilized as a Mutual Customer Success Plan, with these aims:

1. For the **Customer**: To be prescriptive on a phased successful adoption of GitLab, including architecture recommendations, deployment, migration, integration, onboarding users and applications at scale, along with recommendations for any automation processes as well as dashboards and monitoring.  As an SA you should always collaborate with the customer, to create the Mutual Success plan and help them understand, preliminary, what is involved in adopting GitLab as their AI powered DevSecOps Unified Platform,  from not only a technological or deployment point of view, but from a people and process point of view.

2. For the **Customer Success Manager (CSM)**: Collaborate with CSMs for all deals over the appropriate threshold (currently 300k Net ARR),  as it transitions from pre to post sales.  It is important to provide the CSMs with all the relevant context as they take over the relationship.  As an SA, you collaborate with the CSM to help them understand the customer's objectives and milestones for the next 30, 60, 90 days as well as for the next 6 months.  The CSM can then formulate a cadence and enablement plan.  The CSM will be responsible to update and maintain the Mutual Customer Success Plan after the sale.  It will serve as a customer facing document, helping to facilitate the customer achieving their initiatives, and objectives.  A CSP should be created and reviewed w/ the customer even in cases where there are no CSMs assigned.

3. For the **Professional Services Team**: Present the Customer Success Plan with the scope of initiatives that can be used to determine a Statement of Work.

4. For the **Go To Market Team**:  When a GitLab executive sponsor or anyone in the GTM or customer support needs to be engaged, the Mutual CSP acts as a source of truth to provide context between the customer's and GitLab's interactions.

## When to Create a Mutual Customer Success Plan

A Mutual Customer Success Plan should be initiated once the opportunity has completed Stage-3 Technical Evaluation, with a technical win.  This is when an SA begins to prescribe what a phased adoption and customer adoption journey would look like, in collaboration with the customer.  Please note that a Technical Close Plan should be started in stage 2 or 3 and will contain the required information for a CSP.

### Which Opportunities Should Have a Mutual Customer Success Plan?

1. All opportunities with an [SA Validated Tech Evaluation](/handbook/solutions-architects/processes/activity-capture/#sa-specific-opportunity-fields)
2. First Order opportunities for accounts with [LAM](/handbook/sales/field-operations/sales-systems/gtm-technical-documentation/#landed-addressable-market-lam) over $2M  in Proposal stage (Stage-4) and beyond.
3. All New or Growth Opportunities over $300k net ARR, in Proposal stage (Stage-4) and beyond. *(The SA is the DRI, which is handed over to the CSM)*
4. All existing customers with upcoming Renewals, over $300k in ARR basis.  *(The CSM is the DRI, to create a Mutual Customer Success Plan.  In these cases the SA may optionally create a Technical Close Plan to capture necessary context if one did not exist, or add to the CSM's Mutual Customer Success Plan as needed.)*

SA Managers have discretion for additional opportunities to be included or excluded.

Once an opportunity has been identified using the criteria above, as requiring a Customer Success Plan, the Solutions Architect should initiate it at the end of Stage-3 Technical Evaluation, and place the URL in the Customer Success Plan field, in the opportunity, in Sales Force.

Then the SA ensures that the releavnt fields in the Customer Success Plan section, on the Opportunity level in SFDC, is maintained throughout the process:

![Customer Success Plan Opportunity Fields](/handbook/solutions-architects/processes/Customer-Success-Plan-SFDC.png)

1. Customer Success Plan: field for the URL to the plan
1. CSM Ready: Check if the plan is/can be handed over to the CSM
1. Customer Accepted: Check if the the CSP has been reviewed with the customer.  The customer doesn't need to formally "accept" the CSP for this to be checked.

See how to [initiate a Customer Success Plan from a Technical Close Plan below](/handbook/solutions-architects/sa-practices/customer-success-plan/#how-to-build-a-technical-close-plan-and-transition-to-a-customer-success-plan).

## How Does This Differ From a Technical Close Plan

In many instances, the Technical Close Plan can be used as-is for a Customer Success Plan, where the only real difference is the timing.

In other cases, there may be additional adoption information to capture, like other known tools, migration plan, adoption plan, adoption risks, etc.

There also may be parts of the original Technical Close Plan that are no longer relevant to share with the customer, like internal relationship notes, sales or GitLab terminology, or mitigated risks.

Here is a quick reference on what content elements are in a Technical Close Plan vs. a Customer Success Plan:

||**Content Element**|**Technical Close Plan**|**Champion's Deck/ Proposal**|**Mutual Customer Success Plan**|**Kick Off Call/ Onboarding EBR**|
|--|--|--|--|--|--|
|1.|Company Background|X||X||
|2.|What Have We Heard||X|X||
|3.|Key Stakeholders/ Project Team|X||X|X|
|4.|Business Outcomes/ Strategic Initiatives|X|X|X|X|
|5.|Current & Proposed Workflow Diagrams|X|X|X|X|
|6.|Applications & Use Cases/ Risks & Mitigations|X||X|X|
|7.|Activities Planned/ Completed|X||X||
|8.|Technical Evaluation Plan & Activities|X||||
|9.|Value Outcome Map/ Metrics|X|X|X|X|
|10.|Economics/ Pricing||X|||
|11.|Users/ What was bought/ recommended||X|X|X|
|12.|Phased Success Plan and Adoption Journey|||X|X|
|13.|Outcomes, Objectives & Activities - Bus/Technical Milestones (3/6/12 month)|||X|X|
|14.|Enablement Plan|||X||
|15.|Architecture Notes:Producer (Deployment, Configuration, Integration); Consumer (Onboarding, Management,Monitoring)|||X||

### At a High Level What is the Customer Success Plan Process

The Customer Success Plan process is outlined [here](/handbook/solutions-architects/processes/#customer-success-plan).

Please pay attention to the responsibility of the SA to update the opportunity in Sales Force with the Customer Success Plan URL as appropriate.

### How To Build a Technical Close Plan and Transition to a Customer Success Plan

Let's describe in more detail the Day on the Life of an SA.
Every meeting that is conducted with the customer, is an opportunity for you to understand the customer's challenges and outcomes desired.
The following is a recommendation on how to advance an oppotunity, meeting by meeting, stage by stage, and what information you should gather to first build the Technical Close Plan and then transition to a Customer Success Plan.

1. **Technical Close Plan** **(Stage-1:Discovery to Stage-3:Technical Validation)**
   - **Meeting 1 -Discovery** - Discover the Desired ~~Challenge~~ Outcome [Why Change?]
     - *During the Meeting*
       - Research and confirm **"1. Company Background"**
       - Understand who are the **"3. Key Stakeholders"**:
         1. Executive Decision Maker/ Economic Buyer,
         2. Technical Champion/Coach/ Buyer,
         3. Process or Operational Owner, and get introductions
       - Ask about the **"4. Business Outcomes/ Strategic Initiatives"**
       - Start Discovery on any Tool Chain per Stage/ Processes etc.
       - Whiteboard or Present very high level GitLab value
     - *After the Meeting*
       - Create a Technical Close Plan with the following content from your first Meeting
         - **"1. Company Background"**
         - **"2. What We have Heard"**
         - **"3. Key Stakeholders"**
         - **"4. Business Outcomes/ Strategic Initiatives"**
       - **VERY IMPORTANT: Update the Technical Close Plan URL in the opportunity in Sales Force.**
       - If you don't have any of the above information, because most of the time was spent answering the customer's technical questions, schedule another discovery meeting to gather the info.
     - *Next Steps:*
       - Current and Desired Workflow Discussion
       - Can also do a brief "Drive by" Demo, which is a short 5 minute demo to faciliate more discovery

   - **Meeting 2 -Scope** - Scope the Workflows to Achieve Desired Outcomes [Why Now?]
     - *During the Meeting*
       - Present **"2. What We have Heard"** so far
       - Continue any Discovery on any Tool Chain per Stage/ Processes etc. that would form the foundation of a **"5. Current and Proposed Workflow Diagrams"**
       - Ask about all **"6. Applications & Use Cases/ Risks & Mitigations"** if all desired Use Cases are not accomplished.
       - Present or Whiteboard GitLab Use cases and Value
     - *After Meeting*
       - Update the  Technical Close Plan with
         - **"2. What We have Heard"**
         - **"5. Current and Proposed Workflow Diagrams"**
         - **"6. Applications & Use Cases/ Risks & Mitigations"**
         - Start a **"8. Technical Evaluation Plan & Activities"** on what will be done to achieve a Technical Win and Decision.
     - *Next Steps:*
       - Present Current and Desired Workflow Diagrams
       - Optional (Propose Workshop or Demo).

   - **Meeting 3 -Scope** - Qualify the Value [Why GitLab?]
     - *Meeting Prep*
       - For Meeting Prep, work with your Account Executive, to shore up **"2. What We have Heard"** so far.
       - Start to develop your **"8. Technical Evaluation Plan &  Activities"**, that is, what exactly will be done to achieve a Technical Win and Decision.
     - *During the Meeting*
       - During the third meeting Present an updated **"2. What We have Heard"** so far
       - Present the **"5. Current and Proposed Workflow Diagrams"** and solicit feedback and discussion.
       - Present the **"6. Applications & Use Cases/ Risks & Mitigations"** and solicit feedback and discussion.
       - Make sure the customer understands our value in meeting their outcomes and processes.
       - Determine how a Technical Decision would be made and document in  **"8. Technical Evaluation Plan & Activities"**. Get agreement from Customer on the path to making a Technical Decision.
     - *Next Steps:*
        - SA and AE to propose the next steps for Business and Technical Validation: Workshop/ Demo/ POV/ Value Stream Workshop/ Business Value Assessment

   - **Meeting 4 -  Business & Technical Validation Activities** - Validate the Business and Technical Value
     - *Meeting Prep*
       - For Meeting Prep, work with your Account Executive, to review your **"8. Technical Close Plan Activities"** on what will be done to achieve a Technical Win and Decision.
     - *During the Technical Evaluation*
       - Conduct your [Technical Evaluation Plan and Activities](https://docs.google.com/presentation/d/1GnUqWluULPz_rJmwK2mno3KbzYcu1kM11tXTAZXivkg/edit#slide=id.g12b319f6181_0_0) as was decided between GitLab and the customer, e.g. Workshop, POV, Demo, Reverse Demo, Day in the Life
       - Work towards the Technica  win (may require more than 1 meeting)
     - *During and After the Technical Win*
       - Update **"7.Activities Planned/ Completed"** in the Technical Close Plan
       - After the Technical Win, create a **"9. Value Outcome Map/ Metrics"**.
       - The Outcome Map traces the Customer's Outcomes to be achieved, with their Strategic Initiatives, mapped to GitLab's capability and what value will it bring.  This would be used in the proposal.
     - *Next Steps:*
        - After securing Technical Win, work with AE on a Proposal
        - Initiate the Customer Success Plan (see below)

2. **Mutual Customer Success Plan** **(Stage-3:Completed )**
   - Once Technical Validation is completed, initiate and complete. the [Mutual Customer Success plan](vhttps://docs.google.com/presentation/d/1VCzXDiwJAwLu9e_JKTWCFkKbbviUWbtRySyTs75Uldc/edit#slide=id.g2a9229693f5_0_5) with the Following elements from the Technical Close Plan
     - **"1. Company Background"**
     - **"2. What We have Heard"**
     - **"3. Key Stakeholders"**
     - **"4. Business Outcomes/ Strategic Initiatives"**
     - **"5. Current and Proposed Workflow Diagrams"**
     - **"6. Applications & Use Cases/ Risks & Mitigations"**
     - **"7.Activities Planned/ Completed"**
     - **"9. Value Outcome Map/ Metrics"**
   - **VERY IMPORTANT: Update the Customer Success Plan URL in the opportunity in Sales Force.**

3. **Meeting 5 -Proposal** - **(Stage-4:Proposal and beyond )** - Proposal and Recommendations to Achieve Customer's Outcome
   - Prep with your AE on a Proposal/ Champions Deck that includes the following from the Technical Close Plan
     - **"2. What We have Heard"**
     - **"4. Business Outcomes/ Strategic Initiatives"**
     - **"5. Current and Proposed Workflow Diagrams"**
     - **"9. Value Outcome Map/ Metrics"**
   - After Proposal Presentation, continue to update and complete the [Mutual Customer Success plan](vhttps://docs.google.com/presentation/d/1VCzXDiwJAwLu9e_JKTWCFkKbbviUWbtRySyTs75Uldc/edit#slide=id.g2a9229693f5_0_5)
   - **VERY IMPORTANT: Update the Customer Success Plan URL in the opportunity in Sales Force.**
   - *Next Steps:*
     - While Negotiation occurs, As the SA, set up meetings with the customer and with the CSM to add the following to the Mutual Customer Success Plan:
       - **"11. Users/ What was bought/ recommended"**
       - **"12. Phased Success Plan and Adoption Journey"**
       - **"13. Outcomes, Objectives & Activities - Bus/Technical Milestones (3/6/12 month)"**
       - **"15. Architecture Notes:Producer (Deployment, Configuration, Integration); Consumer (Onboarding, Management,Monitoring)"**

4. **Mutual Customer Success Plan handoff to CSM for over 300k/ Or AE and SA maintain after close**
   - The CSM would take the Success Plan started by the SA and add or update the following:
     - **"13. Outcomes, Objectives & Activities - Bus/Technical Milestones (3/6/12 month)"**
     - **"14. Enablement Plan"**
   - The CSM for Renewal opportunities with ARR basis over 300k may also start a Mutual CSP from **"13. Outcomes, Objectives & Activities - Bus/Technical Milestones (3/6/12 month)"**.
   - In those cases, CSM is the one responsible to **update the Customer Success Plan URL in the Renewal opportunity in Sales Force.**
   - The SA may optionally create a Technical Close Plan after the fact  to add all he remaining context, to understand why was GitLab bought previously and what was the customer's expectation of value from GitLab
   - In addition the CSM, when conducting cadences with the Customer, is expected record the following in the Mutual Customer Success Plan:

||**Content Element**|**Technical Close Plan**|**Champion's Deck/ Proposal**|**Mutual Success Plan**|**Kick Off Call/ Onboarding EBR**|
|--|--|--|--|--|--|
|1.|Utilization per Features/ Capabilities|||Update Utilization upon Cadence|X|
|2.|Use Case Adoption in Prod|||Update Use Case Adoption upon Cadence|X|
|3.|Support Tickets/ Enhancements/ issues|||Update Tickets/ Issues upon Cadence|X|
|4.|OnGoing/ Planned Initiatives w/ Status|||Update Milestones upon Cadence|X|
|5.|Outcome/ Metric Updates|||Update Metrics/ Customer upon Cadence|X|
|6.|PS SOWs and RunBook|||Attached|X|

### Tracking Customer Success Plan creation and review

To drive visibility and accountability, CSPs and the associated customer review need to be recorded on the associated opportunity in salesforce. Please use the following fields:

- Customer Success Plan:  contains the link to the plan
- Customer Accepted:  checked when the plan has been reviewed with the customer and the customer accepts it.  There are no formal actions needed to consider the plan accepted.

### The CSM and the Customer Success Plan

[Click here to learn more about the CSM's responsibility with respect to Customer Success Plans](/handbook/customer-success/csm/success-plans/).

## Resources

This [Google Drive Folder](https://drive.google.com/drive/folders/1Bl6I8XCzjhJsr2qIxKPvFpgxYrQFwR9U) contains the [Mutual Customer Success Plan](https://docs.google.com/presentation/d/1VCzXDiwJAwLu9e_JKTWCFkKbbviUWbtRySyTs75Uldc/edit#slide=id.g2a9229693f5_0_5) starting template, an [instructional walkthrough](https://drive.google.com/file/d/1-siKID2qN_HN3X2CirGSAirAsFcUsJ_t/view), and example Customer Success Plans for [Ultimate](https://docs.google.com/presentation/d/16qs1aWshwzMViPN7esP9yvRt4KyJBAfTHxuW1x4NOcs/edit#slide=id.g2a63ef65412_0_150) and [Dedicated](https://docs.google.com/presentation/d/1n-YodJE6ZGOJ1LTT53Vk6PwwOlBf0h-XvVAVotTonf8/edit#slide=id.g24cd733349c_7_898)  as a reference.
