---
title: Strategic Solution Selling
---

This is a practice guide for a Solutions Architect (SA) to engage enterprises for driving a **strategic solution** during discovery and scoping stage, which can lead into the technical evaluation.

A strategic solution is aimed to provide a customer the DevOps capabilities for delivering software better and faster with an organizational wide impact and aligned with the enterprise transformational intiatitives. The SA will assess and provide the solutioning as the right fit for the enterprise from the business and technical perspectives. The solution should aligne with the business outcomes that can be realized based on the DevOps roadmap vision. Further the solution can accelerate the customer's DevOps transformation at scale.

<img src="/handbook/solutions-architects/sa-practices/strategic-solution-selling/strategic-solution.png" alt="Strategic Solution">

## Analyze and Gather Information

When an opportunity is qualified [**during the discovery**](/handbook/sales/playbook/discovery/) by a Strategic Account Executive (SAE), the SAE will work with the SA and decide the plan for next steps. The SA may conduct a **technical** discovery on the first call with the customer. Then the SA can start the analysis for scoping.

The following diagram shows the mindset for the SA to consider when expanding the technical feature considerations to the strategic solutioning, specifically the information that needs to be discovered and gathered. It involves various activities based on the SAE and SA being engaged with a customer during the discovery and scoping.

<div style="width: 640px; height: 480px; margin: 10px; position: relative;"><iframe allowfullscreen frameborder="0" style="width:640px; height:480px" src="https://lucid.app/documents/embedded/fa7a09ed-e840-4c2a-a18b-1270a5cff62b" id="a8lEA_q1dGe5"></iframe></div>

_Note_: _To increase the size of the diagram, press "full screen" icon in the top right corner and increase the size via "zoom options" in the bottom right corner._

Strategic Outcomes play a key role in the overall Strategic Solution Selling process. The below points provide a short introduction.

**Roadmap** - shows key milestones focusing on GitLab solutions and capabilities. The roadmap should be aligned with the customer's business strategy and key initiatives and be supported by the IT / Business alignment deliverables. Additionally, the roadmap will be very beneficial for the Technical Account manager (CSM) to understand the required next steps and the strategic decisions clearly.

**Stakeholders** - identified essential technical and business stakeholders who will drive the initiatives, pre-sales and post-sales engagement.
From the Solution Architecture point of view, it is important to identify the technical decision makers, internal advocates or champions, influencers, as well as saboteurs (the person who is benefiting from the current solution).

**Current State** - a better understanding of why the change is needed regarding the Enterprise / Account environment. The business need(s) and changes required should be an input for defining the "Future State".

**Future State** - the future state organisation focuses on DevOps and DevSecOps, ensuring the key stakeholders have a shared vision of the business outcome. Is is very beneficial to define the conditions to meet the business requirements.

### Activities for SA to Consider

Research and analysis of the opportunity are critical to identify the strategic direction of the "scoping" and "technical evaluation" stages which may require SA lead technical discovery. Technical discovery activity should provide advantageous knowledge to help navigate the conversations with the customer. This can be even more crucial for a new logo, where the relationship with the prospect has not been well established yet.

Since these activities require extensive work, there needs to be pre quallification of the opportunity for the consideration based on the personas engaged and the size of the opportunity.

Discovery should be based on the SAE and SA collaboration but is owned by the SAE. Business-related information will be more easily identified by the SAE, where as the SA can lead to identify technical challenges, the technology landscape and aligned key GitLab capabilities based on the customer environment. The initial discovery information can better equip the SA with the knowledge for the further discussions with the customer.

The initial information is based on various sources of information, which can be found, for example via public channels, such as LinkedIn, Company blogs, or public reports. Although the initial analysis step might not always expose the pain points for the customer it is vital to them which might be used for future discussions with the customer. It will help to align and to address the future value proposition.

### Technical Discovery Approach

SA teams have mapped out technical discovery approach with pre call preparation, conducting the call and followed by the strategic planning. Refer to these documents for details:

- [_SA Technical Discovery Process & Guide_](https://docs.google.com/document/d/1GZnbqE_rtGFRAJxoeje4mtFyP1AfpLLueESijXgikm4/): The goal of this document is to provide a workflow on how to conduct better technical discovery calls with customers to ensure we are aligned for an efficient technical evaluation. (for internal access only)
- [_SA Modern Apps Discovery Process & Guide_](https://docs.google.com/document/d/11-o9oTxSLomBoOTerGnfj3HXzXbouZ2p6yuIfXuJweQ/): The goal of this document is to provide guidance for technical discovery & process for assisting our customers with their modern applications journey. (for internal access only)

### Tools for Information Analysis

Different tools can be used to build successful foundations for the initial conversations with the prospect. For instance, mind maps provide a visual way of presenting information and allow the quick connecting of different dots/areas. It also helps to organise the data and create various relationships between other pieces, which as a result, simplifies the thinking process.

The following mind map provides an example of building the information about the "customer A" environment from a technical standpoint:

<div style="width: 640px; height: 480px; margin: 10px; position: relative;"><iframe allowfullscreen frameborder="0" style="width:640px; height:480px" src="https://lucid.app/documents/embedded/c84e0d57-a0e2-4e77-8a51-3e1554ff09b3" id="QxMxc3zldnvA"></iframe></div>

The complete [example](https://drive.google.com/file/d/1Qy9bsMmBDqr5ZaMguGGVDwJ5-rkPyxb9/view?usp=sharing), was created based on the GitLab's customer and can be found with the above link for reference (accessible only internally).

This [template](https://docs.google.com/presentation/d/1xilP8z7nYHJVa05qiBNFq2cEoq4HtKj-c-bbR0Y29JY/edit?usp=sharing) can be used by the account team to brainstorm. The brainstorming session between the SA and SAE helps with the alignments of the future stages of the sales process, specifically focusing on "discovery", "scoping" and "technical evaluation".

### Example Discussion Areas

Key areas driven by SA during the initial customer engagement include for example:

- Technological landscape
- Strategic technology initiatives
- Migrations from one technology to another
- Key technical stakeholders
- Any technical challenges, which organization is facing
- Application modernisation
- Microservice architecture and development process
- Key technical engagements and collaborations
- Agile practice and process
- Aligned GitLab capabilities / solutions
- Industry related initiatives, such as regulations and compliance, security mindset and practice

After the initial engagement and activities, asynchronous / synchronous collaboration can benefit the SAE and SA to analyze the current data and connect business points with the technical aspects. The SAE should provide the key directions from the business point of view to the solution architecture team. The SA can indicate the main areas or capabilities and the high level idea for solutioning, which should subsequent conversations with the customer.

## During Technical Discovery and Scoping

Armed with the information synthesized, the initial set of calls or reviews with the customer can be oriented based on the personas engaged. The typical personas booked can be:

- DevOps or platform engineers
- App Dev team engineers
- DevOps team manager to director:
- Dev and Operations manager to director

For teams managing the DevOps tools such as DevOps or platform teams, listen to the challenges with tools and process, and identify if there are concerns for adoption by the app dev teams;

For the app dev teams, understanding the challenges with tools and process and how they may present any issues for software delivery;

During the call, listen and probe for the key information about:

- pain points and challenges, or opportunties
- what is the current solution and who owns it
- assess if it is **transactional** to solve a specific problem or pain point with a limited scope and the users with a prescribed solution
- listen and qualify if the problem identified is in a silo by a single unit or it is an opportunity that is across the entire organization

### Activities for Discovery and Scoping

SAE Driven Activities: setting the stage for the discovery with the meetings and right participants; during the call, take the notes, discover/confirm the organizational structure and approach

SA Driven Activities: during the call, more prescriptive in assessing the conversation as **transactional** vs **strategic** solution.

Activities driven by the SA + collaboration with the SAE

- Map out the technical team structure and work with the SAE to expand the stakeholders for discussion if we agree on the pre qualification
- Collaborate on the organizational priority + inject into the discussion for initiatives and changes that can drive the conversation beyond just tools / features

#### Transactional based solutioning

Not all calls will lead into the strategic solution selling and some of them will simply result in a transactional deal. For a more tactical and transaction based sell, here are some points to note:

- Point Solution: a customers is looking for a small team solution or a single stage to address a specific problem and required to integrate to existing tools
- Support: There is no sponsorship or initiative to investigate the bigger DevOps problem at a broader scope
- Sentiment: Uncertain about the Platform approach where the indvidual or team is more focusing on a specific feature

#### Signs to Drive Strategic Discussion for a Broad Solution

The following aspects oultine a more strategic dialog for SA to lead and engage with the customer:

- Appetite for process and structure re-alignment and change, such as
  - Agile process
  - Shift-left security
- Discussion on the organization mind set, people and culture instead of job tools / features:
  - DORA review of accelerated state of DevOps to become top performer for software delivery;
  - Drive developer's experience
- Team/Stakeholders: People we engaged in the discovery have adoption and change management for the organizational thinking instead of individual tools and technology change

When engaging with the topics that lead to good responses from the initial discussion, the SA can expand the topics and discussions to a higher level or to other influential stakeholders.

[**Value Stream Workshop**](/handbook/solutions-architects/sa-practices/value-stream-discovery/#value-stream-workshop) may be positioned for deeper understanding and further solidify the strategic partnership and engagement.

## Capabilities and Solutions

A SA can lead and identify required capabilities and solution framework upon the following information gathered and analysis performed:

- Information and knowledge on the current challenges, pains and problems
- Assessment of the opportunity as transactional based solutioning with limited features vs extending to strategic account planning (coordinate with SAE)
- May be a smaller land but earns the right for a bigger conversation

Capabilities for the DevOps platform should have been explored with the customers in these areas as example:

**Developer Experience**

- Code management with review and approval
- Ownership and process from develop, release and operate
- Team collaboration and transferable skills
- Talent retaining

**Governance and Compliance**

- Regulatory mandate
- Compliance and audits
- Change control

**Security**

- Application security
- Secure software development
- Security posture and Cybersecurity exposure

With these capabilities identify, the solution options can be considered:

[**DevSecOps**](https://about.gitlab.com/solutions/dev-sec-ops/) with shift left security: security team is engaged and measurable business outcome is identified to improve the overall security posture while delivering the software faster;

[**Continous Software Compliance**](https://about.gitlab.com/solutions/compliance/) with built-in compliance, governance, policies and audit needs: compliance and change management teams are engaged to ensure that the app teams have guidance and framework to deliver software with regulatory or enterprise standard compliance;

[**Automated Software Delivery**](https://about.gitlab.com/solutions/delivery-automation/) by transforming and modernizing the continous integration and delivery, and driving the organization to become the top performer in software delivery;

[**DevOps platform**](https://about.gitlab.com/solutions/devops-platform/) to leverage the DevOps innovations for a unified developer experience with scalable and reliable solution for large scale adoption.
