---
title: Solutions Architects - Subject Matter Experts

---

The Subject Matter Experts (SME) Program is an initiative designed to help solutions architects (SAs) provide better support to customers. The program will identify and onboard subject matter experts in key areas, such as AI, security, and agile planning.

SMEs are Solutions Architects who will help SAs in their region to answer more-in-depths questions, provide deep technical expertise, and assist with customer demos and presentations when needed.

## Goals

The goals of the SME Program are:

- Provide fellow SAs with the knowledge and expertise they need to support customers effectively.  
- Improve the quality of customer support by reducing the number of questions that SAs have to answer.  
- Increase customer satisfaction by providing them with access to experts who can answer their questions quickly and accurately.

In order to fulfill the above goals, the [SME Program is structured, appropriately with defined Roles and Responsibilities](/handbook/solutions-architects/sa-practices/subject-matter-experts/sme-program.md), to also support the following processes::

1. [SME Operations - Collab Project, Groups, Slack Channels](/handbook/solutions-architects/sa-practices/subject-matter-experts/sme-operations.md)
2. [SME Nomination and Onboarding \- How to Become a SME](/handbook/solutions-architects/sa-practices/subject-matter-experts/sme-program/#sme-selection)  
3. [How to Request a SME on an opportunity to provide technical guidance and expertise](/handbook/solutions-architects/sa-practices/subject-matter-experts/sme-request/)  
4. [Maintaining Collateral for each SME Area\*](/handbook/solutions-architects/sa-practices/subject-matter-experts/sme-collateral/)  
5. [Regular SME Cadences](/handbook/solutions-architects/sa-practices/subject-matter-experts/sme-cadences/)
6. [Gather Feedback from Customers](/handbook/solutions-architects/sa-practices/subject-matter-experts/sme-customer-feedback/)  
7. [Engage with Product Management](/handbook/solutions-architects/sa-practices/subject-matter-experts/sme-engage-pm/)

\*NOTE: Currently the CSM SMEs have collated resources and materials for each SME Area. They are maintained in Highspot at [CS SME Hub of content](https://gitlab.highspot.com/items/667095b95cc9b08c87d40b68?lfrm=srp.0).

This is [description of the CS SME program](https://gitlab.com/gitlab-com/customer-success/subject-matter-experts/cs-subject-matter-experts/-/tree/main) taking the lead on the gathering of collateral for each SME Area

## Areas of Expertise

The SME Program, with fomal PM engagement will initially focus on the following areas:

- AI
- Security
- Agile planning
- Dedicated

Other areas may be added in the future, depending on customer and SA demand, such as:

- CICD & Runners (TBD - CS only; Can exist but with no formal PM engagement as yet)
- Metrics and Observability (TBD - CS only; Can exist but with no formal PM engagement as yet)
- Embedded Systems (TBD - SA only; Can exist but with no formal PM engagement as yet)
- GitOps
- MLOps

## Responsibilities

In summary, the responsibilities of a SME includes

- Provide technical guidance and expertise
- maintain collateral for each SME Area, Currently the CSM SMEs have collated resources and materials for each SME Area. They are maintained in Highspot at [CS SME Hub of content](https://gitlab.highspot.com/items/667095b95cc9b08c87d40b68?lfrm=srp.0).
- gather feedback from customers
- engage with product management.

SMEs will be responsible for the following:

- **Technical Guidance and Expertise** for the field and/ or customer, often in the form of:
  - Staying up-to-date on the latest trends in their area of expertise.
  - Providing updates to SAs and CSMs on Regional Calls during "SME Corner"
  - Answering questions from SAs about their area of expertise. The preferred channel is our [StackOverFlow for Teams](/handbook/solutions-architects/tools-and-resources/#stack-overflow-for-teams) via #cs-questions.
  - Providing technical expertise to SAs during customer demos and presentations.
  - Office hours to enable other SAs or CSMs
  - Collaborate with Demo Architects on workshop updates and assist Solutions Architects with new feature adoption.
  - Participate in field enablement activities such as [Technical Skills Exchange](https://gitlab.com/gitlab-com/sales-team/field-operations/enablement/-/issues/2800).
  - [Technical Close Plans](/handbook/solutions-architects/sa-practices/technical-close-plan/) reviews
  - [Customer Success Plans](/handbook/solutions-architects/sa-practices/customer-success-plan/) reviews
  - [Deliberate practice](/handbook/solutions-architects/sa-practices/deliberate-practice/)
  - Form [communities of practices](/handbook/solutions-architects/sa-practices/communities-of-practice/) among the SMEs for the same topic and with fellow SAs to foster the knowledge in the team.
- **Maintain Collateral** in the Handbook or Highspot such as the [CS SME Hub of content](https://gitlab.highspot.com/items/667095b95cc9b08c87d40b68?lfrm=srp.0), to be used indepenently by account teams, including:
  - Maintain List of SMEs (also in StackOverFlow) and SME Associates
  - Develop and deliver training materials on their area of expertise.
  - Creating a list of discovery questions to be used during discovery process by SAs
  - Creating frequently asked questions by customers per category
  - Gather and categorize recorded enablement sessions
  - Work with PMs to maintain FAQs for each Area
  - Create Golden [demos](/handbook/solutions-architects/demonstrations/)
  - [Hands-on workshops](/handbook/solutions-architects/tools-and-resources/workshop/)
  - Technical evaluation guidelines
  - [POV](/handbook/solutions-architects/tools-and-resources/pov/) templates
  - Common notional architecture diagrams
  - Competitive intelligence
  - Work with Enablement to ensure SA SME onboarding is updated. Put together a sequence of tasks, by which an SA can gain expertise in a particular area.
- **Engage Product Management and Gather Customer Feedback** from the field to share with product and account teams, such as:
  - Be a counterpart to the Product Manager in the corresponding [product group](/handbook/product/categories/#devops-stages)
  - Communicate with PMs and update the field via a shared medium of communication
  - Ensure that SAs are submitting customer feedback for PM review
  - Review and analyze submissions for patterns, get more context from SAs
  - Meet with their SME Area Leads, at least once a month, async, to calibrate submissions, assign priorities, and prepare to present to PMs a narrative
  - Maintain Issue Board of customer feedback and PM statuses
  - Meet with PMs once a month to review high priority submissions
  - get updates from PMs or work being done
  - ensure submissions are being updated
  - Contribute to product documentation

For other roles including SME Associates, SME Area Lead/ DRI and SME Program Lead, go to [SME Responsibilities](/handbook/solutions-architects/sa-practices/subject-matter-experts/sme-program/#sme-responsibilities) for further details.

## Time Commitment

SMEs are expected to dedicate approximately 10-15% of their time to SME-related activities. This includes:

- Answering questions from other SAs
- Participating in SME/Product meetings
- Developing and delivering training materials
- Staying up-to-date with their area of expertise

The remaining 85-90% of their time will be dedicated to their regular SA responsibilities.

## Recognition and Growth

Being an SME provides opportunities for professional growth and recognition:

- Increased visibility within the organization
- Opportunities to present at internal and external events
- Potential for career advancement
- Recognition in performance reviews

SMEs will be regularly evaluated based on their contributions and impact on the SA team and customer satisfaction.

## Scope

- SME support for an opportunity or an account should be requested by a Primary SA this can include roadmap discussions
- A generalist SA should primarily drive solutions with their broad knowledge. A SME should be consulted ONLY when the generalist SA faces challenges moving forward.
- The existence of SMEs does not guarantee the availability of their engagement.  
- The main focus of SMEs are their regular SA responsibilities and then, their assistance as SMEs
- There will be multiple SME per region (EMEA, APAC, US East, US West) but they will be a cross-regional group of SMEs

## SMEs {#sme-list}

| SME Areas | AI / GitLab Duo | App Security | Agile Planning | Dedicated | CICD / Runners | Metrics / Observability |
|-----------|----|--------------|--------------------|-----------|----------------|------------------------|
| **SME Area Leads** | **SA**: Edmond Chan<br>**CS**: Jess Perry | **SA**: Julia Gaetjens<br>**CS**: Eduardo Guillen, Jess Perry | **SA**: David Astor<br>**CS**: Brianne Parton | **SA**: Alessia Del Vecchio<br>**CS**: Zane Chua | **SA**: Bradley Lee,<br>Ken McKnight<br>**CS**: Rachel Fuerst,<br>Rodney Bowles | **SA**: Zach Henderson,<br>Breno Gomes<br>**CS**: Jordan Monyhan |
| **Product Manager Rep/<br>Engineering Manager Rep** | **AMER**: Taylor McCaslin,<br>Michelle Gill<br>**APAC/EU**: Pini Wietchner,<br>David O'Regan | Alana Bellucci,<br>Sara Meadzinger,<br>Joe Randazzo | **PM**: Melissa Ushakov<br>**EM**: John Hope | **PM**: Chris Balane<br>**EM**: Oriol Lluch | | |
| **APJ** | Ben Ridley,<br>Arun Kumar G,<br>Arjun Krishna | Tomasz Skora | | | | |
| **EMEA NEUR** | Ryan Appleby | Dominique Top,<br>Beatriz Barbosa | Gabriela Dobrescu,<br>James Moverley | Martin McVay | | |
| **EMEA SEUR** | Madou Coulibaly | Paul Dumaitre,<br>Olivier Dupre | | | | |
| **EMEA DACH/META** | Alex Dess | Mirko Brandner,<br>Julia Gaetjens | Ted Gieschen,<br>Hossam Hamdy | Falko Sieverding | Lars Blockken | |
| **US East** | Sam Morris,<br>Manjeet Singh | Bernard Park,<br>James Nyika,<br>Manjeet Singh | Dan Rabinovitz | Adam Zwickey | Jason Morgan,<br>Bradley Lee | Rob Jackson |
| **US West** | Karen Kwentus | Yu-Chen Hsueh,<br>Anthony Baer,<br>Taylor Carr,<br>John Bush | Steve Grossman | Ryan Taylor | Ken McKnight | Siddharth Mathur |
| **High Velocity - AMER** | | | Sophia Manicor | | Noah Ing | |
| **High Velocity - EMEA** | | Claire Marie Champernowne<br>Nupur Sharma | Jan Kunzmann | Corina Patachia | Sarah Matthies | Breno Gomes |
| **Pub Sec** | Kevin Chasse,<br>Josh Swann | Sameer Kamani,<br>Zachary Yates | Joseph Valeriano,<br>Linc Williams | Daniel Marquard,<br>Michael Bradley | Rachel Fuerst | |
| **Partner** | | | | | | |
