---
title: SME Program Structure, Roles and Responsibilities

description: The Structure of the SME Program, Roles and Responsibilities are detailed here.

---

## SME Program Structure

The SME program will be chaired and led by an overall **SME Program Lead,** responsible for establishing and  ensuring that all the SME processes are being adhered to by each SME Area.

The SME Program will consist of one or more [SME Areas of expertise](/handbook/solutions-architects/sa-practices/subject-matter-experts/#areas-of-expertise).
Each SME Area will be represented by two **SME Area Lead/ DRI**, one representative from the SA org, and one from the CS org. They will be responsible for the proper functioning of each area.

Each SME Area should be supported by at least one Product Manager and/or Engineering Manager representative.

In total, each SME AREA will consist of

1. Two SME Area Leads or DRIs - a SA representative and a CS representative
2. At least a Product Manager and/or Engineering Manager representative
3. At Least 3 SMEs, each selected from each of the following regions: EMEA NEUR, EMEA SEUR, DACH/ META, APAC, US East, US West, Commercial, Partners/Pub Sec.

For the SA Org, we recommend that there should be only one Subject Matter Expert (SME) representative per region, for each SME Area of expertise.  This is to ensure that there is one SME per Area who is willing and responsible to carry out the responsibilities and tasks for the propor functioning of the SME program.

Each SME Area, therefore with both SA and CS Area Leads and all SA and CS SMEs can be referred to as a SME Area Pod.  Each Pod will have their own [cadence meetings](/handbook/solutions-architects/sa-practices/subject-matter-experts/sme-cadences/#sme-area-pod-cadence).  Both SA and CSMs can attend the same pod meeting.

| SA SME Program Lead | CS SME Program lead |
| :---- | :---- |

| SME Area Pod | |
| :---- | :---- |
| SA SME Area Lead | CS SME Area Lead |
| SA Regional SME 1 | CS SME 1 |
| SA Regional SME 2 | CS SME 2 |
| SA Regional SME 3 | CS SME 3 |

While it is highly recommended to have only one SA SME for each area per region, there can exist other subject matter experts (SME) or SME Associates.  However one SA should be designated regional SME per area who will take on the responsibilities of being a SME DRI in the SME program, including maintaining collateral, gathering feedback from customers, engaging with product management.

Here is the list of the [current SA SMEs for each Area](/handbook/solutions-architects/sa-practices/subject-matter-experts/#sme-list).  This is the list of the corresponding [CS SMEs for each Area](https://gitlab.com/gitlab-com/customer-success/subject-matter-experts/cs-subject-matter-experts/-/tree/main#who-are-the-current-smes-and-what-areas-are-they-focused-on).

## SME Roles

### **SME Associates**

SMEs are expected in general to fulfill two main responsibilities:

* Be experts and maintain a high level of expertise in their area, craft and domain
* Be the DRI and be responsible for leading and directing various aspects associated with the SME program including, maintaining collateral, gathering feedback from customers, engaging with product management.

However there would be number of SAs (and CSMs) who, as part of their career development, would not desire or are not ready to participate as a DRI in the SME program, but would express interest to focus and go technically deeper in one of the SE Areas: AI, App Security, Agile Planning, Dedicated, CI & Runners (TBD), Metrics and Observability (TBD)

Think of SME Associates as those potential SMES. who declare a major as they look to advance and graduate in their craft.

These are not the regional SME representatives, who are responsible for leading and directing various aspects of the SME program.

These are SME Associates. There are no limits to number of SAs who can express interest in becoming an expert in any one of the SME Areas.

As an example, an SA manager can encourage all SA team members, in a geography or region, to express interest in having one or more focuses, as a part of their development, to improve their craft in that area.

SME Associates can be mentored by their regional SMEs.

SME Associates can form a pool from which the next Regional SME for a particular area can be selected.

Full Responsibilities for this and other SME roles are detailed [here](\#sme-responsibilities).

### **SMEs (Regional SA representative for each SME Area)**

SMEs are SAs and CSMs who, not only have declared a major, attained recognizable expertise, but who are selected officially to represent a region for a particular SME Area.

SMEs will be responsible for their area of expertise for their region, and to ensure the smooth running of the SME program.

SME’s during their tenure in the program must be willing to have the [specified time commitment](/handbook/solutions-architects/sa-practices/subject-matter-experts/#time-commitment)

Full Responsibilities for this and other SME roles are detailed [here](\#sme-responsibilities).

### **SME Area Lead/ DRI**

SME Area Leads/DRIs will be responsible for their area of expertise and leading their SME teams. They are the project managers for their SME Areas.

They are responsible for

* Setting up and maintaining the calendar of SME calls for each areas
* having regular cadences with the SME Area pod
* maintain cadences and engage with Product Management.
* maintaining the roster of SMEs and keeping track of SME Associates.  Ensure that this roster is maintained in this handboom and in Stack OverFlow
* Maintain the membership of all Google Groups and [SME Slack channels](/handbook/solutions-architects/sa-practices/subject-matter-experts/sme-request/#sme-slack) for their area.

Full Responsibilities for this and other SME roles are detailed [here](\#sme-responsibilities).

### **SME Program Lead**

The SME Program Lead is responsible for:

* Ensuring the SME program cadences are taking place
* Ensure that SME Area leads are represented in ARR Driver Meetings
* Ensure the appointment and rotation of SME Area Leads
* Any adjustments needed in Customer Feedback Framework, templates, prioritization process
* Maintaining the Process to engage SMEs
* Track metrics in SME Utilization and Impact
* Maintain relationships with PMs
* Assist with SME Area Lead rotation and selection process
* Help onboard any new SME programs

## SME Responsibilities {#sme-responsibilities}

| Main Responsibility | SME Associate | SME | SME Area Lead | SME Program Lead |
| :---- | :---- | :---- | :---- | :---- |
| **Technical Guidance and Expertise** | -Opportunity consultations <p>-Demo or presentation reviews <br>-Customer calls <br>-Participate in Enablement sessions <br>-Deliberate practice  | <br>- Staying up-to-date on the latest trends in their area of expertise. <br>- Providing updates to SAs and CSMs on Regional Calls during "SME Corner" <br>- Answering questions from SAs about their area of expertise. The preferred channel is our [StackOverFlow for Teams](/handbook/solutions-architects/tools-and-resources/#stack-overflow-for-teams) via #cs-questions.<br>- Providing technical expertise to SAs during customer demos and presentations.<br>- Office hours to enable other SAs or CSMs <br>- Participate in field enablement activities such as [Technical Skills Exchange](https://gitlab.com/gitlab-com/sales-team/field-operations/enablement/-/issues/2800).<br>- [Technical Close Plans](/handbook/solutions-architects/sa-practices/technical-close-plan/) reviews <br>- [Customer Success Plans](/handbook/solutions-architects/sa-practices/customer-success-plan/) reviews <br>- [Deliberate practice](/handbook/solutions-architects/sa-practices/deliberate-practice/) <br>- Form [communities of practices](/handbook/solutions-architects/sa-practices/communities-of-practice/) among the SMEs for the same topic and with fellow SAs to foster the knowledge in the team. |  |  |
| **Maintain Collateral** |  | <br>-Creating a list of discovery questions to be used during discovery process by SAs <br>-Creating frequently asked questions by customers per category <br>-Maintain a list of Recorded enablement sessions for each Area in Highspot <br>-Work with PMs on FAQs Golden [demos](/handbook//solutions-architects/demonstrations/) <br>-[Hands-on workshops](/handbook//solutions-architects/tools-and-resources/workshop/) <br>-Technical evaluation guidelines <br>-[POV](/handbook//solutions-architects/tools-and-resources/pov/) templates <br>-Common notional architecture diagrams <br>-Competitive intelligence | <br>- Maintain List of SMEs (also in StackOverFlow) and SME Associates <br>- Develop and deliver training materials on their area of expertise <br>- Creating a list of discovery questions to be used during discovery process by SAs <br>- Creating frequently asked questions by customers per category <br>- Gather and categorize recorded enablement sessions <br>- Work with PMs to maintain FAQs for each Area <br>- Create Golden [demos](/handbook/solutions-architects/demonstrations/) <br>- [Hands-on workshops](/handbook/solutions-architects/tools-and-resources/workshop/) <br>- Technical evaluation guidelines <br>- [POV](/handbook/solutions-architects/tools-and-resources/pov/) templates <br>- Common notional architecture diagrams <br>- Competitive intelligence <br>- Work with Enablement to ensure SA SME onboarding is updated. Put together a sequence of tasks, by which an SA can gain expertise in a particular area. |  |
| **Customer Feedback/ PM Engagement** |  |  <br>- Be a counterpart to the Product Manager in the corresponding [product group](/handbook/product/categories/#devops-stages) <br>- Communicate with PMs and update the field via a shared medium of communication <br>- Ensure that SAs are submitting customer feedback for PM review <br>- Review and analyze submissions for patterns, get more context from SAs <br>- Meet with their SME Area Leads, at least once a month, async, to calibrate submissions, assign priorities, and prepare to present to PMs a narrative <br>- Maintain Issue Board of customer feedback and PM statuses <br>- Meet with PMs once a month to review high priority submissions <br>- get updates from PMs or work being done <br>- ensure submissions are being updated <br>- Contribute to product documentation | <br>-Lead the Review and analysis submissions for patterns, <br>-get more context from SAs <br>-**Ensure that submissions are properly tagged with the right themes** <br>-**Set up and Lead meeting with SME Area Leads** globally, at least once a month, async, to calibrate submissions, assign priorities, and prepare to present to PMs a narrative <br>-Lead the maintenance of Issue Board of customer feedback and PM statuses <br>-**Set up and Lead meetings with PMs** once a month to review high priority submissions, <br>-get updates from PMs of work being done, <br>-ensure submissions are being updated. <br>-**Maintain relationships and collaboration with PMs** <br>-**Select Customer Feedback that would drive revenue, and meet with other SME Area Leads once a quarter in ARR Driver meeting** <br>-Arrange for PMs to enable SAs, <br>-gain access to Beta functionality etc. <br>-Contribute to product documentation |  |
| **Manage SME Program** |  |  |  | <br>-Ensuring the SME program cadences are taking place <br>-Maintain the calendar of SME calls for all areas <br>-Ensure that SME Area leads are represented in ARR Driver Meetings<br>-Ensure the appointment and rotation of SME Area Leads <br>-Any adjustments needed in Customer Feedback Fraemwork, templates, prioritization process <br>-Maintaining the Process to engage SMEs <br>-Track metrics in SME Utilization and Impact <br>-Maintain relationships with PMs <br>-Assist with SME Area Lead rotation and selection process <br>-Help onboard any new SME programs  |

|  |
| :---- |

## SME Selection, Nomination and Rotations {#sme-selection}

### **SME Associates**

SAs and CSMs as part of their 1-1 process, mid year review, Individual Growth Plans, should indicate a desire to focus on a particular area of the GitLab Platform

SA manager should make this known to the SMEs for their regions

SMEs along with SA managers should ensure that SAs who express this interest should follow a program to gain the necessary expertise. This can take the form of mentorship, office hours, certifications, a prescribed set of training, videos, demos, support for workshops and field events.

### **SMEs (Regional)**

1. SMEs should be prepared to be in the role for at least a year and up to 2 years.
2. SMEs SA Associates who are interesting in representing their regions should make that known to their SA managers
3. SA managers within a region or geographical area should collaborate together, to review areas of expertise and relevant experience. and choose a SME to represent their region
4. Make the SME Area Lead aware of any change in a SME for the region.

### **SME Area Leads and SA Program Lead**

The nomination and selection process for SME Are Leads will be as follows:

1. SME Area Leads should be prepared to be in the role for at least a year and up to 2 years.
2. SME Program Lead should be prepared to be in the role for at least 18 months and up to 3 years.
3. Open call for applications: SAs and existing SMEs who are interested in becoming SME Area Leads can apply by submitting their areas of expertise and relevant experience. The Product Management team is also invited to recommend a nominee.
4. Review of applications: A panel consisting of senior SAs and leadership will review the applications.
5. Selection: The panel will select SME Area Leads based on their areas of expertise and relevant experience.
6. Onboarding: Selected SME Area Leads will undergo a brief onboarding process to familiarize with their new responsibilities and expectations.

## SME Training (TBD)

Training to become a SME can take the form of mentorship, office hours, certifications, a prescribed set of training, videos, demos, support for workshops and field events.

In addition, SMEs should be given the opportunity to attend conferences and speak on behalf of GitLab in their area of experties.

We will offer a Shadow a PM program in the future.

Currently the CSM SMEs have collated resources and materials for each SME Area. They are maintained in Highspot at [CS SME Hub of content](https://gitlab.highspot.com/items/667095b95cc9b08c87d40b68?lfrm=srp.0).

The Goal in the future is to organize the content in a prescribed way to allow a SME Associate to gain expertise to become a SME (TBD)

## SME Onboarding (TBD)

When a new SME for any area is selected, the following steps will be taken:

1. Add the SME to the relevant Goggle Group (TBD) for their Area of Expertise. This will ensure that the SME is added automatically to all cadence calls for that Area.
2. Add the SME to the appropriate Stack OverFlow team area to begin answering questions
3. Add the SME to the appropriate [SME Slack Channel](/handbook/solutions-architects/sa-practices/subject-matter-experts/sme-request/#sme-slack)
4. TBD
