---
title: Support Leadership Sync
description: "Weekly Support Leadership Sync meetings"
---

### Purpose

Support leadership (Managers, Senior Managers and Director) participate in cross-regional meetings weekly.

The purpose of these meetings is to:

- build relationships, trust and context between managers
- address operational items such as availability
- explain context for issues and explore creative ideas in real time
- refine the problem statement of each raised issue by clarifying intent

The purpose of these meetings is **not** to:

- figure out the priority of issues
- gather feedback that can be given asynchronously on related issues
- refine solutions or merge requests related to issues
- make decisions

**Note:** It is worth reiterating that these meetings are not for making decisions or discussing things that could just as effectively be discussed within issues.

### Organization of Support Leadership Meetings

#### Schedule

1. As a global team, we have to strike the right balance in using our synchronous time wisely, and be mindful of the time zones and people's availability. To enable this, the weekly leadership syncs rotate through one region every week.
1. The meetings are available in the GitLab Support calendar.
1. Every meeting is set to automatically record and the recording can be accessed via the [GitLab Videos Recorded](https://drive.google.com/drive/u/0/folders/0APOeuCQrsm4KUk9PVA) shared drive.

#### Agenda

1. The agenda and notes are in a Google Doc: [Support leadership calls agenda and notes](https://drive.google.com/drive/u/0/search?q=parent:1eBkN9gosfqNVSoRR9LkS2MHzVGjM5-t5%20%22Support%20leadership%20calls%20agenda%20and%20notes%20(2021)%22) (internal only)
1. The agenda outline for next week should be created as the last item in the current week's sync. All agenda items should be added before the sync meeting of the week. Anything that is added later will most likely be ignored by most or all of the leadership, or not discussed, losing value. Appropriate Slack channels must be used to discuss any emergency items, especially if the sync meeting of the week is already done.
1. Please follow the below guidelines when adding agenda items:
   1. **Operational**: This section is for standing weekly updates regarding Hiring, Availability, Customer Accounts, Team Call-Outs etc.
   1. **Discuss**: Items under this section should be for things that need to be synchronously discussed, or need input. These may or may not have an associated issue.
   1. **Inform**: Items under this section are:
      1. issues we want to bring to everybody's attention in order to request **asynchronous** input
      1. things we should all be aware of, such as a new process around expense approval, updates from People Business Partner, etc.
   1. **Confidential Doc**: Use this document for discussion surrounding a specific individual's promotion, performance or individual situation, discussion about sensitive or confidential issues and processes. Add `See confidential doc item` as an item under `Inform` or `Discuss` in the general agenda depending on the action required for the item you've added in the confidential doc.
1. Each meeting has a chairperson to ensure that voices are heard equally and we make progress through the agenda.
1. All participants should be familiar with the [Video Calls Section](/handbook/communication/#video-calls) of the Communication page in the Handbook.
1. See this video, [Managing Support Leadership Sync Agendas and Meetings](https://drive.google.com/drive/u/0/search?q=managing%20support%20leadership%20sync%20agendas%20and%20meetings%20parent:1h1iaTgBbZJZG7CBNYUCRQPhMXe1xXlbM), for more information, including how to edit and use the agenda and notes document.

### Call Procedure

#### As a chair

1. Review the meeting agenda before the meeting time.
1. Review the `Operational` section of the agenda and mention anything that may have an action item, or may need an action item such as:
   1. *Hiring data*: *Is there anything that is of note for the regions that are meeting?*
   1. *Holidays*: *Do we have (or need) a coverage plan for this holiday?*
   1. *Availability*: *How are the different regions looking in terms of availability next week?*
   1. *Metrics Review*: *Is there anything that needs to be highlighted to the executive team?*
   1. *Group Conversation*: *Please take a look at the slides, and add any points of interest for the general company*

1. Facilitate discussion of the items in the `Discuss` section of the agenda document.
1. Be aware when people unmute - this is an indication that they have something to say. If necessary, please interrupt and pass the floor. We want everyone to contribute, so it's your job to make sure that this can happen.
1. Assign any action items - including summarizing the discussion in an issue.
1. Stop the recording before discussing items in the confidential doc, if there are any.
1. Create the agenda outline for next week from the template as the last step.

#### As a manager

1. Add agenda items no later than before the start of that week's sync meeting.
1. Review each agenda item. If you have any feedback for items under `Discuss` and will not be joining the meeting synchronously, add them under `Async Notes` for that item.

#### As a synchronous meeting participant

1. If you raised an item for discussion, be brief (everyone should be familiar with the discussion), clear (why did you bring this item to this meeting), and understanding (others may interrupt you while speaking due to the nature of video calls (For more on this see point 13 in the [Video Calls Section](/handbook/communication/#video-calls) of the Communication page)).
1. Use majority of the meeting time to build rapport with the folks on the call.
   1. Talk through team related call-outs, share tips and tricks, latest learnings and others.
   1. You should feel empowered to talk about things not on the agenda - sometimes, we need our peers' guidance and experience on things that might be bothering or challenging us.
1. After the meeting, note any points that you made during the meeting that were relevant to the discussion.

#### As an asynchronous meeting participant

1. Set aside time at the end of the week to review the agenda document and/or meeting recording from that week.
1. Make note of the things under `Inform` and `Discuss`, and contribute via respective issues.

### Setting up the meetings

Due to some weirdness between the Zoom app and web UI, you have to do this in two parts:

#### Part 1 - Zoom app

Because the web UI does not allow for adding it to Google calendar, you need to start via the app.

In your Zoom app, click the `Schedule` button. This will bring up a window to add a scheduled meeting.

On this window:

1. Put the name of the meeting in the Topic box
1. Check the box for `Recurring meeting`
1. Under the `Meeting ID` section, check the bubble to `Generate Automatically`
1. Under the `Security` section, make sure to use the `Passcode` option
1. Under the `Video` section, have both `On` bubbles selected
1. Under the `Audio` section, have the `Telephone and Computer Audio` bubble selected
1. Under the `Calendar` section, have the `Google Calendar` bubble selected
1. Click the down arrow by `Advanced Options` and
   1. check the box for `Allow participants to join anytime`
   1. check the box for `Automatically record meeting`
   1. select the bubble for `In the cloud`

With all that done, click `Save`. This will then open a browser window to authenticate via Google to add the event to the calendar.

When adding the event to the calendar, ensure:

1. The date, start time, end time, and timezone are correct (see [Time Settings](#time-settings-for-the-meetings) down below)
1. The recurring settings are correct (see [Time Settings](#time-settings-for-the-meetings) down below). This is found to the right of the `All day` box
1. You attach the [Support Leadership Google doc](https://drive.google.com/drive/u/0/search?q=parent:1eBkN9gosfqNVSoRR9LkS2MHzVGjM5-t5%20title:%22support%20leadership%20calls%20agenda%20and%20notes%22%20owner:tatkins%40gitlab.com)
1. You put it on the GitLab Support calendar (option is right below the `Add notification` option)
1. You set the availability to `Free` (option is right below which calendar to put it on). This is **vital** to ensure it does not block customer calls.
1. Invite the correct list of people
   - <jmichniewicz@gitlab.com>
   - <rtakken@gitlab.com>
   - <support-managers@gitlab.com>
1. Under `Guest permissions`, have the following boxes checked:
   - Invite others
   - See guest list

With that, click the Save button at the top-right.

#### Part 2 - Zoom web UI

Next we add the co-hosts for the meeting. To do this, go to [My Meetings](https://zoom.us/meeting#/upcoming) in the Zoom Web UI. Then locate the meeting in question , hover over it, and click the `Edit` button.

On the edit page, click the `Options` item (towards the bottom of the section) and then click in the box under `Alternative Hosts`.

You will now need to manually add each manager to the `Alternative Hosts` box. For a complete list, see the [support-managers Google group member list](https://groups.google.com/a/gitlab.com/g/support-managers/members).

Once you have added all of them in, click the blue `Save` button.

#### Time Settings for the meetings

| Meeting | Start Time | End Time | Timezone | Recurruing Schedule|
|---------|:----------:|:--------:|:--------:|--------------------|
| [REC] Support Leadership Sync - APAC<>EMEA   | 0900 | 0950 | +00:00 UTC | Every 3 weeks on Wednesday |
| [REC] Support Leadership Sync - AMER<>APAC-E | 2200 | 2250 | +00:00 UTC | Every 3 weeks on Wednesday |
| [REC] Support Leadership Sync - EMEA<>AMER   | 1600 | 1650 | +00:00 UTC | Every 3 weeks on Thursday |
