---
title: Support 1:1s
description: "Support team 1:1s guidelines"
---

## Aims and context

At GitLab we have [weekly 1-1s](/handbook/leadership/1-1/).

The **aim** of this page is to:

1. Encourage consistency across the global Support team when discussing [Support Engineer Responsibilities](/handbook/support/support-engineer-responsibilities)
1. Help make work visible

This page **does not**:

1. Prescribe exactly how a 1:1 should be conducted - these are guidelines
1. Include guidance on how to discuss career development, performance reviews and personal issues. **Please leave time in 1:1s for these other important areas.**

**Guidelines:**

1. You should be able to cover the key components outlined on this page in 10 to 15 minutes.
1. Leave time for general conversation and other important areas like career development.
1. Some weeks you may focus entirely on another area (e.g. personal issues, or a project you're working on)
1. Sometimes you may wish to schedule a longer or additional call to focus on an important area

## 1:1 Issue Generator Project

You may choose to use the 1:1 Issue Generator for your 1:1s.  See the project [Readme](https://gitlab.com/gitlab-com/support/1-1s/1-1-issue-generator/-/blob/master/README.md) for more details.

## Call structure

### 0. Pre-call

1. Select ticket(s) for review (see below)
1. Review activity links (see below)

### 1. Starting the call

Most people like to start the call with five minutes of general conversation.

We recommend avoiding [small talk](https://en.wikipedia.org/wiki/Small_talk) openers like 'How are you doing?'. Instead, set the context and get precise, actionable information. Some examples:

- Use a five point scale and ask 'On a scale of one to five, how are you feeling this week?' (see below for sample text).
- Ask for two ratings on a 0-10 scale, one for "stress" and one for "happiness."

Pay attention to trends over time.

Questions like these help open the conversation and put the work-related aspects in context. (Credit for the idea from [this GitLab conversation](https://twitter.com/gitlab/status/1244728191069171716).)

**Give the Support Engineer the opportunity to raise anything important they would like to discuss near the beginning of the call. You might want to skip the sections below if there are more important things to focus on.**

### 2. How was ticket work this week?

The core focus of a Support Engineers' work is helping customers by resolving support tickets, so it's important to spend some time each week discussing this work.

**A. Ticket Review**

Each week you should review two tickets together during the 1:1 call. This can be done in 5 to 10 minutes. It's not an in-depth review. Details on how to do this are in the [Working on Tickets page](/handbook/support/workflows/working-on-tickets#1-weekly-ticket-review). We recommend that the manager reads some tickets before the call so that you are ready with concise feedback. The `Comments Review` tab on your personal Zendesk Explore dashboard is a good place to locate relevant tickets. The table on the left shows tickets that your reports have made more than one comment on in the last week. This makes it easy to find tickets they have been primarily focused on.

**B. Public replies on assigned tickets (optional discussion)**

Take a look at your team's Zendesk Explore dashboard and see how they're doing with the goal of around 50-60% of public replies on tickets that are assigned to themselves. [Details about this on the Working on Tickets page](/handbook/support/workflows/working-on-tickets#2-public-replies-on-your-assigned-tickets).

It's likely you can skip this section if people are successfully balancing their contributions.

**C. Meeting the ticket baseline (optional discussion)**

Take a look at your team's Zendesk Explore dashboard and see if they are meeting the ticket baseline. [Details about this on the Support Engineer responsibilities page](/handbook/support/support-engineer-responsibilities#ticket-baseline).

It's likely you can skip this section if you're happy with the contributions people are making.

### 3. Discuss career development and learning

Discuss the career development and learning aspirations of the Support Engineer **at least quarterly** and provide guidance to help reach the goals.

Agree on and document a training plan that accommodates those aspirations and meets the needs of the support team in terms of enhancing team skills and filling knowledge gaps.

Agree on checkin points to review progress and, if necessary, to assist the Support Engineer in prioritizing and allocating the time required for [Learning and Development](/handbook/people-group/learning-and-development/).

[Further details on Career Development Page](/handbook/people-group/learning-and-development/career-development/#recomendations-for-managers-to-support-the-learning-of-team-members)

### 4. Discuss other activities from responsibility areas

Discuss interesting activities from the **activity links** at the top of the document (see below for examples).

There may be activities that the Support Engineer would like to discuss that aren't included in the activity links.

### 5. Time Off

- Ask whether the SE has had a day off in the past month, and if not encourage them to plan for one soon
- Ask whether they have upcoming time off, and if they do:
  - remind them to review the [Support Team Member Time Off page](/handbook/support/support-time-off) and then to get appropriate coverage for their tickets and roles
  - ask them if they have any questions about what to do
  - set a reminder for the day before the first PTO date to check with the SE if they've not yet reported to you on their progress in getting coverage
- If they've had time off recently, ask whether they made all necessary coverage arrangements and discuss any problems that either of you observed

### 6. Other discussions

Everyone has different things they like to focus on in 1:1s. The rest of the call should focus on things the Support Engineer and manager would like to discuss.

---

## Text and links for the 'header' of 1:1 notes documents

All 1:1 notes documents should include similar text and links at the top.

### 1. How are you feeling this week on a scale of 1 to 5?

1. Very positive
1. More positive than usual
1. Same as usual
1. Not as good as usual
1. Not great right now

### 2. Activity Links

1. Assigned tickets: `https://gitlab.zendesk.com/agent/users/{USER_ID}/assigned_tickets` Replace `{USER_ID}` with the engineer's ZenDesk userid (shown in the address bar when viewing their profile).
1. All tickets commented on: `https://gitlab.zendesk.com/agent/search/1?q=commenter%3A{USER_ID}%20order_by%3Aupdated_at%20sort%3Adesc` Replace `{USER_ID}` with the engineer's ZenDesk userid
1. Pairings completed - [Link to the pairings summary page](https://gitlab-com.gitlab.io/support/support-pairing/)
1. Bug report and feature requests - [Link example](/handbook/support/support-engineer-responsibilities#6-create-and-update-issues-for-bugs-and-feature-requests-weekly)
1. Documentation updates - [Link example](/handbook/support/support-engineer-responsibilities#7-improve-documentation-and-publicly-share-knowledge-weekly)
1. Bug fixes - [Link example](/handbook/support/support-engineer-responsibilities#8-fix-gitlab-bugs-and-create-features-occasionally)
1. Learning and training progress - [Link example](/handbook/support/support-engineer-responsibilities#11-develop-your-skills-through-learning-and-training-weekly)
1. Customer calls? (Currently no link for this item. Included as a reminder to mention customer calls completed in the last week.)
1. Interviews? (Currently no link for this item. Included as a reminder to mention interviews completed in the last week.)
