---
title: Zendesk Explore Overview
description: Support Operations documentation page for Zendesk Explore
canonical_path: "/handbook/support/readiness/operations/docs/zendesk/zendesk-explore/overview"
---

## Zendesk Explore

## Overview

Zendesk Explore is a powerful analytics and reporting tool offered by Zendesk, designed to provide in-depth insights into customer support metrics and trends. With Explore, our team can analyze and visualize our support data to make informed decisions, improve customer experiences, and optimize support operations.

Explore offers a user-friendly interface that allows admins to create customized dashboards, reports, and queries without the need for coding knowledge. It integrates seamlessly with Zendesk Support, combining data from multiple sources to deliver comprehensive and actionable analytics.

Explore also offers API access, allowing you to programmatically retrieve data, create and manage queries, and integrate Explore with other systems or custom applications.

Note: Explore refreshes hourly which means Explore based data is not always real time depending on query.

>> Tip: Whenever you start working on Explore yourself, please create a copy of dataset with your name or initials. This way it will preserve your own formulas in reports and dashboards you build.

## Meanings of Common Terms

| Terms | What it means                                                                            |
|-----------------------|------------------------------------------------------------------------|
| Query | A query in Explore refers to a request for specific data from your support dataset. Queries are used to generate reports, charts, and visualizations by selecting the desired metrics, attributes, and filters.   |
| Datasets     | Explore Dataset is a collection of structured data in form of table that represents a specific set of information in Explore.     |
| Datapoints | Datapoint refers to an individual data value within a Dataset. It represents a specific attribute or metric associated with a record in a table.  |
| Metrics         | Metrics in Explore represent quantitative data points that measure various aspects of customer support performance. Examples include ticket volume, resolution time, customer satisfaction score (CSAT), and first response time.         |
| Attributes            | Attributes in Explore are qualitative data points used for categorization and segmentation. They provide additional context to metrics and help analyze support data from different dimensions. Examples of attributes include ticket type, agent name, customer location, and ticket source.             |
| Calculated Metrics | Calculated metrics allow you to perform mathematical operations on existing metrics or attributes to derive new insights. These metrics can be customized based on your specific reporting needs. Examples include average resolution time, ticket backlog, or customer churn rate. |
| Filters        | Filters in Explore allow you to narrow down your data by applying conditions. They help you focus on specific subsets of your support data based on attributes or metrics. For instance, you can filter data to view tickets assigned to a particular agent or tickets created within a specific date range.       |
| Dashboards      | Dashboards are customizable visual displays in Explore that present a collection of reports, charts, and metrics. They provide a consolidated view of your support data, enabling you to monitor key performance indicators (KPIs) and track trends at a glance.      |
| Reports    | Reports in Explore are individual visualizations that present data in various formats such as tables, line charts, bar charts, or pie charts. Reports can be created based on specific queries and customized to display the desired metrics and attributes.    |
| Drill-through      | Drill-through allows you to navigate from one report to a more detailed report, providing a deeper level of analysis. It helps in uncovering insights by drilling down from summarized data to specific ticket or customer details.      |
| Scheduled Delivery   | Scheduled delivery allows you to automate the delivery of reports and dashboards to specified recipients at specific times. It ensures that stakeholders receive up-to-date support metrics without manual intervention.    |
| Joining Datasets      | Joining datasets involves combining data from multiple sources or tables to create a comprehensive dataset for analysis. Explore allows you to join datasets to enrich your support data      |

For detailed Glossary, please visit: https://support.zendesk.com/hc/en-us/articles/4408824134810-Zendesk-Explore-glossary

## Important Links

- [Explore Basics](~/content/handbook/support/readiness/operations/docs/zendesk/zendesk-explore/basics.md)
- [Setting up Explore](~/content/handbook/support/readiness/operations/docs/zendesk/zendesk-explore/setting_up.md)
- [Dashboards](~/content/handbook/support/readiness/operations/docs/zendesk/zendesk-explore/dashboards.md)
- [Important Dashboards](~/content/handbook/support/readiness/operations/docs/zendesk/zendesk-explore/important_dashboards.md)
- [Reports](~/content/handbook/support/readiness/operations/docs/zendesk/zendesk-explore/reports.md)
- [Important Reports](~/content/handbook/support/readiness/operations/docs/zendesk/zendesk-explore/important_reports.md)
- [Formulas](~/content/handbook/support/readiness/operations/docs/zendesk/zendesk-explore/formulas.md)
- [Performing Calculations](~/content/handbook/support/readiness/operations/docs/zendesk/zendesk-explore/performing_calculations.md)
