---
title: Support Team Member Time Off
description: Guidelines for how time off applies to Support team members and what actions need to be taken. Page should not be moved without a Support Global Change Management issue.
---

## Support Team Member Time Off

The Support Team follows [GitLab's paid time off policy](/handbook/people-group/paid-time-off/).
We balance that with the need to deliver support to our customers every day.
This page is intended to provide all Support Team Members with an understanding
of what we need to do to achieve that balance, making it possible for all to
take time off as needed and desired, while we as a team continue to deliver
amazing support and service to our customers.

There is a special point that needs to be emphasized, and that is that time off
for any team member only serves its purpose *if that person truly takes the time
off*. Nobody should feel pressure or the need to check Slack, email, or anything
else associated with work during their time off. **Especially when you are taking
time to be on holiday or to be with family or friends, please, in the timeless
words of the snow queen, Elsa, "let it go."**

### One-time setup actions

#### Support Time Off calendars

1. Be sure you have access to the
[**Support - Time Off**](https://calendar.google.com/calendar/embed?src=gitlab.com_as6a088eo3mrvbo57n5kddmgdg%40group.calendar.google.com)
team calendar.
   1. You should have been granted access during Support Onboarding. If you don't have it, verify whether you are part of the Support Google Group (supportteam@); if you are not, ask to be added (as per the role based entitlements) via the #support_operations Slack channel (cc @jcolyer).

1. Set up the Google Calendar integration with Time Off by Deel, so that you do not need to populate your personal and "Support - Time Off" calendars manually.
   1. In Slack, click the `+` sign next to 'Apps' at the bottom of the left sidebar
   1. Search for 'Time Off by Deel' and click 'View'
   1. Under 'Home', click on 'Your Events' to show a dropdown
   1. Click on 'Calendar Sync' under the Settings break
   1. Click on 'Connect your Calendar' and complete the actions to sync your calendar to Time Off by Deel
      - You will see a 'Success! Your calendar has been connected.' message and
        your calendar listed under 'Your synced calendar' in Time Off by Deel on Slack
      - ***NOTE: this also serves to block your availability in Calendly, and ensures your OOO is included in the [regional capacity calendars](https://gitlab.com/gitlab-com/support/toolbox/support-calendar)***
   1. After your personal calendar is linked, click 'Add calendar' under
   'Additional calendars to include?'. The 'Support - Time Off' calendar ID is
   `gitlab.com_as6a088eo3mrvbo57n5kddmgdg@group.calendar.google.com`
1. Verify the following calendars are shared with you. These are shared with the Support Team Google Group:
   1. [Support OOO - AMER](https://calendar.google.com/calendar/embed?src=c_9166d2302886c4ae23f34099eeb4015e2d520e1dd4029711becd8370be996513%40group.calendar.google.com)
   1. [Support OOO - APAC](https://calendar.google.com/calendar/embed?src=c_408bhp8a8j579lqr99j552u21s%40group.calendar.google.com)
   1. [Support OOO - EMEA](https://calendar.google.com/calendar/u/0/embed?src=c_ev56c9rgjd9l1sn291i368jn78@group.calendar.google.com)

1. If you regularly handle L&R tickets, please subscribe to the global L&R calendar and relevant L&R regional calendar.

##### L&R and USGov Calendar links

| Group |        |        |        |
| ----- | ------ | ------ | ------ |
| [L&R](https://calendar.google.com/calendar/u/0/embed?src=c_200f3afcbd9d0e18cbd80f00163ea7ca84e08bf857bdafc2bcad4202fed64f3e@group.calendar.google.com) | [APAC](https://calendar.google.com/calendar/u/0/embed?src=c_6d683f9a00d982d28055c0ef986561adc1aacf57570b7285a14ec79c31fd5f89@group.calendar.google.com) | [EMEA](https://calendar.google.com/calendar/u/0/embed?src=c_a849778a4950b23ce10953fa4f98d49e3abdc0aa57e88d448a27d87c6286ad0d@group.calendar.google.com) | [AMER](https://calendar.google.com/calendar/u/0/embed?src=c_55ea946dce89e101efa9d377ae355a201cc96b8d91079ada092cd2d9d821d602@group.calendar.google.com) |
| US Gov | [Daytime](https://calendar.google.com/calendar/u/0?cid=Y182Y2JlZTA4ZmFiOWFjYTI2NzE4YjQ5ODFmOWI5YTk0MDNlNzEyNTRjZmYyZTE5NTc0MjBjN2RhODgwYzg2M2IzQGdyb3VwLmNhbGVuZGFyLmdvb2dsZS5jb20) | [Evenings](https://calendar.google.com/calendar/u/0?cid=Y182MzFiMDNkNGRhYmI3NWZmNjczMDNmMTUwNjZmNTRlYzhhMTE2ZWYzNGE5ZDA4Zjg5YTE1NDJlYzA5YTM5ZjgyQGdyb3VwLmNhbGVuZGFyLmdvb2dsZS5jb20) | [Overnight](https://calendar.google.com/calendar/u/0?cid=Y19hYjlhNzM0ODJmNGM3MDE1NzI0N2EzNTEwYmQxMjdiZWE3ZTExYmUzZWQzN2IzN2FlNThiMjNhOTNhOWI3MjQ3QGdyb3VwLmNhbGVuZGFyLmdvb2dsZS5jb20) |

##### Manager Calendar Links

- [Support Managers AMER](https://calendar.google.com/calendar/embed?src=c_d786d5c8e42ba6058b3a5df60448c17e41255f84a0c00549d197f0466000527d%40group.calendar.google.com&ctz=America%2FChicago)

## Choosing and recording time off

Please take time off whenever you need it.

A little thoughtfulness on everybody's part will go a long way toward making it
possible for everyone to take their desired days off. As you look to plan your
time off, please:

- ensure you know the [company wide paid time off guidelines](/handbook/people-group/paid-time-off/#a-gitlab-team-members-guide-to-time-off)
- consider a different time off schedule if your [regional capacity calendar](https://gitlab.com/gitlab-com/support/toolbox/support-calendar) shows that on any of the days you would be absent, the regional team would be short by 20% or more of its people
- check the regional calendar and coordinate with your manager to ensure we have sufficient cover for days with low availability.
- schedule your time off as far in advance as you can, especially for days that
  may be popular, are [holidays](#how-support-handles-holidays), or that are particularly important to you
- don't lock yourself into nonrefundable travel itineraries before you've taken
  steps such as the above to be sure you can get the planned days off
- if possible, plan your time off to avoid disruptions to the various rotations
  such as on-call

## Preparing for time off

When you are approaching a planned absence from work, it is your responsibility
to take reasonable actions to prepare the team and your customers for your
absence. By making these preparations, you will also be making it easier for
yourself to disconnect from work and make your time off effective.

If you're taking off **less than half a day,** you do not need to make entries in Workday or the Support Time Off Calendar, but please consider updating your Slack status. Also consider blocking the interval on your personal Google Calendar, so no one tries to book a pairing/meeting with you during that time.

If you're taking off **a half day or more,** enter the time off in Workday.

At the end of your last work day before taking PTO, update your availability using the [Out of Office](/handbook/support/readiness/operations/docs/zendesk/apps/#out-of-office) app in Zendesk. This is done by navigating to the [app in Zendesk](https://gitlab.zendesk.com/agent/apps/out-of-office) and clicking the `Make unavailable` button on the row with your user information in it.

Follow the guidance below to prepare yourself, your customers, and your colleagues.

### Coverage for roles

If you are assigned to any PagerDuty shifts (such as on-call) during the time off, arrange for coverage:

1. Find a volunteer to cover for you; get help from your manager if necessary.
1. [Create the appropriate override in PagerDuty](https://support.pagerduty.com/main/docs/edit-schedules#create-overrides).

### Coverage for assigned tickets

Tidy your queue before going on PTO. As guidelines cannot cover every case,
this section is meant to provide guidance for you to think critically about
what is required to ensure continued excellent support for each customer with
whom you're working on a ticket.

#### If your absence will be less than three business days

If your PTO will prevent a timely update, ask the customer whether
they would prefer to pause the ticket with the `on-hold` status or
have someone else step in.
For high priority tickets, tend towards a handing over to someone else:

1. Use the [OOO Ticket Summary](https://gitlab.com/search?search=360080271299&group_id=2573624&project_id=17008590&scope=&search_code=true&snippets=false&repository_ref=master&nav_source=navbar)
   macro, providing the same information as described in the
   [Workflow](/handbook/support/workflows/ooo-ticket-management#workflow)
   topic of the `OOO Ticket Management` page.

#### If your absence is three or more business days

1. Change your workflow in advance of your absence:
   1. A week in advance: Start thinking about whether you may need to hand off tickets, and pair with others to get them up to speed.
   1. Two to three days in advance: stop taking new tickets.
   1. Work to resolve and close as many of your assigned tickets as possible.
   1. Contribute more to first responses and other people's tickets - internal comments, pairing
      sessions - to make up for not taking new tickets of your own.
1. Follow the [OOO Ticket Management](/handbook/support/workflows/ooo-ticket-management)
   process to arrange for others to take care of your tickets in your absence.
1. To ensure you're not auto-assigned to GDPR requests in case of an extented leave (e.g 2 weeks or longer):

   - Update the corresponding `yaml` file for yourself in the [Support Team project](https://gitlab.com/gitlab-support-readiness/support-team/-/tree/master/data/agents).
   - Change `works_account_deletion: true` to `works_account_deletion: false`
   - Request a review from your manager.
   - Make sure to undo this change when you return from OOO.
1. After coming back, make sure to follow the guidelines for [catching up after a scheduled time off](#catching-up-after-a-scheduled-time-off).

## How Support Handles Family and Friends Days

During [Family and Friends Days](/handbook/company/family-and-friends-day/#upcoming-family-and-friends-days) GitLab Support continues
to operate as normal. Starting from Q1/FY25, during each quarter you are free to take a day off at your convenience, to celebrate Family and Friends day.
Please follow the same guidelines as you would in [Choosing and Recording Time Off](#choosing-and-recording-time-off).

## How Support Handles Holidays

During Holidays, GitLab Support continues to operate as normal. Always book holidays as required by your locality. For
non-statutory holidays, please follow the same guidelines as you would in [Choosing and Recording Time Off](#choosing-and-recording-time-off).

### Holiday time off ticket management

Guidance around ticket handling over global holiday time off is slightly different, because of the potentially increased impact on the Support team.

The following peak holidays have the greatest potential to affect coverage:

- Australia Day (26-January)
- Republic Day (26-January)
- Anzac Day (25-April)
- International Workers Day (1-May)
- Memorial Day (last Monday in May)
- Independence Day (1-July to 4-July)
- US Thanksgiving Day (4th Thursday of November)
- Immaculate Conception Day (8-Dec)
- Christmas Day, St Stephens Day, Boxing Day, New Years Day and Day After New Years (Period between 24-Dec to 2-Jan)
- Holidays that vary in dates each year that are celebrated in multiple countries:
  - Easter Sunday (late March to early April)
  - Easter Monday (late March to early April)
  - Whit Monday (May or June)
  - Ascension Day (May)
  - Labour Day (first Monday in September)

### If you are planning to take time off during peak holidays

If you plan to be out for more than three days, follow the guidance regarding
[absences of three or more business days](#if-your-absence-is-three-or-more-business-days).
Otherwise:

1. Please do your best to resolve any assigned tickets you have in your queue.
1. Communicate with your customers to let them know the days you'll be away, and
   to ask whether they will need help during your absence. Many of our customers
   might be on the same holiday schedule and will be fine with resuming work on
   a ticket when you both return.
1. For those tickets that will not require action over the holiday, there is no
   special action to be taken.

### If you are working on a holiday

1. Continue to prioritize FRT first, and then management of your own tickets.
1. Please pay **extra** attention to NRT on tickets with an assignee who is currently out-of-office.

## General Tips

In addition to the company-wide tips in
[Communicating Your Time Off](/handbook/people-group/paid-time-off/#communicating-your-time-off),
take a look at these tips to increase your ability to disconnect from work,
truly make the most of your time off, and make it easier to return to work:

1. Unsubscribe from any MRs that will likely resolve while you're away, and then
   you won't have to deal with all the emails from them when you return.
1. Set up some email filters to move emails into buckets that you can address
   one-at-a-time when you return.
1. Disconnect yourself from Slack and Gmail in any of these ways:
   *NOTE: Time Off by Deel is supposed to turn off Slack notifications on your phone and
   set DND mode. But just in case, you may want to do one of these:*
   1. log out from Slack and Gmail on your phone, or
   1. remove Slack and Gmail from your phone, or
   1. pause the Slack and Gmail apps on your phone
   1. manually configure Slack and Gmail to send no notifications on your phone

## Re-connect after time off

Please consider adding an item in the Support Week in Review after you get back to let the rest of the
team know what you've been up to!

## Catching up after a scheduled time off

Trying to catch-up after a scheduled time off - especially if it's a week long, or more - can be a bit overwhelming.
So here is a list of resources to check that should get you up to date with almost everything
that happened while you were away:

- [Support Week in Review (SWIR)](https://gitlab.com/gitlab-com/support/readiness/support-week-in-review/-/issues/?sort=created_date&state=closed&label_name%5B%5D=SWIR%3A%3ADigest&first_page_size=20)

- Slack channels:
  - [#company-fyi](https://gitlab.slack.com/archives/C010XFJFTHN)
  - [#company-fyi-private](https://gitlab.slack.com/archives/C02E7JGBU4E)
  - [#whats-happening-at-gitlab](https://gitlab.slack.com/archives/C0259241C)

Consider setting up a few coffee chats with teammates to simply reconnect with them. You can also ask your teammates who haven't taken PTO while you were out, during coffee chats or pairing sessions, to mention a thing or two that you might have missed.

Once you have taken the time to catch-up, update your availability using the [Out of Office](/handbook/support/readiness/operations/docs/zendesk/apps/#out-of-office) app in Zendesk showing you are no longer OOO. This is done by navigating to the [app in Zendesk](https://gitlab.zendesk.com/agent/apps/out-of-office) and clicking the `Make available` button on the row with your user information in it.

If you unassigned some of your tickets before going on PTO, take the time to go through them and check their status. It's good practice to reassign them to yourself if these are either still missing a DRI, or if it appears that you're still the best equipped person to drive it to a solution.

For more tips, check [returning from pto](/handbook/paid-time-off/#returning-from-pto).
