---
title: Handling Emotionally-Charged Tickets
category: Handling tickets
subcategory: Writing responses and handling feedback
description: How to keep a ticket moving toward resolution when emotions are getting involved
---

## Introduction

While [working on tickets]({{< ref "working-on-tickets" >}}) you may encounter a
customer expressing negatively charged emotions in their responses.
When customers start putting negative emotions into ticket communications, it
can be very difficult to figure out what to do. Our goal remains the same: to
provide a thorough resolution to the customer's problem or answer to their
question. But now we have the added challenge of responding in ways that will
reduce the emotional presence so that we may resume working toward the goal.
Our intention here is to provide tools and tips for doing just that.

## Be Proactive - Prevent the Problem

Often, emotions come in to a ticket as a direct result of our previous actions
or inaction on the ticket or even on a previous ticket. We might answer the
wrong question. We might set an incorrect expectation, or not set an expectation
at all. We might be too slow. We might ask for information they've already
provided. We might contradict what one or more of our colleagues said in an
earlier response. And the list goes on... So let's consider a few ways that we
might avoid those problems and hopefully keep the customer happy with our
support delivery:

### 1. Confirm the Request

As the first action on a ticket, verify that you understand the customer's
request. Use your own words to summarize it in your response. Consider also
verifying the business impact. Through this action, you will avoid the problem
of answering the wrong question or working on the wrong problem.

### 2. Connect the Past, Present and Future

At the beginning of each interaction (which could be a quick series of back-
and-forth messages, for example) with the customer, be sure to indicate what's
happened since the last interaction, what the current state is, what the next
actions are, who will take them, and why those actions should be taken. When you
take this step you're ensuring a common understanding of the situation and the
plan; you're setting expectations.

### 3. Find the Yes

When we won't be able to do exactly what the customer wants, instead of just
saying "no," find good alternatives and present those.

### 4. Communicate Thoroughly

Read every message from the customer thoroughly, twice if it helps, and be
sure that in your reply you respond to everything they presented to you.
Acknowledge their thoughts, concerns, priorities, timelines, etc. Answer each
of their questions **or** tell them you are researching the questions if you
don't yet have an answer. When you do these things, you let the customer know
that you are paying attention, that you care about them, and that you truly
intend to help. This goes a long, long way toward keeping a customer happy.

### 5. Don't Be Silent

When you're researching a customer's problem, keep them informed regularly.
They will be thrilled to know that you're working on their behalf to find the
best answer. So set an expectation with them at each communication of when
you'll update them again - keep the intervals short - and give them updates on
your progress instead of leaving them in silence until you find your final answer.

### 6. Know the Ticket

If you're going to work on a ticket that isn't assigned to you, or that's
had other people involved, be sure you know the whole history of the ticket
before you communicate with the customer. This allows you to avoid the mistakes
of repeating requests and of contradicting previous instructions.

### 7. Meet Your Commitments

If you say you're going to do something, do it. If something changes, explain
what changed and make a new commitment.

## Act Quickly

Despite our best efforts to keep the customer happy from start to finish, there
will still be plenty of times when a customer will express negative emotions in
a ticket. At the first sign of frustration or other negative emotions from a
customer, consider scheduling a Zoom meeting with them. Even if all you do on
the Zoom meeting is review the situation, gain further clarity into their needs,
learn the business impact, etc., it's well worth doing as it will go a long way
toward helping the customer to feel better. It's also a great opportunity to
explain what you're thinking and the next steps you want to take in getting
closer to resolution for them. Amazingly, you can probably do all of this in
only 15 - 30 minutes.

## Dos and Don'ts

### Do

1. Apologize

   If you, or we (GitLab), have created a problem, briefly and sincerely
   apologize. Then talk about the next steps toward resolving the situation.
   In acknowledging the mistake you open the door to regaining the
   customer's trust. And then by focusing on the path forward you invite the
   customer to let the emotions go.

1. Get other GitLab team members involved to help

   You're never alone at GitLab. Ask colleagues, managers and team members in
   other departments whenever you need help, whether with the technical
   aspects of the situation or the nontechnical ones. And if you're feeling
   too emotional or in any way unable to provide a good customer experience,
   please escalate to your manager.

1. Assume good intent

   Almost always the customer just wants to solve a problem. So try focusing
   on what they need and what you can do by stating to yourself:

   1. "This customer wants me to [action words used by the customer]."
   1. "I can help them feel good about our company by [implied or emotional
      need of the customer.]"

1. Try to view things from the customer's perspective

   Start by acknowledging what they've said and validating their problem. Then
   show empathy for their situation and their needs. Remember, you don't have
   to agree with them in order to understand them.

1. Treat the customer with respect

   Remember that every customer is a real human being with real needs, emotions
   and pressures. So if they're showing a little emotion in working with us,
   think about what's driving that and let them know you respect them and what
   they're trying to achieve.

1. Use interest-based problem solving

   Especially if the customer is unhappy that we won't (can't) do what they
   want, figure out their underlying interests, identify our shared interests,
   and speak in terms of those shared interests. Speak about what you can and
   will do, even if it's not what they originally requested. And let them know
   that you want them to succeed.

### Don't

1. Take it personally

1. Blame

   If you place blame on anybody for the situation, you make yourself powerless.
   You're saying the situation is out of your control and influence. You make
   both the other person and yourself look bad.

1. Argue

   Instead, listen and seek to understand. See "Try to view things from the
   customer's perspective", above.

1. Assume

   Confirm your understanding - of the problem, of the question, of the status,
   of anything - with the customer before taking next steps. Validate stated
   facts so you can be sure they're correct. And ask questions to get
   information you don't yet have.

## Reply Wording

### 1. Match Words

Always pay attention to the language, the specific words, that
the customer has used and then match those words in your reply:

- If they wrote "delete", write "delete"
- If they wrote "disaster", write "disaster"

### 2. Don't Assign Emotions to the Customer

Be careful not to tell the customer how they feel. It can seem reasonable to
write "I hear your frustration," for example, but many people will react badly
to that kind of statement. Instead, put the emotion on the situation, not the
person:

> I know this situation is frustrating right now.

### 3. Inconvenience and Unfortunately

Try to avoid using these two words if you can. Why?

- "Inconvenience" can make a problem sound trivial, unimportant. It suggests a
  minimal impact. Instead, call it a problem: "I know this problem is
  disrupting your business, and I will work with you to get it resolved as
  quickly as possible."

- "Unfortunately" tends to be the way we introduce the fact that we're not able
  to help. Try instead to talk about what we can do to help, not what we can't.
