---
title: Cross-Region Coordination and Collaboration
category: Support Team
description: Workflows and information describing how the regions within Support coordinate and collaborate with each other
---

## Overview

Although each region within GitLab Support has its own specific responsibilities
each day, and has the freedom to manage those responsibilities in whatever ways
work best for them, the regions must also provide a consistent experience to
customers. To do that, the regions must coordinate and collaborate with each
other.

The purpose of this page is to present clearly the workflows used by the regions
in working together and all the information about regional structures that
support those workflows.

## Regional queue-related responsibilities

### Regional queue hours

During regional queue hours, Support Engineers are expected to be actively
monitoring and taking new tickets from the queue. These are hours when the
region is responsible for the queue. When two regions' hours overlap, they share
that responsibility.

### Clean queue

Each region is responsible for leaving a `clean queue` for the next region
**by the end of their regional queue hours**. A clean queue for `Region X` has
no unassigned tickets in it with a preferred region of `Region X`. Note that if
a region has a [cleanup hour](#cleanup-hour) at the end of its day, that hour
will come **after** their regional queue hours end.

### Cleanup hour

A cleanup hour is a time during which the region is **not** responsible for
taking tickets from the queue, and is instead responsible for making sure that
their end-of-day activities, such as initiating rehomes, are done.

The purpose of the cleanup hour is to make it reasonable for an SE to take a new
ticket from the queue **before cleanup hour** by having the knowledge that their
normal workday includes an hour **after their FRT responsibilities end**.
They would be able to take a new ticket even at the very last minute of
regional queue hours, and still have time to construct and send a good first
response during the "free" hour that is "cleanup time."

Cleanup hour will occur for different people in a region at different times
during the day, based on each individual's working hours. We only represent
cleanup hour in the table at the end of a region's day, with the understanding
that for all other hours, the ✅ represents both "regional queue hours" (FRT
time) and "individual cleanup hour".

### Extra capacity hour

An extra capacity hour is a time during which some Support Engineers in a
region might be working on tickets even though the region is not
officially responsible for taking new tickets from the queue. We display these
hours to help people to know when they might be able to find people working
outside of [regional queue hours](#regional-queue-hours) in other regions.

### Queue-related responsibilities schedule

This table defines the queue-related responsibilities of Support Engineers in
each region for each hour of the day. The hours are given in UTC. Each hour for
each region is marked with exactly one of the symbols defined here.

**Legend**

| Symbol | Meaning |
|--------|---------|
| ✅ | Regional queue hour |
| ✨ | Extra capacity hour - some Support Engineers might still be working on tickets |
| 🔨 | Cleanup hour |
| -- | No coverage during that hour |

---
---

| Region | 0 | 1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | 10 | 11 | 12 | 13 | 14 | 15 | 16 | 17 | 18 | 19 | 20 | 21 | 22 | 23 |
|--------------|----|---|---|---|---|---|---|---|---|---|----|----|----|----|----|----|----|----|----|----|----|----|----|----|
| APAC | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | -- | -- | -- | -- | -- | -- | -- | -- | -- | -- | ✨ | ✨ | ✅ |
| EMEA | -- | -- | -- | -- | -- | -- | -- | ✨ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅  | ✨ | -- | -- | -- | -- | -- | -- | -- |
| AMER | -- | -- | -- | -- | -- | -- | -- | -- | -- | -- | -- | -- | -- | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | ✅ | 🔨 |
