---
title: TeamOps - Redefining Teamwork for the Modern Era
description: Getting to know GitLab's virtual-first operating model
canonical_path: "/handbook/teamops/"
images:
    - /images/opengraph/all-remote.jpg
cascade:
  type: docs
---

Organizations need people and teams — their creativity, perspectives, and humanity. That need will only grow as we move towards a future with bigger problems to solve, and as AI displaces every variety of rules-based knowledge work which can be automated.

Tomorrow's winners will be determined by how they bring teams together, and how well they're able to get every person on those teams to contribute to their mission.

Up to this point, teams, and the ways the people on them work, have been treated in a profoundly subjective manner: ad hoc, DIY, left up to whims of the individual manager and the quirks of a given corporate culture. It's viewed as a soft problem, mixing 20th century management philosophies with pop psychology. Grounded in opinion, not reality. Feelings, not behaviors.

Meanwhile, other critical areas of business have been studied, made objective, codified, and operationalized. Why not so with our most valuable resource: teams?

## What is TeamOps?

Simply put, **TeamOps is an organizational operating model that helps teams maximize productivity, flexibility, and autonomy by managing information more efficiently.** This virtual-first approach is designed to optimize team dynamics, streamline decision-making, and increase an organization's output. Developed, practiced, and refined by GitLab, it's a framework grounded in actionable principles that transform how teams work and relate.

TeamOps differentiates itself from other management philosophies and people practices by consciously enabling decentralized decision making at a centralized (organizational) level. While guiding principles exist, TeamOps is not static. It is designed to be iterated on and evolved by everyone. This system is designed to apply to **all** work environments, from [no remote to strictly remote](/handbook/company/culture/all-remote/stages/).

By implementing TeamOps at an *organizational* level, *individuals* within the organization are less constrained. Each team member receives greater agency to exert self-leadership. Collectively, we believe this atmosphere allows for more informed decisions, made quicker, more frequently, and with a higher likelihood of successful execution.

## TeamOps Principles and Tenets

TeamOps is comprised of four principles, each with six tenets that outline group member behaviors and guidelines.

| Shared Reality | Equal Contributions | Decision Velocity | Measurement Clarity |
| ----- | ----- | ----- | ----- |
| [Single Source of Truth](/teamops/shared-reality/#single-source-of-truth-ssot) | [Asynchronous Workflows](/teamops/equal-contributions/#asynchronous-workflows) | [Documented Workflows](/teamops/decision-velocity/#documented-workflows) | [Transparent Measurements](/teamops/measurement-clarity/#transparent-measurements) |
| [Public by Default](/teamops/shared-reality/#public-by-default) | [Directly Responsible Individuals](/teamops/equal-contributions/#directly-responsible-individual-dri) | [Give Agency](/teamops/decision-velocity/#give-agency) | [Measure Impact, Not Activity](/teamops/measurement-clarity/#measure-impact-not-activity) |
| [Collaboration Guidelines](/teamops/shared-reality/#collaboration-guidelines) | [Well-Managed Meetings](/teamops/equal-contributions/#well-managed-meetings) | [Push Decisions to the Lowest Level](/teamops/decision-velocity/#push-decisions-to-the-lowest-possible-level) | [Definition of Done](/teamops/measurement-clarity/#definition-of-done) |
| [Shared Values](/teamops/shared-reality/#shared-values) | [Cross-Functional Collaboration](/teamops/equal-contributions/#cross-functional-collaboration) | [Bias for Action](/teamops/decision-velocity/#bias-for-action) | [Prioritize Due Dates](/teamops/measurement-clarity/#prioritize-due-dates-over-scope) |
| [Inclusivity](/teamops/shared-reality/#inclusivity) | [Tool Prioritization](/teamops/equal-contributions/#tool-prioritization) | [Low-Context Communication](/teamops/decision-velocity/#low-context-communication) | [Transparent Feedback](/teamops/measurement-clarity/#transparent-feedback) |
| [Informal Communication](/teamops/shared-reality/#informal-communication) | [Psychological Safety](/teamops/equal-contributions/#psychological-safety) | [Operational Transparency](/teamops/decision-velocity/#operational-transparency) | [Cadence](/teamops/measurement-clarity/#cadence) |

## Prerequisites for TeamOps

There are five foundational elements that should already be in place in an organization in order to support the adoption of TeamOps. These prerequisites relate to the company processes, digital infrastructure, and culture that create an *ideal* environment to implement TeamOps tenets.

1. **Digital Infrastructure.** Before we can teach you how to work in a virtual-first way, we need to make sure that your team has the correct [tech stack](/handbook/business-technology/tech-stack-applications/) to enable digital collaboration. Every infrastructure is different, but at a minimum, all should include one tool from the following categories:
   - Group communication (eg: Slack)
   - File storage (eg: Google Drive)
   - Knowledge management (eg: GitLab, Almanac)
   - Project management (eg: GitLab, Asana)
   - HR management (eg: Workday)
   - Financial management (eg: Quickbooks)
   - Calendars and scheduling (eg: Google Calendar)
1. **Company Handbook.** TeamOps relies heavily on knowledge sharing through documentation and asynchronous communication. If you don't already have some kind of knowledge management system to host this information sharing-such as a wiki or handbook- you'll want to create one before starting the courses and certifications. But don't worry, you only have to get it started, because the TeamOps Practitioner Certification will guide you through the process of using this resource as a [Single Source of Truth](/teamops/shared-reality/#single-source-of-truth-ssot) and populating the content for your team to use.
1. **Shared set of values.** Your [core values](/handbook/values/) must be more than words on a page. They should be actionable, [reinforced](/handbook/company/culture/all-remote/building-culture/#reinforcing-your-values) in everything you do as a team, and act as a [filter for hiring](/handbook/company/culture/all-remote/building-culture/#how-do-i-assess-culture-fit-remotely) to ensure you continue to grow the team with people who are committed to living out these values in their work.
1. **Team trust and inclusion.** Implementing new management and operating techniques can be uncomfortable at first. A baseline of [trust](/handbook/leadership/building-trust/) and [inclusivity](/handbook/company/culture/inclusion/) across the organization will better enable the team to embrace change and assume positive intent along the way.
1. **Focus on results.** [Measuring output](/handbook/company/culture/all-remote/management/#focusing-on-results) instead of input is foundational to managing a virtual-first team. This means establishing clear, transparent goals so that team members at all levels of the organization can see and take ownership for how their work is contributing to the team, department, and company's success.

If your organization is missing some of these building blocks, consider this an opportunity to invest in your team. A variety of [TeamOps Partners](/handbook/teamops/partners/) have been recruited to support you through the change management process.

## TeamOps Tips

While exploring and adopting TeamOps as an operational model, it's important to remember a few things:

1. **TeamOps describes an ideal state**. In management, it is not possible to remain in an ideal state in perpetuity. Competing priorities, conflict tradeoffs, and [coordination headwinds](https://komoroske.com/slime-mold/) will be present at varying times. When applying TeamOps, resist the urge to take a binary approach. Rather than asking, "Have we completely achieved TeamOps in our team or company?," leverage TeamOps principles to *navigate* with [more information](/teamops/shared-reality) and [greater velocity](/teamops/equal-contributions).
1. **TeamOps is for individual contributors *and* people managers.** TeamOps empowers individual contributors to be better stewards of their own time and attention. Concurrently, it empowers people managers to lead with deeper conviction while creating more space for their direct reports to grow, develop, and contribute.

![GitLab TeamOps teamwork illustration](/teamops/images/teamops-illustration_teamwork_blue.jpg)
