---
title: "TeamOps Direction"
description: TeamOps' general timeline, OKRs, and plans.
canonical_path: "/handbook/teamops/direction/"
images:
    - /images/opengraph/all-remote.jpg
---

## Executive Summary

[TeamOps](https://about.gitlab.com/teamops/) is an organizational operating model that helps teams maximize productivity, flexibility, and autonomy by managing decisions, information, and tasks more efficiently. It is how we work at GitLab, and we want to help others do the same. Regardless of workplace model, teams can become more information-centric, handbook-first, and virtual-first when they apply TeamOps.

## Objectives and Key Results

Although TeamOps has been practiced since the beginning of GitLab, it wasn't consolidated into a replicable framework until 2022. In FY2024, the Office of the CEO in GitLab built a business model around TeamOps with the following objectives:

- Internally optimize workforce awareness and universal application of the TeamOps model to standardize organizational behavior
- Externally monetize and market the TeamOps model through professional services to monetize our non-tech thought leadership

The future of TeamOps as an internal operational and as a revenue model is based on the following principles. (See also: [Workplace Handbook]({{< ref "workplace" >}}), [TeamOps Handbook](/handbook/teamops))

- TeamOps is an evolution of the Managing So Everyone Can Contribute (MECC) management model. It is based on the philosophy of using information to stay aligned, instead of shared time or location (proximity).
- TeamOps is **not** exclusively for remote work or distributed teams, but it does enable more schedule and workplace flexibility for every team structure.
- The business case for future investment in TeamOps as a revenue channel is the incorporation of TeamOps certifications into GitLab's educational services. These services have low overhead and maintenance requirements, so they can be used to passively collect market research to inform future decision making.

**Key Results of TeamOps in FY24**
To evolve TeamOps from a management philosophy into an operational framework, Laurel Farrer, a subject matter expert specializing in virtual organizational development, completed the following tasks:

- Strategized business model for TeamOps revenue generation
- Optimized the TeamOps content for productization and marketability, including copywriting, content development, market research, and unique value proposition design
- Calculated the construction and growth roadmap for business operations
- Reclassified the terminology of TeamOps services for accuracy, credibility, customer satisfaction, and legal defensibility
- Performed all program management, including budget, workflow design, documentation, vendor coordination, procurement, and reporting
- Developed all TeamOps learning services content, including 2 presentations, 3 workshops, and 4 certification programs
- Designed, built, and piloted the TeamOps Adoption Assessment
- Designed, built, and piloted the TeamOps Partnership Program
- Strategizes TeamOps sales and marketing, including market research, target persona design, and funnel design
- Delivered all TeamOps training and consulting services, including speaking engagements, workshop facilitation, Q&A calls, etc.
- Coordinated the design and activation of all TeamOps operational systems and assets, including legal contracts, accounts payable invoices, procurement SKUs, tech stack ARs, etc.

**Changes from FY23 Roadmap**
The TeamOps project was originally opened in FY23-Q4 with plans to scale quickly. However, due to headcount adjustments in the Office of the CEO at the end of FY2023, TeamOps scaling goals were reduced and some adjustments to the TeamOps FY2024 roadmap were made to optimize efficiency and sustainability.

- Changing the original enrollment goal (100k learners) to a revenue goal (breakeven/$200k)
- Deprioritizing All-Remote evangelism to boost TeamOps (messaging about how we work instead of where we work)
- Workshops will be the first revenue stream, instead of the LevelUp course (due to higher per-customer profitability and lower marketing costs)
- Department will run lean with minimal hiring (decreasing headcount from 3-5 to 0-2)
- Existing resources will be tapped to (ie: internal brand team for graphic design, internal customer support and customer success for lead generation, internal L&D for facilitator training, partnership with McKinsey for affiliate sales, etc.)
- Postpone high-level TeamOps marketing campaign and new content development to FY25 (ie: Coursera course development, micro-courses in LevelUp, etc.)

**Suspended Projects**

During its research and development phase, TeamOps offered the following training and consulting services. To minimize overhead costs, all have now been closed, in favor of the asynchronous courses and certifications on LevelUp.

| TeamOps Services | Price |
| --- | --- |
| One-hour Q&A calls with an in-house TeamOps expert | $500 USD |
| TeamOps Adoption Assessment | $1,500 USD |
| Keynote presentations about the role of TeamOps in the future of work | $3,000 USD |
| TeamOps Change Management Workshops<br>(maximum of 15 participants) | $5,000 USD |
| TeamOps for Leaders Workshop<br>(virtual, &lt;15 participants) | $7,500 USD |

- *Leadership Q&A Calls* - Ease into the world of TeamOps by resolving questions or concerns from your company's change management team. Schedule one-hour virtual sessions with a TeamOps expert to discuss anything you wish - handbook writing, virtual onboarding, strengthening team connection, preventing meeting fatigue, and more.
- *TeamOps Adoption Assessment* - Learn your team's strengths and weaknesses in the TeamOps framework, and reveal what next steps should be in the change management process. This consulting service includes individual analysis of your company data, a custom results report (pdf), and a 1-hour live consultation call with a TeamOps consultant.
- *Keynote Presentations* - In the past 5 years, the population of remote workers has grown by 10x. New adopters boast higher productivity, retention, and profitability. Yet, other companies are still calling workers back into the office. Why? What are the differences between the flexible or hybrid teams that are thriving, and those that are diving? This 30-60 minute presentation answers that question, defines success in the future of work, and clarifies how any company (including yours) can understand, measure, and optimize productivity of its team members, regardless of where or when they are working.
- *Change Management Workshops* - Designed as a supplemental learning resource for the LevelUp course, this group workshop equips teams to analyze their current success status of TeamOps adoption, and deep dive into a collaborative optimization of specific action tenets.
- *TeamOps for Leaders Workshop* - What is the role of a business manager in the future of work? How does virtual-first leadership differ from traditional management? This workshop is designed to guide your leadership team through the critical mindset and responsibility changes needed in TeamOps work environments.

Additionally, as part of TeamOps research and development, the Office of the CEO maintained (and/or iterates on) the following current projects and responsibilities. All have now been suspended, but can be revived in the future if future investment in TeamOps is confirmed:

- Publicly market and evangelize GitLab's ways of working (TeamOps)
- Internally measure and optimize TeamOps to equalize employee experience
- Produce and publish TeamOps social media content
- Host TeamOps Group Conversation, AMAs, or internal training workshops each quarter
- Optimize virtual "environmental" employee experiences (eg: digestibility and retention of handbook content, organizational behavior observation opportunities during onboarding, "office tours", etc.)
- Maintain GitLab's position as an international, iconic thought leader in workplace innovation

**Stable Counterparts**

The Workplace team collaborates with the following departments for the development and distribution of TeamOps content:

- People: optimize workforce culture, collaboration, productivity, retention, innovation, and engagement
- Customer Success and Solutions Architects: Help customers work like our organization using both our tool and our ways of working
- Marketing: Public speaking and social media marketing about TeamOps
- Sales and Channel Partners: Distribute TeamOps learning services through partners for indirect customer success

## Timeline

**TeamOps: Past**

TeamOps has grown through 5 quarters of research and development:

- FY23-Q4 = Develop the first iteration of TeamOps content and launch publicly
- FY24-Q1 = Build and validate TeamOps service offerings and sales funnel
- FY24-Q2 = Optimize TeamOps content for actionability (change management)
- FY24-Q3 = Transfer manual TeamOps learning services into asynchronous courses for scalability
- FY24-Q4 = Upgrade all learning services into LevelUp certifications for passive revenue generation

**TeamOps: Present**

- TeamOps content is currently documented in the TeamOps handbook pages and TeamOps certifications in LevelUp.

**TeamOps: Future (3 Year Plan)**

- FY25 and beyond = Future investment and development in TeamOps will be informed by revenue, demand, net promoter scores, and completion rates of the TeamOps certifications in LevelUp. Progress is monitored by Education Services and reported to the Office of the CEO quarterly.
