---
title: Financial Wellness
description: A summary of Financial Wellness resources available to team members at GitLab.
---

## Introduction

GitLab has generated this handbook page to provide resources to team members relating to Financial Wellness. Please note that GitLab is not able to directly provide team members with any financial advice.

If you have any great resources that you have used in the past, please feel free to create a merge request to add to this page as everyone can contribute!

## Financial Wellness Resources

### Modern Health

[Modern Health]({{< ref "modern-health" >}}) offers many self service resources to team members as part of the Employee Assistance benefit through GitLab.

Some of these resources include:

- Ability to [add a Financial Coach](https://drive.google.com/file/d/1bZj00YXuWfl47QXOMBzLXkej5NgQvygQ/view?usp=sharing) to your care team.
- Digital program through the app titled `Financial Well-being`.
- [**Modern Health Money Management Circle:**](#modern-health) GitLab hosted a **Money Management Circle** through Modern Health with an emphasis on the psychological component of Financial Wellness. **Link to [Recording](https://www.youtube.com/watch?v=YhoHMT94Mkg)**
  - **Session Description:** What does "wealth" mean to you? Understanding the psychology of money and wealth can help you achieve your financial goals. Join this session with a Modern Health provider to learn how to assess your financial situation and identify your financial values and self-identity.

### SageView

GitLab offers all team members the ability to use the Financial Wellness Program through SageView. This program includes:

- 1:1 sessions for all GitLab team members globally to connect with a dedicated Wellness Specialist to discuss topics such as Investment Assets (including Stock Options), Asset Protection, Income Protection, Debt Management, and Estate Planning.
  - The main goal here is the commitment to help understanding how the GitLab equity plan works, and providing resources in what team members can consider in financial management. SageView won't provide tax, legal, or financial advice, but can help you to understand the pieces of information you will need to seek personal advise on to manage your own personal situation.
- Access to [Sage411](https://sage411.com/) for general questions and investment support.
- Access to SageView's communications
- Financial Wellness Workshops hosted by SageView

Please see the following [flyer](https://drive.google.com/file/d/1FNdQ4i-Jx-jUMjjcAR4Uw4ErB8hyODGN/view?usp=sharing) for more information and a link to schedule a consultation.

GitLab hosted a kickoff call with SageView to discuss an overview of the program's benefit offerings for team members.

- **Recording:** [Presentation (Option 1)](https://www.youtube.com/watch?v=2rsUjnjjYQ0), AMA [(Option 2)](https://www.youtube.com/watch?v=kKJii7YbFxY)
- **[Session Description](https://drive.google.com/file/d/1rPc_7iCiZV33BMuoithOlaJefeWNYgAK/view?usp=sharing):**
  - The specifics of Financial Wellness are different for everyone, but the common underlying theme is similar for most; identify your resources and utilize your opportunities in a way that gives you both peace of mind and the highest likelihood of achieving your financial goals.

### LinkedIn Learning

Self Learning around money management is also available through the company sponsored [LinkedIn Learning](/handbook/people-group/learning-and-development/self-paced-learning/#linkedin-learning) account.

Examples of Learning Courses include:

- [Managing Your Personal Finances](https://www.linkedin.com/learning/managing-your-personal-finances-2021/what-s-your-money-story?autoAdvance=true&autoSkip=false&autoplay=true&resume=true&u=2255073)
- [Behavioral Finance Foundations](https://www.linkedin.com/learning/behavioral-finance-foundations-2/behavioral-finance-and-the-stock-market?autoAdvance=true&autoSkip=false&autoplay=true&resume=true&u=2255073)
- [Personal Finance Tips & Tricks](https://www.linkedin.com/learning/personal-finance-tips-and-tricks/welcome-to-the-series?autoAdvance=true&autoSkip=false&autoplay=true&resume=true&u=2255073)
- [Managing Your Personal Investments](https://www.linkedin.com/learning/managing-your-personal-investments/taking-control-of-your-investments?autoAdvance=true&autoSkip=false&autoplay=true&resume=true&u=2255073)
- [Financial Wellness: Managing Personal Cash Flow](https://www.linkedin.com/learning/financial-wellness-managing-personal-cash-flow/understanding-your-relationship-with-money?autoAdvance=true&autoSkip=false&autoplay=true&resume=true&u=2255073)

### Schwab

Within Schwab, as of no later than December 9th, you will see a summary of your options (vested and unvested) and vested exercised shares.  Exercised unvested options will be held at Computershare. When RSUs are granted, these will also be visible in Schwab.

Schwab can also assist with investment support as a complimentary service through GitLab.

**Resources Available within Schwab:**

- Award Calculators: The following award calculators are available to account holders to hypothetically model different option and share scenarios.
  - Raise cash: How many shares would I need to sell, or options to exercise and sell, to raise a specific dollar amount?
  - Get shares: How much would it cost to exercise a stock option and hold the shares?
  - ​​Estimate the proceeds from a potential sale: How much cash could I receive from selling shares or exercising and selling stock options?
  - Raise cash and get shares: How many shares would I need to sell to pay for a stock option exercise and hold, plus raise additional cash?
  - Schwab also has a [calculator library](https://client.schwab.com/app/accounts/financialplanning/#/tools) for modeling many other types of financial goals.
- Schwab Insights - Examples of Available Modules include:
  - [How to Invest](https://www.schwab.com/how-to-invest)
  - [Investing Basics](https://www.schwab.com/how-to-invest/investing-basics)
  - [How to Start Investing on Your Own](https://www.schwab.com/how-to-invest/how-to-start-investing)
  - How to Invest [1,000](https://www.schwab.com/how-to-invest/what-to-do-with-1k), [10,000](https://www.schwab.com/how-to-invest/what-to-do-with-10k) or [100,000](https://www.schwab.com/how-to-invest/what-to-do-with-100k).
  - There is also a [full Library](https://client.schwab.com/secure/cc/guidance/insights) of content relating
- [Schwab Learning Center](https://client.schwab.com/secured/learning-center/start-learning-about-stocks) with specific content related to:
  - **Stocks:** Develop a better understanding of the benefits and risks of stock ownership and how it may fit in your trading and investing plans.
  - **Options:** Take a closer look at options trading and different ways to build a strategy.

## Total Rewards and Financial Wellness for Managers

An important component of the [Total Rewards Package](/handbook/total-rewards) is [Equity Compensation](/handbook/total-rewards/stock-options/). Team Members can review their equity holdings in Schwab. Please note that vested and exercised shares are currently being held in Computershare. The Stock Admin team will be providing additional information on these shares.

In order for *managers* to understand the full picture of their team members' total rewards package, the People Group has generated a [Total Rewards Summary](#total-rewards-summary) for managers to view vested and unvested holdings as of October 14, 2021 for each direct report.

### Total Rewards Summary

The Total Rewards Summary will be available to managers of team members who have been granted equity on or before 2021-09-03. All RSU grants will not be shown on these summaries as the next grant date for RSUs to be reviewed and approved is 2021-12-15.

- Log into Workday through your Okta dashboard.
- Navigate to the profile of one of your direct reports. Select the Documents tab and expand the `Annual Compensation Review Total Rewards Statements` folder.
- You can either select the linked document name to open a quick view of the Total Rewards Summary in Workday or select the download button that appears to the right of the letter. If you are a manager and are unable to see the Documents tab for your team member, please reach out to `total-rewards@ gitlab` and we will review your access level.
- [Total Rewards Summary example](https://drive.google.com/file/d/1TxOdKxPuFvTRJIswZQEJTmd5IGEMZgx7/view?usp=sharing)
  - Each summary will have a Cash Compensation section outlining the current (FY22) compensation as of November 1st.
  - For team members who are paid a base salary only, the `Target Bonus (Variable)` column will show `Not Applicable`.
  - Each summary will also have a section for Equity Compensation. The table will show the amount and value of vested and unvested shares held by the team member as of 2021-10-14 with the conversion price detailed on the statement.
- Team Members have access to their own equity holdings, so it's not required to share the Total Rewards Summary with team members, unless it is useful in facilitating a conversation. To share the letter directly with the team member, select the gear button to the right of the letter, select "Share with Employee", and, in the pop up prompt, select "Share" again.
- ![share letter](/images/handbook/people-group/Share_Letter.png)

#### Manager Talking Points

The Total Rewards Summary has been generated for management to visualize and understand the total holdings of their direct reports. There is not a specific timeline for managers to have a conversation around Total Rewards with their direct reports, but we want to ensure managers are enabled to have a conversation as equity is likely top of mind for team members. When going into the conversation we recommend to consider the following points:

- It's important for all team members to understand and consider all components of the Total Rewards Package. One key component being the value of our equity program (Options, RSU's & ESPP) as core to our Total Rewards (benefits, cash compensation, equity) at GitLab.
- Equity aligns team members with a long term incentive for the company. By delivering results, GitLab has the ability to contribute to company performance and drive long-term potential value.
- Team members may be eligible for [Equity Compensation](/handbook/total-rewards/stock-options/#restricted-stock-units) as part of their new hire package or the annual refresh program.
- GitLab has recently adjusted the cliff for the RSU program by implementing an industry leading six month cliff for new hire grants and no cliff for promotion or refresh grants.
- Close by checking in on how your team member is doing beyond their financial position. A quick and simple method is to use  the "red, yellow, green" scale to ask your team members how they are feeling about their future at GitLab. The goal is to gain actionable feedback about how you can support them going forward.
- Please note that Total Rewards will be discussed again in February as part of [Annual Compensation Review]({{< ref "compensation-review-cycle" >}}). This is a great opportunity to check in with your direct reports ahead of the planning process, but it is important to not make any forward looking statements on increases during the review cycle.
- Remember, financial incentives are only one aspect of what keeps our team members excited about their role at GitLab. Career opportunity and ability to make meaningful contributions were highlighted as the 2 highest areas of impact for our team members during our last Engagement Survey. Take this opportunity to have a holistic conversation about your team members' future at GitLab in terms of their career and financial growth opportunity. Remember, we're only at Mile 3 of the marathon.
