---
title: "Leave of Absence Tool Kit for Managers and Team Members"
description: "Leave Tool Kit for Managers and Team Members"
---

## Manager Tool Kit

GitLab supports all our team members time away needs by offering multiple leave types in compliance with all applicable federal, state, and laws. At GitLab, we want to support our team members throughout their journey here which includes both the 'highs' and the 'lows'. This includes offering several different leave programs (medical, parental, etc.) to support time away from work, and other resources to support overall well-being, because taking time away from work can be stressful, exciting, and everything in-between.

As a manager, your team members(s) may come to you with questions, concerns, and/or requests for additional support and guidance. These resources are intended to highlight which areas in the leave of absence process you are responsible for, and how you can best support your team members throughout the life-cycle of their leave. No two leaves are ever the same, so there may not always be a "one-size-fits-all" solution. Some leave situations can be exciting and planned for (i.e. Parental Leave) while others may not be able to be planned for and/or may be serious for the team member or their family member. As a Manager it is important you approach each situation with empathy and kindness, and understand how to best support your team member. The resources included in these pages are intended to equip you with the information you need to support your team members through the entire life-cycle of their leave. If you have any questions or need any additional assistance, please contact `leaves@domain`.

### To-Do List

#### Before the Leave Begins: Your team member informs you they need a leave or more information

1. If Applicable: Your team member may inform you that their physician recommended restrictions or requests accommodations to be able to perform the essential functions of their job before their leave starting. Please contact `leaves@domain` and the Absence Management Team can assist you with this request.
1. Arrange Out of Office Coverage: This may vary for work functions (i.e sales, etc), so consider asking your team member to create a Leave Plan documenting projects in progress, pending TODO items, ongoing responsibilities, important meetings, etc. via either a Google Doc or an Issue.
   - Pro-Tips:
       - Consider what happens if the person needs to leave earlier than planned due to medical issues.
       - Tag team members covering during the absence.
       - Review the [Resource Allocation](#general-guidelines-for-managers-on-resource-allocation) section of the handbook.

1. Ask what communication your team members wants while out (if any at all). Some team members may want to stay plugged in a bit and chat informally to ensure they are not forgotten, and others may want to disconnect completely. If the team member does want to chat, please ensure any communication while the team member is on leave is *not* work related.

#### Leave Begins: Your team member is off work

Some situations require a team member to start their leave immediately. Hearing that you will support them throughout their leave, and asking how they need your support as they begin their leave will mean a lot and possibly help ease any stress the team member has about beginning their leave.

1. If your team member has not already reported their need for a leave to the Absence Management Team, please ask them to email `leaves@domain`.
1. Continually update the team member's Leave Plan with any significant changes or events, project progress and updates, etc. to fill them in on once they are back. For example, it may helpful to link to the specific Group Conversations that pertain to their role for ease in finding these resources upon return.
   - Remember to have check-ins with any team member assuming additional responsibilities during the team member's leave:
       - Are there deadlines they are up against? Do they need your support? Are they still excited about these extra responsibilities, or do they need additional support from you or other team members?

#### 1-2 weeks prior to your team member returning from leave

1. Consider drafting a transition "in" or a re-immersion plan for your team member, but be open to changes as your team member returns to work. Treat the re-immersion plan as an opportunity to reengage and reenergize your team member. They've been gone a while, and will need time to immerse back into work.
    - Depending on how long the team member has been gone, consider detailing how the team member will "ramp back" to work and the duration of the ramp back period.
    - Include coffee chats reconnecting with peers, 1:1s checking in with their team or other stakeholders.
    - Alow time to review their Leave Plan and catch up on what they missed.
    - Consider consider if any big changes may have occurred that would impact how they work, who they work with, or the general team.
1. For anyone coming back to work there can be high levels of uncertainty on what to expect when they return; remember their time away was not a vacation. It is important that you set aside time on your calendar to connect with them on their first day back at work.
    - Check-in with them, see how they are feeling about the transition, and what support they may need from you.
1. Make them feel welcome on their first day back and prepare/consider a small welcome back gift (flowers, small gift, sign/card from the team, etc.)
1. Review the [Return from Leave]({{< ref "general-and-entity-benefits#returning-from-parental-leave" >}}) section below to prepare for your team member's first day/week back at work.
1. Reach out welcoming them back. Share what they can expect on their first day back, and that you'll plan on meeting with them first thing on their first day back.
    - We want your team member to see a friendly face on their first day back, and feel comfortable as they return to work.

#### Return From Leave: First Day Back at Work

Welcome them back! Whether your team member was gone for several months, or just a few weeks, it is important for you to acknowledge their return and let them know how you'll be supporting them. Returning to work after a leave, for some, can cause anxiety so it is important the team member eases back slowly. Recognize that there will be a period of readjustment, and personal and professional reflection; be prepared to be transparent and have productive and supportive conversations.

1. Plan to meet with your team member first. It is important to reconnect with the person that has been on leave, and not jump right into work.
    - First, ask how they are doing, how is their family, how was their time away, are they anxious about returning, if so what is causing them anxiety, how would they like to see you show up for them as they transition back, etc.
    - Review what they can expect during their first weeks back at work.
    - We want our team members to ease back into working, so jumping back into projects or taking on new projects may not be the right choice. Instead they should plan to reconnect with their team, and other cross-functional partners.
    - Be prepared to discuss any other questions/concerns that your team member may have upon return.
    - Share team/org changes
1. Your team member may provide you with a Return to Work note upon their return from leave.  Please forward any return to work notes received to leaves@domain.
1. If Applicable: If your team member informs you they have restrictions, and is requesting accommodations to be able to perform their job, please contact `leaves@domain` and the Absence Management Team will assist.
1. Team members may block off time on their calendars.  Please be respectful of these calendar blocks.
1. Check-in routinely with your team members to ensure they are receiving the appropriate level of support as they transition back to work recognizing that there will be a period of readjustment and personal and professional reflection.
    - Check-ins should be done on a regular cadence: 1st day, 1st week, 2 weeks, 1 month, 2-3 months, etc.
    - If the transition seems to be progressing differently than anticipated, you can reach out to your People Business Partner or Team Member Relations for support.
    - Team members have access to [Modern Health]({{< ref "modern-health" >}}) if needed.

## General Guidelines For Managers on Resource Allocation

If you have a team member going out on parental leave, a common question might be "how should I reallocate their tasks and output while they are out?" Below are general guidelines for managers based on the length of leave taken by the team member. **Note** - local law supersedes these guidelines where applicable:

- Leave less than 1 month: Use internal resources.
- Leave less than 6 months: Use internal resources who may be eligible for an [interim bonus]({{< ref "compensation#compensation-for-interim-roles" >}}), and/or consider hiring a temporary contractor
- Leave longer than 6 months: Use internal resources who may be eligible for an [interim bonus]({{< ref "compensation#compensation-for-interim-roles" >}}), hire a temporary contractor.
- Leave longer than 1 year: Consider a backfill ensuring there will be a similar (level, scope, etc) role for the person when they return.

## Parental Leave Reentry Buddies

We want our team members to feel supported throughout the entire life-cycle of their leave. Returning from any leave is hard, and navigating work and parenthood can be challenging. Parental Leave Reentry Buddies are an important part in supporting our team members returning from leave, and we ask GitLab team members to volunteer (being a parent yourself is not required).

A Parental Leave Reentry Buddy helps team members reconnect with GitLab and ease back into working after [parental leave](/handbook/total-rewards/benefits/general-and-entity-benefits/#parental-leave). A Parental Leave Reentry Buddy is an advocate for a successful return to work, and is able to empathize with concerns about reentering the workplace.

Responsibilities may include but are not limited to:

1. Facilitate weekly [coffee chats](/handbook/company/culture/all-remote/informal-communication/#coffee-chats) to catch up on non-work topics, and listen to any concerns they have or issues they've encountered since returning to work.
    - Make it fun! Returning to work can be stressful, so coffee chats are a great time to step away from work and talk about something else.
1. Be available to help your team member navigate through any company or departmental changes that occurred while on leave.

*Future iterations are still being considered, and will be added to this section as the program evolves. If you have any feedback regarding this program, please contact `leaves@domain` or share with the People Connect team via HelpLab.*

### What Makes a Successful Reentry Buddy

1. While it is recommended that this buddy work within the same department as the team member reentering work, it is not a requirement. We just ask that you dedicate your attention and resources to supporting your team member.
    - If you are asked to be a buddy, work with your manager to delegate or temporarily pause certain duties to assist a team member as they ramp back up to 100%.
1. You are passionate about GitLab and its team members.
1. You are able to commit 10-20% of your time for two to four weeks to team members returning from leave.
1. You feel comfortable sharing feedback regarding what is working well, and suggestions for future iterations of this program.
1. (*Recommended but not required*) You are comfortable with Git and GitLab and can answer team member questions.

### Find a Parental Leave Reentry Buddy

Visit the [GitLab Team page](/handbook/company/team/) and search for 'Parental Leave Reentry Buddy', or ask on Slack in `#intheparenthood`.

### Volunteer to Become a Parental Leave Reentry Buddy

1. Contact `leaves@domain` or create a request in HelpLab if you're interested in becoming a Parental Leave Reentry buddy or would like more information.

### Adding Parental Leave Reentry Buddy to your GitLab Profile

1. Find your [yml file](/handbook/about/editing-handbook/#add-yourself-to-the-team-page).
1. Add `Parental Leave Reentry buddy` to the `departments` section in your entry (keeping your existing departments):

   ```yaml
    departments:
      - ...
      - Parental Leave Reentry buddy
   ```

1. Add the following code above the `expertise` section in your entry:

   ```yaml
      expertise:  |
                  <li><a href="">Parental Leave Reentry buddy</a></li>
   ```

1. If you already have an `expertise` section, add the list item portion of the above code:

   ```html
                 <li><a href="">Parental Leave Reentry buddy</a></li>
   ```

## Virtual Baby (or Growing Your Family) Shower

A nice way to celebrate a team member's new addition to their family is by hosting a virtual baby/growing your family shower. In colocated companies, this is something that teams often do to wish a team member well as they head out on parental or adoption leave. We encourage virtual showers to be considered for all team members (not just birthing parents). In order to help teams host a virtual shower, here are some resources that can help you get started:

1. Ask the team member if they would be comfortable with a virtual shower. In a remote environment, surprising the parent-to-be is less effective as they need to be an active participant in the process.
1. If the team member is comfortable and open to an event, ask them who they would like to include in the celebration and if they have any gift registries that other team members can buy gifts from so they are purchasing items that the baby will need. The purchase of gifts should always be optional.
1. Send out an invite in advance of the event so attendees can plan to be available for that date and time.
1. Create an agenda for the event. Be mindful to create an inclusive and welcoming atmosphere. Consider running potential games by the celebrated team member to ensure comfortability. See a sample agenda below:
    - Kick off the meeting by thanking everyone for coming, review the agenda and how games and prizes will be work.
    - Start meeting off with opening ice breaker: An option is a Baby MadLibs game.
    - Game 1 - Measure the belly. If the soon-to-be parent is a birthing parent, you can play this game. It requires a roll of toilet paper. Participants guess how many sheets of toilet paper it will take to wrap around the birthing parent's belly. The closest guess gets a prize.
    - Open presents - Have the soon-to-be parent save the presents shipped to them to be opened during the celebration.
    - Game 2 - Songs with the word "Baby." Have participants write as many songs as they can think of that have the word "baby" in them. Whoever thinks of the most songs within three minutes, wins a prize.
    - Close the event with an open forum for people to ask fun questions and send positive affirmations.

## Team Member Tool Kit

- Review our [parental leave benefits/policy]({{< ref "general-and-entity-benefits#parental-leave" >}})
- Slack channel to connect with other parents — `#intheparenthood` ([Join Slack channel](https://gitlab.slack.com/app_redirect?channel=intheparenthood) - *for GitLab team members only*)
- Read the handbook section on [returning from parental leave]({{< ref "general-and-entity-benefits#parental-leave" >}}) with tips for the transition back to work
- Consider participating in the [**Your 4th Trimester program**]({{< ref "general-and-entity-benefits#return-to-work-resources" >}}), a 90-day coaching program to help parents transition back to work.
- Read [GitLab's guide to parenting as a remote worker](/handbook/company/culture/all-remote/parenting/)
- Consider reaching out to a [Parental Leave Reentry Buddy](#parental-leave-reentry-buddies)
- Watch the video below from [Crucial Conversations](/handbook/leadership/crucial-conversations) entitled `How Working Moms can Do it All`:

{{< youtube "IRvsi-zsKvM" >}}

- Watch the video below from [Crucial Conversations](/handbook/leadership/crucial-conversations) entitled `How Working Moms can Ask for Help at Home`

{{< youtube "6CHPChKAsBE" >}}

## Parental Leave Policy Feedback

If you have any feedback about your parental leave experience for the People group to review you can always email `leaves@domain` or open an issue using our [Parental Feedback Issue Template](https://gitlab.com/gitlab-com/people-group/total-rewards/-/issues/new?issue%5Bassignee_id%5D=&issue%5Bmilestone_id%5D=).

---

Return to the main [GitLab Benefits page]({{< ref "benefits" >}}).
