---
title: Compensation
description: Find answers to your questions about GitLab's compensation framework.
---

## Related Compensation Pages

- [Compensation Calculator Formula]({{< ref "compensation-calculator" >}})
- [Compensation Review Cycle]({{< ref "compensation-review-cycle" >}})

## Use the Compensation Calculator

Team members can access the [calculator](https://comp-calculator.gitlab.net/users/sign_in) at any time with their GitLab credentials. Applicants will be given credentials and will be able access the calculator themselves as well, during the application process.

## Introduction

On this page, we're detailing why we have the compensation framework we have now.

## Contact Total Rewards

If you have any feedback or questions relating to compensation, please reach out to [Total Rewards](/handbook/people-group/#how-to-reach-the-right-member-of-the-people-group).

## GitLab's Compensation Principles

1. We're an open organization, and we want to be as transparent as possible about our compensation principles. Our compensation model is open to data driven iterations.
1. We are [paying local rates](#paying-local-rates) based on [cost of labor market](https://www.erieri.com/blog/post/cost-of-labor-vs-cost-of-living). There is *no* cost of living input in our compensation philosophy.
1. Compensation aims to be at a [competitive rate](#competitive-rate) for your job family, your location, your level, your experience, and your contract type.
1. We use a [compensation calculator]({{< ref "compensation-calculator" >}}) to ensure transparent and consistent compensation.
1. We do not disclose individual compensation since compensation is [not public](/handbook/communication/confidentiality-levels/#not-public).
1. We adjust our calculator based on survey data, feedback from applicants and team members, and candidate data. Please email `total-rewards@ gitlab` if you want to contribute.
1. We offer [restricted stock units (RSUs)](/handbook/total-rewards/stock-options/) for most positions.
1. We base compensation on current position and performance at GitLab – not on what we paid you last month – and, generally, we don't reduce compensation.
1. Increases within the market pay bands will be based on performance.
    - At hire, we base our compensation offer on the position and experience in the market.
    - For promotions, increases are based on ensuring alignment to the new role's market range.
    - At [Annual Compensation review]({{< ref "compensation-review-cycle#annual-compensation-review" >}}), increases will ensure alignment to the market (by being within the entire range of the calculator), and resources will be allocated to top performing team members within the organization.
1. GitLab will continue to monitor [pay equality](/handbook/people-group/people-success-performance-indicators/#sts=Pay%20Equality) to ensure underrepresented groups are paid at the same rate as the company.
1. We want to follow the processes on this page for everyone, please email `total-rewards@ gitlab` when we don't. If you have a specific question around your compensation or one of your direct reports' please schedule a call with `total-rewards@ gitlab` to review.
1. We will update this page and the processes throughout the year.
1. We'll review your pay as soon as your job-family or level factor changes.
1. If we change our [SF benchmark]({{< ref "compensation-calculator#sf-benchmark" >}}) for a job family without changing the requirements, we review the compensation both for existing team members and new hires. If the SF benchmark is changed together with the requirements this review might happen at the time of the change or in our yearly cycle.
1. We offer [bonuses and incentives]({{< ref "incentives" >}}), but we don't offer ping pong tables or free lunches. We think it is more important to offer people flexibility and freedom. See the [Top 10 reasons to work for GitLab on our culture page](/handbook/company/culture/#advantages/).
1. We hire across the globe, but we're not location agnostic. Your timezone, the location factor in your region, and the vicinity to users, customers, and partners can all be factors. For example, we may favor one applicant over another because they live in a region with a lower location factor or because we need someone in that timezone.
1. People on quota (account executives, account managers, and sales leadership) have variable compensation that is about 50% of their On Target Earnings (OTE). Individual contributors in the sales organization have variable compensation that is purely based on commission.
1. Compensation decisions around level and experience levels and for functions not in the calculator are taken by the [Compensation Group](#compensation-group).

## Competitive Rate

**We want our compensation to be at a level where we can recruit and retain people who meet our requirements.**
Our requirements for all [job-families](/handbook/hiring/job-families/) are at **or above** the average in the market.
Therefore, we can expect to be at or above the 50th percentile of the survey data gathered from providers like Comptryx and Radford.
Please do not use the term market rate since this can mean either competitive rate or survey data.
Also see our [SF benchmark]({{< ref "compensation-calculator#sf-benchmark" >}}).

When discussing a competitive rate for a single person at GitLab, please refer to this as their lottery factor. For example, if this person won the lottery and left the company what impact would that have. Other common industry terms are walk away factor or bus factor, but those both hold a negative connotation.

### Placement in the Compensation Range

As part of offering a competitive rate within our [transparent Compensation Calculator]({{< ref "compensation-calculator#the-compensation-calculator" >}}), team members are able to see where they fall within the compensation range for their role in their location. Typically in the technology sector, the majority of team members are likely to sit between the minimum and slightly above the median of the overall compensation range. It is not common to see a team member at the top of the range as this would leave little to no room for salary growth.

It is important to note that where someone falls within the compensation range is *not* an indicator of performance, nor is it a sign of promotional readiness. For more information on how performance is linked to compensation please review the following [handbook section]({{< ref "compensation-review-cycle#performance-factor" >}}). This is *different* from the Compa Groups GitLab used to have when the bands were more narrow. Additionally, where a team member sits in the range may change as GitLab's compensation philosophy around competitive rates iterates to allow more room for salary growth.

### Sharing Compensation

There are no policies in place at GitLab that prevent team members from sharing their personal compensation data, though we encourage that any concern a team member has with compensation be directed directly to your manager or Total Rewards as the most efficient route to address concerns and arrive to a resolution.

## Paying Local Rates

### Why we pay local rates

Competitive rates for roles vary depending on regions and countries.
We pay a [competitive rate](#competitive-rate) instead of paying the same wage for the same role in different regions.
Paying the same wage in different regions would lead to:

1. If we start paying everyone the highest wage our compensation costs would increase greatly, we can hire fewer people, and we would get less results.
1. A concentration of team members in low-wage regions, since it is a better deal for them, while we want a geographically diverse team.
1. Team members in high-wage regions having much less discretionary income than ones in low-wage countries with the same role.
1. Team members in low-wage regions being in [golden handcuffs](https://en.wikipedia.org/wiki/Golden_handcuffs) and sticking around because of the compensation even when they are unhappy, we believe that it is healthy for the company when unhappy people leave.
1. If we start paying everyone the lowest wage we would not be able to attract and retain people in high-wage regions, we want the largest pool to recruit from as practical.

As more companies transition to partial or all remote workforces, we are [tracking (internal only)](https://docs.google.com/spreadsheets/d/1QD3w7QiynCWUuOJ5mDRZ4PM20nuuLbEDB0GEzQRKmNQ/edit#gid=0) the pay philosophy decisions made by these companies to understand the effects these decisions may have on the tech industry and future of remote pay.

### Hire the best candidate

We hire the best candidate for each role regardless of location, cost, or other factors.
During the sourcing we do optimize what potential candidates we approach in order to bring more diversity (both geographically and people from underrepresented backgrounds) to our team.

### Blog Post

We also wrote a [blog post about paying local rates](https://about.gitlab.com/blog/2019/02/28/why-we-pay-local-rates/).

## Market-Based Approach

We have a market-based approach to compensation because:

1. It allows for us to adapt to market changes, thus remaining competitive for local talent
1. Role, location, and level benchmarks keep compensation bands consistent. Market-based benchmarks also help with keeping it fair and consistent rather than expecting our team members to negotiate their pay.
1. Prevents wage compression which occurs when new employees negotiate and get higher wages than those being paid to current team members.
1. As long as budget permits, we do what's right for the market even if it means paying a team member higher than their "expected" pay.

## Compensation Group

The Compensation Group is comprised of the CEO, CFO, and Chief People Officer. The Compensation Group is responsible for all Total Rewards escalations based on the approval matrix. When there is no time to coordinate with the group, the CEO can make a decision and inform the group. When the CEO is away (e.g. vacation), the two other members of the group can make a decision and inform the group. This group is different from the Compensation Leadership Development Committee at the [board level](/handbook/board-meetings/#board-and-committee-composition).

**Approval Matrix:**

| Approval Type | Approvals Needed | Process |
| ------------- | ---------------- | ------- |
| Compensation Requests outside of band (cash/equity) for new hires and current team members | Chief People Officer | [Process Document](https://docs.google.com/document/d/1H9wsq6am4O_Wb5BPDeh8m6cjeR4eBcREQqehB9k01mA/edit#) |
| Approval of Benefit Plan Changes (due to implementation or renewal) | If Under 50k USD, Finance Business Partner (G&A)<br>If 50k-100k USD Finance Business Partner (G&A) and VP, Finance<br>If 100k+ USD Finance Business Partner (G&A), VP, Finance, and CFO | Total Rewards to summarize implementation or renewal details |
| Final Approval of Annual Compensation Review | Chief People Officer, CFO, and CEO | Total Rewards to present final proposed increases and budgetary impact |
| Review/approval of Executive and Board Compensation | Chief People Officer and CEO | Total Rewards to present summary of proposal, once approved escalate to Compensation Leadership Development Committee for Final Approval |
| Internal Demotion requests | Chief People Officer | [Demotion Process](/handbook/people-group/promotions-transfers/#demotions) |

## Compensation for Acting and Interim Roles

Effective Q2 of FY 2021, we have established a one time bonus payment process for team members that are asked to step into an acting or interim management role. Team Members in an acting or interim management role should review [the expectations of an individual in the management group]({{< ref "structure#management-group" >}}).

### Criteria for Eligibility

- For an interim role to be considered, the need for coverage would need to be longer than a 30 day time period.
- The interim role has to be at a higher level than the current role of the team member.
  - If a team member assumes 100% of the workload of a lateral role for 60 days or more **in addition to their permanent full time role,** an interim bonus may be considered by the [People Business Partner](/handbook/people-group/#people-business-partner-alignment-to-division) and leader of the group.
  - Effective 2023-02-01, interim bonuses in Go-to-Market roles (CRO Organization, Sales Development) will be available to people managers temporarily occupying a lateral or higher management position **in addition to their permanent full time role.**
- In case the interim role is within another job family, team members will also be eligible for the interim compensation on a lateral level.

*Since Acting roles do not typically end in promotion, the decision on whether the acting role meets the eligible criteria rests with the Hiring Manager and the Department head.*

### Calculation of Interim Bonus

The formula for the bonus recognizes the length of time that the team member is playing the interim role. Payment of the one time bonus would occur at the completion of the interim role. The bonus would be calculated using the following formula:

The greater value of the standard discretionary bonus amount ($1,000 at the current exchange rate) OR the following calculation:

For team members on a base salary compensation plan, your bonus will be an additional 10% of your salary for the duration of the interim role period. The calculation is as follows:

- `(Annual Base Salary in Local Currency/365) x .10 (10%) x # of Calendar Days in the Interim Role`

For team members on an OTE (On Target Earnings) compensation plan in Go-to-Market roles, interim compensation will generally be based on results achieved by the interim team in the interim period:

- Interim leaders will dotted-line manage the new team, meaning they will not assume direct management of the team in Workday, but will instead act as a temporary leader. As such, quotas will not change during the interim period.
- When interim managing a lateral team:
  - The interim bonus will be calculated based on Net ARR closed during the period x a representative BCR (base commission rate), calculated based on the leader's OTI and the interim role's annual quota
- When interim covering for a higher leadership position:
  - The interim bonus will be calculated based on Net ARR closed during the period x a representative BCR (base commission rate) for the higher leadership position
- Standard commissions payments will continue for the duration of the interim role
- All in-plan (within OTI) components are eligible to be included in an interim bonus calculation for a GTM role, e.g. Net ARR, New Logo, Professional Services Bookings, etc.
- For teams measured on pooled compensation plans (e.g. SAs and CSMs), interim bonuses will be based on OTE for the interim role while in seat instead of performance: (Annual OTE in local currency/365) / x .10 (10%) x # of Calendar Days in the Interim Role
- All people managers in GTM roles are candidates for interim management assignments, outside of members of the CRO or CMO leadership teams, i.e. direct reports of the CRO or CMO
- Total bonus payments for GTM team members in an interim management role shall not exceed $50,000 USD for a single interim leadership assignment

**The interim bonus should be calculated based on the team member's salary during the interim period, not the salary after the interim period.** If your compensation changes during the interim period (for example, relocation, country conversion, etc.), we will calculate the interim bonus based on the pay rate of each calendar day.

### Tracking and Submitting Interim Bonuses

#### Tracking

Interim/acting roles should be tracked in Workday, in some cases the process is initiated in Greenhouse or may also be tracked by the manager by completing a Submission of Acting Role for a Team Member [form](https://forms.gle/KdB4TBtfuHxgGLzE8).

Guidance on different processes can be found below:

| Greenhouse | Acting/Interim Tracker |
| -------- | ---------------------- |
| All interim roles that have gone through our Greenhouse interview process | Lateral acting role in the same job family |
| More senior acting/interim role in the same job family | Lateral acting roles in different job families |

Greenhouse - Acting/Interim Tracker examples:

- Engineering Manager takes on an acting role as a Product Designer
- Engineering Manager takes on another Engineering Manager role simultaneously in a different group

Workday examples:

- An Engineering Manager takes on an interim role as a Senior Engineering Manager
- A Product Manager takes on an interim role as a Senior Backend Engineer (after having gone through an interview process)

The process for tracking interim/acting roles is as follows:

1. *(For Acting)*, Managers will align with their Manager and People Business Partner and align on the following:
    - Whether the role is interim or acting
    - Whether the role is in a new job family or the same job family
    - Whether the interim/acting role is lateral or a higher level
    - The effective start date of the interim/acting period
    - Once agreed and approved, Managers will submit the [Submission of Acting Role for a Team Member form](https://docs.google.com/forms/d/e/1FAIpQLSd5CkHvcDYx6oaNzrAm8QqFZpCVLcoDrcTpaAl-cuKCUERc2A/viewform).
1. *(For Interim)* People Business Partner will submit a [Job Change - Change Job Details](https://docs.google.com/document/d/1hpPikG0STncYKamaY8XlfMTwYdoszP-0Xogvpp5hyZ4/edit?usp=sharing) request in Workday. Job title should not be changed, as compensation and job family are not altered as part of the interim/acting process. Only a modification to the team member's `Business Title` is required. This step is only done for interim positions as acting positions are not tracked in Workday.

#### Submitting

When the interim/acting period ends, the following process should be followed to submit the interim bonus request:

- *(For Acting bonuses)* The manager references the start/end dates Acting period as initially submitted through the Acting form for the bonus calculation.
- *(For Interim bonuses)* The manager references the Workday `Job` tab and clicks into `Job History` and review the 'Business Title' column to confirm the start date of the interim period
- Once confirmed, the Manager submits the bonus in Workday. Follow the [Request a One-Time Payment job-aid](https://docs.google.com/document/d/15_cqMAIoqkxNhoCTL42X3XUpr0E9fNZXFmY3Yitk2LQ/edit?usp=sharing) to submit an OTP. Manager must also provide the start and end date of the of interim period in Workday under the *Additional Information* section in Workday

**Note:** The team member must be an active team member of GitLab at the end of the interim role period to be eligible to recive a bonus payment. If a team member leaves GitLab during the interim role period, they will not be eligible for a prorated payment.

### Examples of the Interim Bonus Calculations below

- Senior Engineer has a base salary of $125,000. She has taken on the interim role of Engineering Mgr for 3 months (Jan-March) which is a total of 90 days. The bonus for this interim role would be `($125,000/365) x .10 x 90 = $3,082.19`
- Finance Business Partner has a base salary of $100,000. He has taken on an interim role covering multiple teams while his coworker is on leave for 4.5 weeks which is a total of 31 days. The bonus for this interim role would be `($100,000/365) x .10 x 31 = $849.32` so we would round up for this bonus and process as a discretionary award.
- Area Sales Manager interim manages a lateral team after a peer ASM has been promoted. The ASM has a base commission rate of 1% for Net ARR and $3,000.00 per New Logo.  During their interim coverage the Area closes $1,000,000.00 of nARR and 2 First Order new logos.  The bonus calculation would be ($1,000,000.00 x .01) + (2 x $3,000.00) = $16,000.00.
- Area Sales Manager interim manages an entire Region after an AVP leaves GitLab. AVP base commission rates are 0.3% for Net ARR and $800 per New Logo. During the interim coverage period, the team closes $5M of Net ARR and 4 New Logos. The bonus calculation would be ($5,000,000.00 x 0.003) + (4 x $800.00) = $18,200.00.

## Exchange Rates

{{< exchange-rates >}}

### Paid in your local currency

The compensation calculator is updated using the November 1 point in time exchange rates according to Google Finance rates. We are using the point in time exchange rate due to significant lag when utilizing an average exchange rate.

The updates to the handbook, compensation calculator, and Workday for the November 1 rates will be made between December and January with an effective date of February 1.

Adjustments to existing team members' compensation who are paid in local currency are made **only during** the applicable [compensation review cycle]({{< ref "compensation-review-cycle" >}}).  We only adjust compensation during the review cycle since being paid in local currency means that your local purchasing power does not change.

#### Exchange Rates for Bonus Processing

All [one-time bonuses]({{< ref "incentives" >}}) including Discretionary, Referral, and Working Group Bonuses where the intended value is awarded in USD will be converted to local currency using the set exchange rates above. This is a reversion of the prior policy put in place to use monthly rates with the reversion going into effect as of September 1, 2023. In the future, when we are able to put an efficient process in place for maintaining more up-to-date conversion rates in Workday, we will further revise this policy to use more current rates.

### Not paid in your local currency

Team members contracted through CXC or IT BV may have the option to choose to be paid in USD or EUR when there is volatility in their local currency. This change can only be made once during your employment and only if CXC and payroll can support it. USD and/or EUR payment options are not available in all countries. This change will be made according to the conversion from local currency to USD or EUR at the time of the update. All future salary adjustments will be made based on the new salary regardless of fluctuations to local currency in order to provide a stable experience to team members who opt into this.

Please reach out to People Connect in order to understand if you are eligible to update your currency to USD or EUR and to initiate this process.

## Hourly Employees

GitLab is committed to following all applicable wage and working hours laws and regulations. To help ensure that all work performed for GitLab is compensated correctly, team members compensated on the basis of hours worked must [report and record time](/handbook/finance/#timesheets-for-hourly-employees) accurately.

## Sales Compensation

Sales and Sales Development roles at GitLab that are subject to quota and paid commission based on the [Sales Compensation Plan](/handbook/finance/sales-comp-plan/) are not located in the [compensation calculator]({{< ref "compensation-calculator" >}}). This includes roles in the following departments:

- Channel
- Commercial Sales
- Enterprise Sales
- Sales Development

These roles are still [benchmarked using market data]({{< ref "compensation-calculator#sf-benchmark" >}}) and are assigned to a pay differential zone based on their [location factor]({{< ref "compensation-calculator#location-factor" >}}) according to the following table:

| Zone | Location Factor Range | Zone Differential |
| ---- | --------------------- | ----------------- |
| Zone 4 | 0.01 - 0.49 | 0.60 |
| Zone 3 | 0.50 - 0.69 | 0.75 |
| Zone 2 | 0.70 - 0.85 | 0.85 |
| Zone 1 | 0.86 - 1.00+ | 1.00 |

## Variable Pay Frequency

The Variable Pay Frequency is a field held in Workday and applicable to roles that receive a commission or bonus. Variable Pay Frequency is assigned according to the following chart:

| Department/Role Description | Variable Pay Frequency Type |
| --------------------------- | --------------------------- |
| VP (non-sales), Executives | [Company Executive Bonus Program](#company-director-and-above-bonus-plan) |
| VP (Channel, Field Operations, Customer Success) | Sales Executive Bonus Program |
| VP (Commercial Sales, Enterprise Sales) | Monthly Bonus |
| Director (non-sales) | [Company Director Bonus Program](#company-director-and-above-bonus-plan) |
| Director (Field Operations) | Sales Director Bonus Program |
| Director (Channel, Customer Success, Enterprise Sales) | Monthly Bonus |
| Director (Consulting Delivery) | Quarterly Bonus |
| Channel, Commercial Sales, Customer Success, Enterprise Sales, Sales Development (IC) | Monthly Bonus |
| Sales Development (Manager) | Quarterly Bonus |
| Consulting Delivery, Education Delivery, Practice Management | Quarterly Commissions |

## Director Compensation

Director compensation is determined as part of the [GitLab Compensation Calculator]({{< ref "compensation-calculator" >}}) and is comprised of base salary and bonus. The location factors for Directors have a floor built in where the location factor for a team member is subject to either the US Director Minimum location factor of 0.8 or Global Director Minimum location factor of 0.7. If someone is in a location with a higher location factor then this minimum does not apply and the higher location factor will be used.

Directors who are not already enrolled in the Sales Compensation Plan or other performance incentive plan are eligible for a 15% bonus of current base salary. More information on the bonus plan can be found in the [Company Director and above Bonus Plan](#company-director-and-above-bonus-plan) section.

## Executive Compensation

Executive Compensation (VP and above) is derived outside of the GitLab Compensation Calculator using the following process:

1. The Total Rewards team collects survey data to review against current compensation to ensure alignment in cash (base/variable) and equity refresh values.
    - Survey Data from the GitLab peer group: GitLab will analyze the peer group data from Radford against peer group data from Compensia.
1. The Total Rewards team will advise on a market increase or performance factor as determined in the [performance enablement review](/handbook/people-group/learning-and-development/career-development/#performance-enablement-review), whichever is appropriate.
1. The recommendation will be reviewed by the e-group leader for VPs and above. The final approval for VP compensation is the Compensation Group. Total Rewards will work with finance to ensure alignment to budget.
1. E-Group compensation is reviewed in partnership with Compensia based on the peer group data provided. The CEO will recommend increaes and refresh grants for his direct reports to the Compensation Leadership Development Committee for approval.
1. The Total Rewards team will then notify the CEO or direct manager of the increase who will then communicate it to the individual.

As each Executive has an individual market assessment upon hire, we expect compensation to be aligned to market at each compensation review. If there are large changes in the market for a specific role, those will be addressed.

## Company Director and above Bonus Plan

Directors and above are eligible for the Company Bonus Plan.

**Communication**

- Prior to the bonus payment and after Compensation & Leadership Development Committee approval, the CFO will confirm the achievement % of the bonus plan in the #director-and-above slack channel.

**Timing:**

- Payments expected to occur 60 days after the end of the fiscal period but are dependent on the accounting close process and committee approval.

**Payout:**

- The bonus will be paid out semi-annually.
- The first semi-annual payment will be funded up to a maximum of 80% of target bonus amount for the period of February through July. Any full plan year adjustments will be made as part of the final bonus payout.
  - Example: A director who has been eligible for the bonus plan from February 1 has an annual target of 30,000 USD. Their target bonus amount for the first half of the fiscal year, February through July, is 15,000 USD. Therefore, they will receive 80% of 15,000 USD or 12,000 USD for their first semi-annual payment.
- The final bonus payout will be based on actual performance against plan less amount paid at the semi-annual payout.
- If the first semi-annual bonus is achieved but Company performance falls below the annual threshold the second half bonus will not be achieved but the first half bonus will not be rescinded or otherwise payable back to the Company.

**Approvals:**

- The bonus plan is approved by the [Compensation Leadership Development Committee](/handbook/board-meetings/#compensation-and-leadership-development-committee) of the Board of Directors.
- Performance against Plan targets is reviewed and approved by the [Audit Committee](/handbook/board-meetings/#audit-committee) of the Board of Directors.
- Bonus payouts are recommended by the CFO and approved by the Compensation Leadership Development Committee of the Board of Directors.

**Proration and Eligibility:**

- The Director bonus will be prorated for team members who start or are promoted into the Director bonus pool between February 1 and July 31 (first half bonus), or start or are promoted between August 1 and January 31 (second half bonus).
- In addition, the team member must be actively employed by GitLab at the time of payout.

GitLab reserves the right to change or discontinue the bonus program at any time. All bonus payouts are discretionary and require the achieving of specific company results that will be communicated each year.

[Sales Commissions handbook page](/handbook/sales/commissions/).

### Bonus Payout Approvals

The Compensation Leadership Development Committee approves all bonus payouts for direct reports to the CEO and overall bonus funding at the end of each Fiscal Year. The Compensation Group internally at GitLab approves all other bonus payouts.

1. The Finance team will generate a calculation of the total bonus payout for the Fiscal Year within 30 days of the last day of the fiscal year including: Employee #, Name, Reporting to, Division, Department, Title, Hire Date, Total Eligible, Total Payout.
1. The Total Rewards Team will audit the calculation and eligibility list.
1. Once approved by the Total Rewards and Finance team, a meeting will scheduled with the CEO, CPO, and CFO for approval of the bonus payout. The CEO and CFO will review and approve all bonus payouts (aligned with the [authorization matrix](/handbook/finance/authorization-matrix/#authorization-matrix)) and discuss exceptions with the CPO.
1. The Total Rewards Team will collaborate with the Finance team to include the total spend for the bonus plan, attainment, and executive specific payout for the Compensation Leadership Development Committee meeting. Approval of the bonus plan would be captured in the Committee meeting minutes.
1. Once approved by the Compensation Leadership Development Committee, the Total Rewards team will notify Finance that the bonuses are ready for processing via payroll. The file approved internally will be shared with payroll by the Finance team.

## Compensation Data Analysis and Modeling Sheet

This is an internal process for the Total Rewards team which details how to refresh the Compensation Data Analysis and Modeling sheet which is used for processes such as calculating [percent outside of compensation band](/handbook/people-group/people-success-performance-indicators/#percent-over-compensation-band).

To update:

1. Navigate to the sheet "Comp Data Analysis and Modeling - Workday Report".
1. Download the "Comp Data Analysis & Modeling" report from Workday as a CSV.
1. Duplicate the "Template" tab in the sheet and rename it based on the date the Workday report was pulled using format: yyyy-mm-dd.
1. Copy and paste the Workday report starting from cell A2.
1. Delete any test accounts, denoted "Test" in their name, by deleting the entire row.

## Learning GitLab's Compensation Framework

As part of our Q1 OKR, we will be working on ensuring there are materials for a compensation certification. The following are the initial questions to generate the certification.

### Compensation Fundamentals Training

Please take time to complete the [Total Rewards Compensation Fundamentals Training](https://levelup.gitlab.com/courses/total-rewards-compensation-fundamentals-training) in Level Up.

This training includes details such as:

- Purpose of Total Rewards
- Components of Total Rewards (Cash, Equity, Benefits) resulting in a Total Package
- Cash comp versus Equity
- Market Pay Practices
- Pay Ranges and how they operate
- Pay for Performance vs Market Rates
- Cost of Labor Market vs Cost of Living
- Compensation in an emerging remote environment

### The Why Questions

- [Why do we have the compensation framework we have now?](#gitlabs-compensation-principles)
- [Why does GitLab aim to pay a competitive rate?](#competitive-rate)
- [Why does GitLab pay local rates?](#paying-local-rates)
- [Why does GitLab have a Compensation Calculator?]({{< ref "compensation-calculator#the-compensation-calculator" >}})

### The What Questions

- [What is the foundation of GitLab's compensation framework?]({{< ref "compensation-calculator#the-compensation-calculator" >}})
- [What is the formula of the Compensation Calculator or otherwise known as the Calculator "Inputs" or "Factors"?]({{< ref "compensation-calculator#the-compensation-calculator-formula" >}})
- [What does the SF Benchmark mean on the Compensation Calculator?]({{< ref "compensation-calculator#sf-benchmark" >}})
- [What does the Location Factor mean on the Compensation Calculator?]({{< ref "compensation-calculator#location-factor" >}})
- [What does the Exchange Rate mean on the Compensation Calculator?](#exchange-rates)

### The How Questions

- [How do we continue to make sure that our team members are compensated according to their skill level and receive equitable pay?]({{< ref "compensation-review-cycle#compensation-review-cycle" >}})
- [How do we make sure that the different Compensation Calculator inputs remain relevant and competitive to market?]({{< ref "compensation-review-cycle#annual-compensation-review" >}})
- [How does the Total Rewards team carry out the Annual Compensation Review?]({{< ref "compensation-review-cycle#annual-compensation-review-timeline" >}})

## Knowledge Assessment

You can test your knowledge on our compensation by taking the [GitLab Compensation Knowledge Assessment](https://docs.google.com/forms/d/e/1FAIpQLSe7cf8j9EMk3raWY7nHwSSVSdO0eE7bSHZ8TxSbm-L7hgQvuw/viewform) quiz.

If you have questions about compensation or the content in the Knowledge Assessment, please reach out to the [Total Rewards](/handbook/people-group/#how-to-reach-the-right-member-of-the-people-group) team.
