---
title: "Equity Compensation"
description: "Learn more about Equity Compensation at GitLab"
---

## About Your Ownership in GitLab

At GitLab, we strongly believe in team member ownership in our Company. We are in business to create value for our shareholders and we want our team members to benefit from that shared success.

This guide is meant to help you understand the piece of GitLab that you're going to own!  Its goal is to be more straightforward than the full GitLab 2015  & GitLab 2021 Equity Incentive Plans (the "2015 Equity Plan") and (the "2021 Equity Plan") and your stock option agreement or RSU agreement which you are advised to read, which both go into the full legal details. Please note, however, that while we hope that this guide is helpful to understanding the stock options and/or stock issued to you or RSU grants under the both Equity Plans, the governing terms and conditions are contained in the 2015 and 2021 Equity Plans and the related stock option agreement. You should consult an employment attorney and/or a tax advisor if you have any questions about navigating your stock options or RSU grants before you make important decisions.

Two things must happen for your stock options or RSUs to be meaningful,  for example:

1. You must meet the vesting schedule of the stock options (i.e. we have a 1 year cliff and 3 years of monthly vesting).
1. RSUs are granted quarterly, with a six month cliff vest for new team members and quarterly thereafter up to 4 years.  Refresh grants vest quarterly over 4 years.

If a team member leaves GitLab, they have 90 days post termination to exercise their vested options. Unvested RSUs and options are forfeited upon the date of the team member's exit from the company.

## Equity Incentive Plans

[2015 Equity Incentive Plan](https://www.sec.gov/Archives/edgar/data/1653482/000162828021018818/exhibit102-sx1.htm) and related form agreements would cover information related to GitLab options.

[2021 Equity Incentive Plan](https://www.sec.gov/Archives/edgar/data/1653482/000162828021019505/exhibit103-sx1a1.htm) and related form agreements would cover information related to GitLab RSUs.

[2021 Employee Stock Purchase Plan](https://www.sec.gov/Archives/edgar/data/1653482/000162828021018818/exhibit104-sx1.htm) would cover information related to GitLab ESPP purchases.

## Stock Options

In the past at GitLab, we have given equity grants in the form of Incentive Stock Options (ISOs) and Non-Qualified Stock Options (NQs). It's called an option because you have the option to    buy GitLab stock, subject to vesting terms, at the exercise price provided at the time of grant.  

The difference in these two types of grants are, generally, as follows:

- ISOs are issued to US employees and carry a special form of tax treatment recognized by the US Internal Revenue Service (IRS).
- NQs are granted to contractors and non-US employees.

GitLab is not giving equity grants in the form of options at this time.

### Restricted Stock Units (RSUs)

In September 2021, in connection with our IPO that occurred on October 14, 2021, our board of directors and stockholders approved the  2021 Equity Incentive Plan (the "2021 Plan") as a successor to our 2015 Plan (together the "Plans"). The  2021 Plan authorizes the award of both stock options, which are intended to qualify for tax treatment  under Section 422 of the Internal Revenue Code, and nonqualified stock options, as well for the award of  restricted stock awards ("RSAs"), stock appreciation rights ("SARs"), restricted stock units (RSUs), and performance and stock  bonus awards. Pursuant to the 2021 Plan, NQ stock options may be granted only to our team  members. Since September 2021, we have issued RSUs for grants of shares of the Company's common stock, the vesting of which is based on the requisite service requirement. Generally, the Company's RSUs are subject to forfeiture and are expected to vest over two to four years ratably on a combination of bi-annual and quarterly basis. For RSU Grant Cadence and Vesting please see the following [slide deck](https://docs.google.com/presentation/d/1a3iisaLdoMFdujTyh9K2gYB2eOTi1xC2Ul7ycj7HkSg/edit#slide=id.p)

### Sell-to-cover - RSUs

Shares are sold to pay the taxes due on the RSU vesting.  This is an automatic sale and the shares sold are based on the tax rate for your country.  For example, if 100 shares vest, and your tax rate is 30%, then 30 shares will be sold to cover the tax and the remaining shares will be placed in your E*TRADE account.  Taxation for selling of options or GitLab stock owned:

Taxation of Ordinary Income - RSU - More Detail

- Compensation - At the time of vest for RSUs, you will recognize ordinary income equal to the cash value of the shares that vest.
- Tax Liability - Your tax obligation will be based on current tax rates due at the time of vest.  A portion of the shares are sold to pay your tax liability.   For each country, your local tax rates are used.
- For example, for U.S. team members tax withholding at the time of vest is computed using your federal supplemental tax rate (a fixed percentage), plus state and local and other applicable taxes- such as disability, FICA and Social Security.
- Remaining Shares - The remaining shares from your RSU grants are fully owned by you and deposited in your E*Trade Securities stock plan account.

(You should always consult with your own tax advisor concerning how holding periods, capital gains and losses, and your personal circumstances may affect your taxes, and before taking any action that may have tax consequences.  Your actual taxes paid will vary depending on your personal circumstances. )

Please note that all tax withholding is based on tax rates provided by Baker McKenzie - You can find our current Tax Matrix [here](https://drive.google.com/file/d/13deasDMvCiXcInQOFvORM6cKNazim7pz/view?usp=drive_link)

## Employee Stock Purchase Plan ("ESPP")

### What is an ESPP?

An ESPP is a benefit GitLab offers that allows team members to optionally purchase shares of their company's stock at a discount through regular payroll deductions over specified Offering Periods.

In September 2021, the Company's board of directors and its stockholders approved the 2021 Employee Stock Purchase Plan ("ESPP") to enable eligible team members to purchase shares of the Company's Class A common stock with accumulated payroll deductions and provides a 15% purchase price discount of the fair market value of the Company's Class A common stock on the IPO date or purchase date, whichever is lower. The 2021 ESPP also provides up to a 24-month look-back period with four purchase dates in May and November of each year, and the first purchase occurred in May 2022.

### Eligibility Requirements

1. Team member is employed via a GitLab entity with 50+ headcount
1. Team members work more than 20 hours per week.
1. Must be actively employed at the beginning of the Offering Period to enroll
1. Must be actively employed on the last date of the Purchase Period to be able to purchase
1. Eligible ESPP GitLab Entities
   - Canada Corp (Canada)
   - GmbH (Germany)
   - BV (Netherlands/Belgium/Finland)
   - Inc. & Federal (United States)
   - Ltd (United Kingdom)
   - PTY Ltd (Australia/New Zealand)
   - Ireland Ltd (Ireland) - as of 2023-06-01
   - BV (Finland)  - as of 2023-06-01

### Changing Contribution Amounts

- Contribution increases and decreases are limited during Offering and Purchase Periods
- Increases: Team members may not increase their contributions after the Offering Period begins.
- Decreases: Team Members  may decrease their contribution rates once during any Offering Period.

### Stop Contributions

- Team members may reduce their contribution to 0% during an offering period.
- Any prior contributions will be used to purchase shares on the scheduled purchase date.
- At the end of the offering period, the team member will be automatically withdrawn from the offering period effective as of the day after the purchase date following the date of the request.
- Team members would need to re-enroll as a new participant in the next open enrollment window and begin a new Offering Period  if they wish to participate in the future.

### Withdrawals

- Team members may withdraw from the ESPP at any time and receive a refund of their withheld contributions. The refunds are processed through Payroll.
- Team members who withdraw would need to re-enroll in order to participate in future Offering Periods.

Details on eligibility, enrollment, calculations, pricing and dollar value can be found at [ESPP Training Deck](https://docs.google.com/presentation/d/1X_IcuK8ORiQg_nsi1km6c9_Ewbv5FD1bdnO06C-snV8/edit#slide=id.gede224808f_0_39)

### Alternate ESPP Non-US

The Alternate ESPP is for team members not eligible for the ESPP, mainly in PEO countries.  Team Members in the Alternate ESPP will be eligible to receive RSUs on the expected earnings as if they would have been able to participate in the ESPP.  There are no payroll deductions or contributions required. The RSUs will be automatically granted to team members as calculated by the following formula for each 6 month purchase period:  Details on eligibility, enrollment, calculations, pricing and dollar value can be found at [ESPP Training Deck](https://docs.google.com/presentation/d/1X_IcuK8ORiQg_nsi1km6c9_Ewbv5FD1bdnO06C-snV8/edit#slide=id.gede224808f_0_39)

### What is an Offering Period?

- The Offering Period consists of a 24-month period beginning on the applicable Enrollment Date and includes four six-month Purchase Periods.*
- Team members can only be enrolled in one Offering Period at a time.
- Your Offering Period might be different from the one your coworker is enrolled in.

ESPP Calendar for Offering periods can be found at [ESPP Training Deck](https://docs.google.com/presentation/d/1X_IcuK8ORiQg_nsi1km6c9_Ewbv5FD1bdnO06C-snV8/edit#slide=id.gb84b7497fb_0_24)

### When do Purchases Occur?

On the respective Purchase Dates at the end of each Purchase Period. Only whole shares can be purchased.  Purchase dates are normally May 31 and November 30 of each year.

### Other ESPP references

- [ESPP FAQs](https://docs.google.com/document/d/1Be1gz-_iGGNjuOku7N4ipnEFhGLfbxOZp68PEcoXUYU/edit)
- [ESPP/RSU Vesting AMA](https://docs.google.com/document/d/1ELjTI_X29KKpmO1AuI8IMXW8oNqnKexy2jRs8T-SiLE/edit#)
- [ESPP 101](https://docs.google.com/document/d/12KQBTHz7QbXSkC4HncUp4rT4DINvysPu1emLnRDO2xs/edit)

## Grant Levels

RSUs and at times Option Grants (Option Grants are rare since September 2021) are determined by Grade Level. If you have any questions on what grant should be offered to a new hire, please reach out to the Compensation and Benefits team by email to `total-rewards@gitlab.com`. References and information for Grant Levels is held within the  compensation calculator.

Note: All stock options and RSU grants are subject to approval by the Board of Directors and no grants are final until such approval has been made. The Company reserves the right in its own determination to make any adjustments to stock option grants at its sole discretion including the decision not to make a grant at all.

## Promotions

Promotion grants are based on the differential between the new hire equity dollar value at the new grade minus the new hire equity dollar value at the current grade using the median of the compensation range. The vesting schedule for the new equity grant will align to the terms and conditions of the equity plan for [RSUs](#restricted-stock-units-rsus).

Formula for number of Promotion Equity Grant: (New Hire Equity Grant Dollar Value Median at Promoted Level - New Hire Equity Grant Dollar Value Median at Previous Level)

For example, if my current role is Backend Engineer and the median new hire equity grant dollar value grant for my role, level, and location is 20,000 USD, and I am promoted to Senior Backend Engineer and the median new hire equity grant dollar value for that role, level, and location is 40,000 USD, the calculation would be: 40,000 USD - 20,000 USD = 20,000 USD.

The output of this calculation will also be compared to 0.5x of the Refresh Equity Grant Dollar Value Median at the Promoted Level. If this calculation yields a higher dollar value than the standard Promotion Equity Grant Formula then this value will be used for the promotional grant value.

## Refresh Grants

As part of the updated [Annual Compensation Review process]({{< ref "compensation-review-cycle#annual-compensation-review" >}}), eligible GitLab team members will be reviewed for a refresh grant once per year. Refresh grants use the formula above to determine the range of equity dollar value a team member may be eligible for in that cycle based on their current role/grade. Refresh grants will vest in accordance with the equity plan agreement between GitLab and the team members.

Note: All equity grants are subject to approval by the Board of Directors and no grants are final until such approval has been obtained. The company reserves the right in its sole discretion to make any adjustments to equity grants including the decision not to make a grant at all.

## Annual Refresh Grant Program Eligibility

Team members may be eligible to participate in the annual refresh grant cycle review if they have completed six months of service with the company. However, participation will be based upon individual team member talent assessments (including if a team member is currently in good standing) and [key talent criteria](/handbook/people-group/talent-assessment#key-talent-criteria). Therefore, not all team members will receive a refresh grant in the annual review cycle. Leaders will have discretion on the size of the refresh grant based on talent assessments and equity budget as allocated to each E-group member's division. All proposed grants will be reviewed by the People team for pay equality. All proposed equity grants are subject to review and approval by the GitLab Board of Directors.

## Option Vesting

Vesting means that you have to remain employed by, or are otherwise a service provider to, GitLab for a certain period of time before you can fully own the stock under your stock option grant. Instead of giving you the right to purchase and own all of the common stock under your stock option on day one, you get to own the stock under your stock option in increments over time. This process is called vesting and different companies offer vesting schedules of different lengths. At GitLab, our standard practice is to issue options with a four year vesting schedule so you would own a quarter of your stock after 12 months, half of your stock after two years, and all of it after 4 years. Vesting happens on a monthly basis after the first year for new hire grants and monthly after grant for refresh grants. A cliff on a new hire grant is the period at the beginning of the vesting period where your equity does not vest monthly, but instead vests at the end of the cliff period. At most companies, including GitLab, this cliff period is generally one year. This means that if you leave your job either voluntarily or involuntarily before you've worked for a whole year, none of your options will be vested. At the end of that year, you'll vest the entire year's worth (12 months) of equity all at once. This helps keep the ownership of GitLab stock to team members who have worked at the company for a meaningful amount of time.

## RSU Vesting & Grant Cadence

RSUs are grants of shares of the Company's common stock, the vesting of which is based on the requisite service requirement. Generally, the Company's RSUs are subject to forfeiture and are expected to vest over two to four years ratably on a combination of bi-annual and quarterly basis. New hire grants vest after 6 months, quarterly thereafter over the 4 years.  Refresh grants vest quarterly over 4 years.

Per our [SAFE framework](/handbook/legal/safe-framework/), we do not add specific dates to the handbook regarding equity. For more information on grant cadence & vesting, please see the following [slide deck](https://docs.google.com/presentation/d/1a3iisaLdoMFdujTyh9K2gYB2eOTi1xC2Ul7ycj7HkSg/edit#slide=id.p).

- RSUs begin vesting on the corresponding grant date.
- RSUs are reviewed for approval quarterly.
- New Hire: 12.5% vest after ~6 months (depending upon grant date - some new hires may wait a bit longer); remaining RSUs vest quarterly thereafter for 3.5 years (four-year total vest).
- Promotion and Refresh Grants do not require a cliff, begin vesting quarterly for four-year vest.

## Exercising Your Options

"Exercising your options" means buying the stock per your option agreement. You pay the exercise price that was set when the options were first granted and you receive stock certificates back. To give team members an opportunity to benefit from any existing tax incentives that may be available (including under the US the Dutch tax laws and tax laws of your country of residence) we have made the stock immediately exercisable. This means you can exercise your right to purchase the unvested shares under your option to start your holding period. However, the Company retains a repurchase right for the unvested shares if your employment or other services ends for any reason. An early exercise of unvested stock may have important tax implications and you should consult your tax advisor before making such a decision.

While the company has the right to repurchase the unvested shares upon your termination of services, the company is not obligated to do so. Accordingly you could lose some or all of the investment you made. Because we are a young company there are lots of risks, so be aware and informed of the risks.

You may exercise and hold your options even outside of an open trading window. If you are a Designated Insider, please email stockadmin@gitlab.com and they will enable you to do so in your E-TRADE account. Team members will have 5 trading days to execute their exercise. Please seek advice from your financial advisor or tax advisor prior processing your exercise.

## E-TRADE: Exercising your Shares in an Open Trading Window

For trading in an open trading window, please find the following instructions for specifics on exercise and trading options.

- [GitLab Stock Plan Non-US](https://drive.google.com/file/d/1pBZsudczsgSv_xxPEJlMc1wA0TumDm97/view)
- [GitLab Stock Plan RSUs & Stock Options](https://drive.google.com/file/d/16Hby-UdCKA-BJDHvZQ9bpbU5cEQlzeUE/view)

## Purchasing GTLB Stock

If you would like to purchase GTLB shares, this must be done through your E*TRADE retail account during an open trading window. We would ask that you send us a message at stockadmin@gitlab.com as we will need to get consent from you to track your GTLB retail shares.

## Questions about your stock plan or retail account

### E-TRADE Securities Customer Service 12 a.m. Monday to 11:59 p.m. Friday ET   Closed holidays  (800-838-0908)

- Activating your account
- Navigating the Stock Plan section of etrade.com
- Finding tax information
- Disbursing cash from and depositing cash to your brokerage account
- Buying and selling securities in your brokerage account

### Option Expiration

If you leave GitLab, you will generally be able to exercise your options that are vested (as of the last day of service).
In addition, if not otherwise expired (through termination of your employment), your stock options expire 10 years after they were issued.

### Exercise Window After Termination

If your employment ends for whatever reason, you have a three month window to exercise your vested options, or lose them. During this window you would have to pay the exercise price and in some cases the tax on the gain in value of your stock options, which could be considerable.

### Equity Administration

Administration of (i.e. RSUs, stock options, ESPP share transactions) and equity grant transactions at GitLab are conducted on the ETrade platform.  Equity Grants are approved by the Board of Directors "or their designee" at regularly scheduled quarterly board meetings, which contain  information relevant to the grant including the number of shares, exercise price, vesting period and other key terms. This information is then recorded in your account at ETrade. New participant grants, will need to accepted the Grant Agreements in ETrade document under "Grant Acceptance" under the Plan Elections section in your E-TRADE account. Please see [GitLab Stock Plan RSUs & Stock Options](https://drive.google.com/file/d/16Hby-UdCKA-BJDHvZQ9bpbU5cEQlzeUE/view).

With the implementation of WorkDay, interfaces to ETrade provide for electronic files for status updates to participants, such as terminations and change in Cost Centers.

### Taxes

Tax law is complex and you should consult a tax attorney or other tax advisor who is familiar with startup stock options before making any decisions. Please go to the [tax team's stock options](https://internal.gitlab.com/handbook/tax/stock-options/) page for more information on taxation of stock options.

### US employees with Incentive Stock Options (ISOs)

Taxation from the US perspective is not as straightforward as you might like. You aren't taxed when you exercise your options. Tax is due on the gain or profit you make when you sell the stock. Depending on your holding period, the tax may be treated as ordinary income or capital gain. Moreover, when you hold the options long enough you may be subject to 0% capital gains tax. To outline the five possibilities of the different scenarios that may apply:

1. Exercise your options to purchase shares, and hold.
1. Exercise your options to purchase shares, and sell the shares within the same year.
1. Exercise your options to purchase shares, and sell the shares in less than twelve months, but during the following year.
1. Sell shares at least one year and a day after you exercised the options, but less than two years from the original grant date.
1. Sell shares at least two years from the original grant date.

Please note, however, that any gain upon exercise of an ISO (difference between the exercise price and fair market value at date of exercise), even if you do not sell the shares, may be counted as a "tax preference" towards the Alternative Minimum Tax limit. For instance, under scenario 1 above you have to make an adjustment in your tax return for the Alternative Minimum Tax (AMT) that equals the so-called bargain element. Each scenario has a different tax treatment, so be careful of the tax consequences when you exercise your options. In the long term, holding onto your stock does save taxes, however be aware of the AMT that you will be confronted with. It is strongly advised that you contact a tax advisor to be aware of the US tax consequences.

In addition to the benefits of a longer holding period, the IRS does have an additional benefit for holders of Qualified Small Business Stock (QSBS for short). GitLab meets the criteria for QSBS treatment for options exercised prior to August, 2018, however (again), the Company is not in a position to offer tax or legal advice nor does it make any representation about compliance with the QSBS provisions, so check with your own tax and financial advisors. We found [this article](https://blog.wealthfront.com/qualified-small-business-stock-2016/) helpful  in describing the QSBS program in greater detail.

### US service providers with Non-qualified Statutory Options (NQs)

For non-employees of GitLab that have been granted stock options, their stock options are treated as NQs.

GitLab's stock is actively traded on NASDAQ, the NQ is taxed at exercise. The gain of the exercise (fair market value minus the exercise price) has to be reported by form [1099-MISC](https://www.irs.gov/pub/irs-pdf/f1099msc.pdf) (box 7). Withholding is typically not required, however when the service provider fails to provide a valued tax identification number in form 1099, GitLab has to ensure backup withholding (roughly 25%).

### Netherlands, Germany and Australia

For our team members based in the Netherlands, Germany and Australia, the difference between the exercise price and the fair market value is considered taxable at the date you exercise your stock options. With respect to reporting taxes: the taxable gains are subject to employer tax withholding. The tax payable is therefore deducted from your gross payroll with respect to the exercise of your stock options.

### The United Kingdom

In the United Kingdom there is a small difference in the tax treatment of exercising your stock options as opposed to the other entities; the difference between the fair market value and the exercise price is taxed at the date of exercise.

### Dual-Class Stock

Often companies will create multiple classes of stock, with each class having different voting rights, in order to provide protection to the company's founders, early investors, and early employees, whose long-term vision for the company may not align with that of later stage investors. At the GitLab Board of Directors meeting held on January 31, 2019, the Board approved the creation of such a dual-class structure.

### Effect of Dual-Class Stock

- Class B stockholders retain significant influence over stockholder votes and actions.
- The Influence of long-term Class B stockholders increases as other stockholders from before being public sell or distribute their Class B stock, which converts into Class A common stock upon sale or distribution.

### Dual-Class Voting

Class A Common Stock - 1 vote per share

Class B Common Stock - 10 votes per share

### Creation of Dual-Class Stock

## Being Public

- Class B converts to Class A in sale or distribution unless "permitted transfer" (see below).
- Additional sales of Class A common stock.
- Permitted transfers would be transfers to one or more family members, transfers to a trust for the benefit of the stockholder or in favor of a family member of the stockholder, or transfers   to a general partnership, limited partnership, limited liability corporation, or other entity controlled by the stockholder or a family member of the stockholder.
