---
title: Intermediate Frontend Engineer
---

Frontend Engineers at GitLab work on our product. This includes both the open source version of GitLab, the enterprise editions, and the GitLab.com service as well. They work with peers on teams dedicated to areas of the product. They work together with product managers, designers, and [backend engineers](/job-families/engineering/backend-engineer/) to solve common goals.

## Responsibilities

- Develop features and improvements to the GitLab product in a secure, well-tested, and performant way
- You'll work with Product Management and other stakeholders (Backend, UX, etc.) to iterate on new features within the GitLab product.
- Craft code that meets our internal standards for style, maintainability, and best practices for a high-scale web environment. Maintain and advocate for these standards through code review.
- Consistently ship small features and improvements with minimal guidance and support from other team members. Collaborate with the team on larger projects.
- Help improve the overall experience of our product through improving the quality of the Frontend features both in your [group](/handbook/product/categories/#hierarchy) and features that benefit other groups.
- You'll help identify areas of improvements in the code base, both specific to your [group](/handbook/product/categories/#hierarchy) and outside your group (eg. component library) and help contribute to make it better
- You'll learn, collaborate and teach other Frontend Engineers. Everyone can contribute something new to the team regardless of how long they've been in the industry.
- You'll fix prioritized issues from the issue tracker. These are typically bugs listed in a GitLab issue with an attached severity and priority label.
- You'll contribute to and follow our workflow process, alongside the rest of the Frontend Engineers and the GitLab community as a whole.

## Requirements

- Professional experience with VueJS **or** another modern JavaScript web framework (React, Angular, Ember, etc)
- Experience with writing automated tests (eg. Jest, Karma, Jasmine, Mocha, AVA, tape)
- Experience using Git in a professional/workplace environment
- A solid understanding in core web and browser concepts (eg. how the browser parses and constructs a web page)
- A solid understanding of semantic HTML, CSS, and core JavaScript concepts.
- Proficiency in the English language, both written and verbal, sufficient for success in a remote and largely asynchronous work environment
- Demonstrated capacity to clearly and concisely communicate about complex technical, architectural, and/or organizational problems and propose thorough iterative solutions
- Experience with performance and optimization problems and a demonstrated ability to both diagnose and prevent these problems
- Comfort working in a highly agile, [intensely iterative](/handbook/values/#iteration) software development process
- Demonstrated ability to onboard and integrate with an organization long-term
- Positive and solution-oriented mindset
- Effective communication skills: [Regularly achieve consensus with peers](/handbook/values/#collaboration), and clear status updates
- An inclination towards communication, inclusion, and visibility
- [Self-motivated and self-managing](/handbook/values/#efficiency), with great organizational skills.
- Demonstrated ability to work closely with other parts of the organization
- Share [our values](/handbook/values/), and work in accordance with those values
- Ability to thrive in a fully remote organization
- Ability to use GitLab

## Nice-to-haves

- Working knowledge of Ruby on Rails and Haml
- Experience in a peak performance organization, preferably a tech startup
- Experience with the GitLab product as a user or contributor
- Product company experience
- Experience working with a remote team
- Enterprise software company experience
- Developer platform/tool industry experience
- Experience working with a global or otherwise multicultural team
- Experience contributing to open source software
- Domain knowledge relevant to the product stage in which you are looking to join (eg. someone with CI/CD experience applying for the Verify & Release team)

## Levels

- Intermediate
- [Senior](/job-families/engineering/development/frontend/#senior-frontend-engineer)
- [Staff](/job-families/engineering/development/frontend/#staff-frontend-engineer)

## Job Grade

The Frontend Engineer is a [grade 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

## Performance Indicators

- [Frontend Unit Test Coverage](/handbook/engineering/development/performance-indicators/#frontend-unit-test-coverage)
- [Open MR Review Time (OMRT)](/handbook/engineering/development/performance-indicators/#open-mr-review-time-omrt)
- [Open MR Age (OMA)](/handbook/engineering/development/performance-indicators/#open-mr-age-oma)

## Hiring Process

Candidates for a Frontend Engineering position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process. To learn more about someone who may be conducting the interview, find their job title on our [team page](/handbook/company/team/).

- Selected candidates will be invited to complete a short written assessment.
- Next, candidates will be invited to schedule a 30 minute [screening call](/handbook/hiring/#screening-call) with our Global Recruiters
- Next, candidates will be invited to schedule a 90 minute technical interview with either a Frontend Engineer or a Frontend Engineering Manager
- Next, candidates will be invited to schedule a 45 minute behavioral interview with an Engineering Manager
- Candidates will then be invited to schedule a 60 minute interview with a Director of Engineering
- Successful candidates will subsequently be made an offer.

Additional details about our process can be found on our [hiring page](/handbook/hiring/).
