---
title: "Fullstack Engineers"
description: "Learn more about requirements and responsibilities for Fullstack Engineering roles at GitLab."
---

Fullstack Engineers will work across the backend (Ruby on Rails), and frontend (Vue.js) parts of our application.
Specialties may require experience in different technologies.
Due to the nature of our tech stack, the volume and complexity of work is weighted more strongly towards backend, rather than frontend.

### Job Grade

The Fullstack Engineer is a [grade 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).
The Senior Fullstack Engineer is a [grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).
The Staff Fullstack Engineer is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

## Responsibilities

- Develop features and improvements to the GitLab product in a secure, well-tested, and performant way
- Analyze and interpret highly complex data to arrive at actionable recommendations
- Collaborate with Product Management and other stakeholders within Engineering (e.g. UX) to maintain a high bar for quality in a fast-paced, iterative environment
- Advocate for improvements to product quality, security, and performance
- Solve technical problems of moderate scope and complexity.
- Craft code that meets our internal standards for style, maintainability, and best practices for a high-scale web environment. Maintain and advocate for these standards through code review.
- Represent GitLab and its values in public communication around specific projects and community contributions.
- Confidently ship small features and improvements with minimal guidance and support from other team members. Collaborate with the team on larger projects.
- Participate in Tier 2 or Tier 3 weekday and weekend and occasional night [on-call rotations](/handbook/engineering/development/processes/infra-dev-escalation/process/) to assist troubleshooting product operations, security operations, and urgent engineering issues.
- Senior Fullstack Engineers improve the [engineering projects](/handbook/engineering/projects/) at GitLab as a [project maintainer](/handbook/engineering/workflow/code-review/#maintainer). For more information regarding timelines and exceptions, [see this page](/handbook/engineering/workflow/code-review/#senior-maintainers).
- Staff Fullstack Engineer only - Participate in the [Incident Management on-call rotation](/handbook/engineering/infrastructure/incident-management/#incident-manager-responsibilities) to help ensure the availability goals for GitLab.com are met, by working with reliability engineers and development team members.

## Requirements

- Professional experience with Ruby and Rails
- Professional experience with JavaScript and associated web technologies (CSS, semantic HTML)
- Proficiency in the English language, both written and verbal, sufficient for success in a remote and largely asynchronous work environment
- Demonstrated capacity to clearly and concisely communicate about complex technical, architectural, and/or organizational problems and propose thorough iterative solutions
- Experience with performance and optimization problems and a demonstrated ability to both diagnose and prevent these problems
- Comfort working in a highly agile, [intensely iterative](/handbook/values/#iteration) software development process
- Demonstrated ability to onboard and integrate with an organization long-term
- Positive and solution-oriented mindset
- Effective communication skills: [Regularly achieve consensus with peers](/handbook/values/#collaboration), and clear status updates
- An inclination towards communication, inclusion, and visibility
- Experience owning a project from concept to production, including proposal, discussion, and execution.
- [Self-motivated and self-managing](/handbook/values/#efficiency), with strong organizational skills.
- Demonstrated ability to work closely with other parts of the organization
- Share [our values](/handbook/values/), and work in accordance with those values
- Ability to use GitLab
- Ability to thrive in a fully remote organization

### Nice-to-haves

- Experience working with modern frontend frameworks (eg. React, Vue.js, Angular)
- Experience in a peak performance organization, preferably a tech startup
- Experience with the GitLab product as a user or contributor
- Product company experience
- Experience working with a remote team
- Enterprise software company experience
- Developer platform/tool industry experience
- Experience working with a global or otherwise multicultural team
- Computer science education or equivalent experience
- Passionate about/experienced with open source and developer tools

## Specialties

### Fullstack Engineer (Handbook)

- Extends the responsibilities and requirements of the Senior or Staff level [Fullstack Engineer](/job-families/engineering/development/fullstack/)
- Reports into a team member of the [Strategy and Operations Team](/job-families/chief-executive-officer/strategy-and-operations/), an organization that rolls into the CEO
- Perform enhancements to the look-and-feel of the published handbooks
- Help facilitate the [support process](/handbook/content-websites-responsibility/#support-process-for-content-websites) for [Content Sites](/handbook/content-websites-responsibility/#what-are-the-content-websites) by answering team member questions and triaging/responding to issues
- Coordinate with various stakeholders regarding site content or structure changes, including helping mediate potential - ownership issues encountered when refactoring or splitting up existing shared code/content/infrastructure
- Maintain and improve the CI/CD pipelines, build processes, and review environments
- Improve content-authoring experience and tooling
- Perform and/or coordinate/delegate resolution of any other content sites issues related to infrastructure, code, - architecture, projects, security, CI/CD, builds, deployments, upgrades, performance, scalability, metrics, monitoring, etc
- Support [dogfooding of GitLab features](https://about.gitlab.com/direction/dogfooding/) on [Content Sites](/handbook/content-websites-responsibility/#what-are-the-content-websites) and related infrastructure

### Hiring Process for Handbook Specialty

Candidates for this speciality can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process. To learn more about someone who may be conducting the interview, find their job title on our [team page](/handbook/company/team/).

- Selected candidates will be invited to schedule a 25 minute [screening call](/handbook/hiring/#screening-call) with our Global Recruiters
- Next, candidates will be invited to schedule a 50 minute high-level technical and fit interview with the Hiring Manager on the [Strategy and Operations team](/job-families/chief-executive-officer/strategy-and-operations/)
- Next, candidates will be invited to schedule a 90 minute technical interview with one of our Fullstack Engineers or Engineering Managers
- Next, candidates will be invited to schedule a 25 minute interview with one of our Engineering Managers
- Finally, candidates will be invited to schedule a 50 minute interviews with the Chief of Staff to the CEO

## Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process. To learn more about someone who may be conducting the interview, find their job title on our [team page](/handbook/company/team/).

- Selected candidates will be invited to schedule a 30 minute [screening call](/handbook/hiring/#screening-call) with our Global Recruiters
- Next, candidates will be invited to schedule a 90 minute technical interview with one of our Backend Engineers
- Next, candidates will be invited to schedule a 90 minute technical interview with one of our Frontend Engineers
- Next, candidates will be invited to schedule one or more 45 minute interviews with an Engineering Hiring Manager
- Next, candidates may be invited to schedule a 60 minute behavioral interview with a Senior Manager or Director of Engineering

- Successful candidates will subsequently be made an offer.

Additional details about our process can be found on our [hiring page](/handbook/hiring/).

## Career Ladder

For more details on the engineering career ladders, please review the [engineering career development](/handbook/engineering/careers/#roles) handbook page.
