---
title: "Engineering Management - Quality"
description: "Engineering Managers in the Quality Department are motivated and experienced leaders who grow our test automation efforts across the entire GitLab ecosystem."
---

At GitLab, Quality is everyone's responsibility and the output of the Quality Department is instrumental to GitLab's success.

Engineering Managers in the Quality department are motivated and experienced leaders who grow our test automation efforts across the entire GitLab ecosystem.
They demonstrate a passion for high quality software, strong Engineering principles, and methodical problem solving skills.

They own the delivery of test automation tools and strategy and coordinate across departments and teams to accomplish collaborative goals.

## Manager, Quality Engineering

### Job Grade

The Manager, Quality Engineering is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Responsibilities

- Help define the team's road map and author project plans to deliver against that roadmap.
- Draft team's quarterly OKR and manage the team's priorities.
- Drive improvements to test framework architecture and test coverage.
- Work across engineering to inject testing earlier into the software development process.
- Drive adoption of best practices in code health, testing, testability and maintainability (clean code, test pyramid).
- Track test gaps, quality, and productivity metrics. Work with other engineering teams to improve gaps from this data.
- Recommend improvements into overall best practices, design, testability and quality and productivity.
- Recruit Engineers, grow the team and stay in step with the hiring plan.
- Help engineers grow their skills and experience.
- Hold regular 1:1's with all members of their team.
- Create a sense of psychological safety on their team.
- Excellent written and verbal communication skills.
- Give clear, timely, and actionable feedback.
- Strong sense of ownership, urgency, and drive.

### Requirements

- Technical credibility: Past experience as a Software Engineer in Test (or similar title).
- Experience developing in Ruby or Golang or a proven ability to pick up a new language quickly.
- Experience with UI & API test automation tools, particularly in Ruby stack (e.g. Capybara, Watir, Selenium).
- Experience working with Docker containers, Kubernetes, and/or Cloud providers (e.g. GCP, AWS).
- Experience with Continuous Integration systems (e.g. Jenkins, Travis, GitLab).
- Experience defining high-level test automation strategy based on DevOps industry's best practices.
- Experience driving organizational change with cross-functional stakeholders.
- Demonstrate longevity at, at least, one recent job.
- Ability to be successful managing at a remote-only company.
- Humble, servant leader.
- You share our [values](/handbook/values/), and work in accordance with those values.
- [Leadership at GitLab](/handbook/company/structure/#management-group)
- Ability to use GitLab.

### Nice-to-have Requirements

- Management credibility: Past experience as an engineering manager.
- Experience with non-functional testing like performance, security, and chaos testing.
- Deep Ruby on Rails or Golang experience.
- Be a user of GitLab, or familiar with our company.
- Experience in a peak performance organization.
- Product company experience.
- Startup experience.
- Enterprise software company experience.
- Computer science education or equivalent experience.
- Passionate about open source, developer tools, and shipping high-quality software.
- We value diversity, inclusion, and belonging in leadership.
- Be inquisitive: Ask great questions.

### Interview Process

Candidates for this position can expect the hiring process to follow the order below.
Please keep in mind that candidates can be declined from the position at any stage of the process.
As a result an interview can be canceled at any time even if the interviews are very close (e.g. a few hours apart).

- A short questionnaire from our Recruiting team
- 30 minute [Screening call](/handbook/hiring/#screening-call) with a recruiter
- 1 hour interview with the hiring manager
- 1 hour technical Interview with a Software Engineer in Test
- 1 hour direct report interview with two Software Engineers in Test
- 1 hour peer interview with a Manager, Quality Engineering
- 45 minute interview with the skip manager (hiring manager's manager)

## Senior Manager, Quality Engineering

The Senior Manager, Quality Engineering role extends the [Manager, Quality Engineering](#manager-quality-engineering) role.

### Job Grade

The Senior Manager, Quality Engineering is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Responsibilities

- Manage up to 4 Quality Engineering teams.
- Conduct managerial interviews for candidates, and train engineering managers to do said interviews.
- Generate and implement process improvements, especially cross-team processes.
- Hold regular 1:1s with team managers and skip-level 1:1s with all Software Engineers in Test (SETs).
- Collaboratively build and execute on the current and upcoming fiscal years' QE Direction.
- Break down long-term QE Direction into iterative quarterly OKR goals and drive success.
- Regularly review PIs, recommend process changes or business initiatives to improve lagging PIs, and suggest new PIs when needed for department alignment.
- Ensure alignment with cross-functional peers by developing relationships with quad counterparts in Development (section Director+), Product (section Director+), and Design (section/stage Manager+).
- Drive success of cross-functional projects by defining quality needs, coordinating SET involvement and timely execution, and reporting results to stakeholders.
- Drive success and autonomy of the team through mentorship and coaching.
- Improve company awareness of QE initiatives through multi-modal communication and education.

### Requirements

- Management credibility: Past experience as a (Senior) Engineering Manager.
- Ability to understand, communicate, and improve the quality of multiple teams.
- Proven track record of successful career development of direct reports.
- Ability to influence quality across an organization by converting peers outside of QE into champions of quality.
- You share our [values](/handbook/values/), and work in accordance with those values.

### Nice-to-have Requirements

- Experience managing managers.

### Interview Process

Candidates for this position can expect the hiring process to follow the order below.
Please keep in mind that candidates can be declined from the position at any stage of the process.
As a result an interview can be canceled at any time even if the interviews are very close (e.g. a few hours apart).

- A short questionnaire from our Recruiting team
- 30 minute [Screening call](/handbook/hiring/#screening-call) with a recruiter
- 1 hour interview with the hiring manager
- 1 hour technical Interview with a Software Engineer in Test
- 1 hour direct report interview with two Software Engineers in Test
- 1 hour peer interview with a Manager, Quality Engineering
- 45 minute interview with the VP of Quality

## Director, Quality Engineering

The Director, Quality Engineering role extends the [Manager, Quality Engineering](#manager-quality-engineering) role.

### Job Grade

The Director, Quality Engineering is a [grade 10](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Responsibilities

- Define and own all of GitLab's Quality Engineering efforts.
- Define the Quality Engineering sub-department's fiscal year Direction (in handbook).
- Define plans and quarterly OKRs to execute against key objectives and roadmap. Align efforts strategically across R&D.
- Drive improvements to KPIs and PIs that is in Quality Engineering's line-of-work and job-family.
- Hire world class Engineering Managers and Software Engineers in Test (SETs) for the Quality Engineering sub-department.
- Publish and socialize the progress of the Quality Engineering sub-department.
- Drive retrospective and improvements that impacts Quality Engineering.
- Manage the sub-department's priorities and define prioritization guidelines for teams in Quality Engineering.
- Excellent written and verbal communication skills. Able to convey bottom-line messages to executives at C & VP level.
- Hold regular skip-level 1:1's with all Software Engineer in Tests (SETs)
- Help the teams in Quality Engineering grow their skills and experience, ensure that they are happy and productive.
- Interface with GitLab customers to address Functional and Performance test gaps.
- Research and advice team on new technology and tools in the Quality Engineering space.
- Occasionally contributes to the company blog.
- Occasionally pepresent the company publicly at conferences.

### Requirements

- This position does not require extensive Ruby development experience but the candidate should be very familiar with
industry standard libraries (test tooling, orchestration, performance, and etc) and able to provide feedback on these topics.
- Experience leading Quality focused SLA driven metrics across the Engineering organization (time to resolve bugs, time to merge code, and etc).
- Experience presenting at conferences and meet-ups in the Quality Engineering space.
- Proven track record of shipping multiple iterations of an Enterprise Product.
- You share our [values](/handbook/values/), and work in accordance with those values.

## VP of Quality

The VP of Quality role extends the [Director, Quality Engineering](#director-quality-engineering) role.

### Job Grade

The VP of Quality is a [grade 12](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Responsibilities

- Define and own all of GitLab's Quality Engineering, Engineering Productivity, Engineering Analytics, and Engineering Open Source efforts.
- Drive the Quality Department's roadmap and quarterly OKRs.
- Set an ambitious vision for the department, product, and company.
- Manage the department's budget.
- Hire world class leaders for the Quality department.
- Ensure that the department recruiting efforts stay in step with the product roadmap and company hiring plan
- Track, publish and socialize the progress of the department.
- Drive improvements and process that impacts Quality.
- Manage the department's priorities, set guidelines for Quality sub-departments and teams and align them strategically across all of Engineering.
- Work across the company to define and implement mechanisms to bake in Quality and testing earlier in the software development process.
- Work across the company to improve the efficiency and productivity of community contributions.
- Work across Engineering to improve the Division's Data Analytics capabilities.
- Excellent written and verbal communication skills. Able to convey bottom-line messages to executives at C & VP level.
- Hold regular skip-level 1:1's with all members of their team.
- Help the teams in the Quality Department grow their skills and experience, ensure that they are happy and productive.
- Interface with GitLab customers to address Quality and Performance gaps.
- Research and advice team on new technology and tools in the Quality space.
- Represent Engineering open-source software efforts and community out-reach.
- Represent the company publicly at conferences.

### Requirements

- This position does not require extensive Ruby development experience but the candidate should be very familiar with
industry standard libraries (test tooling, orchestration, performance, and etc) and able to provide feedback on these topics.
- Experience driving the adoption of the DevOps across the Engineering organization (test pyramid, shifting left, and etc).
- Experience leading Quality focused SLA driven metrics across the Engineering organization (time to resolve bugs, time to merge code, and etc).
- Experience presenting at conferences and meet-ups in the Quality Engineering space.
- Proven track record of shipping multiple iterations of an Enterprise Product.
- You share our [values](/handbook/values/), and work in accordance with those values.

## Performance Indicators

Quality Engineering Management has the following job-family performance indicators.

- [Hiring actual vs plan](/handbook/engineering/infrastructure/performance-indicators/#hiring-actual-vs-plan)
- [Diversity](/handbook/engineering/infrastructure/performance-indicators/#diversity)
- [Handbook update frequency](/handbook/engineering/infrastructure/performance-indicators/#handbook-update-frequency)
- [Team member retention](/handbook/engineering/infrastructure/performance-indicators/#team-member-retention)

## Career Ladder

For more details on the engineering career ladders, please review the [engineering career development](/handbook/engineering/careers/#roles) handbook page.
