---
title: "Engineering Management - Infrastructure"
---

## Manager, Infrastructure

The Manager, Infrastructure has a primary focus on hiring and building a world-class team, and putting them in the optimal position to succeed.
They need to be familiar with GitLab's underlying technologies and processes to be able to support their teams growth, as well as be the final conclusive vote in cases where the team is blocked on a path forward. They must also efficiently coordinate across departments to accomplish collaborative goals. More on [Leadership at GitLab in our handbook](/handbook/leadership/#management-group).

### Job Grade

The Manager, Infrastructure is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Responsibilities

- Hire an incredible team that lives our [values](/handbook/values/)
- Maintain an environment where Team Members can thrive and the team produces [Results](/handbook/values/#results)
- Hold regular 1:1's with team members
- Manage agile projects
- Work across sections within engineering
- Improve the quality, security and performance of the product
- Work on small changes outside of the critical path
- Participate in either the [Release Manager rotation](https://gitlab.com/gitlab-org/release/docs/-/tree/master/release_manager#responsibilities) **OR** the [Incident Management on-call rotation](/handbook/engineering/infrastructure/incident-management/#incident-manager-responsibilities) to help ensure that the availability goals for GitLab.com are met.

### Requirements

- Relevant experience managing software engineering teams
- Excellent technical background
- Demonstrated teamwork in a peak performance organization
- Experience running a consumer scale platform
- Product company experience
- Enterprise software company experience or startup experience
- Computer science education or equivalent experience
- Exquisite communication skills

**Nice-to-haves**

- Ability to use GitLab
- Online community participation
- Remote work experience
- Startup experience
- Passion towards and/or significant open source contributions

### Performance Indicators

The Manager, Infrastructure contributes to the success of [Infrastructure Performance Indicators](/handbook/engineering/infrastructure/performance-indicators).

## Specialties

### Manager, Infrastructure (Delivery)

The Manager, Infrastructure (Delivery) manages the engineering team responsible for tasks relating to release management of GitLab releases as well as continuous delivery/deployment on GitLab.com.

The Manager is responsible for ensuring, and evolving the team mandate described in the [team handbook](/handbook/engineering/infrastructure/team/delivery/), and leading the team that consists of [Site Reliability Engineers](/job-families/engineering/infrastructure/site-reliability-engineer/) and
[Backend Engineers](/job-families/engineering/backend-engineer/).

In addition to the same requirements, responsibilities, and performance indicators defined above for the Manager, Infrastructure, Delivery specialty requires:

- Guiding self-managed release and GitLab.com continuous deployment processes
- Owning the [Mean Time to Production](/handbook/engineering/infrastructure/performance-indicators/#mean-time-to-production-mttp)

### Manager, Infrastructure (Production Engineering)

The Manager, Infrastructure (Production Engineering) leads an engineering team composed of [SREs](/job-families/engineering/infrastructure/site-reliability-engineer/), primarily focused on the operational reliability and core infrastructure services of GitLab SaaS offerings.

In addition to the same requirements, responsibilities, and performance indicators defined above for the Manager, Infrastructure, the Production Engineering specialty requires:

- Ensuring Incident Response, Change Management, and Disaster Recovery
- Experience and general knowledge of networking and cloud infrastructure

### Manager, Infrastructure (Scalability)

The Manager, Infrastructure (Scalability) leads the engineering team responsible for GitLab and GitLab.com at scale, working on the highest priority scalability items in the application in close coordination with all teams in Engineering, and providing feedback to other Engineering teams so they can become better at scalability as well.

The Manager is responsible for ensuring, and evolving the team mandate described in the [team handbook](/handbook/engineering/infrastructure/team/scalability/), and leading the team that consists of [Site Reliability Engineers](/job-families/engineering/infrastructure/site-reliability-engineer/) and [Backend Engineers](/job-families/engineering/backend-engineer/).

In addition to the same requirements, responsibilities, and performance indicators defined above for the Manager, Infrastructure, Scalability specialty requires:

- Driving scalability initiatives for GitLab and GitLab.com, and coordinate with the Development Department through the [Availability and Scalability Board](https://gitlab.com/groups/gitlab-org/-/boards/1193197?&label_name[]=gitlab.com&label_name[]=infradev)
- Improving the scalability of the product

### Manager, Infrastructure (Environment Automation)

The Manager, Infrastructure (Environment Automation) directly manages the engineering team responsible for tasks relating to GitLab Dedicated environment provisioning, and configuration. The team consists of [Site Reliability Engineers](/job-families/engineering/infrastructure/site-reliability-engineer/) and [Backend Engineers](/job-families/engineering/backend-engineer/).

In addition to the same requirements, responsibilities, and performance indicators defined above for the Manager, Infrastructure, Environment Automation specialty requires:

- Driving efforts around, and ensuring efficiency around GitLab production environments automation

### Manager, Infrastructure (Switchboard)

The Manager, Infrastructure (Switchboard) leads [a Fullstack team](/handbook/engineering/starting-new-teams/#fullstack-teams) responsible for the GitLab Dedicated customer-facing control panel referred to as "Switchboard".

The team consists of [Backend Engineers](/job-families/engineering/backend-engineer/) and [Frontend Engineers](/job-families/engineering/development/frontend/).

In addition to the same requirements, responsibilities, and performance indicators defined above for the Manager, Infrastructure, the Switchboard specialty requires:

- Experience in managing a combined team of engineers that have a focus on backend and frontend interfaces
- Experience in running a customer-facing application
- Experience in collaborating with Design and Product teams on wireframes for the customer-facing control panel

### Manager, Engineering (US Public Sector Services)

The Manager, Infrastructure (US Public Sector Services) directly manages the engineering team responsible for tasks relating to provisioning, and configuring GitLab environments for US public sector customers in accordance with their compliance and security requirements. Team consists of [Site Reliability Engineers](/job-families/engineering/infrastructure/site-reliability-engineer/) and [Backend Engineers](/job-families/engineering/backend-engineer/).

In addition to the same requirements, responsibilities, and performance indicators defined above for the Manager, Infrastructure, US Public Sector Services specialty requires:

- Driving efforts around, and ensuring efficiency around GitLab production environments automation
- Developing, implementing, and assuring compliance with engineering processes that enable compliance with US federal standards
- Familiarity with operating SaaS services which adhere to compliance requirements like SOC2 and FedRAMP
- Being a US Citizen, living and working in the United States, willing and able to achieve US federal security clearance (minimum Public Trust Position)

### Manager, Engineering (Cloud Efficiency Engineering)

The Engineering Manager, Infrastructure Cloud Efficiency Engineering leads programs and contributes to tools which directly increase the efficient use of cloud provider services. The primary focus for this leader is establishing tools and practices which result in improved spend efficiency. Additionally, this role will also engage to ensure we continually improve our partnership with primary Cloud providers through product engagement, training, and other collaborative efforts. This leader engages with our cloud providers to ensure that we are getting the most value out of their services.

In addition to the same requirements, responsibilities, and performance indicators defined above, this specialty requires:

- Specific knowledge and experience about AWS and GCP cost structures, methods, and discounting tools.
- Experience operating a program of activities which lead to improved cloud unit cost economics.
- Experience creating effective reporting for key counterparts in finance organizations.
- Effective third-party vendor communication and coordination skills along with experience driving initiatives among multiple providers.

This role collaborates most frequently with the SREs on their team as well as peer Engineering Managers in Infrastructure. Stable Counterparts for this Cloud Efficiency Engineering role include Finance Planning & Analysis, Product Managers, Development Engineering Managers, and the entire Cloud Service Provider team.

### Senior Engineering Manager, Infrastructure (Platform)

The Senior Engineering Manager, Platform manages multiple teams within the Infrastructure Platform Section specialty, who work on GitLab.com and contribute to our on-premise product.
They are capable of managing multiple teams within a specialty, and their projects at the same time. They are expert recruiters of both engineers and managers. They also grow the existing talent on their teams. This is an influential role and models the behaviors we want to see in our teams and holds others accountable when necessary. They create the collaborative and productive environment in which managers, reliability, backend and frontend engineers do their work and succeed.

#### Senior Engineering Manager, Infrastructure (Platform) Job Grade

The Senior Engineering Manager, Infrastructure is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Responsibilities

- Manage the Delivery and Scalability Infrastructure teams
- Conduct managerial interviews for candidates, and train engineering managers to do said interviews
- Generate and implement process improvements, especially cross-team processes
- Hold regular [1:1s](/handbook/leadership/1-1/) with team managers and skip-level 1:1s with all members of their team
- Management mentorship
- Participate in either the [Release Manager rotation](https://gitlab.com/gitlab-org/release/docs/-/tree/master/release_manager#responsibilities) **OR** the [Incident Management on-call rotation](/handbook/engineering/infrastructure/incident-management/#incident-manager-responsibilities) to help ensure that the availability goals for GitLab.com are met.

#### Senior Engineering Manager, Delivery and Scalability Requirements

- Technical credibility: Past experience as a product engineer and managing teams thereof
- Management credibility: Past experience (3 to 5 years) as an engineering manager
- Ability to understand, communicate and improve the quality of multiple teams
- Demonstrate longevity at, at least, one recent job
- Ability to be successful managing at a remote-only company
- Value and exhibit servant-leadership behaviors

#### Nice-to-have Requirements

- Be a user of GitLab, or familiar with our company
- Prior Developer Platform or Tool industry experience
- Prior product company experience
- Prior high-growth startup experience
- Experience working on systems at massive (i.e. consumer) scale
- Deep open source experience
- Experience working with global teams
- We value [diversity, inclusion and belonging](/handbook/company/culture/inclusion/) for all team members
- Be inquisitive: Ask great question
- Hire and manage multiple teams that live our [values](/handbook/values/)
- Maintain an environment where Team Members can thrive and the team produces [Results](/handbook/values/#results)

### Director, Infrastructure (Reliability)

The Director, Infrastructure (Reliability) manages the Engineering Reliability teams within the Infrastructure Department. These teams work on GitLab.com and also contribute to our core product. They are capable of managing multiple teams and guiding a portfolio of projects to successful outcomes. They are expert recruiters of Database Reliability Engineers, Site Reliability Engineers and Engineering Managers. They understand how to assess team capabilities and grow the existing talent on their teams. They possess a vision for successful reliability engineering and are advocates for supporting practices and technology. This role is a senior influencer who models the behaviors we want to see in our teams and contributes to great results.

#### Director, Infrastructure (Reliability) Job Grade

The Director, Infrastructure is a [grade 10](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Director, Infrastructure (Reliability) Responsibilities

- Lead hiring and management success across multiple Infrastructure Reliability Engineering teams
- Measure and improve productivity of the team while supporting a great Team Member experience and belonging
- Drive quarterly OKRs
- Collaborate across departments within engineering
- Own the overall reliability of GitLab.com
- Own the process for incident response and management
- Guide the process for team workflow and project management
- Ensure team process and capability to stay ahead of system capacity demands
- Support improvements in infrastructure spend efficiency
- Communicate effectively across all company departments and roles
- Implement Site Reliability process, tools, and knowledge consistent with a clear vision for driving reliability at GitLab.

#### Director, Infrastructure (Reliability) Requirements

- Relevant experience managing multiple operational reliability and/or engineering teams
- Excellent recruiter capable of attracting top talent
- Experience with consumer-level scale systems and Software as a Service (SaaS) product delivery
- Passionate about open source and developer tools
- Experience in a results-oriented organization
- Enterprise software company experience
- Approach challenges with a growth mindset

#### Nice-to-haves

- Candidates with diverse experience and backgrounds
- Prior remote work experience
- Significant open source contributions
- Experience with global teams

### Senior Director, Infrastructure

The Senior Director, Infrastructure leads one or more compartments within Infrastructure. They are experienced with operating large and growing organizations through change and building effective teams of leaders to deliver on higher level company results. They are effective in achieving long-term results by establishing clear vision and appropriate performance indicators. Those in a Senior Director, Infrastructure role will identify iterations of organizational structure which support GitLab growth targets and optimal evolution in our DevOps effectiveness. This role is a senior influencer who models the behaviors we want to see in our teams and contributes to great results.

#### Senior Director, Infrastructure Job Grade

The Senior Director, Infrastructure is a [grade 11](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Senior Director, Infrastructure Responsibilities

- Establish and lead the direction for core SaaS and Infrastructure related cross-company initiatives such as Reliability Engineering practices, the architecture of platform services, or programs such as Incident Management
- Lead the evolution of the individual Infrastructure compartment direction
- Coordination with their leadership team on effective changes in team structure to meet new needs and accomodate overall growth
- Recruit and hire other effective leaders to take on key roles within Infrastructure
- Own the delivery of results for some Infrastructure department-level Performance Indicators
- Coordinate the creation, and lead the execution of Key Result efforts within their teams
- Collaborate across Engineering and Product to achieve quarterly project objectives and other longer-term initiatives
- Own the responsibility and results delivery for all DRI assignments within the scope of their leadership team

#### Senior Director, Infrastructure Requirements

- Experience organizing, growing, and evolving an organization to meet the changing requirements of growth and/or customer need
- Experience leading through multiple levels of management and in global organizations
- Excellent recruiter capable of attracting top talent
- Experience with consumer-level scale systems and Software as a Service (SaaS) product delivery
- Experience fostering a results-oriented organization
- Enterprise software company experience
- Approach challenges with a growth mindset

#### Nice-to-haves

- Prior remote work experience
- Significant open source contributions

### VP of Infrastructure

The VP of Infrastructure manages multiple teams that work on GitLab.com and contribute to our on-premise product. They see their teams as their products. They are capable of managing multiple teams and projects at the same time. They are expert recruiters of DBREs, SREs, Backend and Frontend Engineers, and managers. They can also grow the existing talent on their teams. Like all GitLab Engineering Directors, this role is a senior influencer that models the behaviors we want to see in our teams and holds others accountable when necessary. And they create the collaborative and productive environment in which SREs and SRE managers do their work and succeed.

#### VP of Infrastructure Job Grade

The VP of Infrastructure is a [grade 12](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### VP of Infrastructure Responsibilities

- Hire and manage multiple infrastructure teams that live our [values](/handbook/values/)
- Maintain an environment where Team Members can thrive and the team produces [Results](/handbook/values/#results)
- Define the agile development and continuous delivery process
- Drive quarterly OKRs
- Work across departments within engineering
- Write public blog posts and speak at conferences
- Own the availability, reliability, and performance of GitLab.com
- Drive process for incident management
- Drive process for project management with transparent status and high productivity
- Plan ahead of required system capacity
- Drive infrastructure cost efficiency
- Communicate clearly and concisely with peers within Engineering and executives
- Create easy-to-understand SLOs and transparent dashboards

#### VP of Infrastructure Requirements

- 10 years managing multiple operations teams
- Excellent recruiter capable of attracting top talent
- Experience with consumer-level scale systems
- Passionate about open source and developer tools
- Experience in a peak performance organization
- Enterprise software company experience
- Product company experience
- Startup experience

**Nice-to-haves**

- Candidates with diverse backgrounds
- Prior remote work experience
- Significant open source contributions
- Experience with global teams

#### VP of Infrastructure Performance Indicators

The VP Infrastructure, is responsible for ensuring [Infrastructure Performance Indicators](/handbook/engineering/infrastructure/performance-indicators).

## Career Ladder

For more details on the engineering career ladders, please review the [engineering career development](/handbook/engineering/careers/#roles) handbook page.
