---
title: "Engineering Analyst"
---

Engineering Analysts at GitLab build and improve on the data capabilities needed to support a highly productive Engineering Division.
They equip Engineering leaders with metric intelligence and actionable performance indicators.
They work closely with GitLab's Data team to enable new data capabilities that drives our analysis and visualizations.

## Responsibilities

- Create data queries that provide actionable data-driven insights.
- Create actionable, concise, and presentable data visualizations
- Ensure accuracy of Performance Indicators in the Engineering Division and all it's departments.
- Continuously improve the accuracy and efficiency of Engineering Departments' performance indicators.

## Requirements

- [Self-motivated and self-managing](/handbook/values/#efficiency), with strong organizational skills.
- Share our [values](/handbook/values/), and work in accordance with those values.
- A track record of using quantitative analysis to generate insights, and drive better organizational decision making.
- Clear and concise communication, able to convey complex business logic, and analytical recommendations to stakeholders.
- Deep understanding of SQL and track record of hands-on SQL experience.
- Experience with Data Visualization Tools (E.g. Sisense, Looker, Tableau)
- Experience with performance and optimization problems at scale, demonstrate ability to diagnose and prevent these problems.
- Excellent analytical skills.
- Good understanding of data warehouses (e.g. Snowflake)
- Good understanding of data ingestion methodologies (e.g. ETL, ELT)
- Confidentiality in handling sensitive organizational information.
- Proficiency in the English language, with excellent written and oral communication skills.
- Working knowledge of Git and source control.
- Working knowledge of basic Ruby scripting.
- Working knowledge of HTML.
- Able to thrive in a fully remote organization.
- Able to use GitLab.

### Nice to haves

- Experience in a peak performance organization
- Enterprise software company experience.
- Developer platform/tool industry experience.

## Levels

### Engineering Analyst

#### Engineering Analyst Job Grade

The Engineering Analyst is a [grade 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Engineering Analyst Responsibilities

- Develop analytical models to provide data-driven guidance on business decisions.
- Develop utilization/forecasting models to predict future outcome of business or financial objective.
- Create visualizations that conveys Engineering metrics that are concise and easy to comprehend.
- Create SQL/Sisense code that meets our guidelines and coding standards.
- Explain trends from data sources and identify opportunities for improvements in the assigned Engineering Department.
- Understand business processes and policies of assigned Engineering Department.
- Manage, analyze and report on assigned Engineering Department's Performance Indicators.
- Attend and ensure key-review readiness of assigned Engineering Department.
- Interface with leaders to provide timely, accurate and relevant data.
- Document Engineering Analytics team process in the handbook.

### Senior Engineering Analyst

#### Senior Engineering Analyst Job Grade

The Senior Engineering Analyst is a [grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Senior Engineering Analyst Responsibilities

The Senior Engineering Analyst role extends the [Engineering Analyst](#engineering-analyst) role.

- Deliver data analytics and visualization with minimal guidance and support.
- Contribute to our SQL/Sisense guidelines and coding standards, make recommendations that improve our best practices and efficiency.
- Improve our handbook performance indicator pages content and guidelines.
- Contribute to data quality improvement efforts; review, optimize, and refactor data models for efficiency.
- Deep understanding of how data is created and transformed into Sisense visualization at GitLab.
- Understand data trends across Engineering data sources.
- Understand business processes and policies to improve Engineering processes and workflow.
- Document Engineering Division's data-lifecycle and metrics framework in the handbook.
- An expert in data domain of assigned Engineering Department.
- Attend and ensure key-review readiness of assigned Engineering Department.
- Occasionally represent Engineering Analytics in broad company communication and announcements.
- Occasionally contribute to the company's strategic Data direction in collaboration with the [Data team](/handbook/enterprise-data/#data-job-families).
- Influence the overall objectives and long-range goals of the Engineering Analytics team.

### Staff Engineering Analyst

#### Staff Engineering Analyst Job Grade

The Staff Engineering Analyst is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Staff Engineering Analyst Responsibilities

The Staff Engineering Analyst role extends the [Senior Engineering Analyst](#senior-engineering-analyst) role.

- Coach and mentor other team members so they can confidently deliver data analytics and visualization with minimal guidance.
- Enforce and improve our SQL/Sisense guidelines and coding standards, review and make strategic improvements to achieve organizational objective.
- Advocate for and deliver improvements to data quality, security, model refactoring and query performance.
- Drive our handbook performance indicator pages' efficiency, guidelines and maintenance efforts.
- Deep understanding of how data flows within GitLab and identify new data sources needed to unblock business objectives.
- Enforce and champion handbook-first documentation.
- Ensure broad organizational awareness of the Engineering Division's data-lifecycle and metrics framework.
- An expert in data domains of two or more Engineering Departments.
- Attend and ensure key-review readiness of assigned Engineering Departments.
- Represent Engineering Analytics in broad company communication and announcements.
- Contribute to the company's strategic Data direction in collaboration with the Data team.
- Drive innovation across GitLab and research new data analytics methodologies with minimal guidance and support from other team members.
- Create training guides, blog posts, templates, and recorded training sessions to help Team Members understand how to accurately view data and create insight.
- Maintain awareness and guide other Team Members about the implications of data-driven analysis in relation to legal and security constraints.
- Influence the overall objectives and long-range goals of the Engineering Analytics team.

## Specialties

### Development

- Merge Request Rate (known as Throughput outside of GitLab)
- Review Efficiency

### Infrastructure

- Deep understanding of Infrastructure resource utilization, finance & forecast models.
- Deep understanding of the infrastructure vendor landscape and their cost models.
  - Compute queries
  - Data storage
  - Capacity planning
- Business & finance intuition, interface and guide non-engineering partners on cost & contract management:
  - Assist Legal in navigating vendor contracts.
  - Assist Finance with contract management, provide clarity in decisions via modeling on present and future cost visibility.
  - Understand Sales pipeline and it's effect on GitLab.com Infrastructure.
- Deep understanding of Infrastructure data, common data framework, business processes and policies.
- Support Infrastructure with cost efficiency in service of GitLab.com and the rest of the company.

### Quality

- Merge Request Rate (known as Throughput outside of GitLab)
- Review Efficiency
- Community Contributions

### UX

- SUS Scores
- Deferred UX

### Security

- Security Vulnerabilities
- Compliance levels

### Support

- Cost of goods sold
- CapEx

## Performance Indicators

- Engineering PI Content MR Rate
- Handbook MR Rate
- Open Engineering Analytics Issue Age
- Infrastructure Specialty:
  - [Infrastructure Cost per GitLab.com Monthly Active Users](/handbook/engineering/infrastructure/performance-indicators/#infrastructure-cost-per-gitlab-com-monthly-active-users)
  - [Infrastructure cost vs plan](/handbook/engineering/infrastructure/performance-indicators/#infrastructure-cost-vs-plan)

## Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process. To learn more about someone who may be conducting the interview, find their job title on our [team page](/handbook/company/team/).

- Selected candidates will be invited to fill out a short questionnaire.
- Next, candidates will be invited to schedule a [screening call](/handbook/hiring/#screening-call) with our Global Recruiters
- Next, candidates will be invited to schedule a first interview with the hiring manager.
- Next, candidates will be invited to schedule a second technical interview with an Engineering Analyst.
- Next, candidates will be invited to schedule a third interview with am additional member of the Engineering Analytics Team.
- Next, candidates will be invited to schedule a forth interview with an additional members of the GitLab Data Team.
- Finally, candidates may be asked to interview with the VP of Quality.

Additional details about our process can be found on our [hiring page](/handbook/hiring/).

## Career Ladder

For more details on the engineering career ladders, please review the [engineering career development](/handbook/engineering/careers/#roles) handbook page.
