---
title: "Support Management"
description: "Support Engineering Management at GitLab isn't your typical management opportunity because of our approach to the function."
canonical_path: "/job-families/engineering/support-management/"
---

## A brief overview

GitLab is building an open source, single application for the entire software development lifecycle—from project planning and source code management to CI/CD, monitoring, and security.

Right now, we're in a period of growth, we're quickly increasing the size of the [Support team](/handbook/support/), in step with the number of GitLab employees.

At GitLab, we live and breathe open source principles. This means our entire [handbook](/handbook/) is online, and with a few clicks, you can find the details of [future releases](https://about.gitlab.com/direction/#future-releases), check out our [past releases](https://about.gitlab.com/releases/), and see some of the [customers you'd be supporting while working here](https://about.gitlab.com/customers/).

Support Engineering Management at GitLab isn't your typical management opportunity because of our approach to the function. Support is embedded within the Engineering department and truly operates in an environment where Support and Engineering meet. Your team will be interacting with customers daily as they encounter the difficult edge cases of running GitLab in complex environments.

In the space of a day, our engineers might be doing behind the scenes work of a Linux administrator troubleshooting performance problems by using strace on a particular process, interacting with the Product team to ensure that steps in a bug report are reproducible, or with the Engineering team itself diving deep into our codebase and putting together a merge request to actually fix a customer issue. That's not all though - they'd equally be invited to improve our documentation, help build out more efficient support processes in our [issue tracker](https://gitlab.com/gitlab-com/support/support-team-meta/issues/) and dive into the cutting edge technologies that will define how we will do work tomorrow.

At GitLab, we hold that [managers should be technically competent and experienced in the subject matter](/handbook/leadership/#no-matrix-organization). So, it would be your job to use your technical expertise to support all of those moving pieces - including stepping into the shoes of a Support Engineer when needs be.

We want to live in a world where [everyone can contribute](/handbook/values/#mission), and as a member of the support team there are no barriers to using your skills to improve the experience of our users, our customers and importantly the folks you'd be supporting as a manager.

## Support Management Roles

### Manager, Support Engineering

#### Job Grade

The Manager, Support Engineering is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### What you can expect in a Manager, Support Engineering role at GitLab

As a Manager, Support Engineering, you will be:

- helping hire a team of Support Engineers who are focused on delivering world class technical support.
- helping Support Engineers develop and nurture their skills and experience.
- driving team members to be "managers of one".
- building processes that enable team members to collaborate and execute.
- holding regular 1:1s with all members on your team.
- creating a sense of psychological safety on your team.
- engaging with our customers to triage their issues via tickets and video conferencing.
- creating, updating, or reviewing documentation changes based on customer interactions.
- fostering an environment for the engineers on your team to maintain good ticket performance and satisfaction.
- training Support Engineers to screen applicants and conduct technical interviews.
- improving the customer experience in measurable and repeatable ways.
- participating in escalation on-call rotation (limited to regional working hours during the week and weekend).

For more details, see our [Support Manager Responsibilities page](/handbook/support/managers/manager-responsibilities/).

#### Projects you might work on

Support Managers also work on things that will make your (and the lives of your coworkers) easier. Current and past Support team members have:

- Created a tool to [quickly analyze strace output](https://gitlab.com/gitlab-com/support/toolbox/strace-parser)
- Built and maintained tooling to handle our call scheduling
- Scripted a [solution to capture the state of a customer's server](https://gitlab.com/gitlab-com/support/toolbox/gitlabsos) for easier troubleshooting
- Added functionality to [ChatOps](https://docs.gitlab.com/ee/ci/chatops/) to make it easier to identify user accounts on GitLab.com
- Written a [Chrome Extension to route downloads from Zendesk tickets into organized folders](https://gitlab.com/gitlab-com/support/toolbox/zd-dl-router)
- … and more!

#### You should apply if

- You have an affinity for (and experience with) providing customer support, and making customers happy.
- You have more than 2 years experience leading Support Engineering teams.
- You've got advanced analytical and problem solving skills.
- You've got a keen eye for forward thinking solutions (Kubernetes, Containers, etc.).
- You enjoy solving many small problems per day.
- You've got 5+ years of support experience.
- Within the last 5 years, you have held a role at one company for at least 2 years.
- You understand DevOps processes and you appreciate the value technologies like Serverless and Kubernetes bring to the software deployment and development process.
- You're able to communicate complex technical topics to customers and coworkers of varying technical skill level.
- You've got extensive experience building and scaling teams.
- You demonstrate excellent spoken and written English.
- You're experienced in creating and implementing new processes and procedures.
- You're experienced in writing support content.
- You've got experience leading remote, distributed teams across geographies with a keen focus on employee development and the achievement of desired results.
- You've got extensive experience in leading teams to take ownership and work to manage the entire issue lifecycle, from customer, to development team, to resolution.
- You're able to perform complex Linux System Administration tasks.
- You've got experience with web application development using an MVC framework e.g. Rails (Ruby), Django (Python), Laravel (PHP).
- You've got experience with Git and CI/CD.
- Our [values](/handbook/values/) of collaboration, results, efficiency, diversity, iteration, and transparency resonate with you.

### Senior Manager, Support Engineering

Senior Support Managers manage multiple teams and Staff-level individual contributors (ICs) within the Customer Support Department. As a Senior Manager, Support Engineering you will ensure that the managers and/or ICs who report to you, and the engineers they work with have everything they need to deliver world-class support to GitLab customers.

#### Job Grade

The Senior Manager, Support Engineering is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### What you can expect in a Senior Support Engineering Manager role at GitLab

A Senior Manager, Support Engineering will:

- Hire a world class team of Support Managers by actively seeking and hiring globally distributed talent who are focused on delivering world class customer support
- Conduct managerial interviews for Support Engineering candidates and train Support Engineering Managers to do said interviews
- Hold regular 1:1s with their team managers and skip-level 1:1s with all members of their team
- Mentor the managers on their team
- Ensure there is clarity around the priorities and goals in the Customer Support Department
- Explain vision, build buy-in for direction and catalyze tactical and operational changes that result in OKR and KPI achievement
- Build a collaborative environment where strategy development is done in coordination with Support staff at all levels
- Develop, implement and review Support procedures, policies and activities
- Communicate KPI achievement and intermediate goal results with the executive team and across the wider Support team
- Work across functions with peers in other groups to facilitate the accomplishment of shared goals
- Simplify and speed up decision making by ensuring that every issue has a DRI, that every decision has data backing it up, and that every issue relates to a Support priority, goal or KPI
- Represent GitLab Support in client meetings, networking events and other official functions
- Partner with management on budget requirements and executing to established budgets

See also our [Support Manager Responsibilities page](/handbook/support/managers/manager-responsibilities/).

#### Requirements

- Technical credibility: Past experience as a Support Engineer or leading teams thereof
- Management credibility: Past experience (3 to 5 years) in Support Management
- Ability to understand, communicate and improve the quality of multiple teams
- Demonstrate longevity in at least one recent job
- Ability to be successful managing at a remote-only company
- Humble, servant leader

#### Nice-to-have Requirements

- Be a user of GitLab, or familiar with our company
- Prior product company experience
- Prior high-growth startup experience
- Experience working on systems at a massive (i.e. consumer) scale
- Deep open source experience
- Experience working with global teams
- Values diversity, inclusion and belonging in their leadership style

### Director of Support

The Director of Support role extends the Support Engineering Manager Role

- Hire a world class team of managers and Support Engineers to work on their teams
- Help their managers and developers grow their skills and experience
- Manage multiple teams and projects
- Hold regular skip-level 1:1's with all members of their team
- Create a sense of psychological safety on their teams
- Drive technical and process improvements
- Draft and Report quarterly OKRs
- Own the support experience across all products
- Exquisite communication: Regularly achieve consensus amongst departments
- Represent the company publicly at conferences

### VP of Support

The VP of Support role extends the Director of Support Role through:

- Set the vision for GitLab's global Support Department
- Develop a strategy, execution roadmap, priorities and investment plan to deliver proactive support vision, deflection and scale/productivity
- Implement initiatives to raise the bar for hiring senior talent in Support teams
- Lead the Global Support organization to deliver world-class Support and proactive technical health to our customers
- Innovate and develop new ways to achieve high levels of customer loyalty and satisfaction
- Lead monthly Support Key Review meeting
- Monitor and improve performance on performance indicators for the department (Customer satisfaction with Support, Manage team within approved operating expenses etc.)
- Drive quarterly OKRs
- Define KPIs for the Customer Support Department *e.g.* SLAs, Customer Satisfaction
- Partner with Finance to manage budget, drive capacity planning and identify needs and present investments required to improve service levels and customer experience
- Work cross-functionally with other customer-facing departments to guarantee a great customer experience
- Analyze and optimize support operations. Drive a culture of continuous improvement
- Represent the company publicly at conferences

## Support Management Performance Indicators

Support Management have the following job-family performance indicators.

- [Customer satisfaction with Support](/handbook/support/#support-satisfaction-ssat)
- [Manage team within approved operating expenses](/handbook/support/#customer-support-operating-expenses)
- [Service Level Agreement](/handbook/support/#service-level-agreement-sla)
- [Maintain hiring plan and capacity to achieve IC:Manager ratio](/handbook/support/#individual-contributor-to-manager-ratio)
- [Develop a team of experts](/handbook/support/#increase-capacity--develop-experts)

## Span of Control in Support Management Positions

Support Management roles have the following spans of control:

- Support Managers: ~10 Intermediate and Senior Support Engineers
- Senior Support Managers: ~3 Support Managers, 0-2 Staff Support Engineers, ~30 Support Engineers (indirectly)

## Specialties

### US Federal Support Manager

Support Managers with verified US Citizenship may join the GitLab US Federal Support Team. This group works through the [US Federal Support portal](https://about.gitlab.com/support/us-government-support/) to collaborate with Public Sector organizations and United States Government agencies in order to support, maintain, and resolve issues in their GitLab environments.

The US Federal Support Portal is unique in that it is the first restricted support instance at GitLab, this provides managers an opportunity to shape the way engineers and customers interact in order to improve the support experience in measurable ways. This instance is also used as a testbed for process change as it is easier to implement and roll out changes on a smaller scale with less impact than attempting to deploy them globally. As GitLab's federal offerings grow, the US Support workflows may serve as a template that can be used to extend federal support to other areas of the globe.

If you look forward to the challenges and opportunities and meet the requirements please apply today!

#### Additional Responsibilities Unique to US Federal Include

- Work closely with Public Sector CSM and SAEs in order to adapt to the needs of the unique user base
- Be responsible for maintaining customer confidentiality and data security when working with cases

#### Requirements

In addition to the above requirements for Global Support Managers, you will need:

- Valid proof of US Citizenship

### Director of Support Readiness

Director, Support Readiness is a global role responsible for leading a Support Readiness function within the GitLab Customer Support organization.  This role will lead a team of Support Operations managers and individual contributors working closely with Product, Engineering, & Sales teams to ensure that the Customer Support organization is ready to support product releases. This role will manage all aspects of planning and enablement in ensuring that the appropriate Support delivery team is ready to support all existing and new releases across the entire GitLab solution.

This includes overall supportability of the product and Support's readiness of new releases, which entails development of training plans, assist in building tools as needed as well as preparing and delivering regular Key Reviews.  Working with teams globally, this role will be responsible for enabling the global Support team towards continuous improvement in key Support metrics – Service Levels, SSAT, TTR, staffing model input, etc.

This role also closely interacts with counterparts in Product, Development, QA, UX, Customer Success and Sales, to clearly understand the upcoming release features and enabling the global delivery teams to ensure customer support has the appropriate knowledge and troubleshooting procedures to minimize time to resolution.

#### Additional Responsibilities for Director of Support Readiness

- Manage multiple teams and projects affecting consistent global execution
- Own the support readiness and operations across all products

## What it's like to work here at GitLab

The [culture](/handbook/company/culture/) here at GitLab is something we're incredibly proud of. Because GitLabbers are currently located in over 51 different countries, you'll spend your time collaborating with kind, talented, and motivated colleagues from across the globe. Some of the [benefits](/handbook/total-rewards/benefits/) you'll be entitled to vary by the region or country you're in. However, all GitLab team members are fully remote and receive a "no ask, must tell" paid-time-off policy, where we don't count the number of days you take off annually. You can work incredibly flexible hours, enabled by our [asynchronous approach](/handbook/communication/) to communication. We'll also help you set up your [home office environment](/handbook/finance/spending-company-money/), pay for your membership to a co-working space, and contribute to the [travel costs](/handbook/total-rewards/incentives/#visiting-grant) associated with meeting other GitLab employees across the world.

Also, every year or so, we'll invite you to our [Contribute event](/handbook/company/culture/summit/).

Find more information about what it's like to work here in [our candidate FAQ](/handbook/hiring/candidate-faq/).

## Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process. To learn more about someone who may be conducting the interview, find their job title on our [team page](/handbook/company/team/).

### All Candidates

- Qualified candidates will be invited to schedule a 30min screening call with our Global Recruiters.
- Selected candidates will receive a short questionnaire from our Global Recruiters

Next, candidates will move to interviews with Support team members:

### Support Manager Candidates

Round 1:

- 60 Minute Peer Behavioral Interview (Panel)
- 90 Minute Technical Interview with a member of the Support team
  - The Tech Interview will involve live break-fix/bug-fix scenarios as well as customer scenarios.  You will need to have access to a terminal with Bash or similar. You will also need to have an SSH key pair installed locally so you can connect to the server. Windows users must have 'Git Bash for Windows' installed prior to the call. If the Tech Interview is not passed, the Behavioral Interview will be canceled.

Round 2:

- 60 Minute Interview with the hiring manager for the role (a Senior Support Manager in that region).
- 60 Minute Interview with the VP of Customer Support.

### Director of Support Candidates

Round 1:

- 60 Minute Peer Behavioral Interview (Panel)

Round 2:

- 90 Minute interview with Senior Support Managers in that region (may be a panel)
- 60 Minute Interview with the hiring manager for the role (VP of Costumer Support)

Successful candidates will subsequently be made an offer

Additional details about our process can be found on our [hiring page](/handbook/hiring/).

## Career Ladder

For more details on the engineering career ladders, please review the [engineering career development](/handbook/engineering/careers/#roles) handbook page.
