---
title: "Technical Program Management Individual Contributors"
description: "Driving strategy and initiatives across Engineering"
---

Technical Program Manager (TPM) is responsible for the planning, execution, and delivery of complex projects across Engineering. TPMs work with a variety of stakeholders, including engineers, architects, and business leaders, to ensure that projects are completed on time and within budget, and to the required quality standards. This includes the tracking, monitoring and influencing priority of significant objectives, goals and plans from all sub-departments.

TPMs typically have a background in engineering or computer science, and have a deep understanding of the technical aspects of product management and infrastructure scalability. They also have strong leadership and communication skills, and able to work effectively in a fast-paced and demanding environment.

## Responsibilities

- Establish a reliable and visible cadence for initiative reviews, decision making, prioritization, and staffing management.
- Lead and drive projects such as: Availability, Disaster Recovery, Releases, CI/CD Pipeline Efficiency, and Engineering Productivity
- Provide technical project management, coordination, and inter/intra team communications to deliver outstanding program outcomes.
- Work closely with Software Engineers, SREs, Engineering Leadership, and other Product & Engineer teams to deliver a high quality and resilient SaaS Infrastructure Platform with world class Availability.
- Manage programs, define milestones and success criteria, staffing allocation to ensure successful on-time deliverables.
- Lead strategic planning with direct influence over staffing decisions, project timelines, and planning stakeholders.
- Work on massive distributed, large-scale systems, storage solutions, applications, and new platforms.
- Be a change advocate responsible for initiating and leading multiple organizations through pivots needed to address shifts in business trends and priorities
- Utilize technical acumen in working with large, cross-functional distributed teams.

## Requirements

- Experience managing execution of complex programs that span multiple engineering teams through the software project lifecycle (build, test, and release on time).
- Experience with technologies such as virtualization and complex software infrastructure systems, compute, storage, data migration, capacity, load balancing, and software defined networking.
- Experience driving cross-functional initiatives according to plan and timelines
- Prioritize effectively and multitask efficiently
- Proven track record of successful collaboration with internal and external partners
- Communication, presentation, and documentation skills

## Levels

### Intermediate Technical Program Manager

#### Intermediate Technical Program Manager Job Grade

The role is a [grade 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Intermediate Technical Program Manager Responsibilities

All responsibilities listed above (applicable to all roles) plus:

- Define and manage the program scope, schedule, and budget
- Develop and maintain program plans, status reports, and other project documentation
- Facilitate cross-functional communication and collaboration between stakeholders, technical teams, and management
- Ensure program milestones are achieved on time and within budget
- Identify and manage program risks, issues, and dependencies
- Provide regular updates on program status to stakeholders and senior management

#### Intermediate Technical Program Manager Requirements

- Technical degree in Engineering, or related technical field
- 3-5 years of experience in technical program/project management or equivalent
- Experience with infrastructure-related projects such as cloud infrastructure, data center operations, and network engineering
- Experience in Agile development methodologies
- Excellent verbal and written communication skills
- Strong analytical and problem-solving skills
- Ability to work effectively in a fast-paced and dynamic environment

### Senior Technical Program Manager

#### Senior Technical Program Manager Job Grade

The role is a [grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Senior Technical Program Manager Responsibilities

All responsibilities of previous roles plus:

- Coordinate with technical teams to ensure adherence to established project standards, processes, and methodologies
- Drive continuous process improvement and operational excellence within the program
- Identify and coordinate the interdependencies among programs, products and other critical initiatives for 1 or more engineering sub-departments
- Provide insight and suggestions to mitigate
- Examine risks associated with programs and prioritize risks accordingly
- Collaborate on strategy and direction with organizational stakeholders; Oversee project planning and management
- Communicate successfully within the project team and at multiple levels of management, building trust across the organization, and demonstrating care with sensitive information
- Develop and coach intermediate program managers

#### Senior Technical Program Manager Requirements

All requirements of previous roles plus:

- 5+ years of experience in technical program/project management or equivalent
- Experience with infrastructure-related projects such as cloud infrastructure, data center operations, and network engineering
- Experience influencing others without having direct management authority and motivating them to successfully complete tasks within required timelines
- Risk analysis and problem-solving skills
- Excellent at building relationships with partners.

### Staff Technical Program Manager

#### Staff Technical Program Manager Job Grade

The role is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Staff Technical Program Manager Responsibilities

All responsibilities of previous roles plus:

- Identify and coordinate the interdependencies among programs, products and other critical initiatives across all engineering sub-departments within our organization
- Assist defining business requirements and roadmaps in alignment with the overall engineering strategy
- Define acceptance criteria for solutions, value proposition and milestones for execution; Validate prototypes with partners and iterate solutions as needed to deliver value
- Track and provide reporting and measurements of program effectiveness and communicate findings to management
- Develop repeatable, scalable, efficient, and effective processes

#### Staff Technical Program Manager Requirements

All requirements of previous roles plus:

- 7+ years of experience in technical program/project management or equivalent
- Advanced understanding of application, development and frameworks
- Advanced anaytical skills for assessing and recommending solutions based on data and research

### Principal Technical Program Manager

#### Principal Technical Program Manager Job Grade

The role is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Principal Technical Program Manager Responsibilities

All responsibilities of previous roles plus:

- Develop and implement strategies for program growth and expansion
- Contribute to technical program management budgeting and financial reporting artifacts
- Expanded sphere of influence in driving initiatives across Engineering
- Drive goals and objectives that results in further progress of the department roadmap and strategy
- Accountable and responsible for overflow responsibilities from senior leadership
- Identify, define and implement programs across Engineering

#### Principal Technical Program Manager Requirements

All requirements of previous roles plus:

- 10+ years of experience in technical program/project management or equivalent
- Influence and implement change across the company
- Speak to and represent GitLab to customers and vendors

## Specialties

- Currently no specialties defined

## Performance Indicators

- Individual TPM's Performance Indicators will be defined based on their quarterly goals
- Project Completion rate
  - Measure by tracking the percentage of projects completed on time and within budget.
- Stakeholder Satisfaction score
  - Measure through regular feedback surveys or interviews with stakeholders, assessing the program management effectiveness, communication and responsiveness.

## Career Ladder

- To Be Defined (TBD)

## Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process. To learn more about someone who may be conducting the interview, find their job title on our [team page](/handbook/company/team/).

1. Qualified candidates will be invited to schedule a 30 minute [screening call](/handbook/hiring/interviewing/#screening-call) with one of our Global Recruiters.
1. Candidates will be invited to schedule a 50-minute interview with a Manager/Sr. Manager within Engineering.
1. Candidates will be invited to schedule a 50-minute interview with a Director/Sr. Director in Engineering.
1. Candidates will be invited to schedule a 50-minute interview with a cross-functional stakeholder.
1. Candidates will be invited to schedule a 50-minute interview with an existing TPM/Program Manager.
1. Candidates will be invited to schedule a 50-minute interview with the CTO.

Additional details about our process can be found on our [hiring page](/handbook/hiring/).
