---
title: "Accounting and External Reporting"
description: "The Accounting and External Reporting team are responsible for generating accurate and complete financial statements based on the applicable GAAP for all GitLab entities."
---

The Accounting and External Reporting team are responsible for generating accurate and complete financial statements based on the applicable GAAP for all GitLab entities.  This team also is responsible for managing the consolidated and statutory audits for all entities.

## Senior Accountant, Accounting and External Reporting

The Senior Accountant, Accounting and External Reporting reports to the Manager, Accounting and External Reporting; Senior Manager, Accounting and External Reporting; or Director, Accounting and External Reporting.

### Job Grade

The Senior Accountant, Accounting and External Reporting is a [grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Responsibilities

- Compile "provided by client" support for the consolidated and statutory audits and review processes conducted by external auditors and verify that all requested information is complete and accurate prior to submission.
- Run reports and validate data for the production of consolidated financial statements on a monthly, quarterly and annual basis.
- Ensure footnote disclosures in audited financial statements and SEC filings are accurately populated with supporting documentation.
- Assist with running reports and data validation of stock based compensation and equity related accounts.
- Ensure compliance with Sarbanes-Oxley Section 404 key controls in the financial areas of responsibility.
- Assist with preparation of reports and presentations for Board of Directors and Audit Committee meetings.
- Work with and support the accounting team in day-to-day activities, special projects, and workflow process improvements.
- Support overall department goals and objectives

### Requirements

- 3-5 years of accounting / reporting experience
- Public company accounting experience and SEC reporting experience is preferred
- Eligible to obtain a CPA license with current plans to take the CPA exam is required
- Working knowledge of GAAP principles and financial statements
- Experience with Netsuite or other big ERP system is preferred
- Proficient with Microsoft Office and/or Google Docs and Sheets
- Experience working on clients or for a company with a presence outside the US preferred but not required
- Workiva experience preferred but not required
- Flexible to meet changing priorities and the ability to prioritize workload to achieve on time accurate results
- Detail-oriented and self-directed
- You share our [values](/handbook/values/), and work in accordance with those values.
- Ability to use GitLab

## Manager, Accounting and External Reporting

The Manager, Accounting and External Reporting reports to the Senior Manager, Accounting and External Reporting or Director, Accounting and External Reporting.

### Job Grade

The Manager, Accounting and External Reporting is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades)

### Responsibilities

- Extends the Senior Accountant, Accounting and External Reporting responsibilities.
- Manage the consolidated audit and review process conducted by external auditors and ensure all requests are completed timely and all necessary support is provided.
- Work with local service providers for each operating entity to ensure compliance with statutory reporting, collaborating with the Tax team as needed.
- Ensure efficient, accurate, and timely production of consolidated financial statements on a monthly, quarterly and annual basis.
- Draft variance explanations around balance sheet and income statement fluctuations in conjucntion with the General Ledger team.
- Assist with recording, reconciling, and analysis of stock based compensation and equity related accounts and ensure the proper accounting and reporting of the same.
- Ensure compliance with Sarbanes-Oxley Section 404 key controls in the financial areas of responsibility.
- Assist with monitoring the need for business process improvements and assist with the design processes, procedures, and reporting enhancements to improve financial and operational processes.
- Assist with system implementations across the accounting department, as needed.
- Perform analysis to determine the impact of new accounting standards, changes in accounting policies, impact of non-GAAP policies, etc.
- Respond to inquiries from the CFO, Controller, and company wide managers regarding financial results, special reporting requests and the like.

### Requirements

- Extends the Senior Accountant, Accounting and External Reporting requirements
- 6+ years of experience with at least two years working on SEC reporting
- Proven work experience as an Accounting Manager or similar leadership role
- CPA license or actively working towards a CPA license is required
- Ability to contribute to the career development of staff and a culture of teamwork
- Strong working knowledge of GAAP principles and financial statements
- Must have experience with Netsuite or other big ERP system
- Experience working on clients or for a company with a presence outside the US is required
- Able to effectively complete tasks with minimal supervision

## Senior Manager, Accounting and External Reporting

The Senior Manager, Accounting and External Reporting reports to the Director, Accounting and External Reporting.

### Job Grade

The Senior Manager, Accounting and External Reporting is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Additional Responsibilities

Senior Accounting and External Reporting Manager shares the same responsibilities as listed above, but also includes the following:

- People manager of 1 or more
- Initiate design and implementation of new policies and procedures to support new audit requirements and business activities
- Drive the implementation of any tools to improve financial reporting
- Ensure variance explanations for balance sheet and income statement fluctuations provide the necessary information for financial statement users to understand what drove the changes period-to-period.
- Directly responsible for monitoring the need for business process improvements and assisting with the design processes, procedures, and reporting enhancements to improve financial and operational processes.
- Identify the need for resources, hire and train new staff

### Additional Requirements

Senior Accounting and External Reporting Manager share the same requirements as listed above, but also carry the following:

- Active CPA license required
- Eight plus years experience with at least four years in public accounting working on SEC clients

## Director, Accounting and External Reporting

### Additional Responsibilities

Director, Accounting and External Reporting shares the same responsibilities as listed above, but also includes the following:

- Collaborate on implementation of policies and procedures around new accounting pronouncements with the Technical Accounting and General Ledger teams, as appropriate
- Ensure all disclosures are properly included in audited financial statements, working in conjunction with the Technical Accounting team.
- Ensure all processes, procedures, and reporting enhancements are implemented appropriately and all related risks are mitigated.
- Collaborate with the General Ledger team to ensure all journal entries are recorded appropriately and account reconciliations are performed timely.
- Develop, implement and maintain systems, procedures and policies to support the possibility of a public filing, which would include Form S-1 and the related subsequent SEC reporting requirements including Forms 10-K, 10-Q, 8-K and Proxy filings.
- Verify all financial statements and footnote disclosures are accurate and complete prior to review by upper management

### Additional Requirements

Director, Accounting and External Reporting shares the same requirements as listed above, but also requires the following:

- 10 plus years experience with at least six years in public accounting working on SEC clients
- Proven leadership managing projects across various accounting areas

## Performance Indicators

- [Average days to close](/handbook/finance/accounting/#average-days-to-close-kpi-definition)
- [Number of material audit adjustments = 0](https://internal.gitlab.com/handbook/internal-audit/#performance-measures-for-accounting-and-finance-function-related-to-audit)
- [Percentage of ineffective Sox Controls = 0%](https://internal.gitlab.com/handbook/internal-audit/#performance-measures-for-accounting-and-finance-function-related-to-audit)

## Career Ladder

The next step in the Accounting & External Reporting job family is to move to the [Controller](/job-families/finance/corporate-controller/) job family.

## Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process. To learn more about someone who may be conducting the interview, find their job title on our [team page](/handbook/company/team/).

- Selected candidates will be invited to schedule a 30 minute screening call with our Global Recruiters
- Next, candidates will be invited to schedule a 45 minute interview with our Controller
- Candidates will then be invited to schedule a 45 minute interview with our CFO
- Finally, candidates may be asked to interview with the CEO
- Successful candidates will subsequently be made an offer via email

Additional details about our process can be found on our [hiring page](/handbook/hiring/interviewing/).
