---
title: IT Systems Engineer
---

The IT Systems Engineer is responsible for performing functions such as evaluation, testing, debugging and implementation of applications programs supporting the company infrastructure business processes and operations. Other functions include analyze, install, modify and support operating systems, databases, and utilities software. The IT Systems Engineer also plans, conducts and directs the analysis of business problems with automated systems solutions. This job family reports to the [IT Manager](/job-families/finance/manager-it/).

## Responsibilities

- Design, implementation, and ongoing management of the Okta Identity and Access management platform.
- Configure and customize Okta to meet the organization's authentication and authorization requirements.
- Identity Lifecycle Management: Manage the complete lifecycle of user identities, including provisioning, de-provisioning, and access modifications. Implement and maintain automated workflows for user onboarding and offboarding.
- Single Sign-On (SSO) Integration: Integrate applications and systems with Okta for seamless single sign-on experiences. Troubleshoot and resolve issues related to SSO integrations. Remove applications as required.
- Create and manage access policies to improve security and adhere to compliance standards.
- Administer and optimize VDI solutions to provide a seamless and secure virtual desktop experience. Collaborate with end-users and IT teams to troubleshoot VDI-related issues and ensure optimal performance.
- Collaborate with Engineering and Security teams to coordinate on IT policies
- Build policies and scripts using vendor APIs to support company owned devices and SaaS services such as Google Workspace, Slack and Zoom
- Develop and maintain documentation for supported applications, processes, and training material to internal employees and IT staff
- Work with Security, PeopleOps and IT to develop automated onboarding and offboarding processes
- Develop tooling and processes to facilitate end-user asset management, provisioning and tracking
- Participate in general IT operations and user support
- Build and maintain cross-functional relationships with internal teams to drive initiatives
- Design, develop, and support integrations using tools such as Okta Workflows, Workato or custom code to reduce repetitive and manual tasks
- Maintenance of existing scripts written in PHP Laravel and Python
- Oversee and provide operations support including account management, workflow, log analysis, troubleshooting and service optimization
- Assist in ongoing evaluation and management of major vendor relationships and outsourcing arrangements
- Develop system-monitoring and support automation to enhance and scale the quality of support
- Provide emergency response either by being on-call or by reacting to symptoms according to monitoring and escalation when needed

## Requirements

- Experience administering SaaS applications such as Okta (Okta Identity Engine & Identity Governance), Google Workspace, Slack, and Zoom
- In-depth knowledge of identity and access management concepts and practices.
- Hands-on experience supporting Linux and Mac users
- Ability to create, analyze and action the output of custom reports
- Developing automation workflows and integrations for repetitive or manual tasks
- Experience working with CI/CD tools and Git
- Be part of an on-call (PagerDuty) rotation to respond to incidents that impact Corporate IT system availability
- Use your on-call shift to prevent incidents from ever happening.
- Ability to use GitLab

## Levels

### IT Systems Engineer (Intermediate)

#### Job Grade

The IT Systems Engineer is a [grade 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Responsibilities

The IT Systems Engineers share the same responsibilities outlined above.

#### Requirements

The IT Systems Engineer position has all the same requirements as the ones outlined above plus the following:

- 5+ years of experience in IT in a high growth Software as a service (SaaS) environment
- 3+ years of experience in user support in a cloud-first modern IT environment
- Experience with log management tools such as Splunk and ElasticSearch and/or security information and event management (SIEM) tools like Devo
- Knowledge of identity and access management
- Knowledge in one of the following scripting languages - Python or Ruby
- Knowledge of CI/CD pipelines

### Senior IT Systems Engineer

#### Senior IT Systems Engineer Job Grade

The Senior IT Systems Engineer is a [grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Senior IT Systems Engineer Responsibilities

The Senior IT Systems Engineer has all the same responsibilities as the intermediate position plus the following:

- Provide senior level technical guidance and serve as an escalation point for Engineering and Security teams
- Provide senior level direction to the Information Technology team, assist with mentoring and providing technical guidance to more junior staff members
- Work on and manage all phases of systems administration including definition, design, implementation, and testing of new service rollouts
- Define, communicate and manage the execution of IT strategy, standards and roadmaps based on the current state and short and long term needs of the enterprise
- Participate in the Global IT planning process and ensure architectural designs and principles are incorporated in enterprise implementations
- Evaluate existing or emerging technologies to consider factors such as cost, security, compatibility and usability
- Establish strong relationships with key technology stakeholders and facilitate, communicate, collaborate, and persuade others in the definition, adoption and implementation of a coherent architecture
- Provide guidance around "Cloud/SaaS" Infrastructure, Business Applications architectures and address unique security considerations
- Build roadmaps for acquiring, integrating, and implementing high-value technology and processes. Oversee efforts (e.g. proof of concepts) to measure and prove new technology value
- Design and deploy best practices regarding system monitoring, change control, service level agreements, and in the creation of the company's infrastructure policies and standards

#### Senior IT Systems Engineer Requirements

The Senior IT Systems Engineer has all the same requirements as the ones outlined above plus the following:

- 7+ years of experience in IT in a high growth SaaS environment
- 5+ years of experience in user support in a cloud-first modern IT environment
- Advanced knowledge of identity and access management
- Advanced knowledge in one of the following scripting languages - Python or Ruby
- Advanced knowledge of CI/CD pipelines
- Ability to use GitLab

### Staff IT Systems Engineer

A Staff IT Systems Engineer focuses on multiple disciplines and cross-department meta-level challenges related to IT to tactically improve efficiency across the organization. They provide technical and thought leadership, and drive innovation through next-generation architecture and iterating on larger problems while leading efforts to reduce tech debt across the organization.

#### Staff IT Systems Engineer Job Grade

The Staff IT Systems Engineer is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Staff IT Systems Engineer Responsibilities

The Staff IT Systems Engineer has all the same responsibilities as the senior position plus the following:

- Architecting next-generation automation and integration between IT managed systems that provides data consistency, reliability, strong security, and audibility.
- Building relationships with cross-department system owners and proposing solutions to ensure our tech stack applications conform to our latest IT and Security best practices in collaboration with the Security Department Staff and Principal engineers.
- Consolidating and refactoring legacy tech debt.
- Designing and developing software that improves back office automation.
- Escalation engineering and emergency response for IT Operations and Security teams, and providing assistance to team members with all of the systems that we build and manage.
- Factor in cost, security, compatibility, maintainability and user experience when making decisions.
- Growing other team members' skill sets through mentorship to improve operational efficiency and encourage professional development.
- Handbook documentation for processes and systems architecture.
- Identifying and communicating the technical direction of our broader IT department to team members, stakeholders, and engineers.
- Joint collaboration with Compliance, IT, People, and Security team members for improving automation efficiency, security posture, and vulnerability management.
- Keeping leaders and stakeholders informed of next-gen initiatives and contributing to creating automated analytics for day-to-day IT operations.
- Leading innovation opportunities between several teams with a willingness to experiment and to boldly confront problems of large complexity and scope.
- Making technical decisions on behalf of the department and organization while providing presentation support to leaders during technical discussions.

#### Staff IT Systems Engineer Requirements

The Staff IT Systems Engineer has all the same responsibilities as the ones outlined above plus the following:

- 10+ years of experience in IT in a high growth SaaS environment
- 5+ years of experience in user support in a cloud-first modern IT environment
- Knowledge of software engineering practices and DevOps lifecycle
- Advanced knowledge of identity and access management
- Advanced knowledge in one of the following scripting languages - Python or Ruby
- Advanced knowledge of CI/CD
- Ability to use GitLab

## Performance Indicators

- Automation workflows created / GitLab Merge Requests
- Handbook Merge Requests
- [Number of days since last environment audit](https://internal.gitlab.com/handbook/it/it-performance-indicators/#number-of-days-since-last-environment-audit)

- [Cycle Time for IT Support Issue Resolution](https://internal.gitlab.com/handbook/it/it-performance-indicators/#cycle-time-for-it-support-issue-resolution)
- [Customer Satisfaction Survey (CSAT)](https://internal.gitlab.com/handbook/it/it-performance-indicators/#customer-satisfaction-survey-csat)

## Career Ladder

The next step in the IT Systems Engineer job family is to move to the [IT Manager](/job-families/finance/manager-it/) job family.

## Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process. To learn more about someone who may be conducting the interview, find their job title on our [team page](/handbook/company/team/).

- Qualified candidates will be invited to schedule a 30 minute [screening call](/handbook/hiring/interviewing/#screening-call) with one of our Global Recruiters
- Next, candidates will be invited to schedule an interview with the Hiring Manager
- Candidates will then be invited to schedule a Team technical interview with two members of the IT Operations team in a panel interview
- Candidates will also then be invited to schedule a Technical interview with two other team members

Additional details about our process can be found on our [hiring page](/handbook/hiring/).
