---
title: Analytics and Insights
---
The Analytics and Insights job family is responsible for providing data driven insights to the business to improve decision making. These are either a centralized analytics team working on cross-functional initiatives such as top 12 initiatives or Go-to-market or embedded analytics teams that live in the functional areas providing support and insights.

## Responsibilities

- Business Partnership: Own stakeholder relationships regarding either business strategy, corporate metric forecasting, go to market, product strategy, pricing strategy and functional strategy needed to answer GitLab's hardest questions.
- Data Subject Matter Expert.
- Partner with executive team members to provide data driven decision support using your analytical, process and business acumen.
- Highly skilled in being able to provide analysis and scientific data to answer GitLab's toughest analytical questions.
- Communication: Prepare and review visualizations of all types of data to promote internal understanding of your team's insights. Expert influencer to our executive team. Clearly articulate insights.
- Data Science Modeling: Design, implement and apply analytics techniques (e.g., optimization, machine learning, experimentation, mathematical modeling) using analytical tools and programming languages (e.g., R, Python, SAS). Be comfortable with a boring solution such as a heuristic when it helps drive the insight.
- Data Driven Insights and Analysis: Summarize key data driven insights to members of the executive team to drive better outcomes, an increase in revenue or decrease in cost. Provide insights across the company.
- The ability to discover data gaps and provide requirements to the Data team and to product management for the proper logging and data repositories.
- Be customer zero for our product teams as they design the MLOps and Product Analytics product areas.
- Be a culture definer and evolver of GitLab Values.
- Land data products with end stakeholders including preparing how to operationalize the data products, measure the impact of the data products and enable users.

## Requirements

- Data Analysis: A passion for understanding business questions and making data driven insights. Excellent analytical skills.
- Proficient in SQL; R, Python preferred.
- A/B Testing experience: experience designing and executing A/B tests in collaboration with growth or product teams.
- Business Acumen: Be able to understand the business at a level to influence EVP priorities and company strategy.
- Business Partnership: Consistent track record of using quantitative analysis to impact key business decisions.
- Communication: Ability to present financial data concisely through written and oral communication. Expert at influencing business stakeholders.
- BS degree in Mathematics, Engineering, Statistics or relevant degree. MBA preferred.
- Ability to use GitLab.

## Functional Specialties

- Go-to-market: provide data insights to improve GTM motions and activities from both operational and product data. Deliver data science products and data visibility.
- Product: provide insights for growth, product managers and pricing teams.
- Finance: Support the Finance function with corporate metric forecasting and driver analysis. Public company reporting and analysis as part of the quarterly close.
- Marketing: TBD
- Sales: TBD
- Engineering: TBD

## Levels

### Analytics and Insights Analyst

#### Job Grade

The Analytics and Insights Senior Analyst is a [grade 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Responsibilities

- Business Insights: understanding of business models and ability to apply data analytics methods to formulate actionable insights and recommendations.
- Stakeholder Partnership: execute appropriate analysis to add value to stakeholder decision making.
- Analytical Modeling: ability to formulate models for segmentation, sizing, prediction and forecasting.
- Data Subject Matter Expert: Identify data gaps and document it for our product, data and IT teams. Improve your personal data workflow.
- Testing and test design: Follow A/B testing best practices, execute analysis for A/B tests, experiments across multiple functions.
- Presenting Data and Insights: make dashboards, visualizations and presentations to advance decision making power in the company.
- Work is typically guided by a Sr. Analyst, Manager or Director

#### Requirements

- Experience recommendation: Experience in a consulting or analytics role ideally with enterprise SaaS software model.
- Analytical modeling experience, SQL required, Python and R experience preferred.
- Experience contributing to data modeling.
- Experience in developing dashboards and visualizations.
- Experience with test design and analysis, preferably in the high tech industry.
- Experience with web analytics platforms such as Google Analytics, Adobe Analytics is a big plus.
- Experience working in cloud environments such as AWS, GCP is a plus.

### Analytics and Insights Senior Analyst

#### Job Grade

The Analytics and Insights Senior Analyst is a [grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Responsibilities

- All responsibilities of Analyst
- Expertise in one area: test design, web analytics, data modeling, dashboarding/visualization, analytical modeling
- Work is typically guided by Manager or Director, however the complexity of projects indepedently run increases.
- Mentorship: mentor, coach and train analysts and junior analysts.

#### Requirements

- More in depth experience than the Analyst in terms of years of experience or depth of experience

### Business Analytics and Insights Manager

#### Job Grade

The Business Analytics and Insights Manager is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Responsibilities

- All responsibilities of Sr. Analyst
- Expertise in two areas: test design, web analytics, data modeling, dashboarding/visualization, analytical modeling
- Work is self-guided and sourced by interacting with stakeholders. Runs Large Complexity projects.
- Mentorship: mentor, coach and train Sr analysts and analysts.

#### Requirements

- More in depth experience than the Sr. Analyst in terms of years of experience or depth of experience.
- Experience driving projects of large complexity on your own with little guidance.
- Ability to influence decisions at the VP level with little support.

### Business Analytics and Insights Senior Manager

#### Job Grade

The Business Analytics and Insights Senior Manager is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Responsibilities

- All responsibilities of Sr. Analyst
- Expertise in two areas: test design, web analytics, data modeling, dashboarding/visualization, analytical modeling
- Work is self-guided and sourced by interacting with stakeholders. Runs Large Complexity projects.
- Mentorship: mentor, coach and train Sr analysts and analysts.

#### Requirements

- More in depth experience than the Sr. Analyst in terms of years of experience or depth of experience.
- Experience driving projects of large complexity on your own with little guidance.
- Ability to influence decisions at the VP/C-Level level with little support.

### Director, Business Analytics and Insights

#### Job Grade

The Director, Business Analytics and Insights is a [grade 10](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Responsibilities

- Participate in monthly key reviews. Provide insights across the company starting with a focus on product and website analytics, customer behavior including the pricing and growth teams.
- Data Subject Matter Expert: Identify and drive improvements to processes and policies in collaboration with product, data and IT teams on process improvements on data collection or data instrumentation.
- Testing and test design: A leader in designing A/B tests, experiments that affect user behavior and broaden these tests into an A/B testing framework for the company.
- Management: Set the vision, hire, build, coach and manage a highly productive team day to day. Expert management skills, especially at developing talent. Set goals and priorities for the team.
- Stakeholder Management: Ensure there is alignment with stakeholders, including success and failure criteria of projects, operational resources to operationalize data products.
- Review: Review work and analysis produced by the team you manage or from other members of the team. Expert at providing feedback.

#### Requirements

- Management: management experience in a consulting, analytics or data science role.
- Experience recommendation: experience in a consulting or analytics role ideally with enterprise SaaS software model.

## Performance Indicators

- Throughput: [Issues or merge requests closed as measurement of analyses completed](/handbook/ceo/office-of-the-ceo/performance-indicators/#throughput-for-the-cost)
- Business partnering satisfaction
- Dollars of ARR growth found through Analysis
