---
title: "Digital Marketing Manager"
summary: Developing and managing the digital demand strategy and plans to support GitLab marketing campaigns across paid search, paid social, programmatic display, and sponsored publisher channels
---

## Overview

The Digital Marketing Manager works under the Demand Generation team and is responsible for developing and managing the digital demand strategy and plans to support GitLab marketing campaigns across paid search, paid social, programmatic display, and sponsored publisher channels. This role will drive digital campaign execution across integrated marketing teams, and will develop and manage demand execution to drive inquiries and meet pipeline goals from both inbound and outbound campaigns.  The ideal candidate is a proven marketing technologist and strategist who possesses a start-up mentality, can quickly uncover new opportunities to optimize and build, takes ownership of key tools, aligns and organizes with cross-functional teams toward one mission. They will have a genuine curiosity for testing new and innovative approaches to generate demand, and will take a data-driven approach to planning and optimizing digital demand across both inbound and outbound channels.

## Responsibilities

- Have a firm understanding of historical campaign performance by segment, audience, product, channel, content and region to drive data-driven strategic campaign recommendations
- Leverage segmentation and buying group data to define target audiences and channels of reach for demand programs, and deliver insights to drive campaign optimization
- Develop quarterly forecasts to ensure inquiries, MQLs and pipeline deliver on goals across all channels and align to demand and sales targets
- Be an expert on our customer lifecycle, and ways in which customer needs are evolving/how our product meets them.
- Work with product team to implement marketing strategies that span into trial/product experience, and impact both customer conversion and future retention/upsell
- Drive innovation and experimentation on the marketing site & trial experience to improve demand creation & conversion.
- Oversee our paid demand generation programs with our Ad Agency to maximize return on marketing spend.
- Analyze and report data across multiple channels to monitor marketing site growth
- Research marketing trends to continually innovate and test new lead generation approaches
- Effectively communicate campaign strategy, plans and performance across key stakeholders and executives

## Levels

### Digital Marketing Manager

#### Job Grade

The Digital Marketing Manager is a [grade 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Responsibilities

- Assist in building and improving paid demand generation campaigns across paid search, paid social, programmatic display, and/or sponsored publisher channels.
- Help manage paid demand generation strategy to assist in building sales pipeline by driving high quality leads to our Sales team
- Leverage the customer's buyer's journey to architect innovative multi-channel engagement programs that will lead customer prospects through the sales funnel (inquiry through closed-won).
- Manage budgets and project plans to ensure campaigns launch on due date and meet their objectives
- Partner with Campaigns team to develop creative, content, and web experiences that follow media best practices that will engage customers throughout their journey
- Provide campaign support to other parts of the organization (field marketing, corporate, account-based marketing, etc).
- Work closely with our Ad Agency to ensure the execution of our demand generation campaigns
- Partner with Analytics team to establish measurement framework for digital media campaigns that map to the program goals
- Monitor market trends and competitors to determine marketing opportunities and recommend and take actions to improve visibility of site.

#### Requirements

- 3+ years in Digital Marketing or Demand Generation role
- 3+ years technical/industry experience focused on SEO, SEM, paid social, programmatic display, and/or web conversion rate optimization to improve lead generation, sales pipeline, and revenue.
- 2+ years experience with web analytics such as Google Analytics (or related tool)
- 1-3 years of enterprise software marketing experience
- Advanced analytics and reporting experience including advanced knowledge of Excel, Tableau, SQL, and/or similar.
- Experience in using Salesforce, Marketo (or other marketing automation software) a plus

### Senior Digital Marketing Manager

#### Job Grade

The Senior Digital Marketing Manager is a [grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Responsibilities

- Define our overall paid demand generation strategy across paid search, paid social, programmatic display, and/or sponsored publisher channels
- Plan quarterly media budgets across various segments and regions in order to help Sales meet their pipeline goals
- Leverage the customer's buyer's journey to architect innovative multi-channel engagement programs that will lead customer prospects from inquiry > MQL > SAO > closed won
- Lead efforts and strategy with our Ad Agency proactively test and improve demand generation campaigns
- Improve closed-loop reporting and analysis capabilities for all paid demand generation efforts
- Drive innovation and experimentation in our demand generation programs to improve our demand creation & conversion
- Work with marketing and sales ops to evaluate and implement adtech and martech
- Partner with Analytics team to establish measurement framework for digital media campaigns that map to the program goals
- Work with inbound marketing teams to build conversion rate optimization strategies around onsite content and strucutre
- Monitor market trends and competitors to determine marketing opportunities and recommend and take actions to improve visibility of site.

#### Requirements

- 5+ years in Digital Marketing or Demand Generation role
- 5+ years technical/industry experience focused on SEO, SEM, paid social, programmatic display, and/or web conversion rate optimization to improve lead generation, sales pipeline, and revenue.
- 5+ years experience with web analytics such as Google Analytics (or related tool)
- 1-3 years of enterprise software marketing experience
- 1-3 years experience in using Salesforce, Marketo (or other marketing automation software) required
- Advanced analytics and reporting experience including advanced knowledge of Excel, Tableau, SQL, and/or similar.=

### Staff, Digital Marketing Programs

#### Job Grade

The Staff Digital Marketing Manager is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Responsibilities

- Define strategic direction and independently lead the execution of the Digital Marketing media budget and oversee our paid search, paid social, programmatic display, and sponsored publisher programs (end-to-end, including finance processes, tracking, and performance reporting)
- Maximize channel and tactic performance and ensure an efficient return-on-ad-spend (RoAS)
- Build and implement a broader digital growth strategy—understand key partnerships within the organization to drive full-funnel customer acquisition, retention, and upsell.
- Provide technical and functional knowledge representing Digital Marketing and paid media as the subject-matter expert with stakeholders across organizations. Act as the go-to person and thought partner for the Digital Strategy Director on all aspects of digital media
- Work across marketing teams on alignment for digital tactics, navigating sometimes conflicting priorities to deliver the best business outcomes
- Create and lead execution of cross-team projects (e.g. conversion rate optimization efforts).
- Mentor more junior teammates on digital media best practices, support them with complex problem solving.
- Lead cross-functional efforts to create standardized marketing reporting and dashboards, presenting performance to the marketing department as well as stakeholders throughout the company
- Ensure GitLab benefits from the latest in digital marketing technologies and best practices, innovating when it will improve program RoAS

#### Requirements

- 10+ years in a Digital Marketing role
- 5+ years of enterprise software marketing experience
- Experience managing advertising publishers and media agencies across all areas of digital media: SEO, SEM, Paid and Organic Social, ABM, Paid sponsorships, and Conversion Rate Optimization
- Experience managing large-scale paid programs (e.g. $1M+ annual)
- In-depth industry experience and knowledge in at least one digital marketing or marketing programs specialty
- Strong technical marketing and advanced digital analytics skills and deep understanding of complex data and reporting to drive strategy and direction
- Experience in content marketing and website UX optimization are also helpful in this role

### Manager, Digital Marketing Programs

The Manager of Digital Marketing Programs for GitLab should have a background and hands-on experience in all areas of marketing: SEO, SEM, Paid and Organic Social, ABM, Paid sponsorships, and Conversion Rate Optimization. They will have experience managing marketing teams and working with marketing agencies. They should also be able to maintain a budget, use analytics tools, CRM, MAT, and other marketing tools, and have a data-driven approach to marketing. Experience in content marketing and website maintenance are also helpful in this role.

#### Job Grade

The Manager, Digital Marketing is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Responsibilities

- Administer the Digital Marketing media budget and ensure marketing costs are tracked correctly.
- Manage, build, and lead a strong team by coaching and developing existing members and closing talent gaps where needed through acquisition of new team members.
- Build and implement Digital Marketing strategy—understand key partnerships within organization to drive full-funnel customer acquisition, retention, and upsell.
- Define, manage, and implement our overall digital strategy together with marketing team and digital marketing agency.
- Create strategies for conversion rate optimization (CRO) projects
- Lead effort to create standardized marketing reporting and dashboards, presenting performance to the marketing department as well as stakeholders throughout the company
- Oversee our paid search, paid social, programmatic display, and sponsored publisher programs, maximizing for return on marketing spend
- [Leadership at GitLab](/handbook/company/structure/#management-group)

#### Requirements

- 10+ years in a Digital Marketing role
- 5+ years of enterprise software marketing experience.
- Experience managing a marketing team.
- In-depth industry experience and knowledge in at least one digital marketing or marketing programs specialty.
- Strong technical marketing and advanced digital analytics skills

### Director, Digital Strategy

#### Job Grade

The Director, Digital Strategy is a [grade 10](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Responsibilities

- Lead the global media strategy and planning to drive awareness and acquisition growth across SMB, Mid Market and Enterprise segments
- Partner with Campaigns, Brand, and ABM teams, as well as agency partners to build programmatic, content syndication and search campaigns
- Own and deliver reporting analysis on performance and business impact, as well as conceiving and executing testing strategies
- Accountable for conversion efficiency across multiple personas and creating full-funnel programs, including moving effectively from awareness to consideration stage
- Guide, mentor and lead a team of digital media strategies and specialists, in addition to managing our important agency relationships

#### Requirements

- 12+ years experience in direct response, B2B demand gen and media planning
- Experience in driving differentiated strategies across multiple segments, including SMB and Enterprise, from trial flows to ABM execution
- Deep understanding and practical experience of planning global, regional and localized campaigns, including emerging markets
- Deep understanding of programmatic media buying and experience with paid social media platforms
- Skilled in audience insights, segmentation, persona targeting and integrating propensity models
- Experience in analyzing and reporting on digital media performance to a range of audiences, including marketing counterparts and business stakeholders
- Extensive team management skills, including career development and coaching
- Experience partnering cross-functionally across marketing, internal stakeholders and agency partners

## Key Performance Indicators

- No. of leads/MQLs created, cost per lead

- % increase in MQL to SAO conversion rate and nurture progression
- % of SMB/MM leads from digital source, cost per trial acquisition
- % YoY growth in accounts engaged
branded/non-branded Search volume, keyword rankings
- Campaign conversion rates

## Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process. To learn more about someone who may be conducting the interview, find their job title on our [team page](/handbook/company/team/).

- Qualified candidates will be invited to a [screening call](/handbook/hiring/#screening-call) with our Global Recruiters.
- Candidates will be invited to a 50 min interview with the VP, Integrated Marketing
- Candidates will be invited to a 50 min interview with the Sr. Manager, Campaigns (and ABM)
- Candidates will be invited to a 50 min interview with the Director, Content
- Candidates will be invited to a 50 min interview with the Marketing - Director, People Business Partner
- Final candidates will be invited to a 30 min interview with the Chief Marketing & Strategy Officer

- Successful candidates will subsequently be made an offer via video or phone call
