---
title: Analytics Engineering
---

**Analytics Engineers** sit at the [intersection](/handbook/enterprise-data/#data-job-families) of business teams, [Data Analytics](/job-families/marketing/enterprise-data/data-analyst) and [Data Engineering](/job-families/marketing/enterprise-data/data-engineer) and are responsible for bringing robust, efficient, and integrated data models and products to life. Analytics Engineers speak the language of business teams and technical teams, they are able to translate data insights and analysis needs into models powered by the [Enterprise Data Platform](/handbook/enterprise-data/platform). The successful Analytics Engineer is able to blend business acumen with technical expertise and transition between business strategy and data development.

## Associate Analytics Engineer

The Associate Analytics Engineer reports to the [Manager, Data.](/job-families/marketing/enterprise-data/manager-data)

### Associate Analytics Engineer Job Grade

The Associate Analytics Engineer is a [grade 5](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Responsibilities

As a team member responsible for helping to bridge the gap between business and technology, the Associate Analytics Engineer role requires equal amounts business acumen and technical acumen.

- Collaborate with team members to collect business requirements, define successful analytics outcomes, and design data models
- Build trust in all interactions and with [Trusted Data Development](/handbook/enterprise-data/data-development/#trusted-data-development)
- Serve as the [Directly Responsible Individual](/handbook/people-group/directly-responsible-individuals) for small sections of the [Enterprise Dimensional Model](/handbook/enterprise-data/platform/edw/)
- Design and develop [dbt](https://www.getdbt.com/) code to extend the Enterprise Dimensional Model
- Create and maintain architecture and systems documentation in the [Data Team Handbook](/handbook/enterprise-data/)
- Maintain the [Data Catalog](/handbook/enterprise-data/data-catalog/), a scalable resource to support Self-Service and Single-source-of-truth analytics
- Document plans and results in either issue, MRs, the [handbook](/handbook/), or READMEs following the GitLab tradition of [handbook first!](/handbook/about/handbook-usage/#why-handbook-first)
- Implement the [DataOps](https://en.wikipedia.org/wiki/DataOps) philosophy in everything you do
- Craft code that meets our internal standards for style, maintainability, and best practices (such as the [SQL Style Guide](/handbook/enterprise-data/platform/sql-style-guide)) for a high-scale database environment. Maintain and advocate for these standards through code review.

### Requirements

- Ability to use GitLab
- Ability to thrive in a fully remote organization
- Positive and solution-oriented mindset
- Comfort working in a highly agile, [intensely iterative](/handbook/values/#iteration) environment
- [Self-motivated and self-managing](/handbook/values/#efficiency), with task organizational skills
- Great communication: Regularly achieve [consensus](/handbook/values/#collaboration) amongst technical and business teams
- Demonstrated capacity to clearly and concisely communicate complex business activities, technical requirements, and recommendations
- Demonstrated experience with one or more of the following business subject areas: marketing, finance, sales, product, customer success, customer support, engineering, or people
- 1+ years in the Data space as an analyst, engineer, or equivalent
- 1+ years experience designing, implementing, operating, and extending commercial Kimball enterprise dimensional models
- 1+ years working with a large-scale (1B+ Rows) Data Warehouse, preferably in a cloud environment
- 1+ years experience building reports and dashboards in a data visualization tool
- 1+ years creating project plans to identify tasks, milestones, and deliverables

## Analytics Engineer (Intermediate)

The Analytics Engineer reports to the [Manager, Data.](/job-families/marketing/enterprise-data/manager-data)

### Analytics Engineer Job Grade

The Analytics Engineer is a [grade 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Analytics Engineer Responsibilities

Responsibilities for the Analytics Engineer (Intermediate) extend the Associate Analytics Engineer job. In addition:

- Serve as the [Directly Responsible Individual](/handbook/people-group/directly-responsible-individuals) for major sections of the [Enterprise Dimensional Model](/handbook/enterprise-data/platform/edw/)
- Design, develop, and extend [dbt](https://www.getdbt.com/) code to extend the Enterprise Dimensional Model
- Approve data model changes as a Data Team Reviewer and [code owner](https://gitlab.com/gitlab-data/analytics/blob/master/CODEOWNERS) for specific database and data model schemas
- Provide data modeling expertise to all GitLab teams through code reviews, pairing, and training to help deliver optimal, DRY, and scalable database designs and queries in Snowflake and in Periscope.

### Analytics Engineer Requirements

Requirements for the Analytics Engineer (Intermediate) extend the Associate Analytics Engineer job. In addition:

- 4+ years in the Data space as an analyst, engineer, or equivalent
- 4+ years experience designing, implementing, operating, and extending commercial Kimball enterprise dimensional models
- 4+ years working with a large-scale (1B+ Rows) Data Warehouse, preferably in a cloud environment
- 2+ years experience building reports and dashboards in a data visualization tool
- 1+ years creating project plans to identify tasks, milestones, and deliverables

## Senior Analytics Engineer

The Senior Analytics Engineer reports to the [Manager, Data.](/job-families/marketing/enterprise-data/manager-data)

### Senior Analytics Engineer Job Grade

The Senior Analytics Engineer is a [grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Senior Analytics Engineer Responsibilities

Responsibilities for the Senior Analytics Engineer extend the Analytics Engineer (Intermediate) job. In addition:

- Own one or more stakeholder relationship in Go To Market, Research & Development, or General & Administrative business functions
- Serve as Data Model subject matter expert and data model spokesperson, demonstrated by the ability to address questions quickly and accurately
- Advocate for the [Data Quality Program](/handbook/enterprise-data/data-quality/) and [Trusted Data](/handbook/enterprise-data/platform) to help ensure all data is profiled, reviewed, and accurate to support critical decisions
- Guide [Work Breakdown](/handbook/enterprise-data/how-we-work/planning/#work-breakdowns) Sessions
- Organize and Plan quarter-long development initiatives per the [Data Team Planning Drumbeat](/handbook/enterprise-data/how-we-work/planning/)

### Senior Analytics Engineer Requirements

Requirements for the Senior Analytics Engineer extend the Analytics Engineer (Intermediate) job. In addition:

- 6+ years in the Data space as an analyst, engineer, scientist, or equivalent
- 2+ years managing the same data model system over time, evolving the model to meet new business requirements
- Demonstrated experience leading 4 or more analytics projects from beginning to operationalization
- Demonstrated experience designing and socializing Entity Relationship Diagrams and reference SQL scripts to scale data acumen and adoption
- Experience working with multiple commercial data warehouses, ETL tools, and data visualization tools
- Extensive experience in 2 or more major data subject areas (marketing, sales, finance, product, people, etc.)

## Staff Analytics Engineer

The Staff Analytics Engineer reports to the [Manager, Data.](/job-families/marketing/enterprise-data/manager-data)

### Staff Analytics Engineer Job Grade

The Staff Analytics Engineer is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

**Market Justification:** From a survey data perspective 98 companies have this role with an average of 3 employee incumbents in all industries. In tech there are 33 companies reporting an average of 2 employee incumbents. The business justification for Analytics Engineer Staff and Principal job grades is to retain and develop deep technical talent by establishing Individual Contributor focused career paths for our team members who do not want to move into [Data People Management](/job-families/marketing/enterprise-data/manager-data/). Despite residing in the Finance Division, all Data job families are deeply technical in nature and require knowledge of databases, SQL, and modeling. Education in a technical field, typically Computer Science, Mathematics, Management Information Systems, or Data Analytics is typical for individuals in Data careers. At GitLab, the Analytics Engineer role is critical to support the growing Data Program because it helps glue together the business-facing Data Analyst roles with the technology-focused Data Engineering roles by creating data solutions for both roles. The Analytics Engineer is a specialized in dbt, which GitLab has chosen as the standard for developing Trusted Data Models.

### Staff Analytics Engineer Responsibilities

Responsibilities for the Staff Analytics Engineer extend the Senior Analytics Engineer job. In addition:

- Help promote data innovation across GitLab with a willingness to experiment and to confront hard and complex problems
- Identify and resolve impediments to efficiency and enable the entire Data Program to iterate faster
- Review and improve the data system as a whole, inclusive of data model designs, process flows, and end use cases
- Research new data engineering and analytics methodologies with minimal guidance and support from other team members
- Regularly participate in the Data Community/Industry outside of GitLab through writing, speaking, and/or networking
- Organize and Plan multi-quarter initiatives and develop the **Enterprise Model Roadmap**
- Help create a sense of psychological safety in the department

### Staff Analytics Engineer Requirements

Requirements for the Staff Analytics Engineer extend the Senior Analytics Engineer job. In addition:

- Demonstrated experience leading 2 or more multi-department analytics projects from inception to operationalization
- Demonstrated proficiency with data system design, including databases, schema, marts, aggregates, and views
- Experience introducing a new tool or technique to a multi-person team, leading to measurable productivity improvement
- Experience with data access and security techniques, both inside and outside of a data warehouse
- Experience creating data pipelines in support of near real-time event stream processing
- Presented multi-quarter development roadmaps to non-technical audiences

### Staff Analytics Engineer Specializations

Specializations within the Staff Analytics Engineer extend the Senior Analytics Engineer job:

- Staff Analytics Engineer, Data Architect:
  - Sets data architecture principles, standards and guidelines
  - Continuously reviews current data modeling principles and initiate any improvements to enable the implementation of the intended architecture
  - Creates an inventory of the data and tools needed to implement a scalable data architecture.

- Staff Analytics Engineer, Technical Lead:
  - Sets the technical direction for data and cross-functional projects
  - Coordinates the technical effort during design and development and resolves technical disagreements
  - Manages the technical quality of team deliverables

## Principal Analytics Engineer

The Principal Analytics Engineer reports to the [Manager, Data](/job-families/marketing/enterprise-data/manager-data) or [Director, Data & Analytics](/job-families/marketing/enterprise-data/data-and-insights-executive/#director-data-and-insights).

### Principal Analytics Engineer Job Grade

The Principal Analytics Engineer is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

**Market Justification:** While there is limited supporting survey data for a grade 9, the same market justification for a Staff Analytics Engineer holds true for a Principal Analytics Engineer. In addition, Analytics Engineering is a relatively new job family in the Data space and is not as mature as the well-established Data Analysis, Data Engineering, and Data Scientist job families. Despite this, the Analytics Engineering job family is growing quickly and there are reasonable analysis to support the addition of new job grades:

- From a survey data perspective 11 companies have this role with an average of 1 employee incumbent in all industries.
- a LinkedIn search on 2021-08-16 identified 3 Principal Analytics Engineers within the tech sector.
- Companies which support the Analytics Engineer job family include: Netifly, Miro, Spotify, Netflix, Frame.io, Slalom, Pluralsight, and dbt.

### Principal Analytics Engineer Responsibilities

Responsibilities for the Principal Analytics Engineer extend the Staff Analytics Engineer job. In addition:

- Lead major strategic data projects and initiatives, spanning 6 months or more
- Interface with Senior leadership to design, plan, and implement strategic data projects
- Willingness to experiment and to confront the hardest or most complex problems
- Attain a measurable positive impact on the performance of multiple team members and teams
- Regularly participates in the Data Community/Industry outside of GitLab through writing, speaking, and networking
- Provide mentorship to help team members grow their technical and business capabilities

### Principal Analytics Engineer Requirements

Requirements for the Principal Analytics Engineer extend the Staff Analytics Engineer job. In addition:

- Demonstrated experience leading an analytics initiative that significantly improved business performance, acknowledged by executive staff
- Ability to work productively as a Contributor in any Data Job, including Data Analysis, Data Engineering, and Data Science
- Experience with data access and security techniques, both inside and outside of a data warehouse
- Experience creating data pipelines in support of near real-time event stream processing
- Recognized in the industry as a result of publications, seminars, presentations, or equivalent

## Performance Indicators

Analytics Engineers are evaluated on their contributions to the four [Data Team Impact Dimensions](/handbook/enterprise-data/#how-we-measure-impact):

- Data Platform Stability
- Data Quality & Governance
- Data Adoption
- Revenue/Efficiency Impact

## Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process.

- Qualified candidates will be invited to schedule a 30 minute [screening call](/handbook/hiring/candidate-faq/#screening-call) with one of our Global Recruiters.
- Next, candidates will be invited to schedule a first interview with a Data Director or Manager
- Next, candidates will be asked to complete a 'take home assessment' that is completed in their own time.
- Next, candidates will be invited to schedule one or more interviews with members of the Data Team
- Next, candidates will be invited to schedule one or more interviews with Business Partners
- Finally, candidates may be asked to interview with our VP, IT or similar

Additional details about our process can be found on our [hiring page](/handbook/hiring/).
