---
title: "Data Analytics"
---

## Responsibilities

- Collaborate cross-functionally to deeply understand business questions, and design single-source-of-truth reports and dashboards to address them
- Enable data-driven decision-making through the detection of trends, discovery of anomalies/nuances, and identification of potential opportunities for growth / improvement
- Craft SQL code and dashboards that meet our internal standards for style, maintainability, and best practices for a high-scale analytics environment. Maintain and advocate for these standards through code review.
- Partner with [Analytics Engineers](/job-families/marketing/enterprise-data/analytics-engineer/), [Data Engineers](/job-families/marketing/enterprise-data/data-engineer/), and [Governance/Quality Analysts](/job-families/marketing/enterprise-data/data-governance-and-quality-analyst/) to contribute to the enterprise data model and deliver trusted data sources and reports
- Understand and contribute to the full lifecycle of data in our [Data Catalog](/handbook/enterprise-data/data-catalog/), applying the DataOps philosophy (including an emphasis on automation and continuous iteration/deployment) across the development lifecycle
- Deliver high-quality, actionable reports and data products to functional stakeholders and the enterprise at large
- Conduct comprehensive data quality checks and validation against source systems to ensure data accuracy
- Document development work and process changes in issue/MR templates and/or the [handbook](/handbook/)
- Continuously upskill on analytics and data visualization methodologies, staying up-to-date on and adapting to industry changes

## Requirements

- Ability to use GitLab
- Ability to thrive in a fully remote organization
- Ability to share and work in accordance with our [values](/handbook/values)
- A positive and solution-oriented mindset
- Strong analytical and critical thinking skills with the ability to understand and implement complex business logic, gather and fulfill technical requirements, and design effective reporting solutions in an iterative manner
- Fluency in SQL with an ability to write complex SQL including multi-table joins, grouping and aggregation, common table expressions, and conditional filters
- Fluency in business intelligence tools (we use Tableau)
- Proficiency in data visualization best practices, with an interest in evangelizing those practices across the organization
- Experience working with a variety of data sources. Our data includes GitLab.com, Salesforce, Zuora, Zendesk, Marketo, NetSuite, Snowplow and many others (see the [Data Team page](/handbook/enterprise-data/platform/))
- Effective communication [collaboration](/handbook/values/#collaboration) skills, including the ability to provide clear status updates to stakeholders and leaders
- Comfort working in a highly agile, [intensely iterative](/handbook/values/#iteration) environment
- [Self-motivated and self-managing](/handbook/values/#efficiency), with strong organizational skills
- Prior experience in an analytics role, or equivalent education
- Awareness of, and willingness to research/experiment with, new technologies in the analytics space (including but not limited to the proliferation of AI/LLM applications in data)

## Levels

### Data Analyst Intern

An intern is not required to meet the base Data Analyst responsibilities and requirements, but is required to be interested in developing in towards them.
An intern must:

- Have a track record of asking hard questions and thinking critically
- Self-starter committed to remote work and its intricacies
- Proactive, positive, energetic, customer service personality
- Ability to articulate in a clear, concise manner, disseminating complete and accurate information
- Ability to deal effectively with people of multi-cultural societies
- Attention to detail
- Organizational skills

#### What you'll do

- Work with and learn from a talented team of data professionals
- Develop and execute a project with the help of a mentor
- Update the handbook using git and GitLab
- Identify Data team process weaknesses and blind spots
- Contribute fresh perspective and speak up where you can add value
- Summarize and present your learnings in an end-of-internship summary

### Junior Data Analyst

The Junior Data Analyst reports to the [Manager, Data.](/job-families/marketing/enterprise-data/manager-data)

#### Junior Data Analyst Job Grade

The Junior Data Analyst is a [grade 5](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Junior Data Analyst Responsibilities

The responsibilities of the Junior Data Analyst are listed in the Responsibilities section above.

#### Junior Data Analyst Requirements

The Junior Data Analyst Requirements extend the Requirements section above and include:

- 1+ years experience in an analytics role or equivalent experience/training

### Data Analyst (Intermediate)

The Data Analyst (Intermediate) reports to the [Manager, Data.](/job-families/marketing/enterprise-data/manager-data)

#### Data Analyst (Intermediate) Job Grade

The Data Analyst (Intermediate) is a [grade 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Data Analyst (Intermediate) Responsibilities

The responsibilities of the Data Analyst extend the Junior Data Analyst role and include:

- Serve as a Subject Matter Expert (SME) in one or more business domain areas (i.e. customer intelligence, sales pipeline, product usage, etc.)
- Serve as a Subject Matter Expert (SME) for data visualization and analysis, providing support to other GitLab analysts through code reviews, pairing, and knowledge sharing to help maximize the effectiveness of analyses and reports across the enterprise
- Act as a reviewer / approver for updates to enterprise data model and dashboards, with a comprehensive understanding of the impact of those changes
- Understanding of, and targeted experimentation with, new technologies in the analytics space

#### Data Analyst (Intermediate) Requirements

The requirements of the Data Analyst extend the Junior Data Analyst role and include:

- 2+ years experience in an analytics role or equivalent experience/training
- Demonstrated analytical experience with one or more of the following business subject areas: marketing, finance, sales, product, customer success, customer support, engineering, or people
- Demonstrated ability to make significant contributions to data & analytics projects at every stage, from initial requirement gathering to final insight delivery.

### Senior Data Analyst

The Senior Data Analyst reports to the [Manager, Data.](/job-families/marketing/enterprise-data/manager-data)

#### Senior Data Analyst Job Grade

The Senior Data Analyst is a [grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Senior Data Analyst Responsibilities

The responsibilities of the Senior Data Analyst extend the Data Analyst (Intermediate) role and include:

- Build close relationships with functional teams to truly democratize data understanding and access
- Solve technical/business problems of medium scope, ambiguity, and/or complexity
- Influence the long-range strategy and goals of the Analytics team
- Advocate for improvements to data quality, security, and performance across the data lifecycle
- Develop a deep understanding of data domain(s) to drive innovation and to proactively spot inconsistencies and edge cases
- Provide mentorship for Junior and Intermediate members of the team to help them grow in their responsibilities

#### Senior Data Analyst Requirements

The requirements of the Senior Data Analyst extend the Data Analyst (Intermediate) role and include:

- 6+ years experience in an analytics role or equivalent experience/training
- Fluent in all Data Analysis technologies defined in the [Data Team Platform](/handbook/enterprise-data/platform/)
- Recognized expert in SQL, Data Visualization and Business Intelligence
- Demonstrated ability to lead projects at every stage, from initial requirement gathering to final insight delivery, with minimal oversight/support

### Staff Data Analyst

The Staff Data Analyst reports to the [Manager, Data.](/job-families/marketing/enterprise-data/manager-data)

#### Staff Data Analyst Job Grade

The Senior Data Analyst is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades) and is equivalent to the [Manager,Data (Intermediate)](/job-families/marketing/enterprise-data/manager-data/#manager-data-intermediate) job grade.

#### Staff Data Analyst Responsibilities

The responsibilities of the Staff Data Analyst extend the Senior Data Analyst role and include:

- Help promote data innovation across GitLab with a willingness to experiment and to confront hard and complex problems
- Identify and resolve impediments to efficiency and enable the entire Data Program to iterate faster
- Solve technical/business problems that are high in scope, ambiguity, and/or complexity
- Understand broader trends in the Data Analytics industry (including but not limited to the proliferation of AI/LLM applications in data as one example) and at GitLab, and use them to inform the strategy and goals of the Data Team
- Provide mentorship for analysts across GitLab to help them grow in their business and technical capabilities, remove blockers to their autonomy, and share knowledge across the organization
- Create training guides, blog posts, templates, and recorded training sessions to help all at GitLab understand how to accurately view data, use data for insights, and the implications of data-driven analysis in conjunction with legal and security concerns
- Have the business context and foresight to anticipate analytical reporting needs for strategic business initiatives and evolving priorities
- Help contribute to the success of the department by creating a healthy culture of feedback, transparent discourse, and psychological safety

#### Staff Data Analyst Requirements

The requirements of the Staff Data Analyst extend the Senior Data Analyst role and include:

- 8+ years experience in an analytics role or equivalent experience/training
- Fluency in all major technologies in the [Data Team Platform](/handbook/enterprise-data/platform/), with a particular emphasis on driving Data Visualization, Business Intelligence and understanding/contributing to Data Modeling
- Influence on the long-term planning and roadmap for the Enterprise Data Team
- Demonstrated ability to propose, champion, and lead end-to-end projects that are high in complexity and broad in scope with minimal oversight/support

## Specialties

### Business Intelligence (BI) Platform Team

- Configure, administer, and troubleshoot our Tableau Cloud environment to achieve high reliability, availability, and performance
- Create and maintain documentation, standards, and policies for the form, structure, and attributes of the BI applications and products
- Provide first-line technical support to the Tableau user community at GitLab: triaging issues, troubleshooting, and resolving questions
- Partner with other members of the Enterprise Data team to develop and conduct training that will enable the internal community of Tableau developers and users
- Collaborate with analytics teams across the enterprise to recommend and implement best practices that will optimize the performance of our Tableau environment/workbooks, drive user adoption, and increase user engagement
- Design and manage Tableau processes to minimize friction in the user experience and support single source of truth reporting (i.e. processes related to dashboard publication, curation, archival, and management)
- Report on and optimize Tableau statistics for performance and usage
- Perform and streamline user provisioning, user permissioning, and system account management

## Performance Indicators (PI)

As with other job families in the Enterprise Data team, Data Analysts are evaluated on contributions to the four [Data Team Impact Dimensions](/handbook/enterprise-data/#how-we-measure-impact):

- Data Platform Stability
- Data Quality & Governance
- Data Adoption
- Revenue/Efficiency Impact

### Career Ladder

The next step in the Data Analyst job family is to move to the [Data Management](/job-families/marketing/enterprise-data/manager-data/) job family.

## Hiring Process

- Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process. To learn more about someone who may be conducting the interview, find their job title on our team page.

- Selected candidates will be invited to fill out a short questionnaire.
- Next, candidates will be invited to schedule a screening call with our Global Recruiters
- Next, candidates will be invited to schedule a first interview with a leader from the Data team
- Next, candidates will be invited to schedule individual interviews with each of the following: a Data team member, a business division team member, and an executive leader

Additional details about our process can be found on our [hiring page](/handbook/hiring/).
