---
title: "Data and Insights Executive"
---

The Data job family comprises executive-level roles dedicated to delivering a resilient data platform infrastructure, data-driven insights, data governance, data quality, and innovative data science products to empower informed decision-making and drive business success. These executives lead data teams focused on collaborating on cross-functional initiatives like top-priority projects or Go-to-Market challenges that thrive on data-driven solutions.

Their mandate includes driving company results by cultivating trusted, reliable, and innovative data products, Single Sources of Truth (SSOTs), and insights wherever and whenever needed. They strive to minimize the time from question to insight to action, enabling team members to work more efficiently by implementing streamlined processes, developing SSOTs, and facilitating self-service analytics.

Moreover, they focus on building and maintaining secure, efficient, and reliable data systems, ensuring data integrity, consistency, accuracy, and security through established policies and processes. Transforming raw data into clean, structured, and usable formats for data decision-making is a key priority, utilizing advanced analytics and machine learning techniques to gain insights into customer behavior and company performance. Additionally, they prioritize data governance and data quality initiatives to ensure that data across the organization meets the highest standards of reliability and accuracy.

## Director, Data and Insights

The director of data and analytics is an organizational leader with a passion for data and analysis who has a clear vision for how data can transform company strategy. The role requires hands on leadership necessary to grow a team through the start up phase into a mature organization. The director of data and analytics is responsible for scaling the data function in an environment based primarily on cloud based SaaS systems.  The director must consider global operations and be able to manage a remote, geographically dispersed team. The director ensures that the organization always approaches work with the goal of continuous improvement.

### Job Grade

The Director, Data and Insights is a [grade 10](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Responsibilities

1. Drive the scope and effectiveness of the data and analysis function at GitLab.
1. Ensure the Company's cloud and on-premise data that is centralized into a single data lake is modeled to support data analysis requirements from all functional groups of the Company.
1. Create a common data framework so that all company data can be analyzed in a unified manner.
1. Work with the product, operations, and executive management teams to create a data enabled user journey.
1. Create and execute a plan to develop and mature our ability to measure and optimize usage growth, mapped to our user journey.
1. Ensure that production data adheres to a unified data model.
1. Develop a roadmap for the data and analytics function that clearly defines ownership and responsibility between the central data function and the functional groups.
1. Collaborate with all functions of the company to ensure data needs are addressed and the required data is modeled and available to analysts and end-users.
1. Build a multi-modal service model that meets the non-homogeneous needs of our functional groups -- Full-service to Self-Service, and across our data stack.
1. Work with product, operations and executive management to guide maintain a holistic vision of the future of data at GitLab, and help leadership plan for any changes in our data strategy or needs. An example is in-product analytics.
1. This position reports directly to the VP of Data and works closely with the executive team to develop an organization plan that addresses company wide analytic resources in either a direct report or matrix model.

### Requirements

1. Postgraduate work or equivalent experience (Masters or PhD) in a quantitative field such as math, physics, computer science, statistics etc.
1. Minimum of 7 years experience in a senior leadership position managing an analytics team.
1. Experience with a high growth company using on-premise tools and on-demand (SaaS) transactional systems.
1. Hands on experience with Python, SQL and relational databases. Experience with Snowflake is a plus.
1. Have previously lead a corporate data platform project.
1. Experience with open source data & analytics tools.
1. Experience working with multiple executive level business stake holders.
1. Must have experience with analytic and data visualization tools such as Tableau.
1. Share and work in accordance with our values.
1. Must be able to work in alignment with Americas timezones.
1. Ability to use GitLab

## Director, Data Platform

The director of data platform will be responsible for overseeing the development and management of scalable and efficient data platform and enabling seamless and secure integrations of diverse data sources. By collaborating across functional teams internally and with partners externally, the director of data platform will identify and prioritize long term strategic key areas of improvement, focus on reducing security and compliance risk, and drive continuous advancements in our data platforms.

### Job Grade

The Director, data platform is a [grade 10](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Responsibilities

1. Drive the scope and effectiveness of the data and analysis function at GitLab.
1. Ensure the Company's cloud and on-premise data is centralized into a single data platform.
1. Create a common data framework so that all company data can be analyzed in a unified manner.
1. Ensure that all transactional systems can communicate with the data platform.
1. Develop a roadmap for the data and analytics function that clearly defines ownership and responsibility between the central data function and the functional groups.
1. Carries the responsibility to keep all components in the data platform up to the latest standards.
1. Sets data architectural standards.
1. Manage budget for tooling used inside the data platform.
1. Keeps up to data with the latests trends and technologies by building up relationship with external stakeholders and proactively advices Data Leadership team on strategic directions.
1. This position reports directly to the VP of Data and works closely with the executive team to develop an organization plan that addresses company wide analytic resources in either a direct report or matrix model.

### Requirements

1. Postgraduate work or equivalent experience (Masters or PhD) in a quantitative field such as math, physics, computer science, statistics etc.
1. Minimum of 7 years experience in a senior leadership position managing an analytics team.
1. Experience with a high growth company using on-premise tools and on-demand (SaaS) transactional systems.
1. Hands on experience with Python, SQL and relational databases. Experience with Snowflake is a plus.
1. Have previously lead a corporate data platform project.
1. Experience with open source data & analytics tools.
1. Experience working with multiple executive level business stake holders.
1. Must have experience with analytic and data visualization tools such as Tableau.
1. Share and work in accordance with our values.
1. Must be able to work in alignment with Americas timezones.
1. Ability to use GitLab.

## Director, Data Governance and Quality

The Director, Data Governance and Quality is responsible for implementing and maintaining robust data governance frameworks and ensuring the highest standards of data quality across the organization. They work closely with cross-functional teams to develop and enforce data policies, procedures, and standards, as well as establish metrics and processes for monitoring and improving data quality.

### Job Grade

The Director, Data Governance and Quality is a [grade 10](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Responsibilities

1. Develop and implement data governance policies, procedures, and standards to ensure the accuracy, consistency, and integrity of data across the organization.
1. Collaborate with cross-functional teams to define data ownership, stewardship, and accountability roles and responsibilities.
1. Establish data quality metrics, thresholds, and processes to monitor and measure data quality, and develop strategies for continuous improvement.
1. Conduct data quality assessments and audits to identify issues, root causes, and areas for improvement, and implement corrective actions as needed.
1. Work with IT teams to implement data quality tools and solutions, and provide training and support to users on data governance and quality best practices.
1. Develop and maintain data dictionaries, metadata repositories, and data lineage documentation to support data governance and compliance efforts.
1. Ensure compliance with data privacy regulations and policies, such as GDPR and CCPA, and collaborate with legal and compliance teams to address data privacy risks and issues.
1. Stay up-to-date on industry trends and best practices in data governance, quality management, and data privacy, and recommend and implement enhancements to the data governance framework as needed.

### Requirements

1. Postgraduate work or equivalent experience (Masters or PhD) in a quantitative field such as math, physics, computer science, statistics etc.
1. Minimum of 7 years experience in a senior leadership position managing data governance and quality teams.
1. Experience with a high growth company using on-premise tools and on-demand (SaaS) transactional systems.
1. Strong understanding of data governance principles, practices, and frameworks, such as DAMA-DMBOK or COBIT.
1. Experience developing and implementing data governance policies, procedures, and standards and the ability to translate and implement this in a Data-Ops/ML-Ops environment.
1. Proficiency in data quality assessment methodologies and tools, and experience conducting data quality audits and assessments.
1. Familiarity with data privacy regulations and compliance requirements, such as GDPR, CCPA, and HIPAA.
1. Excellent analytical, problem-solving, and communication skills, with the ability to collaborate effectively with cross-functional teams.
1. Experience working with data management tools and technologies, such as data governance platforms, metadata management tools, and data quality tools in a modern data tech stack environment.
1. Strong attention to detail and ability to prioritize and manage multiple tasks and projects simultaneously.
1. Experience working with multiple executive level business stakeholders.
1. Share and work in accordance with our values.
1. Must be able to work in alignment with Americas timezones.

## Senior Director, Data and Insights

### Job Grade

The Senior Director, Data and Insights is a [grade 11](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Responsibilites

- **Leadership**: Set the vision, hire, build, coach and manage a highly productive team of analytics professionals and data scientists. Expert management skills, especially at developing talent. Set goals and priorities for the team.
- **Results**: Deliver analysis and scientific data to answer GitLab's toughest analytical questions. Turn those answers into actionable operational results to drive ARR in the business. Ask the right questions to help leaders think through tough business challenges that can be solved with data.
- **Stakeholder Management**: Ensure there is alignment with stakeholders, including success and failure criteria of projects, operational resources to operationalize data products.
- **Communication**: Prepare and review visualizations of all types of data to promote internal understanding of your team's insights. Expert influencer to our executive team. Clearly articulate insights.
- **Data Science Modeling**: Design, implement and apply analytics techniques (e.g., optimization, machine learning, experimentation, mathematical modeling) using analytical tools and programming languages (e.g., R, Python, SAS). Be comfortable with a boring solution such as a heuristic when it helps drive the insight.
- **Data Driven Insights and Analysis**: Summarize key data driven insights to members of the executive team to drive better outcomes, an increase in revenue or decrease in cost. Provide insights across the company.
- **Review**: Review work and analysis produced by the team you manage or from other members of the team. Expert at providing feedback.
- **Contribute**: Be customer zero for our product teams as they design the MLOps and Product Analytics product areas. Discover data gaps and provide requirements to the Data team and to product management for the proper logging and data repositories.
- **Values**: Be a culture definer and evolver of GitLab Values.

### Requirements

- Leadership: Experience leading data science and analytics team with a track record of delivering measurable business results with your team's insights and data products
- Business Partnership: Consistent track record of using quantitative analysis to impact key business decisions in partnership with the business.
- Communication: Ability to present financial data concisely through written and oral communication. Expert at influencing business stakeholders.
- Data Analysis: A passion for understanding business questions and making data driven insights. Excellent analytical skills.
- Proficient in SQL; R, Python preferred.
-Experience with results in a SaaS, software business.
- A/B Testing experience: experience designing and executing A/B tests in collaboration with sales, growth or product teams.
- BS degree in Mathematics, Engineering, Statistics or relevant degree. MBA preferred.
- Ability to use GitLab.

## VP, Data and Insights

### Job Grade

The VP, Data and Insights is a [grade 12](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Responsibilities

- Extends Sr Director Data and Insights responsibilities
- Leads data engineering function including data platform tool selection, data models and scalable data solutions
- Develop a roadmap for the data and analytics function that clearly defines ownership and responsibility between the central data function and the functional groups.
- Drive data governance and data quality throughout GitLab
- Hold Engineering accountable for SLAs for data freshness and quality of product logging
- Expectations of transformational data solutions that fundamentally changes the way GitLab does business increasing ARR and efficiency.
- Transform the culture around data driven decision making at GitLab across all teams.
- As MLOps and Product Analytics capabilities evolve, participate in Sales and Marketing efforts.
- Have complete ownership of all VP+ level relationships required to meet team objectives and business impact.

### Requirements

- Extends Sr Director Data and Insights requirements
- Experience driving company wide changes to company operations and analytics strategy.

## Performance Indicators (PI)

- TBD

### Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process. To learn more about someone who may be conducting the interview, find their job title on our team page.

1. Selected candidates will be invited to schedule a screening call with our Global Recruiters
1. Next, candidates will be invited to schedule a first interview with our VP, Finance and Business Technology
1. Candidates will then be invited to schedule a second round of interviews with members of the e-group, finance, data and sales strategy teams.
Additional details about our process can be found on our hiring page.

### Career Ladder

The next step is not defined.
