---
title: Data Science
---

The [Data Science program](/handbook/enterprise-data/organization/data-science/) at GitLab focuses on supporting internal teams and developing model-based insights to help us understand our business, customers, and product better. Data Scientists work across the entire development lifecycle, from inception to final delivery. As a result of helping GitLab understand major trends across our business, Data Scientists make significant strategic contributions to new and existing business initiatives.

Data Scientists work with peers on the Data Team and functional teams to:

- perform ad-hoc exploratory analysis
- solve well-defined business problems
- regularly measure and improve analytics initiatives
- create and maintain production models and related applications

Example Data Science projects include:

- account scoring
- propensity to buy
- customer segmentation
- sentiment analysis
- customer churn and uplift prediction
- hypothesis testing and forecasting

Data Scientists are a part of the [Data Team](/handbook/enterprise-data/) and report to the [Director/ Sr. Director, Data & Analytics](/job-families/marketing/enterprise-data/data-and-insights-executive/).

## Job Grades

Read more about GitLab [Job Grades](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Data Scientist (Intermediate)

#### Data Scientist (Intermediate) Job Grade

The Data Scientist (Intermediate)  is a [grade 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Data Scientist (Intermediate) Responsibilities

- Communicate with business partners to understand their needs to help develop new strategic insights
- Define, collaborate, and communicate key influences, levers, and impacts to non-technical audiences
- Perform exploratory data analysis to understand ecosystems, behavioral trends, and long-term trends
- Build machine learning models (training, validation, and testing) with appropriate solutions for data reduction, sampling, feature selection, and feature engineering
- Design and evaluate experiments (including hypothesis testing) by creating key data sets
- Apply data mining or NLP techniques to cleanse and prepare large data sets
- Help grow the Data Science function by defining and socializing best practices, particularly within a [DataOps](https://en.wikipedia.org/wiki/DataOps) and [MLOps](https://en.wikipedia.org/wiki/MLOps) data ecosystem
- Craft code that meets our internal standards for style, maintainability, and best practices for a high-scale database environment. Maintain and advocate for these standards through code review
- Document every action in either issue/MR templates, the [handbook](/handbook/), or READMEs so your learnings turn into repeatable actions and then into automation following the GitLab tradition of [handbook first!](/handbook/about/handbook-usage/#why-handbook-first)

#### Data Scientist (Intermediate) Requirements

- Ability to use GitLab
- 4+ years professional experience in an analytics role OR 2+ years professional experience in a predictive analytics, data science, or similar role
- Developed 2 or more automated machine learning models for production use
- Developed and presented 4 or more predictive analytical projects
- Familiarity with the [CRISP-DM](https://en.wikipedia.org/wiki/Cross-industry_standard_process_for_data_mining) analytics development model
- Experience working with a variety of statistical and machine learning methods (time series analysis, regression, classification, clustering, survival analysis, etc)
- Professional experience with python, including python data libraries (numpy, pandas, matplotlib, scikit-learn), or R
- Deep understanding of SQL in data warehouses (we use Snowflake SQL) and in business intelligence tools (we use Sisense for Cloud Data Teams)
- Working knowledge of statistics
- Comfort working in a highly agile, [intensely iterative](/handbook/values/#iteration) environment
- Positive and solution-oriented mindset
- Effective communication skills: Regularly achieve consensus with peers, and clear status updates
- Experience owning a project from concept to production, including proposal, discussion, and final delivery
- [Self-motivated and self-managing](/handbook/values/#efficiency), with excellent organizational skills
- Share our values, and work in accordance with those values
- Ability to thrive in a fully remote organization

#### Data Scientist (Intermediate) Performance Indicators

- Number of Models Operationalized
- Number of Strategic Insights Discovered ([Data Value Calculator](/handbook/enterprise-data/how-we-work/#data-team-value-calculator) score 2 or higher)
- Business Partner Customer Satisfaction Score ([CSAT](https://en.wikipedia.org/wiki/Customer_satisfaction))
- Merge Request Rate

## Career Ladder

The next step in the  Data Scientist job family is to move to Senior Data Scientist.

### Senior Data Scientist

#### Job Grade

The Senior Data Scientist is a [grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Responsibilities

The Senior Data Scientist has all of the responsibilities of an Intermediate Data Scientist, plus:

- Improve predictive models with data from multiple sources
- Automate feedback loops for algorithms/models in production
- Create repeatable processes and scalable data products
- Influence functional teams and develop best practices across the organization
- Review, scale, and enhance operationalized statistical models and algorithms

#### Requirements

The Senior Data Scientist meets all of the requirements of an Intermediate Data Scientist, plus:

- 6+ years professional experience in an analytics role OR 4+ years professional experience in a predictive analytics, data science, or similar role
- Developed 4 or more automated machine learning models for production use
- Developed and presented 6 or more predictive analytical projects
- Developed communication skills with ability to explain statistic and mathematical concepts to non-experts
- Extensive knowledge, application, and experience in creating and implementing recommendation systems, machine learning, NLP, statistics, and deep learning
- Ability to quantify improvements from business efficiency or customer experience based on research outcomes

#### Senior Data Scientist Performance Indicators

- Number of Models Operationalized
- Number of Strategic Insights Discovered ([Data Value Calculator](/handbook/enterprise-data/how-we-work/#data-team-value-calculator) score 3 or higher)
- Business Partner Customer Satisfaction Score ([CSAT](https://en.wikipedia.org/wiki/Customer_satisfaction))
- Merge Request Rate

### Staff Data Scientist

#### Job Grade

The Staff Data Scientist is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Responsibilities

The Staff Data Scientist has all of the responsibilities of a Senior Data Scientist, plus:

- Focus on strategic business impact through activation of Data Product use cases
- Coordinate with a cross-functional group of team members to effect change
- Develop a technical data science team vision and strategy
- Review, scale, and enhance operationalized statistical models and algorithms
- Mentor data scientists and data analysts

#### Requirements

The Staff Data Scientist meets all of the requirements of a Senior Data Scientist, plus:

- 5+ years professional experience in a predictive analytics, data science, or similar role
- Knowledge and experience automating machine learning models at scale
- Expertise solving complex and highly impactful quantitative business problems
- Demonstrated proficiency with python (pandas, numpy, etc.), SQL, and cloud environments
- Expert understanding of statistics and the math behind data science algorithms
- Identify and spearhead new data science initiatives, projects, and collaborations that improve results
- Willingness to experiment and to confront the hardest or most complex problems

#### Staff Data Scientist Performance Indicators

- Number of Data Products Released
- Number of Use Cases Activated
- Measurable $ARR Impact (New Business, Cost Savings, or Efficiency Improvement)

### Principal Data Scientist

#### Job Grade

The Principal Data Scientist is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Responsibilities

The Principal Data Scientist has all of the responsibilities of an Staff Data Scientist, plus:

- Assist management with project forecasting, roadmapping, and resourcing
- Lead major strategic data science projects and initiatives, spanning 6 months or more
- Attain a measurable positive impact on the performance of multiple team members and teams
- Regularly participates in the Data Community/Industry outside of GitLab through writing, speaking, and networking

#### Requirements

The Principal Data Scientist meets all of the requirements of an Staff Data Scientist, plus:

- 8+ years professional experience in a predictive analytics, data science, or similar role
- Experience leading strategic projects and large initiatives spanning multiple teams, people, and roles
- Demonstrated track record of forming effective cross-functional partnerships; desire to work collaboratively and in a diverse team
- Stays current on the state of data science research, processes, tools, and algorithms
- Recognized as a leader in the Data Science space across the company

#### Principal Data Scientist Performance Indicators

- $ARR Impact (New Business, Cost Savings, or Efficiency Improvement)
- Number of Business Functions which achieve Level 4 of the [Data Capability Model](/handbook/enterprise-data/direction/#data-capability-model)
- E-Group Customer Satisfaction Score ([CSAT](https://en.wikipedia.org/wiki/Customer_satisfaction)) of 4 or higher

## Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process.

- Selected candidates will be invited to fill out a short questionnaire.
- Qualified candidates will be invited to schedule a 30 minute [screening call](/handbook/hiring/candidate-faq/#screening-call) with one of our Global Recruiters.
- Next, candidates will be invited to schedule an interview with a member from our Data Science team
- Next, candidates will be invited to schedule an interview with a member from our Data team
- Next, candidates will be invited to schedule an interview with the business division DRI
- Next, candidates will be invited to schedule an interview with the Senior Director, Data and Analytics

## Specialties

### Full Stack Data Scientist

#### Full Stack Data Scientist Description

Full Stack Data Scientist is a hybrid position between [Data Scientist](/job-families/marketing/enterprise-data/data-science/) and [Analytics Engineer](/job-families/marketing/enterprise-data/analytics-engineer/)

In order for the Data Science team to scale and be successful, we need to develop and promote skills of Analytics Engineers on the team to deliver predictive models faster and more accurately. Full Stack Data Scientist will perform duties of Data Scientist by building predictive models, but also be responsible for backend to ensure smooth delivery.

The job description of this specialization include all of the resposibilities for the **Data Scientist** role. In addition, resposibilities for the specialization include:

- Collaborate with team members to collect business requirements, define successful analytics outcomes, and design data models to support data science projects
- Build trust in all interactions and with Trusted Data Development to expand data science capabilities
- Serve as the Directly Responsible Individual for major sections of the Enterprise Dimensional Model and data science models
- Design, develop, and extend dbt code to feed and automate predictive models

#### Full Stack Data Scientist Requirements

The job requirements of this specialization include all of the requirements for the **Data Scientist** role. In addition, requirements for the specialization include:

- Demonstrated experience with one or more of the following business subject areas: marketing, finance, sales, product, customer success, customer support, engineering, or people
- 2+ years experience designing, implementing, operating, and extending commercial Kimball enterprise dimensional models
- 2+ years working with a large-scale (1B+ Rows) Data Warehouse, preferably in a cloud environment
- 2+ years experience building reports and dashboards in a data visualization tool

Additional details about our process can be found on our [hiring page](/handbook/hiring/).
