---
title: "Data Management"
---

The Manager, Data is responsible for delivering trusted data and analytics results to help GitLab make better and faster decisions by creating, developing, and leading a [high-performance](/handbook/people-group/learning-and-development/manager-development/high-performing-teams/) Team and continually improving the Data Platform along the [Data Capability Model](/handbook/enterprise-data/direction/#data-capability-model).
The Manager, Data possesses a broad range of people skills and technical skills across the Data domain, as well as business acumen required to establish trusted partnerships with people inside and outside of GitLab.
The Manager, Data reports to the [Director/Senior Director, Data and Analytics](/job-families/marketing/enterprise-data/data-and-insights-executive/#director-data-and-insights).

## Levels

### Manager, Data (Intermediate)

The Manager, Data may report to the [Senior Manager, Data](/job-families/marketing/enterprise-data/manager-data/#senior-manager-data) or to the [Director/Senior Director, Data and Analytics](/job-families/marketing/enterprise-data/data-and-insights-executive/#director-data-and-insights).

#### Job Grade

The Manager, Data is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Responsibilities

- Help create a leading Data Program to support GitLab's [vision](/handbook/company/vision/#vision)
- Manage, lead, and develop a [High-Performance](/handbook/people-group/learning-and-development/manager-development/high-performing-teams/) Team, including day-to-day assignments, bi-weekly milestone planning, [1-1s](/handbook/leadership/1-1/), quarterly objectives, and annual reviews
- Manage operational components of the [Data Platform](/handbook/enterprise-data/platform/infrastructure/) to ensure updated data are available per [established SLOs](/handbook/enterprise-data/platform)
- Work with all divisions to continually grow the value of our Data Platform by [onobarding new data](/handbook/enterprise-data/platform) from our SaaS, Telemetry, Product, and Corporate systems
- Understand the big picture and demonstrate how your team supports it through prioritization, planning, and solutioning
- Participate in [Monthly Key Reviews](/handbook/company/key-review/) to represent Data and stay up-to-date of company developments
- Implement the [DataOps](https://en.wikipedia.org/wiki/DataOps) philosophy in everything you do
- Continuously develop the [Data Team Handbook](/handbook/enterprise-data/) to ensure it represents the current state of our strategy, processes, and operations

#### Requirements

- Ability to use GitLab
- [Leadership at GitLab](/handbook/company/structure/#management-group)
- Share [our values](/handbook/values/), and work in accordance with those values
- 5+ years hands on experience in a data analytics/engineering/science role
- 2+ years hands on experience performing quantitative analysis to tackle business problems with a focus on feature and usage metrics to increase conversion and retention OR reporting for key business metrics, including revenue, sales metrics, and customer metrics
- 1+ years hands on experience creating dimensional models composed of facts and dimensions
- 1+ years leading or managing a team of 3 or more data analysts/engineers/scientists
- Demonstrate ability to understand and communicate end-to-end data systems: from compute to ETL to Reporting to Analysis
- Exceptional experience creating and developing partnerships with internal team members towards delivery of impactful analytics solutions
- Experience communicating technical concepts to non-technical team members
- Experience defining and executing project plans at the day, week, and month time spans
- Ability to break-down quarterly objectives into two-week delivery milestones
- Demonstrably deep understanding of SQL and relational databases (we use Snowflake)
- Experience working with large quantities of raw, disorganized data
- Must be able to work in alignment with Americas timezones

#### Performance Indicators (PI)

- [SLO Achievement](https://internal.gitlab.com/handbook/it/it-performance-indicators/#slo-achievement-per-data-source) for Tier 1 Data
- Data Platform Performance and Security Audits
- Contributions to the four [Data Team Impact Dimensions](/handbook/enterprise-data/#how-we-measure-impact)
    1. Data Platform Stability
    1. Data Quality & Governance
    1. Data Adoption
    1. Revenue/Efficiency Impact

### Senior Manager, Data

#### Senior Manager, Data Job Grade

The Senior Manager, Data is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Senior Manager, Data Responsibilities

- Extends the Manager, Data responsibilities
- Envision and draft [Quarterly Objectives](/handbook/company/okrs/), driven by requirements gathered from multiple business partners
- Regularly meet with business partners, understanding and solving for Data needs, short-term and medium-term
- Monitor, Measure, and Improve key aspects of the Data Program and Data Platform, guided by established KPIs and SLOs
- Coordinate with Security and Compliance to ensure Data is accessed, processed, and stored per standards
- Propose and define strategies to continually improve the scale, performance, and capabilities of the Data Platform
- Develop partnerships with external vendors and technology suppliers to ensure delivery of high-quality services
- Manage technology expenses per an established Fiscal Budget

#### Senior Manager, Data Requirements

- Extends the Manager, Data requirements
- 4+ years managing a team of 6 or more data analysts/engineers/scientists
- 2+ years managing a team consisting of principal/staff/lead level team members
- 6+ experiences with team member career development including reviews, promotions, demotions, and performance improvement
- Experience working with management to define and measure KPIs and other operating metrics
- Experience creating and delivering multi-quarter roadmaps
- Ability to clearly articulate vision, mission, and objectives, and change the narrative appropriate to the audience
- Experience developing a team in a fast-paced, high-growth environment
- Familiarity with data management policies and regulations (GDPR, SOX, PCI)

#### Performance Indicators (PI)

- [SLO Achievement](https://internal.gitlab.com/handbook/it/it-performance-indicators/#slo-achievement-per-data-source) for Tier 1 Data
- Data Platform Performance and Security Audits
- Contributions to the four [Data Team Impact Dimensions](/handbook/enterprise-data/#how-we-measure-impact)
    1. Data Platform Stability
    1. Data Quality & Governance
    1. Data Adoption
    1. Revenue/Efficiency Impact

## Career Ladder

The next step in the Data Management job family is to move to the [Director of Data](/job-families/marketing/enterprise-data/data-and-insights-executive/) job family.

## Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process. To learn more about someone who may be conducting the interview, find their job title on our [team page](/handbook/company/team/).

- Selected candidates will be invited to schedule a [screening call](/handbook/hiring/candidate-faq/#screening-call) with our Global Recruiters
- Next, candidates will be invited to schedule a first interview with our Director of Data & Analytics
- Next, candidates will be invited to schedule one or more interviews with members of the Data Team
- Next, candidates will be invited to schedule one or more interviews with Business Partners
- Finally, candidates may be asked to interview with our VP, IT or similar

## Specialties

### Data Science

#### Manager, Data Science Description

The [Data Science Team](/handbook/enterprise-data/organization/data-science/) closely partners with various teams across GitLab to facilitate making better decisions faster using predictive analytics.

The job description of this specialization include all of the resposibilities for the **Manager, Data** role. In addition, resposibilities for the specialization include:

- This is a hands-on role and requires significant experience as a Data Science Individual Contributor
- Define, collaborate, and communicate key influences, levers, and impacts to non-technical audiences
- Perform exploratory data analysis to understand ecosystems, behavioral trends, and long-term trends
- Build machine learning models (training, validation, and testing) with appropriate solutions for data reduction, sampling, feature selection, and feature engineering

#### Manager, Data Science Requirements

The job requirements of this specialization include all of the requirements for the **Manager, Data** role. In addition, requirements for the specialization include:

- Ability to make decisions regarding the direction of the project based on amount and quality of data
- Experience leading end-to-end data science projects, starting with requirements gathering, to data extraction, to building models and translating outcomes to stakeholders
- Ability to use Python for analysing, visualising data and building models
- Assigning tasks across team and advising team members on how to get to expected outcomes including improving performance of models
- Ability to translate model outcomes to prescriptive, predictive and descriptive solutions and lead others on how to do it

### Data Platform

#### Manager, Data Platform Description

The [Data Platform Team](/handbook/enterprise-data/platform) closely partners with various teams across GitLab to facilitate making better decisions faster by developing and maintaining a Big Data Platform.

The job description of this specialization include all of the responsibilities for the **Manager, Data** role. In addition, responsibilities for the specialization include:

#### Manager, Data Platform Responsibilities

- Define, collaborate, and communicate key influences and impacts to technical and non-technical audiences
- Plan and prioritize projects and work amongst stakeholders throughout the organization and Data Platform Team members
- Assigning tasks across team and advising team members on how to get to expected outcomes including data architecture and infrastructural recommendations
- Guide, help and support Data Engineers in their daily job
- Own one or more operational areas of the Data Platform, measuring successful results against established SLOs
- Assigning tasks across the Data Platform Team and advising team members on how to achieve expected results including data architecture and infrastructural recommendations
- Foster collaboration and partnerships with the Data Fusion Team and Data functions accross GitLab

#### Manager, Data Platform Requirements

The job requirements of this specialization include all of the requirements for the **Manager, Data** role. In addition, requirements for the specialization include:

- This is a hands-on role and requires experience as a Data Engineering, Data Infrastructure or Data Architecture Individual Contributor
- Ability to make technical (data, infrastructure or architecture) decisions regarding the direction of the project
- Experience leading end-to-end data projects like adding new data sources, updating core infrastructure and adding new technologies to our modern data stack
- Up to date with technologies and trends in the modern data stack world
- Ability to use SQL for analyzing and visualizing data

Additional details about our process can be found on our [hiring page](/handbook/hiring/).
