---
title: Frontend Engineering - Marketing
description: "Frontend Engineering on the Marketing team work on our marketing site. They work closely with product marketing, content marketing, and other members of the Marketing team."
---

Frontend Engineers on the Marketing team work on our marketing site: about.GitLab.com. They work closely with product marketing, content marketing, and other members of the Marketing team. They are a part of the [Digital Experience team](/handbook/marketing/digital-experience/), and report to the [Director, Digital Experience](/job-families/marketing/digital-experience/#director-of-digital-experience).

## Responsibilities

- Work with the Marketing Strategy and Platforms team and other stakeholders (Content, DemandGen, Brand, etc.) to iterate on new features and improvements to GitLab's digital marketing platform.
- Consistently ship small features and improvements to our [Slippers design system](https://gitlab.com/gitlab-com/marketing/digital-experience/slippers-ui)
- Help improve the overall experience of our Marketing website through improving the quality of the Frontend features.
- Help identify areas of improvements in the code base that help contribute to make it better.
- Help plan sprints and complete prioritized issues from the issue tracker.

## Requirements

- Knowledge of HTML, CSS, HAML and JavaScript (jQuery, Vue.js).
- Experience with responsive design and best practices.
- Knowledge of current web accessibility standards and requirements.
- Knowledge of information architecture, interaction design, and user-centered design.
- Strong knowledge in core web and browser concepts (eg. how the browser parses and constructs a web page).
- Experience with performance and optimization problems and a demonstrated ability to both diagnose and prevent these problems.
- Experience using design software to collaborate with designers and create pixel perfect web pages (eg. Figma, Sketch).
- Experience with Git in a professional/workplace environment, ideally using the GitLab product as a user or contributor.
- The ability to work in an agile, [iterative](/handbook/values/#iteration) development process and embrace feedback from many perspectives.
- Proficiency in the English language, with the capacity to communicate complex technical problems, provide clear status updates, and [achieve consensus with peers](/handbook/values/#collaboration).
- [Self-motivated and self-managing](/handbook/values/#efficiency), with great organizational skills and a positive, solution-oriented mindset.
- An interest in [our values](/handbook/values/), and working in accordance with those values.
- Prefer experience with JAMstack, Ruby, and Middleman (and/or other static site generators).
- Prefer SaaS Product company experience.
- Prefer experience working with a global or otherwise multicultural team.
- Prefer understanding of marketing concepts such as conversion, analytics, A/B testing, lead generation, buyer journeys, and search engine optimization.

## Levels

### Frontend Engineer (Intermediate)

The Frontend Engineer (Intermediate) reports to the [Director, Digital Experience](/job-families/marketing/digital-experience/#director-of-digital-experience).

#### Frontend Engineer (Intermediate) Job Grade

The Frontend Engineer (Intermediate) is a [grade 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Frontend Engineer (Intermediate) Responsibilities

- Partner with team members on the simplest solutions to problems.
- Develop features and enhancements to GitLab's marketing site in a secure, well-tested, and performant way.
- Craft code that meets our internal standards for style, maintainability, and best practices for a high-scale web environment. Maintain and advocate for these standards through code review.

#### Frontend Engineer (Intermediate) Requirements

- 3-5 years experience specializing in frontend development for websites and web applications.

### Senior Frontend Engineer

The Senior Frontend Engineer reports to the Engineering Manager, Digital Experience.

#### Senior Frontend Engineer Job Grade

The Senior Frontend Engineer is a [grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Senior Frontend Engineer Responsibilities

- Code and implement high quality technical and engineering work for complex web projects, including troubleshooting and problem solving, communicating with stakeholders and team members, reporting on outcomes.
- Lead and scope major cross-functional projects; including defining business needs, navigating sometimes conflicting priorities to deliver the best business outcomes and making recommendations on the best course of action.
- Initiate longer-term initiatives that will impact the efficiency of the team, the quality of output and reducing technical debt, including introducing new processes and solutions.
- Mentor more junior teammates on engineering and web development best practices, complex problem solving and modeling stakeholder engagement.
- Provide technical and functional knowledge representing Digital Experience and web development as a subject-matter expert with stakeholders across organizations.

### Senior Frontend Engineer Requirements

- 8-10 years in a Frontend engineering role, 3+ years of web development or engineering experience in a B2B or enterprise software marketing organization
- Advanced technical expertise and proficiency in web development and related web technologies, including HTML, CSS, and JavaScript
- Demonstrated capacity to clearly and concisely communicate about technical, architectural, and/or organizational problems and propose solutions
- Demonstrated ability to solve performance and optimization problems and an orientation to improvement and iteration; modeling a service-focused, solution-oriented mindset
- Proficiency working in a highly agile, [intensely iterative](/handbook/values/#iteration) software development process

### Staff Frontend Engineer

The Staff Frontend Engineer reports to the Engineering Manager, Digital Experience.

#### Staff Frontend Engineer Job Grade

The Staff Frontend Engineer is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Staff Frontend Engineer Responsibilities

- Code and implement high quality technical and engineering work for complex web projects, including troubleshooting and problem solving, communicating with stakeholders and team members, reporting on outcomes.
- Lead and scope major cross-functional projects; including defining business needs, navigating sometimes conflicting priorities to deliver the best business outcomes and making recommendations on the best course of action.
- Initiate longer-term initiatives that will impact the efficiency of the team, the quality of output and reducing technical debt, architectural initiatives and including introducing new processes and solutions.
- Mentor more junior teammates on engineering and web development best practices, documentation, complex problem solving and modeling stakeholder engagement.
- Provide technical and functional knowledge representing Digital Experience and web development as a subject-matter expert with stakeholders across organizations.

### Staff Frontend Engineer Requirements

- 10+ years in a Frontend engineering role, 5+ years of web development or engineering experience in a B2B or enterprise software marketing organization
- Advanced technical expertise and proficiency in web development and related web technologies, including HTML, CSS, and JavaScript
- Experience leading cross-functional initiatives and partnering with stakeholders outside of Engineering, including Marketing, Product and leadership teams
- Demonstrated capacity to clearly and concisely communicate about complex technical, architectural, and/or organizational problems and propose solutions
- Demonstrated ability to pivot from core engineering and coding work, to stakeholder conversations to understand business requirements and needs
- Demonstrated ability to coach team members without direct reporting responsibilities
- Experience with diagnosing and solving performance and optimization problems and an orientation to improvement and iteration; modeling a service-focused, solution-oriented mindset
- Proficient working in a highly agile, [intensely iterative](/handbook/values/#iteration) software development process

### Manager, Engineering

The Manager, Engineering reports to the [Director, Digital Experience](/job-families/marketing/digital-experience/#director-of-digital-experience).

#### Manager, Engineering Job Grade

The Manager, Engineering is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Manager, Engineering Responsibilities

- Lead a high-performing team of engineers to implement and bring GitLab's web strategy to life through quality, on-time coding and development
- Code and implement high quality technical and engineering work for complex web projects, including troubleshooting and problem solving, communicating with stakeholders and team members, reporting on outcomes.
- Lead and scope major cross-functional projects; including defining business needs, navigating sometimes conflicting priorities to deliver the best business outcomes and making recommendations on the best course of action.
- Initiate longer-term initiatives that will impact the efficiency of the team, the quality of output and reducing technical debt, - including introducing new processes and solutions.
- Coach team on engineering and web development best practices, complex problem solving and modeling stakeholder engagement.
- Provide technical and functional knowledge representing Digital Experience and web development as a subject-matter expert with stakeholders across organizations.

#### Manager, Engineering Requirements

- 10+ years in a web development/ engineering role in a B2B or enterprise software marketing organization; 5+ years experience managing a team of engineers
- Advanced technical expertise and proficiency in web development and related web technologies, including HTML, CSS, and JavaScript
- Experience leading cross-functional initiatives and partnering with stakeholders outside of Engineering, including Marketing, Product and leadership teams
- Demonstrated capacity to clearly and concisely communicate about complex technical, architectural, and/or organizational problems and propose solutions
- Demonstrated ability to coach and lead a team of direct reports, including hiring, development and growth  and driving a culture of high performance
- Experience with diagnosing and solving  performance and optimization problems and an orientation to improvement and iteration; modeling a service-focused, solution-oriented mindset
- Experience leading team to work  in a highly agile, [intensely iterative](/handbook/values/#iteration0) software development process

## Nice-to-haves

- You have experience contributing to open source software
- You have experience working with modern frameworks (eg. Vue.js, Nuxt.js, etc.cd S)
- You have working knowledge of Ruby on Rails
- You have domain knowledge relevant to GitLab's Marketing site

## Performance Indicators

- Project planning accuracy, project (on-time) delivery, cycle times
- Lead time on changes
- Velocity
- Quality and reliability, # of incidents
- Time to recover (bugs, errors, code fails)

## Career Ladder

The next step in the Frontend Engineer job family is not yet defined at GitLab.

## Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process. To learn more about someone who may be conducting the interview, you can find their job title on our [team page](/handbook/company/team/).

- Select candidates will be invited to schedule a 30 minute [screening call](/handbook/hiring/#screening-call) with one of our Global Recruiters.
- Next, candidates will be invited to schedule a 30 minute interview with our Director, Digital Experience.
- Next, candidates will be invited to schedule a 30 minute technical interview with our Fullstack Engineer and a Frontend Engineer on the Marketing team.
- Next, candidates will be invited to schedule a 30 minute interview with the Senior Director, Growth Marketing.
- Finally, candidates will be invited to schedule a 30 minute follow up interview with the Director, Digital Experience.

Additional details about our process can be found on our [hiring page](/handbook/hiring/).
