---
title: "Social Media Manager"
description: "Requirements for Social Media roles at GitLab"
twitter_image: ""
twitter_image_alt: ""
twitter_site: "gitlab"
twitter_creator: "gitlab"
---

## Social Media Jobs at GitLab

Social Media requires a balance of work behind each of the two words that make up the practice. *Social*, by building trust with our audiences and connecting as personally as appropriate, and *Media*, by scaling our storytelling efforts to brand-level corporate marketing initiatives.

### The "Social" in Social Media

The world's best brands feel more like a trusted source of information to their audience than a company. They could even develop friendly relationships with their followers. This is because the world's best brands understand people and weave that understanding into everything they do. Social Media at GitLab is a key part of building GitLab's brand into one that is loved by its audience of developers, remote work pros, and IT folks up and down the ladder.

Social Media at GitLab focuses on understanding people who make up the GitLab community, creating and sharing content over social channels that they'll find valuable, and educating team members in marketing and beyond on social media best practices for brands, personalities, and how we measure success.

### The "Media" in Social Media

The world's most renowned brands are perceived to be larger than life. As GitLab scales to new heights, the Social Media team prioritizes opportunities for brand-level storytelling initiatives. By sharing our company values, perspectives on remote work, or leaning into our product's features, we'll help users understand how they feel about GitLab overall.

### You must share our values and work under those values

*A sample of how GitLab's core [values](/handbook/values/) show up in Social Media:*

#### 🤝 Collaboration

Across teams and functions as well as externally with customers, followers, and partners. We are not islands to ourselves and lean on each other to deliver on our work. Do everything as kindly as possible. It's also critical to assume positive intent when working with team members that don't work in social media.

#### 📈 Results

Make a difference in the hours you planned to work and then do it again next week. Use GitLab to manage your work. Own everything you touch and create a bias for action in social media marketing.

#### ⏱️ Efficiency

Go for the boring solutions when we can't recreate the wheel. Search for the answers you seek in our handbook first. Build repeatable projects in a way that lets others service themselves in the next round.

#### 🌐 Diversity, Inclusion & Belonging

Be comfortable or willing to get comfortable with communication with team members asynchronously. Find a way to include your quirkiness in your work. Consider inclusive language and imagery in everything we promote internally and externally.

#### 👣 Iteration

Don't wait to contribute. Just make a change today. Make progress for our work in minimal valuable changes consistently. Remember that all of our work is in draft. We don't do big reveals at GitLab, so be ready to share your rough drafts with everyone throughout the process (This is scary for social media managers, but our team is prepared to help you grow into this practice.)

#### 👁️ Transparency

Everything is public by default, including our typos, bad takes, and iterations. We strive to be transparent as often and as clearly as possible with each other and our community. Always share the *why* and not just the what. We're practitioners and educators.

## Levels

### Social Media Manager

#### Job Grade

The Social Media Manager is a [grade 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades) role.

#### Responsibilities

- Support community management efforts, daily monitoring, and engagement.
- Develop content, including creative assets, working with agencies and the internal creative team.
- Schedule organic social content across channels.
- Work with the team to ensure social amplification and engagement are incorporated as part of integrated campaign strategy and execution.
- Contribute to reporting efforts across campaigns and milestones.
- Support creative community activations.

#### Requirements

- Minimum of 3 years of social media experience, preferably at a high-growth enterprise software company or agency.
- Ability to coordinate with multiple stakeholders, perform in a fast-moving environment, and work on multiple projects simultaneously.
- Experience with UTM tracking URLs, social media management tools like Sprout Social, and employee social advocacy tools.
- General management of the social calendar and crafting social campaigns that will help engage, educate, entertain, inspire, and increase our followers
- Contribute your perspective on what to publish, when, and where in support of campaigns
- Contribute to reporting on OKRs and other metrics
- Attention to detail
- Understanding of how social media, public relations, and content strategies intersect to drive business outcomes.
- Previous experience working in a remote environment.

---

### Senior Social Media Manager

#### Job Grade

The Senior Social Media Manager is a [grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades) role.

#### Responsibilities

- Able to coordinate with multiple stakeholders and perform in a fast-moving environment, and ability to work on multiple projects at a time
- Experience with UTM tracking URLs, social media management tools like Sprout Social, and employee social advocacy tools.
- General management of the social calendar and crafting social campaigns that will help engage, educate, entertain, inspire, and increase our followers
- Contribute your perspective on what to publish, when, and where in support of campaigns
- Contribute to reporting on OKRs and other metrics
- Independently develop and execute social media campaigns
- Articulate and document social media strategy and process in the GitLab handbook
- Staying up-to-date and educating others on current technologies and trends in social media
- Work with an in-house creative team to create engaging assets, sometimes designing quick needs yourself
- Provide insight into navigating communications risks and crises, sometimes executing on this alone

#### Requirements

- At least 3-5 years of experience in a social media role at a high-growth enterprise software company or agency
- Proven experience managing B2B social media channels
- In-depth industry and technical community knowledge
- Proven ability to identify new audiences and channels, create a strategy, and execute the strategy
- Exposure to crisis communications and desire to learn more
- Attention to detail
- Understanding of how social media, public relations, and content strategies intersect to drive business outcomes.
- Previous experience working in a remote environment.

---

### Staff Social Media Manager

Market Justification

- The Staff Social Media Manager role will provide a high level of expertise in solving complex problems with a strong understanding of integrated marketing campaigns, audience, and paid & organic social media strategy.
- Additionally, this role will be key in bridging existing gaps between organic social media efforts and more enterprise integrated digital marketing initiatives, helping to shape GitLab's new digital marketing experience.
- Within public enterprise B2B technology organizations, approximately 1-3 team members exist in similar or the same role(s), particularly as a cross-section between social and digital marketing.

This Staff Social Media Manager role bridges the gap between two functional areas, social media, and digital marketing. The "Manager" designation indicates this role's ability to influence decisions across teams for a candidate who can drive innovation and experimentation beyond social media and their title in a specific department and is considered a problem solver.

Staff Social Media Managers on the Social Media team are prolific and creative social media strategists with experience in digital marketing and customer journey marketing. They define GitLab's social media marketing strategy and create full-funnel campaign strategies that intersect areas of paid media, content, and sales. They own the delivery and results of associated Social Media deliverables and OKRs and the social media customer journey. They are focused on improving campaign results, productivity, operational efficiency, brand reputation and influencing customer decision making. They collaborate across digital marketing, sales, and content marketing, bridging more traditional organic social media efforts with integrated campaigns and digital marketing.

#### Job Grade

The Staff Social Media Manager is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades) individual contributor role.

#### Responsibilities

- Defines, implements, and regularly iterates on GitLab's social media strategies
- Leads end-to-end brand-level or product-related social campaigns - including paid social where appropriate
- Oversees external contributors, including agency vendors
- Collaborates with the campaigns team on campaign strategy, position, messaging, and customer journey mapping and engagement, ensuring the social team's contribution
- Performs regular gap analysis to identify areas of success, improvement, and opportunity
- Directly engages with influencers and media, as needed
- Identifies and executes "surprise and delight" moments
- Educates team members on social media best practices and manages social media team member engagement program to increase brand awareness
- Manages daily/weekly/monthly, and quarterly reporting

#### Requirements

- At least 5-8 years of experience in a social media role at a high-growth enterprise software company or agency.
- Attention to detail
- Experience running social listening, executive visibility, and influencer engagement programs
- Experience creating and managing budgets

### Principal Social Media Manager

#### Job Grade

The Principal Social Media Manager is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades) individual contributor role.

#### Responsibilities

- Lead campaigns, positioning, and messaging as the expert on the GitLab brand
- Integrate GitLab's brand voice and GitLab's values into our social media strategy and content
- Ability to act discreetly with non-public information
- Take ownership of the delivery and results of social media deliverables and OKRs.
- Strong focus on improving results, productivity, and operational efficiency.
- Supports social programs beyond channels, including team member engagement, executive visibility, and reputation management

#### Requirements

- 10 years of social media experience in a high-growth enterprise software company or agency.
- Experience with crisis communications
- Strong sense of and experience with high-level concept development, strategy, research, and problem-solving
- Exceptional communication skills and ability to develop, pitch, execute, and report on creative ideas, strategies, and campaigns

---

### Manager, Social Media

Adding "Manager," to the front of the job title indicates that this role is a practice and people manager.

Managers in the Social Media team are prolific and creative social media strategists. They define GitLab's social media strategy and manage a world-class team to expand GitLab's influence, awareness, subscribers, and leads. They own the delivery and results of Social Media deliverables and OKRs. They are focused on improving results, productivity, and operational efficiency. They must also collaborate across departments to accomplish collective goals.

#### Job Grade

The Manager, Social Media is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades) role.

#### Responsibilities

- Define, implement, and regularly iterate on GitLab's social media strategy
- Oversee all social media initiatives
- Collaborate with various teams on campaign strategy, position, and messaging
- Perform regular gap analysis to identify areas of success, improvement, and opportunity
- Hire and manage a world-class team of social media managers and [follow GitLab's existing people manager responsibilities](/handbook/company/structure/#management-group)

#### Requirements

- Minimum of 7 years of overall professional experience
- 5+ years in a social media-related role
- 1+ years of enterprise software marketing experience
- Experience defining the high-level strategy and creating social plans based on research and data
- Strong communication skills without fear of over-communication. This role will require effective collaboration and coordination across internal and external contributors
- Experience with crisis communications
- BONUS: Experience in people management (we have an internal management development program)
- BONUS: A passion and strong understanding of the industry and our mission

---

### Senior Manager, Social Media

Adding "Manager," to the front of the job title indicates that this role is a practice and people manager.

Senior Managers in the Social Media team take their role as a people manager and social media expert to the next level. They lead with data and influence. Senior Managers need to balance the "social" and the "media" of social media. They don't just define GitLab's social media strategy, Senior Managers bring their personal philosophies and practices to teach everyone else on the team.

#### Job Grade

The Senior Manager, Social Media is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades) role.

#### Responsibilities

- Lead campaigns, positioning, and messaging as the expert on the GitLab brand
- Integrate GitLab's brand voice and GitLab's values into our social media strategy and content
- Scale, develop, and manage the social media team to expand GitLab's influence and awareness and engage followers
- Willingness to be a player/coach and to roll up your sleeves
- Own the delivery and results of social media deliverables and OKRs.
- Strong focus on improving results, productivity, and operational efficiency.
- Supports social programs beyond channels, including team member engagement, executive visibility, and reputation management

#### Requirements

- 10 years of social media and at least five years of people management in a high-growth enterprise software company or agency.
- Strong sense of and experience with high-level concept development, strategy, research, and problem-solving
- Exceptional communication skills and ability to develop, pitch, execute, and report on creative ideas, strategies, and campaigns

### Director, Global Social Media

#### Job Grade

The Director, Global Social Media is a [grade 10](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades) role.

- Defines and owns the global social media strategy and execution
- Point of contact for all crises, incidents, and other emergencies
- Ability to act discreetly with non-public information
- Manages integration across teams and programs to ensure social alignment
- Consults and supports social programs beyond channels, including team member engagement, executive visibility, and reputation management
- Owns the development of measurement framework and final reporting
- Owns and manages the social budget and social media team
- Mentor team, ensure local direction is in alignment with and furthers top-line brand objectives

#### Requirements

- 12-15 years of social media and people management in a high-growth enterprise software company or agency.
- Direct experience rolling out social programs globally and establishing new channels in key markets outside of the United States
- Experience in crisis management and public companies
- Strong sense of and experience with high-level concept development, strategy, research, and problem-solving
- Exceptional communication skills and ability to develop, pitch, execute, and report on creative ideas, strategies, and campaigns

---

#### Career Ladder

- Individual contributor roles within Social Media will move from one job grade to the next for career advancement
- Staff and Principal Social Media Managers may shift toward team leadership or people management by moving to a grade 8 or grade 9 people manager role
- People leadership roles will move from one job grade to the next for career advancement

## Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process. To learn more about someone who may be conducting the interview, find their job title on our [team page](/handbook/company/team/).

- Qualified candidates will be invited to schedule a [screening call](/handbook/hiring/interviewing/#screening-call) with one of our Global Recruiters
- Next, candidates will be invited to schedule a series of 30-45 minute interviews that may include:
- At least one member of the social media team
- A member of a supporting team in events, evangelism, brand, partner marketing, or digital marketing
- Our Vice President of Corporate Communications and other leaders on the Communications team
- If Director level, our CMSO and People Business Partner Director will also conduct final interviews
- Successful candidates will subsequently be made an offer

Additional details about our process can be found on our [hiring page](/handbook/hiring/).
