---
title: "Pricing"
description: "The Pricing team owns the definition and execution of pricing strategy at GitLab."
---

The Pricing team owns the definition and execution of pricing strategy at GitLab.  This team is incredibly strategic to GitLab's success, and has the opportunity to make a large positive financial impact through improving Average Selling Price and Average Revenue per User.

## Responsibilities

- Define, track and measure pricing performance, defining actionable decision insights on pricing performance
- Build models to inform the impact of price changes on customer acquisition, usage and churn
- Provide critical thinking to make a huge positive impact on GitLab's top line growth and bottom line profitability

## Requirements

- Self-motivated and self-managing, with strong organizational skills
- Share our values, and work in accordance with those values
- Ability to thrive in a fully remote organization, being collaborative and supportive
- Comfortable with fast-pace and ambiguity in a start-up environment
- Comfort working in a highly agile, intensely iterative software development process
- Ability to use GitLab

## Performance Indicators

The pricing team measures its success by tracking growth in the following areas:

- Net Annual Recurring Revenue (nARR)
- Net Revenue Retention (NRR)
- Average Selling Price (ASP)
- Average Revenue Per User (ARPU)

Additional performance indicators may be added as the team expands.

## Levels

### Pricing Analyst

The Pricing Analyst reports to the [Director of Pricing](/job-families/product/pricing/#director-of-pricing).

#### Pricing Analyst Responsibilities

- Help the pricing team drive informed pricing and packaging decisions
- Generate data reports and conduct data analyses using SQL and Python/R, translate findings into actionable pricing insights, and present recommendations to business teams
- Create dashboards and automated reporting for key pricing performance metrics
- Build models to predict the potential impact of pricing changes, by leveraging sales, product usage, and billing data inputs
- Support executing pricing research and competitve analyses to help drive strategic pricing decisions
- Operate in an iterative mindset, focused on delivering improvements and value at high velocity

#### Pricing Analyst Requirements

- 5+ years of experience with financial analysis, preferably focused on SaaS products
- Advanced Level SQL
- Advanced visualization skills and experienced in building BI dashboards (we use SiSense)
- Effective communication skills: Regularly achieve consensus with peers, and deliver clear status updates, business insights, and recommendations
- Nice to have: Experience with pricing research and a basic understanding of common pricing research techniques
- Nice to have: Understand market research and have experience with survey design and analysis

#### Pricing Analyst Job Grade

The Pricing Analyst is a [grade 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Pricing Analyst Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process.

- Selected candidates will be invited to schedule a 30 minute [screening call](/handbook/hiring/interviewing/#screening-call) with one of our Global Recruiters
- Next, candidates will be invited to schedule an interview with the Principal Pricing Manager
- Next, candidates will be invited to schedule a deep dive interview with a member of the Data Team
- Next, candidates will be invited to schedule an interview with the Director of Pricing

Additional details about our process can be found on our [hiring page](/handbook/hiring/).

### Senior Pricing Analyst

The Senior Pricing Analyst role reports to the [Director of Pricing](/job-families/product/pricing/#sr-director-of-pricing).

#### Senior Pricing Analyst Job Grade

The Senior Pricing Analyst is a [grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Senior Pricing Analyst Requirements

- Extends the Pricing Analyst requirements
- 7+ years of experience with financial analysis, preferably focused on pricing
- 4+ years of experience with pricing research and a basic understanding of common pricing research techniques

### Senior Pricing Manager

The Senior Pricing Manager brings pricing and packaging domain expertise, contributing to the overall success of the monetization strategy of GitLab.  This role reports to the [VP of Product Monetization](/job-families/product/product-management-leadership/#senior-director-of-product-monetization)

#### Senior Pricing Manager Responsibilities

- Develop and implement effective pricing strategies for our individal product offerings
- Analyze market trends, competitor pricing, and customer data to inform pricing decisions
- Conduct regular pricing reviews to help create plans for optimization
- Monitor performance of ongoing initiatives and pricing and packaging changes.
- Partner with key stakeholders in Sales Strategy, Finance, and Marketing on key strategic iniativies

#### Senior Pricing Manager Requirements

- 5+ years of experience in managing SaaS pricing strategy and analysis
- Experience in financial analysis and modeling
- Familiarity in pricing research methodologies, such as conjoint, Van Westendorp, and max diff analysis
- Strong analytical skills with the ability to interpret complex data and provide actionable insights
- Comfortable working in an environment of ambiguity, driving towards clarity to acheive results
- Successful track record of maintaing alignment across key cross functional stakeholders

#### Senior Pricing Manager Job Grade

The Senior Pricing Manager is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Senior Pricing Manager Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process.

- Selected candidates will be invited to schedule a 30 minute [screening call](/handbook/hiring/interviewing/#screening-call) with one of our Global Recruiters
- Next, candidates will be invited to schedule an interview with a Principal Pricing Manager
- Next, candidates will be initied to schedule an interview with a member of the Product Organization
- Next, candidates will be invited to schedule an interview with a member of the Finance Organization
- Next, candidates will be invited to schedule an interview with a member of the Sales and/or Marketing Organization
- Next, candidates will be invited to schedule an interview with the VP of Product

### Principal Pricing Manager

The Principal Pricing Manager role builds upon the Senior Pricing Manager role by bringing additional expertise in pricing and packaging strategies, increased influence over strategic pricing decisions, and leading larger cross functional company wide pricing iniatives. This role reports to the [VP of Product Monetization](/job-families/product/product-management-leadership/#senior-director-of-product-monetization).

#### Principal Pricing Manager Responsibilities

- Drive pricing strategy for key initiatives across the business
- Lead the research and analysis efforts to define our pricing model, including pricing metrics, price points, and package construction
- Collaborate effectively with the executive team and product organization to drive complex pricing decisions
- Ensure pricing and packaging policy is effectively implemented into the customer experience
- Implement continuous pricing optimization plans
- Work cross functionally to execute on pricing changes including close collaboration with Product, Sales, Marketing, Finance and Legal departments.

#### Principal Pricing Manager Requirements

- 7+ years of pricing experience.  MBA preferred.
- Fluency in pricing research methodologies like conjoint and Van Westendorp Analysis
- Deep analytical skill and experience creating complex models to forecast the impact of pricing changes
- Expertise in quantitative and qualitative customer validation techniques, including surveys & customer interviewing to test customer segmentation, value metrics, pricing models, etc.
- Demonstrated ability to drive complex cross-functional pricing & packaging decisions
- Previous experience using customer/market segmentation techniques to effectively map pricing packages to user personas, buyer personas, and/or market segments

#### Principal Pricing Manager Job Grade

The Principal Pricing Manager is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Principal Pricing Manager Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process.

- Selected candidates will be invited to schedule a 30 minute [screening call](/handbook/hiring/interviewing/#screening-call) with one of our Global Recruiters
- Next, candidates will be invited to schedule an interview with the Director of Pricing
- Next, candidates will be invited to schedule an interview with a leader from the Sales Organization (VP of Sales Ops, VP of Sales or CRO)
- Next, candidates will be invited to schedule an interview with a leader from the Marketing Organization (Sr. Director of Strategic Marketing or CMO)
- Next, candidates will be invited to schedule an interview with the VP of Product

Additional details about our process can be found on our [hiring page](/handbook/hiring/).

### Director of Pricing

The Director of Pricing reports to the [VP of Product Monetization](/job-families/product/product-management-leadership/#senior-director-of-product-monetization)

#### Director of Pricing Responsibilities

- Lead the pricing function at the company
- Work closely with the CEO, CMO, CRO, and VP of Product to drive decision making around all aspects of the [pricing model](/handbook/company/pricing/)
- Collaborate effectively cross-functionally to drive complex pricing decisions at all levels including e-group
- Ensure pricing and packaging projects are effectively executed, including customer messaging, product experience, and internal enablement
- Drive robust pricing related research and analysis to generate and test hypotheses to optimize GitLab's pricing model, including pricing metrics, price points, and package construction
- Implement continuous pricing optimization plans
- Work across Fulfillment, Sales, Marketing, Legal, and Finance to deliver pricing and packaging changes
- Contribute to our broader strategy collaborating closely with the Product Leadership Team

#### Director of Pricing Requirements

- 15+ years of overall experience, with 8+ years of pricing experience, preferably as a people manager of a pricing team. Previous experience in Product Management also a plus.
- Experience with open source business models a plus
- Experience with both SaaS and self-managed deployment models a plus
- Demonstrated ability to drive complex cross-functional pricing & packaging decisions, as well as subsequent implementation and success tracking
- Fluency in pricing research methodologies like conjoint and Van Westendorp Analysis
- Deep analytical skill and experience creating complex models to forecast the impact of pricing changes
- Expertise in quantitative and qualitative customer validation techniques, including surveys & customer interviewing to test customer segmentation, value metrics, pricing models, etc.
- Previous experience using customer/market segmentation techniques to effectively map pricing packages to user personas, buyer personas, and/or market segments

#### Director of Pricing Job Grade

The Director of Pricing is a [grade 10](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Director of Pricing Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process.

- Selected candidates will be invited to schedule a 30 minute [screening call](/handbook/hiring/interviewing/#screening-call) with one of our Global Recruiters
- Next, candidates will be invited to schedule an interview with the Sr Director, Product Monetization
- Next, candidates will be invited to schedule a deep-dive interview with a Principal Pricing Manager
- Next, candidates will be invited to schedule an interview with the Director of Product, Fulfillment
- Next, candidates will be invited to schedule an interview with a leader from the Sales Organization (VP of Field Ops)
- Next, candidates will be invited to schedule an interview with a leader from the Marketing Organization (VP, Product Marketing)
- Finally, candidates may be invited to schedule an interview with the VP of Product Management

Additional details about our process can be found on our [hiring page](/handbook/hiring/).

## Career Ladder

The next step for the Pricing job family is not yet defined at GitLab.
