---
title: "Product Analyst"
description: "Product Analysts at GitLab have a unique opportunity to improve the product
through data-driven insights and recommendations"
---

## Role

Product Analysts at GitLab are curious, highly strategic, and focused on making GitLab better
through trusted data insights. Working with product teams, they look at customer behaviors
across the customer journey and help make improvements to the customer experience and
business outcomes.

As a member of the Product Data Insights team, the successful candidate will develop BI
solutions to understand product usage and customer activity, create and own multiple Product
Key Performance Indicators, develop a deep understanding of product health and the customer
experience, advance data acumen across the company, and promote strategic decisions through
data storytelling.

We work in a very unique way at GitLab, where flexibility and independence meet
a high paced, pragmatic way of working. And everything we do is [in the open](/handbook/).

We recommend looking at our [about page](/handbook/company/) and at the
[Product Data Insights handbook](/handbook/product/product-analysis) to get started.

<a id="base-pa-requirements"></a>

### Base Requirements Across All Levels

- 3+ years of data analysis experience, leveraging descriptive and predictive data techniques
- 2+ years of experience focused on feature and usage metrics, A/B testing, conversion and
retention, segmentation, and developing user archetypes and their usage patterns
- 1+ years of experience uncovering data insights to form hypotheses, designing product
experiments, evaluating results and making recommendations
- Experience supporting product team
- Advanced Level SQL
- Advanced BI dashboard development (we use Sisense for Cloud Data Teams)
- Comfort working in a highly agile, intensely iterative software development process
- Excellent proficiency in English
- Effective communication skills: Regularly achieve consensus with peers, explain complex data
concepts to non-technical stakeholders, and provide clear status updates
- Experience owning a project from conception to production, including proposal, discussion,
and execution
- Self-motivated and self-managing, with strong organizational skills
- Ability to thrive in a fully remote organization, comfortable with asynchronous collaboration
- Ability to use GitLab
- You share our [values](/handbook/values/), and work in accordance with those values
- You are living wherever you want and are excited about the [all remote](/handbook/company/culture/all-remote/) lifestyle
- Bonus points: Experience working with a Data Warehouse built using Kimball dimensional modeling
- Bonus points: Experience working with dbt
- Bonus points: Experience using python or R for analysis
- Bonus points: Able to read Ruby to trace data flows and code paths
- Bonus points: Experience with GitLab, Git, and the Git workflows

### Primary Performance Indicator for the Role

Work completed per two-week iteration ([Total Issue Velocity](/handbook/product/groups/product-analysis/team-processes/#team-velocity-calculations))

---

## Career paths

### Job Grades

Read more about GitLab [Job Grades](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Product Analyst (Intermediate)

##### Job Grade

The Product Analyst position is a [grade 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

<a id="base-pa-expectations"></a>

##### Expectations

**Collaborate with product teams**

- Perform strategic and ad-hoc analysis in support of product team members such as: product
managers, engineers, UX, design
- Serve as the Technical DRI for the Product Key Performance Indicators
- Develop dashboards and define metrics that inform success for the Product Team
- Identify opportunities in data to accelerate product adoption, retention, engagement, and/or
monetization
- Help design, execute and evaluate A/B tests to improve the user journey
- Explain trends across data sources, potential opportunities for growth or improvement, and
data caveats for descriptive, diagnostic, predictive (including forecasting), and prescriptive
data projects

**Navigate GitLab data environment and community**

- Explore large, complex, and loosely defined datasets to create actionable insights
- Serve as the Business DRI for the Product areas of the Enterprise Dimensional Model -- the
future of Trusted Data at GitLab
- Craft code that meets our internal standards for style, maintainability, and best practices

**Demonstrate GitLab values on a daily basis**

- Operate in an iterative mindset, focused on delivering improvements and value at high velocity
- Document every action in either an issue, MR, the handbook, or READMEs so analyses and
findings are discoverable, following the GitLab value of [transparency](/handbook/values/#transparency)
and the [handbook-first culture](/handbook/company/culture/all-remote/handbook-first)

##### Requirements

Product Analysts are expected to meet the [base requirements](#base-pa-requirements) outlined
above.

#### Senior Product Analyst

Senior Product Analysts are expected to be product data subject matter experts and are viewed as
such within the Product and Data communities at GitLab. They are expected to prioritize
and manage their work with minimal guidance.

##### Job Grade

The Senior Product Analyst role is a [grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

##### Expectations

Senior Product Analysts are leaders at GitLab. In addition to the [expectations for Product Analysts](#base-pa-expectations),
Senior Product Analysts are expected to:

**Bring subject matter expertise to the product teams**

- Senior Product Analysts are expected to be the subject matter expert in the data related to
their assigned product team
- Articulate both the "what" and the "why" to stakeholders via written and verbal communication
- Bridge the gap between complex data concepts and less technical stakeholders

**Contribute to the data community**

- Collaborate with central Data team to improve data infrastructure, models, and process
- Identify opportunities to create efficiencies in team processes and tooling, including enabling
other teams to self-serve on product data
- Help connect the dots across disparate bodies of work across the Data program

<a id="senior-pa-requirements"></a>

##### Requirements

Senior Product Analysts are expected to meet the [base requirements](#base-pa-requirements),
with the experience requirements adjusted to:

- 6+ years of data analysis experience, leveraging descriptive and predictive data techniques
- 4+ years of experience focused on feature and usage metrics, A/B testing, conversion and
retention, segmentation, and developing user archetypes and their usage patterns
- 2+ years of experience supporting product teams
- 2+ years of experience uncovering data insights to form hypothesis, designing product
experiments, evaluating results and making recommendations
- Expert Level SQL

#### Staff Product Analyst

The Staff Product Analyst role extends the Senior Product Analyst role expectations.

##### Job Grade

The Staff Product Analyst role is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

##### Expectations

**Lead by example**

- Mentor less experienced Product Analysts to enable them add more value sooner
- Be a thought partner to other members of the team, including delivering feedback on
analysis
- Advocate for the team's work to meet internal standards for code style, quality,
maintainability, and best practices

**Elevate product data at GitLab**

- Proactively and independently identify areas of opportunity for analysis
- Regularly contribute to the Product Data Insights and Data handbooks, elevating data literacy
and enabling responsible use of data across GitLab
- Act as a trusted voice of product data and insights in meetings and presentations

##### Requirements

Staff Product Analysts are expected to meet the [Senior Product Analyst requirements](#senior-pa-requirements),
with the experience requirements adjusted to:

- 8+ years of data analysis experience, leveraging descriptive and predictive data techniques
- 4+ years of experience supporting product teams
- 2+ years of experience conducting independent exploratory analysis
- 2+ years of mentoring other teammates or analysts
- Experience leading large, strategic initiatives

#### Manager, Product Data Insights

The Manager, Product Data Insights role extends the Senior Product Analyst role expectations.

##### Job Grade

The Manager, Product Data Insights role is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

##### Expectations

**Manage a small team of ICs (individual contributors)**

- Manage and lead a high performing team of ICs, including day-to-day assignments, weekly 1-1s,
bi-weekly iteration planning, quarterly reviews, and quarterly objectives
- Proactively identify strategic opportunities for product team via data analysis
- Ensure team is delivering high-quality work and maintaining a consistent [velocity](/handbook/product/groups/product-analysis/team-processes/#team-velocity-calculations)
- Mentor and coach members of the team
- Work with stakeholders and product leadership to align the team's priorities with those of
the company
- Be a thought partner to other members of the team, including delivering feedback on
analysis
- Ensure the team's work, including code, meets our internal standards for style,
maintainability, and best practices

**Be a leader in the GitLab data community**

- Help create a leading product Data Program to support GitLab's vision and advocate for a
data-driven culture
- Act as a central contributor to cross-functional groups and initiatives like
[FACE (Functional Analytics Center of Excellence)](/handbook/enterprise-data/functional-analytics-center-of-excellence/)

**Be an individual contributor**

- Managers are expected to contribute in a Senior Product Analyst capacity, as outlined above

##### Requirements

Manager, Product Data Insights are expected to meet the [Senior Product Analyst requirements](#senior-pa-requirements),
with the experience requirements adjusted to:

- 2+ years of experience managing and developing a data analytics team
- 2+ years of experience being responsible for planning, solutioning, work allocation &
prioritization, stakeholder management, and cross-functional collaboration as a data team lead

#### Senior Manager, Product Data Insights

The Senior Manager, Product Data Insights role extends the Manager, Product Data Insights role expectations.

##### Job Grade

The Senior Manager, Product Data Insights role is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

##### Expectations

**Lead a team of ICs and Managers**

- Manage and lead a high performing team comprised of managers, and ICs
- Effective at leading through frontline managers
- Proactively identify strategic opportunities for product team via data analysis
- Ensure team is delivering high-quality work and maintaining a consistent [velocity](/handbook/product/groups/product-analysis/team-processes/#team-velocity-calculations)
- Mentor and coach members of the team, including managers to increase the impact of their teams
- Conduct and maintain skip-level 1:1s and feedback sessions ensuring the team is operaring in line with GitLab's values
- Work cross-functionally with other leaders through the company (including Product, IT, Sales, and Marketing) ensuring the team's direction is aligned with company needs.
- Be a thought partner to other members of the team, including delivering feedback on analysis
- Proacively identify and prioritize high impact, cross section work for the Product division.
- Ensure the team's work, including code, meets our internal standards for style,
maintainability, and best practices

**Be a leader in the GitLab data community**

- Help create a leading product Data Program to support GitLab's vision and advocate for a
data-driven culture
- Act as a central contributor to cross-functional groups and initiatives like
[FACE (Functional Analytics Center of Excellence)](/handbook/enterprise-data/functional-analytics-center-of-excellence/)
- Actively provide feedback on Product strategy direction leveraging insights derived from the team
- Contribute to GitLab's [Analytics section](https://about.gitlab.com/direction/analytics/) providing feedback on tools, technology and use cases for Product Analytics.

**Be an individual contributor**

- Senior Managers are expected to contribute in a Staff Product Analyst capacity, as outlined above

##### Requirements

Senior Manager, Product Data Insights are expected to meet the [Staff Product Analyst requirements](#senior-pa-requirements),
with the experience requirements adjusted to:

- 4+ years of experience managing and developing a data analytics team
- 2+ years of experience managing managers
- 6+ years of experience being responsible for planning, solutioning, work allocation &
prioritization, stakeholder management, and cross-functional collaboration as a data team lead

## Relevant links

- [Product Data Insights Handbook](/handbook/product/groups/product-analysis/)
- [Data Team Handbook](/handbook/enterprise-data/)
- [Product Handbook](/handbook/product/)

## Performance Indicator

Product Data Insights Leadership is responsible for building the capacity and capability of their team and the groups they support to achieve:

1. Support of all section's Product Performance Indicators
1. Our global Product KPIs
1. Job satisfaction of the team members who report to them (as measured by annual employee engagement survey)
1. Hiring versus plan and new hire location factor
1. Ensuring individuals meet and maintain their ([Performance Indicator](/handbook/product/groups/product-analysis/team-processes/#team-velocity-calculations))
