---
title: "Product Design Management"
description: "Managers in the UX department at GitLab see the team as their product. While they are credible as designers and know the details of what product designers work on, their time is spent hiring a world-class team and putting them in the best position to succeed. They own the delivery of UX commitments, are always looking to improve productivity, and are responsible for the user experience in the product."
---

## Product Design Manager

The Product Design Manager reports to the Senior Manager of Product Design, and Product Designers report to the Product Design Manager.

### Job Grade

The Product Design Manager is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Responsibilities

- **Product knowledge:** Understand the technology and features of the areas you are assigned and have working knowledge of the end-to-end GitLab product.
- **Cross-product collaboration:** Proactively identify large, strategic UX opportunities that span both inside your areas and across the product. Work with other product design managers, staff, and principal product designers to drive cross-product initiatives through awareness and prioritization.
- **Design quality:** Be a frequent and active participant in milestones by reviewing UX deliverables (such as research and designs) that your team creates, and provide feedback to ensure high-quality output.
- **Research:** Identify strategic user research initiatives that span multiple stage groups (and possibly the entire product), and work with other product design/research managers to organize research efforts. Help product designers identify when research is needed for their stage group.
- **UX evangelism:** Communicate the value of UX to cross-functional GitLab team members and work with them to leverage the [product development flow](/handbook/product-development-flow/). Work closely with PMs to provide visibility and awareness into UX initiaties (including OKRs) and advocate for their prioritization.
- **Usability:** Help the product teams of areas you support to prioritize UX initiatives including [Deferred UX](/handbook/product/ux/performance-indicators/#deferred-ux), triage and resolution of UX bugs, and overall usability improvements to the product. Lead [UX Scorecard](/handbook/product/ux/ux-scorecards) initiatives in order to consistently measure the experience of your product areas and show improvements over time.
- **UX process**: Set up and manage collaborative processes within your team to ensure product designers, technical writers, and researchers are actively working together. Make sure they have exposure to the work that is happening within the broader team. Collaborate with your peers to make improvements to how we work across the design organization.
- **Hiring:** Help source talent, interview, and conduct portfolio reviews of product design candidates to hire a world-class team. Review and provide feedback on interview scorecards to maintain a high-quality interview process.
- **Vision and direction:** Contribute to product direction conversations, with emphasis on leading the experience vision for your product areas.
- **Career development:** Provide coaching for those on your team to grow technical/soft skills and develop career paths using methods such as weekly [1:1s](/handbook/leadership/1-1/), individual growth plans, and routine career development check-ins.
- **People management:** Improve the happiness and productivity of your team. Recognize and help prevent [burnout](/handbook/company/culture/all-remote/mental-health/) while managing performance.

#### Foundations

The Foundations team works on building a cohesive and consistent user experience, both visually and functionally. You'll be responsible for leading the direction of the experience design, visual style, and technical tooling of the GitLab product. You'll act as a centralized resource, helping to triage large-scale experience problems as the need arises.

You'll spend your time collaborating with a [cross-functional team](/handbook/product/categories/#ecosystem-group), helping to implement our [design system](https://design.gitlab.com/), building comprehensive accessibility standards into our workflows, and defining guidelines and best practices that will inform how teams design and build products. A breakdown of the vision you'll help to deliver within the Foundations group can be found on our [product direction page](https://about.gitlab.com/direction/manage/foundations/).

### Requirements

- Experience managing a group of designers who work on complex products.
- A clear philosophy about how to successfully manage remote design teams.
- Solid visual awareness with understanding of basic design principles like typography, layout, composition, and color theory.
- Proficiency with software like Figma, Sketch, Adobe Photoshop, and Adobe Illustrator.
- Experience defining the high-level strategy (the why) and creating design deliverables (the how) based on research.
- Experience driving organizational change with cross-functional stakeholders.
- Passion for creating visually pleasing and intuitive user experiences.
- Collaborative team spirit with great communication skills.
- You share our [values](/handbook/values/), and work in accordance with those values.
- [Leadership at GitLab](/handbook/leadership).
- Ability to use GitLab.

#### UX Paper Cuts

The UX Paper Cuts team is responsible for identifying and fixing small but impactful usability issues in the GitLab product. The team occasionally takes on larger efforts that target known challenges users face within the DevSecOps lifecycle. Like the Foundations team, UX Paper Cuts does not work within a specific product area, but across the product as a whole, identifying issues and creating merge requests to continually [improve the user experience](https://papercuts.gitlab.com/).

### UX Paper Cuts Requirements

- Experience leading a group of designers who work on complex products.
- A clear philosophy about how to successfully hire and manage remote design teams.
- Experience working in both start-up and enterprise environments.
- Experience writing CSS/HTML and be comfortable working in Git.
- Proficiency with software like Figma or Sketch.
- Strong collaboration skills.

**NOTE** In the compensation calculator below, fill in "Manager" in the `Level` field for this role.

### Interview Process

Candidates can expect the hiring process to follow the below order, although it can change depending on calendar availability. Please keep in mind that candidates can be declined at any stage of the process.

- [Screening call](/handbook/hiring/#screening-call) with a recruiter.
- **Interview with product designer** In this interview, the interviewer will want to understand the experience you have as a manager, what type of teams you have led, and your management style. The interviewer will also look to understand how you define strategy, how you work with researchers, how you handle conflict, and how you dealt with difficult situations in the past. Be prepared to talk about your work, your experience with Design Systems, and your technical ability.
- **Interview with product design manager** In this interview, we want you to share specific examples from your work that provide insight into a problem you solved as part of a project you led. We'll look to understand the size and structure of your team, the goals of the project, how you/the team approached research, how you synthesized research data to inform design decisions, what design standards and guidelines you worked within, how you collaborated with the wider team, and the overall outcome. Broadly, we want to hear how you identified what needed to be done and then guided your team to the end result. A formal case study is not required but you're welcome to share anything you feel will help better answer the question(s) or tell your story.
- **Interview with senior manager of product design** In this interview, the interviewer will want to understand the experience you have as a manager, what types of teams you have led, and your management style. The interviewer will also want to understand how you define strategy, how you work with researchers, how you handle conflict, and how you've dealt with difficult situations in the past. Be prepared to talk about your work, experience with Design Systems, and your technical ability.
- **Interview with a group product manager** In this interview, the interviewer will want to understand how your career experiences will set you up for success at GitLab. They will also look to understand how you work with cross-functional partners, the domains you've worked in previously, and the types of teams you've led.
- **Interview with director of product design** In this interview, the interviewer will want to understand the experience you have as a manager, your experience working remotely, and how these two elements of your career intersect. They will also look to understand your technical skills and the types of products you've worked on previously.

If you are interviewing for the UX Paper Cuts specialty, the hiring process is the same but does not include an interview with a group product manager.

## Senior Manager of Product Design

The Senior Manager of Product Design reports to the Director of Product Design, and the Product Design Manager reports to the Senior Manager of Product Design.

### Job Grade

The Senior Manager of Product Design is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Responsibilities

- **Product knowledge:** Understand the technology and features across all [product sections](/handbook/product/categories/) in order to drive cross-product workflows and identify improvement opportunities.
- **Cross-product collaboration:** Actively advocate for product design throughout the organization. Coach product design managers on how to identify large, strategic UX opportunities and how to move them forward.
- **Design quality:** Use your product knowledge across all stages to have a positive impact in design reviews, UX Forum, and group conversations. Mentor product design managers to be an active participant in monthly milestones to ensure high-quality output.
- **Research:** Improve research quality and [frequency](/handbook/product/ux/performance-indicators/#average-research-projects-per-product-designer) by helping designers and design managers identify strategic user research initiatives.
- **UX evangelism:** Ensure UX is prioritized by working with product leadership to identify opportunities for validation and better cross-functional collaboration.
- **UX process:** Improve processes across the organization to ensure that product design is an active participant throughout the entire [product development flow](/handbook/product-development-flow/). Identify efficiency improvements and scale them across the organization.
- **Hiring:** Help identify growth opportunities needed to support business goals. Hire and retain a world-class team of product designers and product design managers.
- **Vision and direction**: Actively influence and guide the experience strategy and vision of the areas you're assigned.
- **Career development:** Provide coaching for those on your team to grow management/coaching skills and develop career paths using methods such as weekly [1:1s](/handbook/leadership/1-1), individual growth plans, and routine career development check-ins.
- **People management:** Coach your team on how to recognize and prevent burnout while managing performance. Impact the happiness and productivity of your team through methods such as capacity management coaching. Conduct quarterly skip-levels with your reports' direct reports.
- **Goal setting and performance tracking:** Define and manage [performance indicators](/handbook/product/ux/performance-indicators/) and [FY directional next steps](/handbook/product/ux/#fy23-direction) for the product design team. Facilitate the creation and execution of product design [OKRs](/handbook/company/okrs/) in collaboration with the product design team and UX leadership.

### Requirements

- Experience managing product design managers who focus on enterprise, developer, and/or business tools.
- Solid visual awareness with understanding of basic design principles like typography, layout, composition, and color theory.
- Experience defining the high-level strategy (the why) and helping your team connect design and research back to that strategy.
- Experience driving organizational change with cross-functional stakeholders.
- Passion for creating visually pleasing and intuitive user experiences.
- Collaborative team spirit with great communication skills.
- You share our [values](/handbook/values/), and work in accordance with those values.
- [Leadership at GitLab](/handbook/company/structure/#management-group).
- Ability to use GitLab.

**NOTE** In the compensation calculator below, fill in "Manager" in the `Level` field for this role.

### Interview Process

- [Screening call](/handbook/hiring/#screening-call) with a recruiter.
- Interview with a product design manager. In this interview, the interviewer will focus on understanding your experience with driving design strategy, managing managers, and influencing the wider organization in which you worked. Examples of large, complex projects that had a significant impact on product experience will be helpful. Broadly, we want to hear how you identified what needed to be done and then guided your team to the end result.
- Interview with a senior manager of product design. In this interview, the interviewer will spend a lot of time trying to understand the experience you have as a manager, what types of teams you have led and your management style. The interviewer will also want to understand how you define strategy, how you work with researchers, how you've handled conflict, and how you've dealt with difficult situations in the past. Be prepared to talk about your work, experience with design systems, and technical ability, too.
- Interview with a director of product management. In this interview, the interviewer will seek to learn how you and your design teams have interacted and collaborated with product management team members. Be prepared to talk through examples about situations you have led or how you've assisted your team of designers.
- Interview with the director of product design. In this interview, the interviewer will follow up on some areas covered in previous interviews to dive deeper and learn more about you as a manager, your stakeholder management experience, and your comfort in working on and guiding a team on a highly technical product.

## Director of Product Design

The Director of Product Design reports to the VP of UX, and Product Design Manager and Senior Manager of Product Design report to the Director of Product Design.

The Director of Product Design role extends the Senior Manager of Product Design role.

### Job Grade

The Director of Product Design is a [grade 10](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Responsibilities

- **Performance tracking:** Define and manage performance indicators for the product design team by independently managing product design KPIs on the [UX KPIs](/handbook/product/ux/performance-indicators/) page in the handbook.
- **Cross-product collaboration:** Actively advocate for product design throughout the organization by ensuring product design responsibilities are reflected in the product development flow.
- **Product knowledge:** Help drive cross-product workflows by having an awareness of what's happening across all sections through active participation in design reviews, UX Forum, and group conversations.
- **Goal setting:** Independently manage the creation and execution of product design [OKRs](/handbook/company/okrs/) with feedback from the product design team and UX leadership.
- **UX evangelism:** Ensure UX is prioritized by working with product leadership to identify opportunities for validation and better cross-functional collaboration.
- **Design strategy:** Communicate significant product design strategy decisions to leadership and the wider company.
- **People management:** Coach product design managers on how to conduct 1:1s and growth conversations with their direct reports.
- **Skip levels:** Conduct quarterly skip levels with your reports' direct reports.
- **Vision and direction**: Stay informed of direction pages and have an awareness of the strategy and vision across the product.
- **Hiring:** Hire and retain a world-class team of product designers and product design managers.

### Requirements

- Relevant, progressive experience managing product design managers and leading product design for a company that focuses on enterprise, developer, and/or business tools.
- A strong philosophy about how to create an environment that empowers remote design teams and encourages them to deliver high-impact work.
- Solid visual awareness with understanding of basic design principles like typography, layout, composition, and color theory.
- Proficiency with software like Figma, Sketch, Adobe Photoshop, and Adobe Illustrator.
- Experience defining the high-level strategy (the why) and creating design deliverables (the how) based on research.
- Passion for creating visually pleasing and intuitive user experiences.
- Collaborative team spirit with great communication skills.
- You share our [values](/handbook/values/), and work in accordance with those values.
- [Leadership at GitLab](/handbook/company/structure/#director-group).

### Interview Process

- [Screening call](/handbook/hiring/#screening-call) with a recruiter.
- Interview with a senior manager of product design or director of product design. In this interview, the interviewer will spend a lot of time trying to understand the experience you have as a manager, as well as what type of teams you have led and your management style. The interviewer will also be looking to understand how you define strategy, how you work with researchers, how you've handled conflict, and how you dealt with difficult situations in the past. Be prepared to talk about your work, experience with design systems, and technical ability, too.
- Interview with a director of product management. In this interview, the interviewer will seek to learn how you and your design teams have interacted and collaborated with product management team members. Be prepared to talk through examples about situations you have led or how you've assisted your team of designers.
- Interview with the VP of UX.
- Interview with the Chief Product Officer.
