---
title: "Product Designer"
description: "At GitLab, product designers collaborate closely with product managers, engineers, UX researchers, technical writers, and other product designers to create a productive, minimal, and human experience."
---

## Product Design Roles at GitLab

At GitLab, product designers collaborate closely with [product managers](/job-families/product/product-manager/), [engineers](/job-families/engineering/), [UX researchers](/job-families/product/ux-researcher/), [technical writers](/job-families/product/technical-writer/), and other product designers to create a [productive, minimal, and human](https://design.gitlab.com) experience.

A Product Designer reports to a [Product Design Manager](/job-families/product/product-design-management/#product-design-manager).

## Responsibilities

- Help define and improve the user experience (UX) and user interface (UI) of GitLab.
- Design features that fit within the larger experience and flows.
- Create deliverables (wireframes, mockups, prototypes, flows, and so on) to communicate ideas.
- Work with product managers and engineers to iterate on and refine the existing experience.
- Define and contribute to [research initiatives](/handbook/product/ux/ux-research/how-uxr-team-operates/) (usability tests, surveys, interviews, and so on) alongside UX researchers and product managers.
- Stay informed and share the latest on UI/UX techniques, tools, and patterns.

## Base Requirements For All Roles

- Ability to use GitLab.
- Several years professional experience designing for complex products.
- Visual and interaction skills with experience designing responsively.
- Thoughtful decision making motivated by data and research.
- Familiarity with accessibility best practices and WCAG guidelines.
- Comfort working in highly agile, iterative product development process.
- Design systems knowledge, understanding, and practice.
- You share our [values](/handbook/values/), and work in accordance with those values.
- Strong [bias for action](/handbook/values/#bias-for-action) and ability to develop daily priorities to achieve goals ([manager of one](/handbook/values/#managers-of-one)).
- Proficiency in the English language, both written and verbal, sufficient for success in a remote and largely asynchronous work environment.
- Working knowledge of HTML/CSS, and familiarity with JavaScript.
- General knowledge of Git (for example, branching, push/pulling, committing, squashing) and DevOps (for example, pipelines, deployments, security) flows.

## Levels

### Product Designer

A Product Designer is assigned to a [group](/handbook/product/categories/#hierarchy), with exceptions made based on business needs.

#### Job Grade

The Product Designer is a [grade 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Responsibilities

- **Product knowledge:** Have working knowledge of the capabilities in your [group](/handbook/product/categories/#hierarchy).
- **Research:** Conduct competitor evaluations, usability studies, and formative evaluations (like UX Scorecards). Incorporate insights to fulfill user and business needs.
- **Deliverables:** Create tactical deliverables for your group that solve user problems (for example, user flows, low and high fidelity designs, prototypes).
- **Communication:** Communicate UX activities to others with clear language that simplifies complexity.
- **Usability:** Identify small and large usability issues in your group.
- **Iteration:** Practice design iteration and [break down designs](/handbook/product/ux/product-designer/#ideate-and-iterate) to fit the release cadence. [Review merge requests](/handbook/product/ux/product-designer/mr-reviews/) with user-facing changes.
- **Design system:** Actively contribute additions or enhancements to the [Pajamas Design System](https://design.gitlab.com) based on your work.
- **UI copy:** Collaborate early and often with a technical writer on microcopy and documentation.
- **Design reviews:** Participate in [design reviews](/handbook/product/ux/product-designer/#design-reviews), exchanging feedback appropriately.
- **Deferred UX:** Identify, track, and make recommendations to address [deferred UX](/handbook/product/ux/performance-indicators/#deferred-ux) in your group.
- **Recruiting:** Evaluate design portfolios, and interview product design and product management candidates.

#### Requirements

A Product Designer is expected to meet the [base requirements](#base-requirements-for-all-roles) and execute their responsibilities with a [commitment to results and agreed actions](/handbook/values/#results-competency).

### Senior Product Designer

A Senior Product Designer is assigned to a [group](/handbook/product/categories/#hierarchy), with exceptions made based on business needs.

#### Senior Job Grade

The Senior Product Designer is a [grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Senior Responsibilities

Everything in the Product Designer role, plus:

- **Product knowledge:** Have _deep knowledge of the technology and_ capabilities in your [group](/handbook/product/categories/#hierarchy). _Proactively learn and have working knowledge of other groups._
- **Research:** Conduct competitor evaluations, usability studies, and formative evaluations. Incorporate insights to fulfill user and business needs. _Identify research opportunities._
- **Deliverables:** Create tactical deliverables for your group that solve user problems. _Define strategic outputs that connect vision to product outcomes (for example, journey maps, storyboards, design visions)._
- **Communication:** Communicate UX activities to others with clear language that simplifies complexity. _Show a strong point of view on how those activities address user and business needs._
- **Usability:** Identify small and large usability issues in your group. _Influence their prioritization._
- **Iteration:** Practice design iteration and [break down designs](/handbook/product/ux/product-designer/#ideate-and-iterate) to fit the release cadence. [Review merge requests](/handbook/product/ux/product-designer/mr-reviews/) with user-facing changes. _Advocate for and guide others in adopting effective [iteration](/handbook/values/#iteration) practices within your group._
- **Design system:** Actively contribute additions or enhancements to the [Pajamas Design System](https://design.gitlab.com) based on your work. _Help determine use cases and provide recommendations._
- **UI copy:** Collaborate early and often with a technical writer on microcopy and documentation. _Help improve documentation and incorporate guidance in the UI for a better experience._
- **Design reviews:** Participate in [design reviews](/handbook/product/ux/product-designer/#design-reviews), exchanging feedback appropriately. _Model best practices for feedback exchange._
- **Deferred UX:** Identify, track, and make recommendations to address [deferred UX](/handbook/product/ux/performance-indicators/#deferred-ux) in your group. _Mitigate the risk for deferred UX with [MVCs](/handbook/product/product-principles/#the-minimal-valuable-change-mvc). Help prioritize such issues in your group._
- **Public presence:** Promote GitLab publicly through articles, talks, videos, or social media interactions, where appropriate.
- **Cross-stage collaboration:** Note dependencies and advocate for cross-stage collaboration when needed to promote a holistic UX.

#### Senior Requirements

A Senior Product Designer is expected to meet the [base requirements](#base-requirements-for-all-roles) and execute their responsibilities while [modeling a sense of urgency and commitment to deliver results](/handbook/values/#results-competency).

### Staff Product Designer

A Staff Product Designer is assigned to a [group](/handbook/product/categories/#hierarchy), with exceptions made based on business needs.

#### Staff Job Grade

The Staff Product Designer is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Staff Responsibilities

Everything in the Senior Product Designer role, plus:

- **Product knowledge:** Have deep knowledge of the technology and capabilities in your [group](/handbook/product/categories/#hierarchy). Proactively learn and have working knowledge of _the end-to-end product._
- **Research:** Conduct competitor evaluations, usability studies, and formative evaluations. Incorporate insights to fulfill user and business needs. Identify research opportunities. _Collaborate on [problem validation](/handbook/product-development-flow/#validation-phase-2-problem-validation) and strategic research needs._
- **Deliverables:** Create tactical deliverables for your group that solve user problems. Define strategic outputs that connect vision to product outcomes. _Shape the deliverables with a focus on long-term vision and execution._
- **Communication:** Communicate UX activities to others with clear language that simplifies complexity. Show a strong point of view on how those activities address user and business needs. _Exemplify frequent and effective asynchronous communication._
- **Iteration:** Practice design iteration and [break down designs](/handbook/product/ux/product-designer/#ideate-and-iterate) to fit the release cadence. [Review merge requests](/handbook/product/ux/product-designer/mr-reviews/) with user-facing changes. Advocate for and guide others in adopting effective [iteration](/handbook/values/#iteration) practices _across the company._
- **Thought leadership:** Promote best practices and support others in advocating for them.
- **Recruiting:** Evaluate design portfolios, and interview product design and product management candidates. _Help identify top product design talent._
- **Cross-stage collaboration:** Note dependencies and advocate for cross-stage collaboration when needed to promote a holistic UX. _Help others navigate the organization and consider overlaps._
- **Mentoring:** Provide impactful feedback to UX department members and mentor them throughout product development.
- **Vision:** Collaborate with your group on a user-centric vision and long-term roadmap that is connected to company goals.
- **UX process:** Expose operational needs (for example, in [design](/handbook/product-development-flow/#validation-phase-3-design) and [solution validation](/handbook/product-development-flow/#validation-phase-4-solution-validation)), and address them through experimentation and change management.
- **Open source:** Create a welcoming community for design contributors and drive engagement.

#### Staff Requirements

A Staff Product Designer is expected to meet the [base requirements](#base-requirements-for-all-roles) and execute their responsibilities while [coaching team members to collaborate and work iteratively](/handbook/values/#results-competency).

### Principal Product Designer

A Principal Product Designer is assigned to **projects**, based on their skills and business needs. This flexibility enables us to create broader impact and handle the most complex problems, and provide them with more diverse opportunities for career development.

#### Principal Job Grade

The Principal Product Designer is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Principal Responsibilities

Everything in the Staff Product Designer role, plus:

- **Product knowledge:** Have deep knowledge of the technology and capabilities in your _projects_. Proactively learn and have working knowledge of the end-to-end product.
- **Research:** Conduct competitor evaluations, usability studies, and formative evaluations. Incorporate insights to fulfill user and business needs. Identify research opportunities. Collaborate on [problem validation](/handbook/product-development-flow/#validation-phase-2-problem-validation) and strategic research needs. _Help connect research efforts, and cultivate accountability and learning through research._
- **Deliverables:** Create tactical deliverables for your _project_ that solve user problems. Define strategic outputs that connect vision to product outcomes. Shape the deliverables with a focus on long-term vision and execution. _Reduce the scope, complexity, and ambiguity of projects to a more manageable state._
- **Communication:** Communicate UX activities to others with clear language that simplifies complexity. Show a strong point of view on how those activities address user and business needs. Exemplify frequent and effective asynchronous communication. _Unblock conversations and encourage collaboration across teams._
- **Iteration:** Practice design iteration and break down designs to fit the release cadence of your _projects_. Review merge requests with user-facing changes. Advocate for and guide others in adopting effective [iteration](/handbook/values/#iteration) practices across the company. _Help others break down solutions into actionable steps, aligned with long-term goals._
- **Deferred UX:** Identify, track, and make recommendations to address [deferred UX](/handbook/product/ux/performance-indicators/#deferred-ux) in your _projects_. Mitigate the risk for deferred UX with [MVCs](/handbook/product/product-principles/#the-minimal-valuable-change-mvc). Help prioritize such issues in your _projects_.
- **Thought leadership:** Promote best practices and support others in advocating for them. _Bring a UX voice to complex scenarios and build trust with other disciplines. Enable designers to engage on large-scale initiatives._
- **Recruiting:** Evaluate design portfolios, and interview product design and product management candidates. Help identify top product design talent. _Coach others to find and interview design candidates. Help attract and retain a world-class product design team._
- **Cross-stage collaboration:** Note dependencies and advocate for cross-stage collaboration when needed to promote a holistic UX. Help others navigate the organization and consider overlaps. _Identify cross-stage opportunities and drive collaboration to influence product strategy._
- **Mentoring:** Provide impactful feedback to UX members and mentor them throughout product development. _Support designers' career development, mentor cross-functional team members and UX leaders, and foster a skill-building environment within the department._
- **Vision:** _Influence the vision and roadmap of your projects to ensure they are user-centered and connected to company goals._
- **Goal setting:** Help set achievable, measurable, and impactful goals for your projects that drive results.
- **UX process:** Expose operational needs, and address them through experimentation and change management. _Also identify and address cultural and organizational needs. Enable others to help and drive changes._
- **Public presence:** Promote GitLab publicly through articles, talks, videos, or social media interactions, where appropriate. _Be an active voice in the UX industry, and share our learnings._
- **Supporting others:** Support peers in their working rhythm. Translate their successes, concerns, and morale to leadership.

#### Principal Requirements

A Principal Product Designer is expected to meet the [base requirements](#base-requirements-for-all-roles) and execute their responsibilities while [fostering a culture of ownership of personal performance](/handbook/values/#results-competency).

## Foundations Specialty

In addition to embedding in [groups](/handbook/product/categories/#hierarchy) that focus on a specific product area, we also have a Foundations team that works on building a cohesive and consistent user experience across platform experiences like navigation, both visually and functionally. You'll be responsible for leading the direction of the experience design, visual style, and technical tooling of the GitLab product. You'll act as a centralized resource, helping to triage large-scale experience problems as the need arises.

You'll spend your time collaborating with a [cross-functional team](/handbook/product/categories/#ecosystem-group), implementing our [design system](https://design.gitlab.com/), building comprehensive accessibility standards into our workflows, and defining guidelines and best practices that will inform how teams are designing and building products. A breakdown of the vision you'll be helping to deliver within the UX Foundation category can be found on our [product direction page](https://about.gitlab.com/direction/manage/foundations/).

## UX Paper Cuts Specialty

The UX Paper Cuts team is responsible for identifying and fixing small, impactful usability issues in the GitLab product. Like the Foundations team, UX Paper Cuts doesn't work within a specific product area, but across the product as a whole, identifying issues and creating merge requests to continually [improve the user experience](https://papercuts.gitlab.com/). You'll also spend your time helping to implement and evolve the design system and GitLab UI and assist in burning down backlogs of known UI and usability problems. By focusing on small details, you'll help create a more polished and user-friendly interface, leading to increased user satisfaction, engagement, and ultimately a more successful product.

### UX Paper Cuts Responsibilities

Everything in the various levels of product designer roles, plus:

- **Intermediate development skills** We work primarily with Vue, Rails, and SCSS, so designers should be comfortable updating, building, and reviewing code within those frameworks.
- **Advanced Git knowledge** Since we spend most of our time working in merge requests, designers should be comfortable using Git effectively.
- **Creation and management of feature flags** Know when to use feature flags, how to create them, and monitor their progress and potential feedback.
- **Familiarity with unit testing** The ability to fix, update, and write RSpec and Jest tests.

## AI Specialty

Everything in the various levels of product designer roles, plus:

- knowledge of AI technologies, including subsets of GenAI and ML.
- participate in prompt engineering to maximize user satisfaction.
- test prompts and prototype conversation flow happy paths.
- understand model evaluation approaches, and use knowledge of user intents to enhance datasets to closely mirror human interactions.
- stay up to data on emerging technology and UI design patterns.
- leverage solution validation methods that go beyond usability to evaluate user satisfaction with model responses.
- create learning materials that support designers who work on AI-powered features.

## Performance indicators

- [Perception of usability (SUS)](/handbook/product/ux/performance-indicators/#system-usability-scale-sus-score)
- [Product Customer Satisfaction (CSAT)](/handbook/product/ux/performance-indicators/#product-customer-satisfaction-csat-score)
- [Pajamas component migrations](/handbook/product/ux/performance-indicators/#pajamas-component-migrations)
- [Deferred UX](/handbook/product/ux/performance-indicators/#deferred-ux)

## Relevant links

- [UX Team](/handbook/product/ux/)
- [GitLab Design Project](https://gitlab.com/gitlab-org/gitlab-design)
- [GitLab Design System](https://design.gitlab.com)

## Hiring Process

<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/PJxw-O4POyU" frameborder="0" allowfullscreen="true"> </iframe>
</figure>

Candidates for this position can expect the hiring process to follow the order below, although it can change depending on calendar availability. Please keep in mind that candidates can be declined from the position at any stage of the process. To learn more about someone who is conducting your interview, you can find their job title on our [team page](/handbook/company/team/).

- Selected candidates will be invited to schedule a 30-minute [screening call](/handbook/hiring/interviewing/#screening-call) with a member of our hiring team. In this call, we will discuss your experience, understand what you are looking for in a product design role, talk about your work and approach to product design, discuss your compensation expectations and reasons why you want to join GitLab, and answer any questions you have.
- Next, if a candidate successfully passes the screening call, they will have two 1-hour interviews: One with a product designer and another with the hiring product design manager.
  - During these interviews you'll be asked several situational questions to help us learn how you have responded or would respond in certain scenarios.
  - You should be prepared to discuss your design and research process, details about how you collaborate, and how you approach your role.
  - You'll also have an opportunity to talk through a [case study](/job-families/product/product-designer/#case-studies) in your portfolio. We'll look for you to walk through a project so we can understand your process, approach, and philosophy to design, the size and structure of the team you were a part of, the goals of the project, your low-fidelity design work, your high-fidelity design skills, how you approached research, how you synthesized research data to inform design decisions, what design standards and guidelines you worked within, and how you collaborated with a wider team. We are looking for you to give some real insight into a problem you solved, ideally in a project with similar challenges, goals, or context to the type of work you'll find in the [stage group](/handbook/product/categories/#devops-stages) you're interviewing for. Be prepared to discuss your project with your interviewer throughout your walk through. You can expect to spend about 30 minutes discussing your case study.
  - Towards the end of each interview, you'll be given some time to ask questions.
- If you successfully pass the previous interviews, you'll meet with a senior manager of product design for a 50-minute interview. This interview will focus on assessing your research, strategy, and design skills. The interviewer will want to understand how you have incorporated research into your work and get a feel for your understanding of the fundamentals of research and UX methodology. Be prepared to answer questions around the soft skills product designers need, and be prepared to talk to the interviewer about how you apply these skills in the real world.
- The final interview will be with a product manager and engineering manager. They'll focus on your ability to collaborate with product and engineering teams and determine how well your skills align with the needs of a specific stage group.
- Successful candidates will subsequently be made an offer through a video call or phone call.

### Hiring process for UX Paper Cuts Specialty

The UX Paper Cuts specialty has an emphasis on basic coding skills as the role involves making changes to the product by creating, reviewing, and merging MRs. The final interview will be with a member of the UX Paper Cuts team and will focus on discussing the technical exercise you'll receive a couple of days prior to the scheduled call. The technical exercise is brief and to be completed in advance. It's an opportunity to learn your comfort and capability in making small frontend changes. This final interview and exercise replaces the product manager and engineering manager mentioned above.

### Preparing for your interviews

#### Case studies

Here are some helpful tips for when you are sharing a case study:

- A formal presentation is not required but it is helpful to bring your materials together. We recommend not sharing entire design files as it can be difficult for an interviewer to follow along.
- Clearly outlined user and business problems that you were solving and how you learned about them.
- What your role was (for example, who did you work with and what was your responsibility).
- The details of the design process (polished visuals are fine but you may want to include the sketches, wireframes, prototypes, or the ideas that didn't make it).
- The result of your work (learnings, successfully achieved goals, impact on key metrics).

### Internal candidates

The hiring process for internal candidates may be slightly adjusted from the above, but in general the goal is still to evaluate the best fit for the role. Interview questions may be adapted to gauge interest and skills in specific areas the team would like to grow, or about specific team responsibilities. A case study review is not necessary; instead, consider current or previous work assignments and experience in light of the position.

Additional details about our process can be found on our [hiring page](/handbook/hiring/).
