---
title: "Product Management - Leadership"
description: "This job family represents all Managers in the Product Management department."
---

This job family represents all Managers in the Product Management department. They are responsible for managing,
directly or indirectly GitLab team members performing in the role of [Product Manager](/job-families/product/product-manager/).
These roles are responsible for managing and building teams which focus on specific specialties as part
of GitLab's [product hierarchy](/handbook/product/categories/#hierarchy)
([sometimes encompassing entire stages or a section](/handbook/product/product-leaders/product-leadership/#product-organizational-structure)).

## References

- [Product Handbook](/handbook/product/)
- [Product Leadership](/handbook/product/product-leaders/product-leadership/)
- [Product Development Workflow](/handbook/product-development-flow/)
- [Product Management Career Development Framework](/handbook/product/product-management/product-cdf-competencies/)
- [Engineering Workflow](/handbook/engineering/workflow/)

## Responsibilities

- Make sure you have a great product team (recruit and hire, coach and mentor, promote proactively, identify underperformance)
- Work on the vision with the [Product Leadership](/handbook/product/product-leaders/product-leadership/) and CEO; and communicate this vision internally and externally
- Distill the overall vision into a compelling roadmap
- Make sure the vision advances in every release and communicate this
- Communicate our vision though demo's, conference speaking, blogging, and interviews
- Work closely with Product Marketing, Sales, Engineering, etc.
- Support direct reports in their career plans at GitLab and beyond

## Requirements

- Ability to use GitLab
- Experience hiring teams in high growth companies
- Experience in DevOps
- Experience with solutions from the product category, groups or DevOps stages you will be responsible for
- Technical background or clear understanding of developer products; familiarity with Git, Continuous Integration, Containers, Kubernetes, and Project Management software a plus
- You are living wherever you want and are excited about the [all remote](/handbook/company/culture/all-remote/) lifestyle
- You share our [values](/handbook/values/), and work in accordance with those values
- [Leadership at GitLab](/handbook/company/structure/#director-group)

## Levels

### Group Manager, Product (GMP)

This role typically manages 2-4 Product Managers, and reports either to a [Director of Product](#director-of-product-management),
a [Senior Director of Product Management](#senior-director-of-product-management) or the [VP of Product Management]({{< ref "product-leadership#vp-of-product-managemen" >}}).

#### Group Manager, Product (GMP) - Job Grade

The Group Manager, Product is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Group Manager, Product (GMP) - Responsibilities

**Team responsibilities**

- Coach Product Managers through their [responsibilities](/job-families/product/product-manager/#responsibilities)
- Ensure PMs receive regular [CDF](/handbook/product/product-management/product-cdf-competencies/) feedback and, if desired, Career Coaching
- Ensure that Product Managers participate in [Validation](/handbook/product-development-flow/#validation-track) and [Build](/handbook/product-development-flow/#build-track) track activities while following our product principles so that our Product Performance indicators are met
- Enable product managers to make the most effective decisions when [prioritizing R&D investment](/handbook/product/product-processes/#how-we-prioritize-work) in their [product groups](/handbook/company/structure/#product-groups) so that our upcoming releases contain relevant enhancements for our customers, users, prospects and us.
- Convene a set of stable counterparts for your assigned [Product Hierarchy](/handbook/product/categories/#hierarchy) and Use Cases to ensure R&D and GTM [KPIs](/handbook/company/kpis/) are met
- Join customer and partner visits that spawn ideas for new features
- Ensure PMs develop an understanding of the market for their categories, including ensuring that the [DevOps tools](https://about.gitlab.com/competition/) and category directions relevant to their markets are up to date
- Keep relevant [/direction](https://about.gitlab.com/direction) pages up to date as our high level roadmap
- Prioritize, build and assess business cases for new or existing opportunities in your group that have no investment
- Understand deeply and synthesize the market, competition, and upcoming solutions in the space their team is responsible for.
- Review release post announcements to ensure they focus on user problems and [jobs-to-be-done](/handbook/product/ux/jobs-to-be-done/)
- Own driving connections between the groups their PMs drive to ensure a single-application user experience.
- Demonstrate leadership as [expected of Managers across GitLab](/handbook/company/structure/#management-group).
- Find opportunities where teams need to collaborate with each other and help them make those decisions that are optimal for the company even if they maybe sub-optimal in the short term for particular groups.

*Please note: If the Group Manager has less than 4 direct reports or is a first-time manager, some individual contributor responsibilities may be expected to be maintained.*

#### Group Manager, Product (GMP) - Requirements

Requirements are outlined in the [Product Management Career Development Framework](/handbook/product/product-management/product-cdf-competencies/#cdf-for-product-leadership)

#### Group Manager, Product (GMP) - Career Ladder

The next step in the Group Manager, Product is to move to [Director of Product](#director-of-product-management).

#### Group Manager, Product (GMP) - Specialties

##### Verify

Are responsible for managing the team of product managers covering the [Verify stage groups](/handbook/product/categories/#verify-stage). Leading the [Verify direction](https://about.gitlab.com/direction/ops/#verify) is a high impact position. Works with your team to ensure our [industry-leading CI](https://about.gitlab.com/analysts/forrester-cloudci19/) continues to be a [critical entry-point](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/ci/) to our single DevOps platform. Work cross functionally as an expert and invest in your team of high caliber product managers to make sure our [R&D investment in Verify](https://internal.gitlab.com/handbook/product/investment/) is as effective as possible in fulfilling our [mission to enable everyone to contribute](/handbook/company/mission/#mission).

###### Verify - Runner

The GMP for Verify:Runner is responsible for supporting our [Runner product groups](https://docs.gitlab.com/runner/) functional management and vision. Leading the direction as an individual contributor for the categories of [Runner Core](https://about.gitlab.com/direction/verify/runner_core/) and [Runner Fleet](https://about.gitlab.com/direction/verify/fleet_visibility/) while supporting the Product Manager over [Runner SaaS](https://about.gitlab.com/direction/verify/runner_saas/), is an high visibility and mission-critical role. You will be working across two product groups to accelerate our [Verify stage direction](https://about.gitlab.com/direction/ops/#verify) growth and influence our [SaaS Platforms direction](https://about.gitlab.com/direction/saas-platforms/) via the implementation of our [Automated Software Delivery solution](https://about.gitlab.com/solutions/delivery-automation/). Investing in your team to curate Product Management excellence to effectively enable our position of being the [One DevOps Platform](https://about.gitlab.com/topics/devops-platform/).

##### Enablement

Responsible for the [Geo](/handbook/product/categories/#geo-group), [Global Search](/handbook/product/categories/#global-search-group), [Memory](/handbook/product/categories/#memory-group), and [Database](/handbook/product/categories/#database-group) groups. These groups ensure GitLab can meet customer business continuity requirements, is performant at all scales, and enables users to find the content they are looking for in our single platform.

##### Requirements

- Demonstrated understanding of software systems, distributed systems a plus
- Previous experience with self-managed products and their lifecycle operations
- Strong communications skills and ability to work cross-functionally, as these groups affect many parts of GitLab

#### Data Science

##### ModelOps

Responsible for leading the team of PMs who manage the [ModelOps stage groups](/handbook/product/categories/#modelops-stage). This stage leader sets the vision and direction for how to empower GitLab users to leverage data science as part of their DevOps program—both by enabling users to build and run data science workloads, as well as by enriching existing GitLab product functionality with capabilities powered by machine learning. This individual will lead an expansion of GitLab's [core personas](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/ci/#personas) to address the needs of data science teams and will work cross-functionality with [other GitLab stages](/handbook/product/categories/#devops-stages) in leveraging machine learning to deepen our [core differentiators](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/ci/#top-3-gitlab-differentiators). This individual will be responsible for developing new revenue-generating products as well as enhancing existing products used by millions of users across the world.

##### Requirements

- Knowledge of how to operationalize the lifecycle management of data science workloads, including data ingestion and ETL, feature engineering, development environment setup, CI/CD integration, model versioning, testing, and production deployment
- Familiarity with the technical differences and operational requirements of various AI disciplines (e.g. supervised and unsupervised machine learning, deep learning, natural language processing, neural networks, etc.)
- Deep understanding of the production pain points of data science products
- Prior experience with data science products and use cases

#### Sec

##### Secure

Responsible for leading the team of PMs who manage the [Secure stage groups](/handbook/product/categories/#sec-section). This stage leader sets the vision and direction for how to enable GitLab users to minimize their security risk with continuous identification and prioritization of high-impact vulnerabilities and weaknesses across every stage of the DevOps process. This scope includes identifying, prioritizing, and managing security research requirements across the entire Sec section and working with GitLab's Vulnerability Research team to prioritize those requirements. The Secure GMP works hand in hand with the [Govern stage](/handbook/product/categories/#govern-stage) leader to ensure that their teams, together, are providing a holistic and world-class user experience across all of GitLab's security & compliance offerings.

##### Requirements

- Prior experience building or operating Application Security Testing (AST) products (e.g., SCA, SAST, DAST, etc.) products
- Strong ability to understand the technical details underpinning security testing and software engineering concepts
- Strong ability to define and maintain alignment on product vision and strategy
- Excellent communication skills and ability to drive cross-functional execution

#### Software Supply Chain Security

Responsible for leading the team of PMs who manage the [Software Supply Chain Security stage groups](/handbook/product/categories/#software-supply-chain-security-stage). This stage leader sets the vision and direction for how to enable GitLab users with an effective, scalable, and lovable security and compliance solution. This individual also maintains and champions GitLab's [Software Supply Chain Security (SSCS) direction](https://about.gitlab.com/direction/supply-chain/) and coordinates execution of the SSCS roadmap across all GitLab stages. The Govern GMP works hand in hand with the [Secure stage](/handbook/product/categories/#sec-section) leader to ensure that their teams, together, are providing a holistic and word-class user experience across all of GitLab's security & compliance offerings.

##### Requirements

- Prior experience building operating security or compliance products
- Deep knowledge of challenges in Software Supply Chain Security and how it intersects with each phase of the DevOps process
- Strong ability to define and maintain alignment on product vision and strategy
- Excellent communication skills and ability to drive cross-functional execution

#### Group Manager, Product (GMP) - Hiring Process

Candidates for this position can generally expect the hiring process to follow the order below. Note that as candidates indicate preference or aptitude for one or more specialties, the hiring process will be adjusted to suit. Please keep in mind that candidates can be declined from the position at any stage of the process.

- Selected candidates will be invited to schedule a 30 minute [screening call](/handbook/hiring/#screening-call) with one of our Technical Recruiters
- Next, candidates will be invited to schedule a 60 minute first interview with a Director of Product
- Next, candidates will be invited to schedule a 45 minute peer interview with an Engineering Manager
- Next, candidates will be invited to schedule a 45 minute deep dive interview with a member of the Product team
- Next, candidates will be invited to schedule a 45 minute direct report panel interview with members of the Product team
- Next, candidates will be invited to schedule a 45 minute fifth interview with a VP of Product or above

### Director of Product Management

This role typically manages 4-6 direct reports, including Product Managers and Group Managers of Product Management, and reports to either a [Senior Director of Product Management](#senior-director-of-product-management) or the [VP of Product Management]({{< ref "product-leadership#vp-of-product-management" >}}).

#### Director of Product Management - Job Grade

The Director, Product Management is a [grade 10](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Director of Product Management - Responsibilities

##### Team responsibility

- Perform all non-IC responsibilities of a [Group Manager of Product](#group-manager-product-gmp---responsibilities)
- Contribute to the [job family](/handbook/hiring/job-families/), [CDF](/handbook/product/product-management/product-cdf-competencies/) and [hiring content](https://gitlab.com/gitlab-com/people-group/hiring-processes/-/tree/master/Product) for the Product function
- Help the team to avoid shipping our org chart.
  - Within the area of ownership, ensure that team creates product experiences that solve the job-to-be-done.
  - Across your peer group - work to identify areas to partner with peers to create single app experiences that solve the job-to-be-done.
- Ensure adequate Career Coaching is available to all Product Managers in your organization
- Maintain a comprehensive understanding of GitLab's overall, and Section specific Product Direction to spot, propose and complete appropriate [global optimizations](/handbook/values/#global-optimization) of our R&D investment
- Analyze GTM metrics and propose and complete improvements to our R&D and GTM interactions including [pricing](/handbook/company/pricing/), product positioning and process
- Maintain priorities for and champion [acquisitions](/handbook/acquisitions/) that impact our [product maturity](https://about.gitlab.com/direction/#maturity)
- Perform [product walk-throughs](/handbook/product/product-processes/#walk-through) regularly to highlight opportunities for improved workflows that span groups, stages and section.
- Exemplify, coach others on, and contribute to [GitLab values](/handbook/values/)
- Drive cross-functional, high impact business workstreams outside of the direct area of ownership
- Demonstrate leadership as [expected of Directors across GitLab](/handbook/company/structure/#director-group)
- Contribute strategic improvements to how the [Product Leadership Team](/handbook/product/product-leaders/product-leadership/#product-leadership-team-structure) operates and shape the priorities of the Product Management function

#### Director of Product Management - Requirements

Requirements for the role are outlined as part of the [Product Career Development Framework](/handbook/product/product-management/product-cdf-competencies/#cdf-for-product-leadership).

- Prior experience managing product management managers (e.g., [Group Manager, Product roles](#group-manager-product-gmp)) preferred however not required.

#### Director of Product Management - Career Ladder

The next step for a Director of Product Management is to move to [Senior Director of Product Management](#senior-director-of-product-management).

#### Director of Product Management - Specialties

##### CI

The Director of Product Management, CI is the PM DRI for the [CI Section](/handbook/product/categories/#ci-section) and reports to the VP, Product Management - CI/CD, Enablement, & SaaS Platforms. The CI Section includes the Verify and Package Stages

##### Enablement

The Director of Product Management, SaaS Platforms is the PM DRI for the [Enablement Section](/handbook/product/categories/#enablement-section) and reports to the VP, Product Management - CI/CD, Enablement, & SaaS Platforms. The Enablement Section includes the Systems and Data Store Stages.

##### SaaS Platforms

The Director of Product Management, SaaS Platforms is the PM DRI for the [SaaS Platforms Section](/handbook/product/categories/#saas-platforms-section) and reports to the VP, Product Management - CI/CD, Enablement, & SaaS Platforms. The SaaS Platforms Section includes the SaaS Platforms Stage.

##### Fulfilment

The Director of Product Management, SaaS Platforms is the PM DRI for the [Fulfillment Section](/handbook/product/categories/#fulfillment-section), which owns delivering a flexible and powerful billing and licensing system.  Has the opportunity to work cross-functionally to ensure the billing and licensing system meets our evolving business needs and delivers a world class customer experience.

##### Requirements

- Familiarity with industry leading subscription management and CRM tools (e.g. Zuora, Salesforce)
- Strong communications skills and ability to work cross-functionally, especially with GTM counterparts

#### Director of Product Management - Hiring Process

Candidates for this position can generally expect the hiring process to follow the order below. Note that as candidates indicate preference or aptitude for one or more specialties, the hiring process will be adjusted to suit. Please keep in mind that candidates can be declined from the position at any stage of the process.

- Selected candidates will be invited to schedule a 30 minute [screening call](/handbook/hiring/#screening-call) with one of our Technical Recruiters
- Next, candidates will be invited to schedule a 60 minute first interview with the VP of Product Management
- Next, candidates will be invited to schedule a 45 minute second peer interview with a Product Director
- Next, candidates will be invited to schedule a 45 minute third interview with another member of the Product team
- Next, candidates will be invited to schedule a 45 minute fourth peer interview with an Engineering Director
- Next, candidates will be invited to schedule a 45 minute fifth interview with a Product or Engineering Director or above
- Next, candidates will be invited to schedule a 45 minute Deep Dive interview with a Product Director
- Finally, candidates may be asked to schedule a 50 minute final interview with our CEO

### Senior Director of Product Management

This role typically manages 4-6 direct reports, including Product Managers, Group Managers of Product Management, and Directors of Product Management, and reports to the [VP of Product Management]({{< ref "product-leadership#vp-of-product-managemen" >}}).

#### Senior Director of Product Management - Job Grade

The  Senior Director, Product Management is a [grade 11](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Senior Director of Product Management - Requirements

- Effective at hiring, coaching, and leading a team of 10+ that typically spans numerous stages, and is composed of Directors, Group Managers, and IC's
- Demonstrated ability to manage and coach product validation in brand new market areas
- Skilled at curating excellent cross-stage customer experiences
- Experience and skill managing products at all stages of the lifecycle (incubation, growth, maturity, decline), and balancing priorities and investment accordingly

#### Senior Director of Product Management - Responsibilities

- Visible strategic leader across the company
- Skilled at big stage communications
- Capable of coaching team members on excellent communication skills

#### Senior Director of Product Management - Career Ladder

The next step in the Product Management Leadership job family is to move to the [VP of Product Management](/job-families/product/product-management-leadership/) job family.

#### Senior Director of Product Management - Hiring Process

Candidates for this position can generally expect the hiring process to follow the order below. Note that as candidates indicate preference or aptitude for one or more specialties, the hiring process will be adjusted to suit. Please keep in mind that candidates can be declined from the position at any stage of the process.

- Selected candidates will be invited to schedule a 30 minute [screening call](/handbook/hiring/#screening-call) with one of our Technical Recruiters
- Next, candidates will be invited to schedule a 60 minute first interview with the VP of Product Management
- Next, candidates will be invited to schedule a 45 minute second peer interview with a Product Director
- Next, candidates will be invited to schedule a 45 minute third interview with another member of the Product team
- Next, candidates will be invited to schedule a 45 minute fourth peer interview with an Engineering Director
- Next, candidates will be invited to schedule a 45 minute fifth interview with a Product or Engineering Director or above
- Next, candidates will be invited to schedule a 45 minute Deep Dive interview with a Product Director
- Finally, candidates may be asked to schedule a 50 minute final interview with our CEO

## Performance Indicators

Product Leadership is responsible for building the capacity and capability of their team and the groups they support to achieve:

1. Their [relevant Product Performance Indicators](https://internal.gitlab.com/handbook/company/performance-indicators/product/#structure)
1. Our global [Product KPIs](/handbook/company/kpis/#product-kpis)
1. Job satisfaction of the team members who report to them (as measured by annual employee engagement survey)
1. Hiring versus plan and [new hire location factor](https://internal.gitlab.com/handbook/company/performance-indicators/product/#new-hire-location-factor)
1. IACV attained by assigned [use case](/handbook/marketing/use-cases/#specific-use-cases) as designated in `Why GitLab` of opportunity [Command Plans](/handbook/sales/command-of-the-message/command-plan/) ([Dashboard](https://app.periscopedata.com/app/gitlab/705822/Product-Management-+-Sales-Opportunity-Feedback)).

In addition, some roles have role-specific activities and performance indicators.

### Group Manager

#### Activities

- Completion of competitive analysis of [product adjacencies](https://www.mckinsey.com/industries/technology-media-and-telecommunications/our-insights/grow-fast-or-die-slow-pivoting-beyond-the-core#)
- Delivery of cross-stage adoption Opportunity Canvases, such as [Why SCM users do not adopt CI?](https://docs.google.com/document/d/10AqH6kh1b1wSV61e9Hi3XQiLvt3zzdGxhq0Pi4T5m1U/edit#heading=h.4mt5fmtn0ax4)

#### Performance Indicators

- 1 per quarter adjacencies analysis for Stage OR
- 1 per quarter cross-stage opportunity canvas
