---
title: "Product Manager"
description: "Product Managers at GitLab have a unique opportunity to define the future of the
entire DevOps lifecycle"
---

<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/DVLOyaRbAoM" frameborder="0" allowfullscreen="true"> </iframe>
</figure>

## Role

Product Managers at GitLab have a unique opportunity to define the future of the
entire [DevOps lifecycle](https://about.gitlab.com/stages-devops-lifecycle/). We
are working on a [single application](/handbook/product/single-application) that
allows developers to invent, create, and deploy modern applications.

We want to facilitate [Concurrent DevOps](https://about.gitlab.com/topics/concurrent-devops/) so that teams can work simultaneously instead of sequentially, unleashing collaboration across organizations.

We work in a very unique way at GitLab, where flexibility and independence meet
a high paced, pragmatic way of working. And everything we do is [in the open](/handbook/).

We are looking for talented product managers that are excited by the idea to
contribute to our vision. We know there are a million things we can and want to
implement in GitLab. Be the one making decisions.

We recommend looking at our [about page](/handbook/company/) and at the [product handbook](/handbook/product/)
to get started.

## Core PM Responsibilities

As a product manager at GitLab, you are primarily responsible for:

1. Understanding the problem of our users and customers (Sensing Mechanisms)
1. Defining requirements for a solution that is loved by our users and customers (Product Roadmap & PLG)
1. Establish plans for your team to realize commericial viability from the product (Aligning Teams with Values)
1. Communicating and enabling adoption of your product area and the entire platform (Thought Leadership)

In addition, as a PM, you also play a critical role in the regular development and operating cadence of GitLab. There are a few specific required tasks that the PMs are directly responsible:

| Task | Description |
| --- | --- |
| Maintain and update [Direction pages](https://about.gitlab.com/direction/#devops-stages) | Direction pages communicate our [vision](https://about.gitlab.com/direction/) and plan externally and internally. |
| Review PIs and update [PI pages](https://internal.gitlab.com/handbook/company/performance-indicators/product/) | Product Indicators are how we know whether or not we are making the right investments or measuring the right thing. PMs should be intimately knowledgeable with the PIs in their domain. |
| Release planning for every milestone | PMs are the DRIs for planning and [prioritizing](/handbook/product/product-processes/#prioritization-ahead-of-kickoff) the work for their respective development group. Some of the output for release planning can be planning issues and [kick-off](/handbook/product/product-processes/#kickoff-meetings) videos. |
| Create [release post content](/handbook/product/product-processes/#release-posts) | The release post is the way to broadcast what features have been released. PMs are responsible to ensure release post item MRs are created, reviews are complete and posted. |
| Drive alignment with stable counterparts via [OKRs](/handbook/product/product-processes/#objectives-and-key-results-okrs) | PMs play a role in facilitating alignment by ensuring individual functional groups' objectives are appropriately prioritized within their development group. |
| Connect user and customer insights with [product prioritization](/handbook/product/product-processes/#issues-important-to-customers) | Customer interviewing, collecting insights about customer adoption, pain points, and reprioritizing "What's Next". PMs are responsible for continuously refining the most important feature, bugs, and tech debt to ensure relevance to the market, install base, and expansion. |
| [Triage new issues](/handbook/product/product-processes/#prioritization) (features, bugs, security vulnerabilities, etc) | PMs [share responsibility](/handbook/product/product-processes#prioritization-for-feature-maintenance-and-bugs) for prioritizing the most important issues based on [work type](/handbook/product/groups/product-analysis/engineering/dashboards/#work-type-classification). |
| Determine [pricing tier for features](/handbook/company/pricing/) | [The CEO is responsible for pricing, but PMs are responsible for determining which plan features belong to.](/handbook/company/pricing/#departments) |

### How does a PM ensure they are solving a problem for our users?

PMs should spend a significant amount of time understanding the problems our users face. Deeply understanding the problem is the foundation for all other activities PMs take on; understanding the problem enables the PM to define the vision and prioritize effectively.

In order for a PM to deeply understand the problems our users are facing and determine which are the important problems to solve, they can do the following:

- Have a deep knowledge of each category's problem space
- Regularly talk with users and customers
- Enagage with analysts in the market
- Regularly complete competitive analysis
- Communicate with users on issues and epics
- Work with Pre-Sales and Post-Sales to connect with customers and prospects
- Uncover insights through UX Research
- Use other [sensing mechanisms](/handbook/product/product-processes/sensing-mechanisms/). It is through user interactions that we can begin to understand what problems our users are facing and identify how we could make product improvements to help eliminate the pain points. These user interactions can present themselves in many different ways.

### How does a PM ensure we build lovable products?

Producing a lovable product requires more than a deep understanding of the problem. At GitLab, we build lovable products by adhering to our [values](/handbook/values/). PMs are expected to be the ambassador of the GitLab values by:

- Focusing on [results](/handbook/values/#results).
- Embracing [iteration](/handbook/values/#iteration). This is the secret to GitLab moving fast, as we get constant feedback and maintain forward momentum toward GitLab's huge [vision](https://about.gitlab.com/direction/#vision). PMs play a large role in unlocking iteration as a competency.
- Being [transparent](/handbook/values/#transparency). This will enable both our development group to contribute and just as important, enable the wider GitLab community to contribute.
- Being [efficient](/handbook/values/#efficiency). PMs should advocate for the boring solution, optimize for the right group, be the manager of one, always write things down, so they can help their groups also be efficient.
- Being [collaborative](/handbook/values/#collaboration). PMs ultimately don't ship anything on their own. PMs need to be a great teammate so that the development group can produce great work.
- Being someone who helps make GitLab a work place of [diversity, inclusion, and belonging](/handbook/values/#diversity-inclusion), so that everyone can come to GitLab and do their best work.

### How does a PM ensure business viability for our product?

It is not sufficient to just know the problems. It is also insufficient to have a solution to the problem that our customers love. PMs also need to ensure that the solution is viable for GitLab.

- PMs participate in and follow the [product development flow](/handbook/product-development-flow/) so that their development group can consistently release features [every month](https://about.gitlab.com/releases/).
- PMs [determine the tiers of features](/handbook/company/pricing/)
- PMs ensure that issues that impact GitLab are appropriately [prioritized](/handbook/product/product-processes/#prioritization)
- PMs interface with marketing and sales to promote and enable the sale of the product.

<a id="base-pm-requirements"></a>

### Base Requirements Across All Levels

- Experience in product management
- Strong technically: you understand how software is built, packaged, deployed and operated
- Passion for design and usability
- Highly independent and pragmatic
- Excellent proficiency in English
- Excellent communication skills at all levels, including Executive level communication
- Use [Simple Language](/handbook/communication/#simple-language) and [MECEFU Terms](/handbook/communication/#mecefu-terms) to ensure clear and concise communication
- You are living wherever you want and are excited about the [all remote](/handbook/company/culture/all-remote/) lifestyle
- You share our [values](/handbook/values/), and work in accordance with those values
- Have a growth mindset
- Trust and empower your development group to deliver great products
- Receptive to feedback or coaching
- Strong bias for action
- You make thoughtful decisions motivated by data and research
- You develop strong opinions but are willing to change your mind
- Bonus points: Experience with GitLab, Git, and the Git workflows
- Bonus points: Experience building DevOps tools
- Bonus points: Experience in working with open source projects
- Bonus points: Experience engaging with customers in a B2B setting

### Primary Performance Indicator for the Role

[Stage Monthly Active Users](https://internal.gitlab.com/handbook/company/performance-indicators/product/)

---

## Career paths

The job families are the single-source-of-truth (SSoT) for our job responsibilities related to career paths. For more information on how GitLab Product Management thinks about the growth and development through these different roles, see the [Career Development Framework](/handbook/product/product-management/product-cdf-competencies/).

### Product Manager

Product managers are expected to know their product domain and support the processes or ceremonies of planning of product development at GitLab. They are expected to prioritize and manage their products with some guidance from leadership or other product team members and may even have a mentor or Senior Product Manager assigned as a counterpart to support.

#### Job Grade

The Product Manager is a [grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Requirements

Beyond the [base requirements](#base-pm-requirements), Product Manager requirements are:

- Make regular updates and manage the direction of assigned product areas
- Prioritize the most impactful scope and work with counterparts using the right sensing mechanisms to deliver value for users, customers, and the community
- Independently monitor usage and other metrics in your product areas for signals of investment or priority
- Collaborate and partner closely with Product Design, User Research, Product Marketing, Data Analyst team, and Engineering Counterparts to build a plan that is ambitious and attainable for the product group
- Communicate the user problems and storytell the needs for the team the under the value GitLab should deliver

#### Example Behaviors

The unique needs and circumstances of individual roles may vary; however, the list below outlines some examples of behaviors that may be expected at this level:

##### Product Roadmap & Product Led Growth (PM)

- Maintain a one year direction for your group in partnership with your manager.
- Champion feature development in your group and advocate for what you need to contribute to GitLab's success.
- Maintain a roadmap that helps to progress your categories toward the next level of maturity.
- Be adept at socializing your strategy with others. Share your strategy on direction pages, with your counterparts, and in quarterly strategy reviews.
  - Counterparts, executives, customers, key sales, support, and internal team members can find and understand your strategy when they go to look for it.
- Evaluate and reevaluate the 12 month roadmap priorities on a regular basis to prioritize higher demand items over lower demand items. Remove or deprioritize items that don't have enough demand.
- Collaborate with your manager as needed to push back appropriately on requests to prioritize items that provide comparatively lower value.
- Ensure that milestone priorities are ready to go into development and that requirements are clear for engineering.
- Make a significant business impact (revenue, usage) within the Group.

##### Sensing Mechanisms (PM)

- Reactively meet with customers, internal field (Sales/SAs/CSMs) team members, and internal team members matching personas that are relevant to the group as requested.
- Have a high level understanding of competitors in the space, how GitLab compares, and what opportunities exist to close gaps or get ahead.
- As needed, adapt and change your priorities based on changes in customer demand and based on guidance from your manager as needed.
- Validate roadmap items prior to starting development work with guidance from your manager as needed.

##### Thought Leadership (PM)

- Be knowledgeable about the features and functionality in your group. Be capable of describing your existing feature set as well as your roadmap plans to customers.
- Have a good level of understanding of your group-specific domain.
- Collaborate with marketing and technical writing teams to update docs, publish blog posts, revise our marketing materials, or make other changes as necessary to disseminate information about your group's features and functionality.
- Actively work to improve on the features that your group owns to improve your portion of our scores in key analyst reviews (Gartner MQs for example).

##### Aligning Teams with Values (PM)

- Apply GitLab's values (Results, Iteration, Transparency, Collaboration, Diversity & Inclusion, Efficiency) in the way you do your work.
- Collaborate effectively with your stable counterparts (EM, UX, SET).
- Work with your manager as necessary to resolve any conflicts that arise.
- Work with your manager as necessary to respond appropriately to requests (from sales, customers, developers, executives, others) that are not inline with your vision.
- Communicate your vision to others (sales, customers, developers, executives, others) and gain their support with the help of your manager as needed.
- Balance gathering input and feedback with taking action and making decisions for your area. As the DRI for your area, take ownership for the success of your group.
- Make prioritization changes to your strategy in response to changes in company strategy or overall market conditions as requested by your manager.

### Senior Product Manager

Senior Product Managers are expected to be experts in their product domain and viewed as such to the community and internally at GitLab. They are expected to prioritize and manage their products with minimal guidance from leadership or other product team members.

#### Job Grade

The Senior Product Manager is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Requirements

Beyond the [base requirements](#base-pm-requirements), Senior Product Manager requirements are:

- Independently manages and proactively identifies direction updates related to product areas
- Create annual and quarterly plans to align product group to roadmap deliverables
- Uses multiple sources of data (qualitatative, quantiative) and proactibvely monitors usage data and metrics to inform product direction
- Appropriately influence, persuade, and collaborate closely with Product Design, User Research, Product Marketing, Data Analyst team, and Engineering Counterparts to build an ambitious but realistic plan across the stage

#### Example Behaviors

The unique needs and circumstances of individual roles may vary; however, the list below outlines some examples of behaviors that may be expected at this level:

##### Product Roadmap & Product Led Growth (SPM)

- Create and maintain a one year direction for your group. Have a thesis for how and why your group will create and capture value for customers in your market space.
- Surface investment needs that are truly required for the success of your group.
- Curate and maintain a list of what epics are specifically required to advance your categories to the next level of maturity.
- Be skilled at socializing your strategy with others. Share your strategy on direction pages, with your counterparts, and in regular strategy reviews.
  - Counterparts are familiar with your strategy at a high level.
  - Executives, customers, key sales, support, and internal team members can find and understand your strategy when they go to look for it.
- Evaluate and reevaluate the 12 month roadmap priorities on a regular basis to ensure that the effort required by the top priorities is justified by the expected impact on GitLab's profits. Remove or de-prioritize items from the roadmap that are unlikely to impact profits.
- Push back appropriately on requests to prioritize items that provide comparatively lower value.
- Ensure that 12-month roadmap priorities are clear for engineering.
- Make a significant business impact (drive revenue, reduce costs, increase expansion, reduce churn, etc.) within the Stage.

##### Sensing Mechanisms (SPM)

- Regularly and proactively meet with customers, internal field (Sales/SAs/CSMs) team members, and internal team members matching personas that are relevant to the group to explore and validate their needs.
- Have a working understanding of competitors in the space, how GitLab compares, and what opportunities exist to close gaps or get ahead. Regularly revisit and review competitive products to keep your understanding up-to-date.
- As needed, adapt and change your strategy based on shifts in competitor offerings or market trends.
- As needed, adapt and change your priorities based on new learnings from customers, research findings, and changes to your strategy.
- Ensure all roadmap items are appropriately validated prior to starting development work.

##### Thought Leadership (SPM)

- Be knowledgeable about the features and functionality in your group. Be capable of effectively and convincingly pitching your existing feature set as well as your roadmap plans to customers. Demonstrate an ability to effectively handle objections and dissatisfied customers.
- Have a good level of understanding of your group-specific domain and at least a basic understanding of most aspects of your stage-specific domain.
- Collaborate with marketing and technical writing teams to update docs, publish blog posts, revise our marketing materials, or make other changes as necessary to disseminate information about your stage's features and functionality.
- Actively work to improve on the features that your group owns to improve your portion of our scores in key analyst reviews (Gartner MQs for example). Engage regularly with domain-specific analysts as appropriate and work to influence the analyst's perception and understanding of your area's features and roadmap.

##### Aligning Teams with Values (SPM)

- Apply GitLab's values (Results, Iteration, Transparency, Collaboration, Diversity & Inclusion, Efficiency) in the way you do your work. Coach others within your stage on living values as needed.
- As applicable, collaborate well with PMs across groups and within your stage in planning, prioritizing, and releasing cross-group features.
- Collaborate effectively with your stable counterparts (EM, UX, SET).
- Resolve conflicts as they arise.
- Respond appropriately to requests (from sales, customers, developers, executives, others) that are not inline with your vision.
- Demonstrate an ability to inspire others (sales, customers, developers, executives, others) with your product vision and gain their willing support.
- Balance gathering input and feedback with taking action and making decisions for your area. As the DRI for your area, take ownership for the success of your group.
- As needed, proactively realign and reorient your team in response to changes in company strategy or overall market conditions.

### Principal Product Manager

The Principal Product Manager role extends the Senior Product Manager role expectations by bringing special expertise in a specific domain or product management skill. This includes providing guidance on improvements within this specific domain with a focus on usability and user experience.

#### Job Grade

The Principal Product Manager is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Requirements

Beyond the [base requirements](#base-pm-requirements) and Senior Product Manager Requirements, Prinicipal Product Manager requirements are:

- Operational affluence in annual, quarterly, and monthly planning
- Adept at user journey mapping
- Deep understanding of PLG or experimentation frameworks
- Proven ability to deliver value and generate viable products in market
- Strong storytelling skillset and ability to translate technical requirements into user needs
- Coach and mentor to other Product Managers or active in career development for others
- Recognized as thought leader in the industry (e.g. published author or regular speaker at conferences)

#### Example Behaviors

The unique needs and circumstances of individual roles may vary; however, the list below outlines some examples of behaviors that may be expected at this level:

##### Product Roadmap & Product Led Growth (PPM)

- Have a clear understanding and well articulated message showing how your 3+ year strategy relates to the overall stage strategy and the overall company strategy.
- Advocate for investment decisions that are in the best interest of the company. Present clear business reasons to support your proposed investment decisions.
- Be an expert at socializing your strategy with others. Share your strategy on direction pages, with your counterparts, and in quarterly strategy reviews.
  - Counterparts are able to clearly articulate your strategy themselves and have a personal understanding of how your roadmap priorities relate to your strategy.
  - Key sales, support, and internal team members are familiar with your strategy at a high level.
  - Executives and customers can find and understand your strategy when they go to look for it.
- Use your strategy to guide and drive your roadmap priorities. Artfully balance near-term and long-term impact to profit against the need to also make progress on key strategic initiatives.
- Demonstrate that you place the needs of the stage and company ahead of the needs of your own group. Advocate for your group when that is in the company's best interest and willingly help others when success is best achieved by working outside your group.
- Actively explore partnership and acquisition opportunities for your group. Cultivate and recommend next steps for opportunities that make sense and also avoid investing time in those that don't.
- Make a significant business impact (revenue, usage) across Stages within the Section.

##### Sensing Mechanisms (PPM)

- Cultivate high quality key relationships with a variety of trusted stakeholders who can provide quick feedback on ideas. These stakeholders ideally would include a mix of customers, internal field (Sales/SAs/CSMs) team members, and internal team members matching personas that are relevant to the stage.
- Develop a deep understanding of the closest competitors to the extent possible (reading technical docs, evaluating a free or trial version of the product, discussing with other users).
- Monitor market trends and proactively predict where the market is headed. Engage in collaboration with others as needed when market trends impact other groups or necessitate cooperative efforts across groups.
- Excel at extracting valuable insights from customer discussions even when they don't apply to your area. Ensure that those insights are passed on appropriately to the relevant PM.
- Adapt the level of time and effort spent validating based on your level of confidence in the problem/solution and based on the urgency of starting development.
- Lead cross-stage initiatives, feature development, and/or joint projects.
- Perform build vs buy analysis as needed to evaluate the best strategic approach for adding to product capabilities.
- Build acquisition business cases with the best interests of the company in mind and make thoughtful, data-supported recommendations on which companies to acquire (or to not acquire).

##### Thought Leadership (PPM)

- Be capable of reliably pitching any of the functionality in the section. Be able to expertly describe the value-add that comes from purchasing GitLab. Be informed (at a high level) about roadmap plans across the entire section and be able to field general questions about any part of the section roadmap.
- Be well informed about nearly all key aspects of your stage-specific domain and deeply informed at an expert level about the domain area related to your group. Capable of speaking at both internal and external events such as domain-specific conferences or running webinars as the need arises.
- Collaborate with marketing and technical writing teams to help sell and explain GitLab's features in terms of more holistic use cases which may span across multiple stages and feature sets.
- Collaborate with analysts to identify ways that GitLab can advance its position in the market or to sell analysts on the potential of your vision and roadmap. Be able to speak to the broader value that GitLab provides beyond just your area.
- As appropriate, identify opportunities for your group to work together with other groups in delivering solutions that have a significant impact on GitLab's value proposition. Appropriately inspire others with your vision.
- Drive alignment on cross-stage roadmap internally based on a shared vision across the product.
- Build alignment across sections and with senior leadership.
- Lead out and drive partnership conversations as needed.

##### Aligning Teams with Values (PPM)

- Be an example for others in the way you apply GitLab's values (Results, Iteration, Transparency, Collaboration, Diversity & Inclusion, Efficiency) as you do your work. Help to foster GitLab's values across the section.
- As applicable, collaborate well with PMs across stages and within your section in planning, prioritizing, and releasing cross-group and cross-stage features.
- As required, demonstrate an ability to have difficult conversations or to make potentially unpopular but necessary changes in a way that maintains the support and trust of those you work with.
- Provide a sense of stability, calm, and direction to others around you, even when there are significant changes.
- Recognize and appropriately surface inefficiencies and make appropriate and constructive recommendations on ways those can be improved.
- Regularly uplift, coach, mentor, or motivate other PMs.

### Senior Principal Product Manager

The Senior Principal Product Manager role extends the Principal role expectations. Senior Principal Product Managers are experts across multiple domains within GitLab. They are responsible for helping shape the future direction of the organization, assisting management to establish strategic roadmaps, and driving priorities to meet objectives. As a Director-level individual contributor position, Senior Principal Product Managers are expected to perform at a Grade 10 (Director) level according to our [GitLab Job Framework](/handbook/company/structure/#individual-contributor-job-framework) and exemplify GitLab's [leadership principles](/handbook/leadership/). In addition, Senior Principal Product Managers are expected to:

- Senior Principal Product Managers are expected to drive outsized business results via their direct contributions. This can include shaping product prioritization, representing Product in GTM motions, unblocking R&D via a heavy focus on iteration or the generation and utilization of data to inform where we direct our R&D investment.

- Senior Principal Product Managers should possess a unique level of expertise as well as own specific product domains that extend across sections. This includes providing guidance on improvements within this specific domain with a focus on usability and user experience.

- Senior Principal Product Managers are expected to improve entire sections via their outputs. These will include user, market, competitive and technology insights as well as instituting best practices for other Product Managers.

- Senior Principal Product Managers will use their business skills by directly championing M&A (including researching and finding prospects). They will also collaborate directly with the GTM teams to enable sales on our capabilities that cross the entire product.

The Senior Principal Product Manager will report to a Director of Product Management (or above).

#### Job Grade

The Senior Principal Product Manager is a [grade 10](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

##### Requirements

Beyond the [base requirements](#base-pm-requirements), Senior Principal Product Manager requirements are:

- Represent GitLab and its values in public communication around specific projects and community contributions.
- In addition to being an individual contributor product manager of one (or more) of the groups, the Senior Principal PM should be designated as the [product collaborator](/handbook/engineering/incubation/#incubation-engineering-department) for one (or more) [SEG](/handbook/company/structure/#single-engineer-groups)s.
- Lead cross stage initiatives, for example: [Top Cross-Functional Initiatives](/handbook/company/working-groups/#top-cross-functional-initiatives)
- Maintains and owns [cross-section directions](/handbook/product/product-processes/#navigating-cross-stage-or-cross-section-direction-pages).
-Leads working groups to accomplish cross-section [BHAG](/handbook/company/mission/#big-hairy-audacious-goal-bhag)s and targets
- Identifies and submits investment cases for SEGs, Product Groups, and Categories

#### Requirements

Beyond the [base requirements](#base-pm-requirements), Senior Principal Product Manager requirements are outlined in the [Product Management Career Development Framework](/handbook/product/product-management/product-cdf-competencies/).

#### Example Behaviors

The unique needs and circumstances of individual roles may vary; however, the list below outlines some examples of behaviors that may be expected at this level:

##### Product Roadmap & Product Led Growth (SPPM)

- Make a significant business impact (revenue, usage) within the Group.
- Additional example behaviors are to be added in a future iteration.

##### Sensing Mechanisms (SPPM)

- Additional example behaviors are to be added in a future iteration.

##### Thought Leadership (SPPM)

- Additional example behaviors are to be added in a future iteration.

##### Aligning Teams with Values (SPPM)

- Additional example behaviors are to be added in a future iteration.

### Moving to and moving from

The career paths to and from product management positions are varied, but there are some common patterns.

### Moving to Product Management

Successful product managers have a passion for solving problems. As a result they've
been found to start their journey to product management from the following disciplines:

- **Engineering**: Engineers understand deeply how the product is built and how they work. A desire to understand the user problem of their product
and to further influence product direction can lead engineers to pursue Product Management roles.
- **UX**: Product Designers and UX leaders have built a great understanding of the personas and pain points their product
targets. A desire to further influence not just the experience but the way the features alleviate those
pain points can draw UX professionals to Product Management.
- **Engineering Manager**: Engineering team leaders who've gained a strong understanding of the customer persona, pain
points and direction of a product often want to further influence that direction by transitioning to Product Management roles.
- **QA/QE**: Quality engineers are responsible for the validation of a product and service. Those who
have a passion for understanding and testing how products are used in the real world by real users often
find a strong alignment to the Product Management function.
- **Product Marketing**: Product Marketers with a desire to have more influence in shaping the product often
migrate to the Product Management function.
- **Customer Success**: Customer facing functions like Solutions Architects, Customer Success Managers, and
lead Support techs who've developed a strong understanding of customers' needs in the product often transition
to Product Management out of a desire to shape the direction of the product.

### Moving from Product Management

Within their role, Product Managers are empowered to interact and learn more about functions they are interested in.
Whether that be Marketing, Customer Success, Support, Finance or Engineering - Product Managers are encouraged (and often
required) to understand other functions as part of their daily responsibilities. As such there is plenty of room for
Product Managers to transition to roles outside of the Product Management team. Some of those include:

- **Engineering Leadership**: Product Managers often find a desire to dive deeper into Engineering problems, or grow
mentor and lead engineering teams.
- **Product Marketing**: Product Managers often gravitate to how we target, message and deliver value to our customers.
Product Marketing roles are an excellent way to further that expertise.
- **Customer Success**: Few people know our products as well as Product Managers, and product managers who enjoy directly
solving customers problems on a daily basis make great fits for Customer Success roles.
- **General Management**: As a result of their exposure to a wide variety of functions, Product Managers often make a
transition from Product Management to General Management.

---

## Specialties

### Manage (Organization)

We're looking for product managers that can help us work on the future of developer tools. Specifically, building out our lovable support for GitLab by driving strategy to help organizations prosper and by providing functionality that enables them to manage GitLab for their organization.

#### Requirements

- Understanding of permissions and separation of duties
- Knowledge of the Authentication and Authorization space, such as: SAML, LDAP, OAuth, IdAAS, SSO, SCIM

<figure class="video_container">
  <iframe src="https://www.youtube.com/embed/GhUAv1XlhVU" frameborder="0" allowfullscreen="true"> </iframe>
</figure>

### Manage (Optimize)

We're looking for product managers that can help us work on the future of developer tools. Specifically, building out our lovable support for GitLab by driving strategy to help organizations prosper with Observability and Value Stream Analytics. This role takes advantage of the GitLab's end-to-end DevOps platform and help our users understand the efficiency of their DevOps processes and identify bottlenecks and waste as well as learn best practices from high performing teams.

#### Requirements

- Strong understanding of DevOps and cloud-native application development
- Understanding of Analytics and Metrics

### Manage (Import)

We're looking for product managers that can help us work on the future of developer tools. Specifically, building importers that our customers find valuable, reliable and easy to use, thereby removing friction for migrating to GitLab and creating a more positive first impression when adopting GitLab.

#### Requirements

- Experience with import/export/migration features and funcitonality
- Experience with competitor products

### Create

We're looking for product managers that can help us work on the future of developer tools. Specifically, building out our lovable support for GitLab by driving strategy around git, source code management, code review, and the developer experience.

#### Requirements

- Strong understanding of Git and Git workflows
- Knowledge of the developer tool space and workflows
- Practical understanding of source code management tools such as GitHub, Phabricator, or Gerrit

### Verify (CI)

As a Senior Product Manager in the [Verify Stage](/handbook/product/categories/verify/), you will be directly responsible for the [direction](https://about.gitlab.com/direction/verify/) of a large and important scope in DevOps. Specifically, building out continuous integration (CI), code quality analysis, micro-service testing, usability testing, and more. This product manager owns the foundation of our DevOps product and must have a strong understanding of DevOps, CI/CD, and Release Automation. A practical understanding of container technologies including Docker and Kubernetes will come in handy as this role will reach across various groups to ensure we are building scalable, maintainable, and performant solutions.

#### Requirements

- Strong understanding of DevOps, CI/CD, and Release Automation
- Practical understanding of container technologies including Docker and Kubernetes
- Familiarity with software development automation and tools

### Release (CD)

We're looking for product managers that can help us work on the future of the [Release stage](https://about.gitlab.com/direction/release/) and [deployment](https://about.gitlab.com/direction/delivery/) capabilities at GitLab. The PM will work on building out continuous delivery (CD), release orchestration, features flags, and more.

#### Requirements

- Strong understanding of DevOps, CI/CD, and Release Automation
- Understand the challenges of complex, enterprise-level deployment
- Practical understanding of container technologies including Docker and Kubernetes
- Practical understanding of progressive delivery and advanced deployment techniques

### Configure

We're looking for product managers to help us work on the future of DevOps tools; specifically, building out configuration management and other operations-related features.

#### Requirements

- Strong understanding of CI/CD, configuration management, and operations
- Understanding of deployment infrastructure and container technologies
- Practical understanding of container technologies including Docker and Kubernetes

### Package

We're looking for product managers to cover the [Package stage](/handbook/product/categories/#package) of our DevOps lifycle. This candidate will work specifically on features related to the Docker container registry.

#### Requirements

- Strong understanding of CI/CD and container management
- Understanding of the complexity of managing multi-artifact application deployment
- Practical understanding of deployment infrastructure and container technologies including Docker and Kubernetes

### Monitor

We're looking for product managers to build the future of [Monitoring stage](https://about.gitlab.com/direction/monitor/). This PM will work to build out the Monitor categories and features, such as Incident Management, Synthetics, and observability tools.

#### Requirements

- Strong understanding of the SRE persona and their workflow
- Practical understanding of observability

### Distribution

We're looking for product managers to support our [Distribution group](/handbook/product/categories/#admin) and manage our installation, upgrade, and configuration process for our self-managed customers.

#### Requirements

- Strong understanding of system administration
- Practical understanding of deployment infrastructure and container technologies including Docker and Kubernetes

### Secure (Composition Analysis)

We're looking for product managers who can help us empower our users to leverage open source software with confidence by giving them the tools they need to secure their OSS components and meet OSS license compliance requirements.

#### Requirements

- Strong understanding of CI/CD and automated security testing
- Practical understanding of deployment infrastructure and container technologies, including Docker and Kubernetes
- Strong understanding of DevOps and cloud-native application development
- Bonus points: Significant prior experience with software composition analysis

### Software Supply Chain Security

- Strong understanding of SIEM and operational security
- Practical understanding of deployment infrastructure and container technologies including Docker and Kubernetes

### Product Intelligence

Are you a PM who loves data? Are you interested in being at the nexus of GitLab's internal product data AND our building out of tools that enable our customers to derive insights from their product usage data? We're looking for a product manager to join our [Analytics section](https://about.gitlab.com/direction/analytics/) who can help us mature our product usage data set to enable better decision making across the entire company while also building on top of GitLab's built in Product Analytics capabilities to complete the [outer DevOps loop](https://about.gitlab.com/blog/2021/01/20/journey-to-the-outer-loop/).

#### Requirements

- Strong analytical skills, including an ability to translate business needs back to underlying data sets and structures
- Previous experience building scalable data and analytics products
- Excellent communication skills at all levels, including Executive level communication
- Experience balancing cross-functional stakeholder collaboration across GTM, Engineering, and Product teams
- Experience with Developer, Product and Data Analysis personas and the markets for tools that support these personas

### Product Analytics

Do you have a passion for ensuring what gets shipped to users is valuable? Are you a Product Manager who has always wanted to build tools that enable other Product Managers and whole organization to make data driven decsions? GitLab's Analytics section will enable different stakeholders (from product, engineering to finance) to answer the key question of DevOps delivery - is what I built valuable to my users?

We're looking for a Product Manager to chart GitLab's course in this new stage specifically as we invest in it's key category - Product Analytics.

#### Requirements

- Strong understanding of, and experience in Product Analytics tools market
- Practical understanding of product analytics instrumentation and developer workflows
- Practical understanding of high-volume data ingest, data warehousing, data visualization and insight generation platforms
- Experience in [Product-Led Growth](https://productled.com/blog/product-led-growth-definition/) companies
- Experience as a Growth Product Manager
- Experience in new product development and launch

### Fulfillment

We're looking for a PM to ensure an excellent purchase, trial, upgrade, seat addition, and renewal experience for GitLab customers. This role will involve creating a flexible and powerful billing and licensing system upon which we can build world class customer experiences. The role will also involve important system level integrations with key 3rd party systems such as Zuora and Stripe.

#### Requirements

- Strong business operations skills and an ability to think systematically about complex workflows and work cross-functionally to ensure an excellent end-to-end customer experience
- Previous experience with high scale billing & licensing systems
- Familiarity with commercial best practices for no touch, sales assisted, and partner assisted transactions
- Excellent communication skills at all levels, including e-group

### Platforms - GitLab Dedicated

We're looking for a product manager to mature GitLab Dedicated, GitLab's Enterprise DevSecOps Platform as a single-tenant SaaS deployment. This role will involve defining a compeling roadmap that focuses on delivering customer results and growing Dedicated as a platform. You will work closely with several engineering teams and with teams across GitLab to drive adoption of Dedicated.

#### Requirements

- Practical understanding of what it takes to run a SaaS service
- Strong ability to work cross functionally, and through ambiguity
- Excellent communication skills and the ability to translate complex requirements into actionable iterations
- Experience working with customers in highly-regulated industries

#### Responsibilities

- Drive the adoption of GitLab Dedicated
- Collaborate with Engineering and other teams to build a strong foundation (automated, re-usable, extensible)
- Collaborate closely with sales, professional services, support and go-to market teams to scale Dedicated
- Refine pricing and packaging of Dedicated features
- Manage P&L statement for the service

### Platforms - Delivery & Scalability

We're looking for a product manager to work closely with our Delivery and Scalability teams, which are responsible for the operational aspects of our multi-tenant SaaS service, GitLab.com. This role will involve defining the future of how GitLab delivers and operates software on multi-tenant SaaS systems.

#### Requirements

- Strong technical and software architecture foundation
- Practical understanding of what it takes to operate SaaS applications at scale
- Familiarity with the full DevOps lifecycle and effective implementations

#### Responsibilities

- Refine & prioritize the Scalability & Delivery backlog
- Define the vision for how we operate SaaS services as a Product
  - Core framework and tools to empower other teams to deploy & operate their code
  - For example, patterns/framework for: Logging, Cost, Observability, Deployments, etc.
  - Make use of GitLab features where ever possible, and contribute back to the product
- Error Budgets & Cost Dashboard tools/process (using data from above framework)
  - Set Error Budget & Cost targets, enable groups to see their status

### Search

We're looking for a product manager to make finding anything in the one DevOps Platform easy and delightful. Your goals are to improve the overall search experience within GitLab, across all of the content within our single application. You'll ensure the solution can scale from small self-managed instances to large deployments like GitLab.com. An ideal candidate has a proven track record of delivering great search experiences at scale, and is familiar with the rapidly changing landscape of recommendation and search systems.

#### Requirements

- Strong understanding of search engines, algorithms, and workflows
- Excellent communication skills and the ability to translate complex requirements into actionable iterationsn
- An ability to define and analyze key metrics to inform product direction
- Experience with code search is a plus
- Experience with utilizing machine learning to improve the search experience is a plus

### Geo

We're looking for a PM to improve our disaster recovery, global performance, and backup and restore capabilities. GitLab is a business-critical application and keeping GitLab available even when things go wrong is critical to the success of our customers. Your goal is to build robust, scalable and easy to use solutions that help systems administrators stay within their business continuity targets (RTO and RPO) and to ensure that GitLab's users have a great user experience wherever they are located.

#### Requirements

- Experience building business-critical applications, such as backup solutions, disaster recovery, highly-available systems.
- Excellent communication skills and the ability to translate complex requirements into actionable iterations
- Demonstrated ability to work in a cross-functional team
- Experience in agile best practices is a plus

### Application Performance & Database

We're looking for a PM to drive improvements to the responsiveness and scalability of GitLab, and establish best practices for performance oriented development. This role will involve proactively identifying and prioritizing performance hotspots, leading needed architectural changes for additional scalability and efficiency, and delivering improvements to our development process for writing performant code.

#### Requirements

- An understanding of how complex applications function, and an ability to think systematically about application flows
- Strong analytical skills, and a quantitative approach to incremental performance improvements
- Ability to translate best practices into product changes for GitLab
- Hands-on experience with databases, caching strategies, and web applications

### Switchboard

We're looking for a PM to build the [GitLab Dedicated](https://docs.gitlab.com/ee/subscriptions/gitlab_dedicated/) administrative portal (Switchboard). Customers using GitLab Dedicated (ie tenants) should have a delightful experience provisioning and managing their GitLab instance with little to no support from GitLab. Tenants should be empowered to change configurations, such as SAML, Private Link or the IP allowlist. Your goal is to work closely with tenants and prospective customers to identify critical jobs to be done. You'll then work with the engineering team to develop Switchboard from Prototype to General Availability and beyond.

#### Requirements

- Demonstrated experience developing a new product from concept to production
- Experience working on administrative portals for SaaS platforms
- Excellent communication skills and the ability to translate complex requirements into actionable iterations
- Confident working with executive stakeholders
- Demonstrated ability to work in a cross-functional team
- Experience with the fullfilment lifecycle is a plus

### US Public Sector

We're looking for a PM to build the GitLab services for the US Public Sector. As the PM for the US Public Sector Services group, you'll work directly with US Public Sector entities, external assessors and internal stakeholders to define product requirements and ensure successful implementation of GitLab services.

#### Requirements

- Experience with compliance programs, such as FedRAMP, SOC2, or ISO
- Excellent communication skills and the ability to translate complex requirements into actionable iterations
- Confident working with stakeholders across the company to push compliance programs forward
- Demonstrated ability to work in a cross-functional team

### Pods

We're looking for a PM to define GitLab's long-term scalability strategy both for our GitLab.com SaaS platform and self-managed customers. This role is critical to define key customer requirements, for example increased service availability or support for multiple regions and then work with some of the best and most senior engineers at GitLab to execute on that strategy, for example by possibly implementing a [Pod-like architecture](https://gitlab.com/groups/gitlab-org/-/epics/7582).

#### Requirements

- Experience working on scalability challenges for SaaS platforms and/or self-managed platforms
- Excellent communication skills and the ability to translate complex requirements into actionable iterations
- Confident working with executive stakeholders
- Demonstrated ability to work in a cross-functional team

### Ecosystem

We're looking for a product manager to drive the strategy for GitLab as a platform. Ecosystem's goal is to make integrating with, extending the functionality of, or contributing to GitLab accessible to all of our users.

#### Requirements

- Experience building products where developers and 3rd party systems are the primary customers.
- Familiarity with technologies that facilitate system integration including SDKs, APIs and Webhooks.
- Understanding of the DevOps lifecycle tools and integrations is a plus.
- First-hand experience in software engineering and architecture.

### Foundations

We're looking for a product manager that can help us improve GitLab user experience and tie experiences together across a platform. Specifically, building out our lovable support for GitLab by driving strategy to build and rollout the GitLab Design System and cross-stage foundational experiences like documentation and navigation.

#### Requirements

- Experience working on internal products consumed by other teams within a company.
- Excellent communication skills at all levels, including working with executive stakeholders.
- Understanding of the UX design best practices. Bonus points if
  - Experience working as a designer.
  - Experience building design systems.
  - Familiarity with SUS.

### Product Planning

We're looking for a product manager to drive the roadmap for portfolio management functionality at GitLab! Your goal is to increase adoption of GitLab Plan capabilities with non dev personas including Product Managers, Project Managers and Executives while maintaining a delightful experience for dev personas.

#### Requirements

- Passion for building tools that help teams be more effective.
- Experience working on products where executives are the target end users.
- Knowledge of Plan space would be ideal. This includes:
  - Scaled agile planning methodologies like SAFe, Spotify and LeSS.
  - Value stream management.
  - Understanding of various organizational models and their trade-offs.

### ModelOps (Anti-abuse)

We're looking for a Product Manager to drive the roadmap for [Anti-Abuse](https://about.gitlab.com/direction/anti-abuse/) at GitLab! Your goal is to help GitLab protect our flagship SaaS product, GitLab.com and self-managed customer instances from abuse and misuse. You'll help eradicate fake accounts, proactively identify and remove bad actors, and help GitLab better understand our legitimate users. This role will directly protect the stability, performance, and scalability of GitLab for millions of users across the world ensuring they can effectively use GitLab for their daily development needs.

#### Requirements

- Experience working to protect SaaS products from abuse.
- Strong understanding of abuse tactics for SaaS products.
- Practical understanding of challenges of running massive public SaaS platforms with open registration and user accessible compute resources.
- Knowledge of techniques to identify abusive usage from legitimate user activity.
- Experience with global products across different markets, cultures, and languages worldwide.
- Demonstrated ability to work in a cross-functional team in a large Product organization.

### ModelOps (MLOps)

We're looking for a Product Manager to drive the roadmap for [MLOps](https://about.gitlab.com/direction/modelops/mlops) at GitLab! This group is focused on enabling GitLab users to build and run data science workloads across [GitLab's One DevOps Platform](https://about.gitlab.com/stages-devops-lifecycle/). This individual will lead an expansion of GitLab's [core personas](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/ci/#personas) to address the needs of data science teams and will work cross-functionality with [other GitLab stages](/handbook/product/categories/#devops-stages) to ensure our platform supports ML/AI workloads and drive our [core differentiators](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/usecase-gtm/ci/#top-3-gitlab-differentiators) for ML/AI use cases. This individual will be responsible for developing new revenue-generating products and enhancing existing product features used by millions of users across the world.

#### Requirements

- Knowledge of how to operationalize the lifecycle management of data science workloads, including data ingestion and ETL, feature engineering, development environment setup, CI/CD integration, model versioning, testing, and production deployment
- Familiarity with the technical differences and operational requirements of various AI disciplines (e.g. supervised and unsupervised machine learning, deep learning, natural language processing, neural networks, etc.)
- Deep understanding of the production pain points of data science products
- Prior experience with data science products and use cases
- Demonstrated ability to work in a cross-functional team in a large Product organization.

## Relevant links

- [Product Handbook](/handbook/product/)
- [Engineering Workflow](/handbook/engineering/workflow/)
