---
title: "Technical Writer"
description: "At GitLab, our team of technical writers is responsible for ensuring that the documentation for all of our products is clear, correct, comprehensive, and easy to use."
---

At GitLab, our [team of technical writers](/handbook/product/ux/technical-writing/) is responsible for ensuring that the [documentation](https://docs.gitlab.com/) for all of our products is clear, correct, comprehensive, and easy to use. We are looking for great writers with strong technical proficiencies to help our users succeed with our [rapidly evolving suite of DevOps tools](https://about.gitlab.com/releases/).

## Responsibilities

- Collaborate with GitLab engineers, who typically write the first draft of documentation for the new features they create.
- Dive in on special projects, planning and authoring new content, and helping to develop new docs site features and processes.
- Collaborate with others across the organization to craft new and improved content. You'll be at the leading edge of DevOps while contributing to one of the [world's largest open-source projects](https://about.gitlab.com/blog/2017/07/06/gitlab-top-30-highest-velocity-open-source/) and engaging with our wider community.

## Requirements (all levels)

- You have:
  - Experience working with a docs as code workflow.
  - Experience planning, researching, writing, and editing software documentation.
  - Excellent skills in grammar, minimalist documentation design, and effective information architecture.
  - Experience using the Linux shell and command-line Git.
  - General familiarity with one or more coding languages.
  - Experience with some of the following:
    - DevOps tools and open-source software.
    - A rapidly scaling start-up environment.
    - Remote work, especially in collaboration with others across countries and time zones.
- You are:
  - Highly organized and able to triage and prioritize numerous issues and projects.
  - Able to succeed in a remote, globally distributed work environment.
- You share our [values](/handbook/values/), and work in accordance with those values.
- You demonstrate our [remote work competencies](/handbook/people-group/competencies/#remote-work-competencies), and model respectful and professional [communication](/handbook/communication/#effective-communication-competency).
- You have experience with workflows and tooling used by engineering, operations, and product teams.

## Levels

### Technical Writer (Intermediate)

The Technical Writer (Intermediate) reports to the Manager, Technical Writing.

#### Technical Writer (Intermediate) Job Grade

The Technical Writer (Intermediate) is a [grade 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Technical Writer (Intermediate) Responsibilities

- **Content**: Create, merge, and maintain product documentation and release posts for assigned product groups. Balance priorities.
- **Structure**: Ensure newly developed content uses [content topic types](https://docs.gitlab.com/ee/development/documentation/topic_types/) to make product documentation easier to scan.
- **Organization**: Ensure that product documentation pages in your assigned groups are well organized by using good naming and logical groupings.
- **User interface**: Create or improve user interface text, such as field labels or error messages, with a focus on your assigned groups.
- **Reviews**: Provide effective reviews for content created by others mainly within your assigned groups, based on relevant style guides.
- **Product knowledge**: Understand the technology and features of the development groups to which you're assigned.
- **Process**: Contribute changes that help the organization evolve the culture and best practices.
- **Communication**: Communicate effectively and professionally with other team members.
- **Leadership**: Act as the Technical Writing lead for assigned groups.

### Senior Technical Writer

The Senior Technical Writer reports to the Manager, Technical Writing.

#### Senior Technical Writer Job Grade

The Senior Technical Writer is a [grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Senior Technical Writer Responsibilities

Extends the Technical Writer (Intermediate) responsibilities in complexity and scope.

- **Content**: Efficiently create, merge, and maintain product documentation and release posts for assigned product groups. Guide improvements to merge requests. Suggest and balance priorities.
- **Structure**: Implement content topic types in both new and previously created content to make product documentation easier to scan.
- **Organization**: Ensure that product documentation pages are well organized in your assigned stage by using good naming and logical groupings.
- **User interface**: Actively create or improve user interface text, such as field labels or error messages, with a focus on your assigned stage.
- **Reviews**: Provide effective and efficient reviews for content created by others across your assigned stage, based on relevant style guides.
- **Product knowledge**: Deeply understand the technology and features of the development groups to which you're assigned, and have a general understanding of your assigned stage.
- **Process**: Contribute changes that help the organization evolve the culture and best practices.
- **Communication**: Communicate effectively and professionally with other team members.
- **Leadership**: Act as the Technical Writing lead for assigned groups and stages.
- **Recruiting**: Be available to interview potential technical writing candidates.
- **Mentoring**: Mentor other technical writers and team members regarding best practices and other process knowledge.

### Staff Technical Writer

The Staff Technical Writer reports to the Senior Manager, Technical Writing.

#### Staff Technical Writer Job Grade

The Staff Technical Writer is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Staff Technical Writer Responsibilities

Extends the Senior Technical Writer responsibilities in complexity and scope.

Progression beyond a Senior role is not guaranteed by length of time in the role. A need for the Staff role must be justified and the candidate must have some level of demonstrated ability to thrive in the role to be considered for the new position.

These next level opportunities are not guaranteed to be available and should not be viewed as career limiting. Senior Technical Writer is a critical role within GitLab. It is an accomplishment to thrive at the Senior level and should be celebrated as such.

- **Content**: Efficiently create, merge, and maintain product documentation within groups as needed, or across product groups and stages. Guide improvements to documentation and merge requests. Suggest and balance priorities.
- **Structure**: Actively develop and implement content topic types in both new and previously created content to make product documentation easier to scan and comprehend.
- **Organization**: Ensure that product documentation pages are well organized across stages by using good naming and logical groupings.
- **User interface**: Create model examples of user interface text, including field labels or error messages, with a cross-stage focus. Actively improve style guide and [Pajamas](/handbook/product/ux/pajamas-design-system/) content related to user interface text.
- **Reviews**: Model review practices that improve the quality of contributions over time. Support and guide team members to improve reviews in their groups and stages.
- **Product knowledge**: Understand the technology and features of both the development stages to which you're assigned and the end-to-end GitLab product to help improve the documentation, information architecture, and docs site.
- **Process**: Actively contribute documentation workflow changes that help the team evolve the culture and best practices.
- **Cross-stage collaboration**: Drive collaboration across stages by helping technical writers and managers identify dependencies and areas for cross-departmental work.
- **Communication**: Communicate effectively and professionally in all areas, and be a model for effective collaboration.
- **Leadership**: Identify and lead cross-stage projects that improve the deliverables or processes of the Technical Writing team. Model professionalism in all areas. Be an effective thought partner with management to help make technical or project decisions for the team. Be a team leader in a particular segment of responsibility that the team requires: AI, technology, process, content, UX writing, statistics and metrics, and others.
- **Recruiting**: Be available to interview potential technical writing candidates.
- **Mentoring**: Mentor other technical writers and team members around suggesting and balancing priorities, industry best practices, and other process knowledge.

### Principal Technical Writer

The Principal Technical Writer reports to the Director, Technical Writing.

#### Principal Technical Writer Job Grade

The Principal Technical Writer is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades). The Principal Technical Writer has extensive experience in a Staff-level role.

#### Principal Technical Writer Responsibilities

Extends the Staff Technical Writer responsibilities in complexity and scope.

- **Content**: Efficiently create, merge, and maintain product documentation within groups as needed, or across product groups. Guide improvements to merge requests. Help set priorities at a team level.
- **Structure**: Actively implement content topic types in both new and previously created content to make product documentation easier to scan.
- **Organization**: Ensure that product documentation pages are well organized across stages by using good naming and logical groupings.
- **User interface**: Provide expert guidance on user interface text. Actively improve style guide and [Pajamas](/handbook/product/ux/pajamas-design-system/) content.
- **Reviews**: Foster effective review practices for team and community contributions to GitLab documentation and user interface changes.
- **Product knowledge**: Deeply understand the technology and features of the development stage to which you're assigned, and have a general understanding of the end-to-end GitLab product to help improve the information architecture of the docs site.
- **Process**: Actively contribute changes that help the organization evolve the culture and best practices, and lead efforts to encourage other team members regarding contributions.
- **Communication**: Communicate effectively and professionally across all product groups and stages, and be a model for collaboration with community contributors.
- **Leadership**: Identify and lead cross-GitLab department projects that improve the deliverables or processes of the Technical Writing team.
- **Recruiting**: Be available to interview potential technical writing candidates.
- **Mentoring**: Mentor other technical writers and team members regarding best practices and other process knowledge.
- **Impact**: Provide positive influence on the adoption of [stages per organization](https://internal.gitlab.com/handbook/company/performance-indicators/product/#stages-per-organization-spo) through more usable documentation, with the ultimate goal being a contribution to higher [ARR](/handbook/sales/sales-term-glossary/arr-in-practice/#annual-recurring-revenue-arr).

## Performance Indicators

- [Technical Writing team member MR rate](/handbook/product/ux/performance-indicators/#technical-writing-team-member-mr-rate)
- [Technical Writing collaboration on UI text](/handbook/product/ux/performance-indicators/#technical-writing-collaboration-on-ui-text)

## Hiring Process

Candidates for this position can expect the hiring process to generally follow these steps. Please keep in mind that candidates can be declined from the position at any stage of the process.

1. Candidates who demonstrate interest in the role will be asked to share work samples and respond to questions related to technical writing.
1. Qualified candidates will be invited to schedule a 30-minute [screening call](/handbook/hiring/interviewing/#screening-call) with one of our Global Recruiters. In this call, we will discuss your experience, understand what you are looking for in a Technical Writing role, talk about your work and approach to technical writing, discuss your compensation expectations and reasons why you want to join GitLab, and answer any questions you have.
1. If you successfully pass the screening call, you will be invited to schedule a 50-minute interview with our Technical Writing Manager. In this interview, we will want you to talk through the approach you took in the examples of work you shared as part of your application, your experience up to now, understand what you're looking for in a technical writing position, and answer any questions you have.
1. The next interview is 50-minutes long and with one of our Technical Writers. We'll discuss your experience, why you're looking to join GitLab, your domain experience, and what it's like to be a technical writer at GitLab. We'll assess your alignment with our [values](/handbook/values/#credit), and answer any questions you have.
1. Next, you'll meet with a cross-functional partner from our Product, Engineering, or Customer Support team for a 50-minute interview. We'll discuss your experience and why you're looking to join GitLab. We'll assess your alignment with our [values](/handbook/values/#credit), and answer any questions you have.
1. Finally, you'll meet our Senior Manager, Technical Writing for a 50-minute interview. At this stage, we'll look to understand your views on how documentation impacts user experience and your experience up to now. You'll have a discussion around technical writing maxims, and the interviewer will answer any questions you have.

Additional details about our process can be found on our [hiring page](/handbook/hiring/).
