---
title: "Technical Writing Management"
---

Technical Writing Managers, part of the UX department at GitLab, support their teams by helping to create an environment in which everyone can succeed. While they are credible as Technical Writers and know the details of technical writing processes, their time is spent hiring and supporting a world-class team. They own the delivery of technical writing commitments and are always looking to improve productivity and process. They must also coordinate across departments to accomplish collaborative goals.

## Manager, Technical Writing

The Technical Writing Manager reports to a Senior Manager or Director of Technical Writing. A team of Technical Writers report to the Technical Writing Manager.

### Job Grade

The Technical Writing Manager is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Responsibilities

- Hire, manage, and support a world-class team of remote Technical Writers.
- Promote a results-focused approach and work-life balance by helping to balance assignments across the team when workloads are uneven, manage conflicting priorities, and prevent over-resourcing.
- Make sure Technical Writers effectively prioritize high-priority feature release work with other content, experience, and process improvements.
- Help Technical Writers refine their writing skills by spot-checking content and providing editorial feedback.
- Encourage efficient collaboration by defining processes that align with the rest of the product and engineering teams, are consistent and efficient, and use GitLab capabilities (like labels) to power process flows and metrics.
- Create practices that encourage keeping documentation up to date and easily discoverable.
- Promote and optimize the experience for documentation contributions from the GitLab team and the wider GitLab community.
- Deliver input on promotions, function changes, demotions, and offboarding in consultation with the other Technical Writing Managers, the Technical Writing Director, and the VP of UX.

### Requirements

- Experience in creating and managing online documentation is a hard requirement for this role.
- Previous experience using Git is a hard requirement for this role.
- A clear philosophy about how to successfully manage remote technical writing teams.
- Proven experience in managing, mentoring, and training teams of Technical Writers.
- Experience working on production-level documentation.
- Self-motivated and robust organizational skills.
- Substantial written and spoken communication skills.
- Familiarity with static site generators, HTML, CSS.
- Experience with workflows and tooling used by engineering, operations, and product teams.
- Familiarity with continuous integration, containers, Kubernetes, and project management software a plus.
- Experience engaging with a wide range of stakeholders across a company, its customers, and/or open-source communities.
- Share our [values](/handbook/values/) and work in accordance with those values.
- [Adhere to our view of Leadership at GitLab](/handbook/company/structure/#management-group)

### Performance indicators

View [UX Department Performance Indicators](/handbook/product/ux/performance-indicators/) for this position.

### Hiring Process

- Screening call with a recruiter.
- Interview with a Technical Writing Manager. The peer interviewer will spend time learning about your managerial experience, your experience with docs-as-code workflows, how you define strategy, how you work with cross-functional partners, how you handle conflict, and how you have dealt with difficult situations in the past.
- Interview with a Technical Writer. The interviewer will spend time learning about your management style, your approach to writing work, your experience with docs-as-code workflows, and your technical abilities.
- Interview with the Technical Writing Director. The interviewer will spend time learning about your work, management, and collaboration styles and your career goals.
- Interview with the VP of UX. The interviewer will spend time learning about your leadership experience, management style, and why you want to join GitLab.

## Senior Manager, Technical Writing

The Senior Manager of Technical Writing reports to the Director, Technical Writing. Technical Writing Managers can report to the Senior Manager of Technical Writing.

### Job Grade

The Senior Manager, Technical Writing is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Responsibilities

- Hire, retain, and support a world-class team of Technical Writers and Technical Writing Managers.
- Actively advocate for Technical Writing throughout the company.
- Mentor managers and writers to grow their soft skills and technical experience.
- Make docs.gitlab.com an exceptional experience by coordinating UX research, metrics, planning, design, and development work.
- Identify opportunities for process improvement, including automation, and coordinating the implementation and communication of these changes.
- Promote efficiency and usability using a clear content strategy that defines the types and structure of content, as well as optimal workflow and continued maintenance.
- Deliver input on promotions, function changes, demotions, and offboarding in consultation with the Technical Writing Managers and the VP of UX.
- Collaborate with Director, Technical Writing on quarterly [Technical Writing OKRs](/handbook/company/okrs/) and [Performance Indicators](/handbook/product/ux/performance-indicators/).

### Requirements

- Experience in creating and managing online documentation.
- Previous experience in using command-line Git.
- Experience working on production-level documentation.
- Proven experience in managing, mentoring, and training teams of Technical Writers and Technical Writing Managers.
- Self-motivated and robust organizational skills.
- Substantial written and spoken communication skills.
- Familiarity with static site generators, HTML, CSS.
- Able to use GitLab.
- Experience with workflows and tooling used by engineering, operations, and product teams.
- Familiarity with Continuous Integration, Containers, Kubernetes, and Project Management software a plus.
- Able to work with the wider GitLab community.
- Experience collaborating with cross-functional partners at all levels of seniority.
- Able to shape documentation process in a high-growth, quickly changing organization.
- Able to give clear, timely, and actionable feedback.
- You share our [values](/handbook/values/) and work in accordance with those values.
- [You adhere to our view of Leadership at GitLab.](/handbook/company/structure/#management-group)

### Performance indicators

View [UX Department Performance Indicators](/handbook/product/ux/performance-indicators/) for this position.

### Hiring Process

- Screening call with a recruiter.
- Interview with a Technical Writing Manager. The interviewer will spend time learning how you think about a tech writing team within an organization, ways of ensuring the team is well-positioned to produce content that has a substantial impact on the user experience, and specific examples of large content initiatives.
- Interview with a Technical Writer. The interviewer will spend time learning about the experiences and challenges you've had as a manager, along with the documentation-related tooling you are comfortable with, and how you've addressed various content usability considerations.
- Interview with the Technical Writing Director. The interviewer will spend time learning about your experience as a manager, your management style, your approach to content usability and improvement, your mentoring experience, and career goals. Be prepared to talk about your work and technical abilities, too.
- Interview with the VP of UX. The interviewer will spend time learning about the types of teams you have led, your management style, how you define strategy, and how you've handled difficult situations.

## Director, Technical Writing

The Director of Technical Writing reports to the VP of UX. Technical Writing Managers, Senior Technical Writing Managers, and Full Stack Engineers, Technical Writing report to the Director of Technical Writing.

### Job Grade

The Director, Technical Writing is a [grade 10](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

### Responsibilities

- Hire, retain, and support a world-class team of Technical Writers, Technical Writing Managers, and Full Stack Engineers, Technical Writing.
- Actively advocate for Technical Writing throughout the company.
- Mentor team members and managers to grow their soft skills and technical experience.
- Make docs.gitlab.com an exceptional experience by coordinating UX research, metrics, planning, design, and development work.
- Identify opportunities for process improvement, including automation, and coordinating the implementation and communication of these changes.
- Promote efficiency and usability using a clear content strategy that defines the types and structure of content, as well as optimal workflow and continued maintenance.
- Deliver input on promotions, function changes, demotions, and offboarding in consultation with the Technical Writing Managers and the VP of UX.
- Independently manage [Technical Writing OKRs](/handbook/company/okrs/) and [Performance Indicators](/handbook/product/ux/performance-indicators/).
- Communicate significant Technical Writing strategy decisions to senior leadership.
- Manage the Technical Writing budget with oversight from the VP of UX.

### Requirements

- Proven experience in managing, mentoring, and training teams of Technical Writers and levels of Technical Writing management.
- Previous experience in using command-line Git.
- Experience working on production-level documentation.
- Self-motivated and robust organizational skills.
- Substantial written and spoken communication skills.
- Familiarity with static site generators, HTML, and CSS.
- Ability to use GitLab.
- Experience with workflows and tooling used by engineering, operations, and product teams.
- Familiarity with Continuous Integration, Containers, Kubernetes, and Project Management software a plus.
- Able to work with the wider GitLab community.
- Experience collaborating with cross-functional partners at all levels of seniority.
- Able to shape documentation process in a high-growth, quickly changing organization.
- Able to give clear, timely, and actionable feedback.
- You share our [values](/handbook/values/) and work in accordance with those values.
- [You adhere to our view of Leadership at GitLab](/handbook/company/structure/#management-group).

### Performance indicators

- [Hiring Actual vs Plan](/handbook/product/ux/performance-indicators/#hiring-actual-vs-plan)
- [Diversity](/handbook/product/ux/performance-indicators/#diversity)
- [Team Member Retention](/handbook/product/ux/performance-indicators/#team-member-retention)

### Hiring Process

- Screening call with a recruiter.
- Interview with Technical Writer. The interviewer will spend time learning about the experiences and challenges you've had as a manager, along with the documentation-related tooling you are comfortable with, and how you've addressed various content usability considerations.
- Interview with Technical Writing Manager. The interviewer will spend time learning how you think about a tech writing team within an organization, ways of ensuring the team is well-positioned to produce content that has a substantial impact on the user experience, and specific examples of large content initiatives.
- Interview with VP of UX. The interviewer will spend time learning about the experience you have as a manager, what types of teams you have led, your management style, how you define strategy, your approach to content usability and improvement, how you've handled difficult situations, and how you've helped mentor technical writers. Be prepared to talk about your work and technical abilities, too.
