---
layout: job_family_page
title: UX Engineer
description: At GitLab, UX engineers collaborate closely with product designers, product managers, and engineers. They work on all versions of our product, including open source, enterprise editions, and the GitLab.com service.
---

## UX Engineer roles at GitLab

At GitLab, UX engineers collaborate closely with [product designers](/job-families/product/product-designer/), [product managers](/job-families/product/product-manager/), and [engineers](/job-families/engineering/) to create a productive, minimal, and human experience.

A UX Engineer reports to a [Product Design Manager](/job-families/product/product-design-management/#product-design-manager).

## Responsibilities

- Help define and improve the user experience (UX) and user interface (UI) of GitLab.
- Develop design system components and help evolve the design system.
- Perform accessibility evaluations and build standards into our workflows.
- Work with product designers, engineers, and product managers to iterate on and refine the existing UX.
- Confidently ship small features and improvements with minimal guidance and support from other team members.
- Stay informed and share the latest UX/UI techniques, tools, and patterns.
- Craft code that meets our internal standards for style, maintainability, and best practices in a high-scale web environment.
- Identify areas of improvement in the code base, both within and outside of your group.

## Requirements

- Proficient in frontend programming languages like HTML, CSS, and JavaScript.
- Have professional experience working with the Vue.js framework.
- Have deep design systems knowledge, understanding, and practice.
- Solid understanding of visual design, interaction design, and usability testing.
- Experience using Git and package managers like Yarn or NPM.
- Experience with writing automated tests (such as Jest, Karma, Jasmine, Mocha, AVA, tape).

## Levels

[UX Engineer](/job-families/product/ux-engineer/#ux-engineer)
[Senior UX Engineer](/job-families/product/ux-engineer/#senior-ux-engineer)

### UX Engineer

#### Job Grade

The UX Engineer is a [grade 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Responsibilities

- **Product knowlege**: Have working knowledge of the group(s) you are assigned.
- **Deliverables**: Implementation of design system components and migrations in a secure, well-tested, and performant way. Define best practices to inform how teams design and build across GitLab.
- **Communication**: Communicate the results of UX activities within your product area to the UX department, cross-functional partners within your product area, and other interested GitLab team-members using clear language that simplifies complexity.
- **Usability**: Proactively identify both small and large usability issues within your group(s). Incorporate accessibility standards into workflows.
- **Iteration**: Practice iteration by breaking down design and development efforts to fit the release cadence of your group(s).
- **Design system**: Be a primary contributor to the [Pajamas Design System](https://design.gitlab.com/) by building components, helping maintain the [Pajamas UI Kit](https://www.figma.com/community/file/781156790581391771/component-library), and ensuring that components fit together visually and functionally.
- **Design reviews**: Participate in [Design Reviews](/handbook/product/ux/product-designer/#design-reviews) by giving and receiving feedback in an appropriate way.
- **Deferred UX**: Understand Deferred UX and make improvements directly to the product.
- **Recruiting**: Help evaluate candidates during the interview process by participating on the interview panel.

#### Requirements

A UX Engineer is expected to meet the requirements and execute the responsibilities with some assistance from their manager.

### Senior UX Engineer

The Senior UX Engineer reports to a [product design manager](/job-families/product/product-design-management/#product-design-manager).

#### Job Grade

The Senior UX Engineer is a [grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Responsibilities

- **Product knowledge**: Deeply understand the technology and features of the group(s) you are assigned and proactively learn about other groups.
- **Deliverables**: Implementation of design system components and migrations in a secure, well-tested, and performant way. Define best practices to inform how teams design and build across GitLab.
- **Communication**: Communicate the results of UX activities with a strong point of view to the UX department, cross-functional partners with your group(s), and other interested GitLab team-members using clear language that simplifies complexity.
- **Usability**: Proactively identify both small and large usability issues within your group(s) and help influence prioritization. Incorporate accessibility standards into workflows.
- **Iteration**: Practice iteration by breaking down design and development efforts to fit the release cadence of your group(s).
- **Design system**: Be a primary contributor to the [Pajamas Design System](https://design.gitlab.com/) by building components, helping maintain the [Pajamas UI Kit](https://www.figma.com/community/file/781156790581391771/component-library), and ensuring that components fit together visually and functionally. Help organize and drive participation in Pajamas Migration Days and Hackathons.
- **Design reviews**: Participate in [Design Reviews](/handbook/product/ux/product-designer/#design-reviews) and model best practices for giving and receiving feedback.
- **Deferred UX**: Help reduce the creation of additional Deferred UX with MVCs and advocating the importance of releasing value to users within your group(s). Identify and influence the prioritization to fix Deferred UX when it occurs. Directly address Deferred UX by making improvements in the product.
- **Public presence**: Help promote GitLab publicly by writing blog articles, giving talks, publishing videos to GitLab Unfiltered, or responding on social media, where appropriate.
- **Cross-stage collaboration**: Support your Product Design Manager and Product Manager in identifying dependencies between groups and stages, and advocating for cross-stage collaboration when needed.
- **Mentoring**: Mentor other members of the UX department, both inside and outside of your group(s) on how to make changes directly in the product that help accelerate implementing design system components in the product, or to address usability issues.
- **Recruiting**: Evaluate candidates during the interview process by reviewing portfolios or technical exercises, and participating on the interview panel.

#### Requirements

The Senior UX Engineer role extends the UX Engineer role and is expected to execute the responsibilities with minimal assistance.

## Performance Indicators

- [Pajamas component migrations](/handbook/product/ux/performance-indicators/#pajamas-component-migrations)
- [SUS-impacting issues](/handbook/product/ux/performance-indicators/#sus-impacting-issues-openedclosed-each-month)
- [Deferred UX](https://gitlab.com/handbook/product/ux/performance-indicators/#deferred-ux)

## Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process.

- Qualified candidates will be invited to schedule a 30 minute [screening call](/handbook/hiring/interviewing/#screening-call) with one of our global recruiters.
- If a candidate successfully passes the screening call, they'll be assigned a brief technical exercise to be completed ahead of the next interview with a product designer or UX engineer. It's an opportunity to learn your comfort and capability working with design systems and building components.
- Next, the candidate will meet with the hiring product design manager. They'll want to learn how you work in teams and about your past relevant experience.
- If the candidate successfully passes the previous interviews, they'll meet with a senior manager of product design for a 50-minute interview.
- The final interview will be with a product manager and engineering manager. They'll focus on your ability to collaborate with product and engineering teams and determine how well your skills align with the needs of the group.
- Successful candidates will subsequently be made an offer via a video call or phone call.
