---
title: "UX Research Management"
---

## UX Research Management Roles at GitLab

Managers in the UX Research department at GitLab see the team as their product. While they are credible as researchers and know the details of what UX Researchers work on, their time is spent hiring a world-class team and putting them in the best position to succeed. They own the delivery of UX Research commitments and are always looking to improve productivity. They must also coordinate across departments to accomplish collaborative goals.

### Manager, UX Research

The User Experience (UX) Research Manager reports to the Senior Manager or Director of UX Research, and UX Researchers report to the Manager, UX Research.

#### Job Grade

The Manager, UX Research is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Responsibilities

- Manage a high performing UX Research team.
- Manage the Research Operations Coordinator by supervising all activities necessary to ensure Research Operations provides efficient support for the UX Research team, and secure compliance
- Formulate Research Operations strategy to continously improve Research Operations performance
- Create an open and collaborative culture based on trust in the UX Research team.
- Set clear expectations and goals for UX Researchers while holding them accountable for success.
- Provide clear, actionable feedback and support to develop and grow UX Researchers.
- Support your team's career development by ensuring: 1) they each have a Individual Growth Plan in place, 2) there are frequent check-ins on the plan, and 3) when applicable, special projects are being matched to support each team member's Individual Growth Plan.
- Maintain an accurate and current understanding of the active UX Research projects being worked on by the team.
- Build and develop your research toolkit to extend across all levels of complexity.
- Demonstrate, explain, and teach others how to apply a range of research methods, understanding the balance and trade-offs between scrappy research and rigor.
- Personally initiate and conduct research projects to help build foundational knowledge of our GitLab users. Research should consist of a mix of problem validation, foundational research, and strategic research projects.
- Communicate, advocate for, and socialize actionable insights in a clear and compelling way.
- Regularly sync with Product Management Directors to understand strategy, discover blockers, manage quality, and help ensure UX Research prioritization.
- Develop and utilize reusable research project prioritization approaches for UX Researchers to leverage within their own teams.  Work with UX Researchers and Product in applying these approaches to ensure UX Researchers have a clear set of prioritized research projects.
- Manage the UX Research peer-review process to ensure test plans and final deliverables have been reviewed by at least one other UX Researcher.
- Build relationships with other managers across disciplines, and act as a liaison with teams throughout the wider organization that have ongoing research needs.
- Actively seek out difficult impediments to our efficiency as a team (process, tooling, etc), and propose and implement solutions that will enable the entire team to work more efficiently.
- Exert significant influence on the overall objectives and long-range goals of the UX Research team.
- Facilitate the schedule and content on what the team presents within meetings and events where UX research and/or Research Operations insights are presented out.
- Actively contribute to the UX Research team culture, processes, and documentation.
- Demonstrate UX Research team mission and lead by example. Regularly evaluate how the team acts upon our mission and make changes accordingly.

#### Requirements

- Deep knowledge in the field of UX Research with a proven understanding of quantitative and qualitative research methods.
- Experience managing UX Researchers who focus on enterprise, developer, and/or business tools.
- Outstanding communicator both verbally and in writing.
- Excellent collaboration skills.
- A proven record of driving change through UX Research.
- Passion for the field of UX Research.
- Evangelize research. Share user insights within the broader organization and externally in creative ways to increase empathy.
- Able to use GitLab to plan/manage work and update the company handbook.
- You share our [values](/handbook/values/), and work in accordance with those values.
- [Leadership at GitLab](/handbook/company/structure/#management-group)

**NOTE:** In the compensation calculator below, fill in "Manager" in the `Level` field for this role.

#### Interview Process

- [Screening call](/handbook/hiring/#screening-call) with a recruiter. In this call we will discuss your experience, understand what you are looking for in a UX Research leadership role, talk about your work and approach to user research, discuss your compensation expectations and reasons why you want to join GitLab, and answer any questions you have.
- After that, we'll invite you to record a case study walkthrough video. The recording is expected to be **~20-minutes in duration** and returned **within ten days** of the screening call.

> ### Why we ask for a pre-recorded presentation
>
> 1. It helps create a shared understanding of your work between you and our interviewers ahead of the first interview.
> 1. It allows us to ask more informed questions about your experience and work during the interview process.
> 1. Generally, we [avoid using meetings as a means to present](/handbook/communication/#common-meeting-problems). Instead, we record presentations, upload to our Unfiltered Youtube channel, and use a meeting as a Q&A. This interview exercise provides you with an opportunity to experience this style of work.
>
> ### Presentation Topics
>
> 1. An introduction: who you are, where you're based, your background, and why you're a UX Research Manager.
> 1. An overview of two case studies.
    <br> - One (1) should be an overview of a high-impact individual project. We want to understand how you approached the research questions, how you synthesized research data to inform product and design decisions, the challenges you faced along the way, and the impact your research had.<br>
    - The second (2) should be something related to your people management experiences. We want to understand your management style & why you decided to become a people manager. We'd also like to understand the details of a project you've led as a Manager. This could be a story on how you overcame some kind of challenge, a process you introduced that had a lot of impact, or how you coached an employee to success. We want to understand: the size, discipline make-up, and structure of the team you were a part of; the goals of the project; what you personally did on the project, the challenges you faced throughout the project; and the meaningful business impact that the research resulted in.
>
> ### What we're looking for
>
> - A recording that is up to 20 minutes in duration and returned to us within ten days of your screening call being completed.
> - You share the recording using either a [private Youtube link](https://support.google.com/youtube/answer/157177?co=GENIE.Platform%3DDesktop&hl=en), a [Google Drive link](https://support.google.com/drive/answer/2494822?co=GENIE.Platform%3DDesktop&hl=en), or a [Loom link](https://www.loom.com/).
>
>
> ### Some useful resources
>
> - Unsure on where to get started? Check out our [handbook page on recording a presentation in Zoom](/handbook/tools-and-tips/zoom/#how-to-share-a-presentation-in-zoom). A free Zoom account is all you'd need to complete this presentation.
> - Interested in the type of work our UX team does? Check out our [UX Forum on GitLab Unfiltered](https://www.youtube.com/playlist?list=PL05JrBw4t0Kq89nFXtkVviaIfYQPptwJz), our [UX Research handbook](/handbook/product/ux/ux-research/), and our [UX Department's handbook](/handbook/product/ux/).
> - We work with a [low level of shame](/handbook/values/#low-level-of-shame) at GitLab. In this context, this means we don't expect your presentation to be highly polished.
> - Other questions? Want the Recruiter to review your presentation before the review from the Hiring Manager? Don't hesitate to get in touch with the Recruiter who conducted your screening call.

#### The following steps would be scheduled after a successful review of your case studies

- Interview with a UX Researcher. In this interview, the interviewer will spend a lot of time trying to understand the experiences and challenges you've had as a manager, specific details of any initiatives you've led, the problems you were trying to solve, and the outcomes of these initiatives. Do be prepared to talk about your work and research experience, too.
- Interview with a Product Design Manager. The interviewer will also want to understand how you work with cross-functional partners, how you've handled conflict, and how you've dealt with difficult situations in the past.
- Interview with a UX Research Director. In this interview, the interviewer will spend a lot of time trying to understand the experience you have as a manager, your ways of ensuring the team is well-positioned to produce research studies that have a strong impact on product strategy, what types of teams you have led, and your management style.  This interviewer will also want to know how you think about the place of user research within an organization, understand how you define strategy and vision, and understand the size and scope of teams you've managed throughout your career.
- Interview with Product Management Group Manager. In this interview, the interviewer will want to understand how your career experiences will set you up for success at GitLab. They will also look to understand how you work with cross-functional partners, the domains you've worked in previously, and the types of teams you've led.
- Interview with VP of UX. In this interview, the interviewer will want to understand the experience you have as a manager, your experience working remotely, and how these two elements of your career intersect. They will also look to understand your technical skills and the types of products you've worked on previously.

### Senior Manager, UX Research

The Senior Manager, UX Research reports to the Director of UX, and Manager, UX Research report to the Senior Manager, UX Research.

#### Job Grade

The Senior Manager, UX Research is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Responsibilities

- Create an open and collaborative culture based on trust in the UX Research team.
- Manage the Research Operations Coordinator by supervising all activities necessary to ensure Research Operations provides efficient support for the UX Research team, and secure compliance
- **Set Research Operations vision that supports the UX Research vision**, and formulate Research Operations strategy to continously improve ReOps performance.
- Facilitate the creation and execution of UX Research OKRs in collabration with the UX Research team and UX Leadership.
- Define and manage performance indicators for the UX Research team by actively contributing to the UX Research KPIs on the UX KPIs page in the handbook.
- Coach UX Research Managers on how to conduct 1:1s, growth, and feedback conversations with their direct reports.
- Help drive cross-product research by having an awareness of what's happening across all sections through active participation in UX Research peer reviews, UX Forum, and Group Conversations.
- Actively advocate for UX Research throughout the company, so that the company is aware of what UX Research does, how they do it, and what insights they have delivered.
- Support UX Research Managers' career development by ensuring: 1) they each have a Career Development Plan in place, 2) there are frequent check-ins on the plan, and 3) when applicable, special projects are being matched to support one's Career Development Plan.
- Align the way that UX Researchers work with how their cross-functional partners in Product Managment, Product Design, and Engineering prioritize, track, and manage work.
- **Facilitate the creation and execution of UX Research team mission**, lead by example to deliver our mission. **Regularly evaluate** how our team culture matches our mission and adjust accordingly.
- Facilitate the schedule and content on what the team presents within meetings and events where UX research and/or Research Operations insights are presented out.
- Stay informed of industry best practices, and help the team to evolve our research practice accordingly.

#### Requirements

- Expert-level knowledge in the field of UX Research with expert-level understanding of quantitative and qualitative research methods.
- Experience managing UX Research Managers who focus on enterprise, developer, and/or business tools.
- Outstanding communicator both verbally and in writing.
- Strong collaboration skills.
- A proven record of leading a team that drives change through UX Research.
- Experience advocating for UX Research and broadly communicating about research insights to stakeholders and partners.
- Passion for the field of UX Research.
- Able to use GitLab to plan/manage work and update the company handbook.
- Ideally, has experience leading a remote UX research team that conducts research fully remote, too.
- You share our [values](/handbook/values/), and work in accordance with those values.
- [Leadership at GitLab](/handbook/company/structure/#management-group)

**NOTE:** In the compensation calculator below, fill in "Senior Manager" in the `Level` field for this role.

#### Interview Process

Our interview process for this role is slightly longer than usual as it is a highly collaborative role within UX and across the organisation. It is just as important for you to learn more about us as it is for us to learn about you.

- [Screening call](/handbook/hiring/#screening-call) with a recruiter. In this call we will discuss your experience, understand what you are looking for in a UX Research leadership role, talk about your work and approach to user research, discuss your compensation expectations and reasons why you want to join GitLab, and answer any questions you have.
- Interview with the Hiring Manager, the VP of UX. In this interview, the interviewer will talk about your leadership and vision, getting results and user-centricity
- You'll then record a case study walkthrough video. The recording is epected to be **~20 minutes** in duration and returned **within 10 days** of the screening call.

> ### The reason we ask for a pre-recorded presentation
>
> 1. It helps create a shared understanding of your work between you and our interviewers ahead.
> 1. It allows us to ask more informed questions about your experience and work during the interview process.
> 1. Generally, we [avoid using meetings as a means to present](/handbook/communication/#common-meeting-problems). Instead, we record presentations, upload to our Unfiltered Youtube channel, and use a meeting as a Q&A. This interview exercise provides you with an opportunity to experience this style of work.
>
> ### Case Study Presentation Topics
>
> 1. An introduction:  Tell us about your relevant education and career highlights, and your motivation to apply to this role.
>
> 1. An overview of two case studies: <br>
>
> - The first (1) is related to your prior experience and acumen as a UX researcher. Tell us about a high-impact project/initiative that you led as a hands-on researcher which you’re proud of. What are you most proud of? As applicable, describe the research effort and how you approached it (both from a planning and stakeholder alignment perspective). What methodologies did you employ? How did you go about synthesizing the data? What was the outcome of the research and/or key insights that were adopted? <br>
> - The second (2) is related to your people management style & leadership approach. Tell us about a time when you led your team/member(s) to be successful on a challenging initiative. What were the specific challenges? How did you assure a successful outcome for your team/member(s) and the initiative?
>
> ### What we are looking for
>
> - A recording that is up to 20 minutes in duration and returned to us within ten days of your screening call being completed.
> - You share the recording using either a [private Youtube link](https://support.google.com/youtube/answer/157177?co=GENIE.Platform%3DDesktop&hl=en), a [Google Drive link](https://support.google.com/drive/answer/2494822?co=GENIE.Platform%3DDesktop&hl=en), or a [Loom link](https://www.loom.com/).
>
>
> ### Some other useful resources
>
> - Unsure on where to get started? Check out our [handbook page on recording a presentation in Zoom](/handbook/tools-and-tips/zoom/#how-to-share-a-presentation-in-zoom). A free Zoom account is all you'd need to complete this presentation.
> - Interested in the type of work our UX team does? Check out our [UX Forum on GitLab Unfiltered](https://www.youtube.com/playlist?list=PL05JrBw4t0Kq89nFXtkVviaIfYQPptwJz), our [UX Research handbook](/handbook/product/ux/ux-research/), and our [UX Department's handbook](/handbook/product/ux/).
> - We work with a [low level of shame](/handbook/values/#low-level-of-shame) at GitLab. In this context, this means we don't expect your presentation to be highly polished.
> - Other questions? Want the Recruiter to review your presentation before the review from the Hiring Manager? Don't hesitate to get in touch with the Recruiter who conducted your screening call.

We will schedule the next stages if the recording indicates your past experiences will lead to your success in a role at GitLab.

- Interview with a UX Researcher. In this interview, the interviewers will focus on UXR hard skills, maturity and impact, and team development.
- Interview with your UX Peers in Product Design and Technical Writing. In this interview, we want to get a picture of your stakeholder management experience, understanding of the UX development lifecycle and quality.
- Interview with Product Management. We want to understand your business acument (working with OKR's and metrics), cross-functional collaboration and UXR business impact.
- A final interview to wrap up the process with the VP, UX to close out any final questions for both sides.

### Director, UX Research

The Director of UX Research reports to the Director of UX, and UX Research Managers report to the Director of UX Research.

#### Job Grade

The Director, UX Research is a [grade 10](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Responsibilities

- Create an open and collaborative culture based on trust in the UX Research team.
- Align UX Research to business goals and company revenue and clearly communicate the resulting impact.
- Mentor UX Research Managers in their career growth, including making sure they each have an [Individual Growth Plan](/handbook/people-group/learning-and-development/career-development/#internal-resources).
- Help scale UX research by providing research training for Product Managers and Product Designers within GitLab to enable the company to conduct UX research at scale. This also involves keeping a pulse on the needs of the business and team members in order to provide the appropriate training needs.
- Actively advocate for UX Research throughout the company, so that the company is aware of what UX Research does, how they do it, and what insights they have delivered.
- Stay informed of industry best practices, and help the team to evolve our research practice accordingly.
- Identify ways to more efficiently and effectively conduct remote user research, and share those learnings with the wider community.
- Define and manage [Performance Indicators](/handbook/product/ux/performance-indicators/) for the UX Research team.
- Independently create and manage [OKRs](/handbook/company/okrs/) for the UX Research team.
- Align the way that UX Researchers work with how their cross-functional partners in Product Managment, Product Design, and Engineering prioritize, track, and manage work.
- Conduct regular [1:1 meetings](/handbook/leadership/1-1/) with their direct reports and quarterly [skip-level meetings](/handbook/leadership/skip-levels/) with the reports of their direct reports.
- Provide clear and direct feedback to the people they manage, their own manager, and cross-functional partners when needed.
- Manage the UX Research budget with oversight from UX leadership.
- **Build and manage** a high performing UX Research team.

#### Requirements

- Expert-level knowledge in the field of UX Research and experience setting UX Research vision for a product company.
- Experience managing UX Research Managers.
- A clear philosophy about how to create an environment that empowers remote UX Research teams and encourages them to deliver high-impact work.
- Outstanding communicator both verbally and in writing.
- Strong collaboration skills.
- A proven record of leading a team that drives change through UX Research.
- Experience advocating for UX Research and broadly communicating about research insights to stakeholders and partners.
- Passion for the field of UX Research.
- Able to use GitLab to plan/manage work and update the company handbook.
- Ideally, has experience leading a remote UX research team that conducts research fully remote, too.
- You share our [values](/handbook/values/), and work in accordance with those values.
- [Leadership at GitLab](/handbook/company/structure/#management-group)

**NOTE:** In the compensation calculator below, fill in "Director" in the `Level` field for this role.

## Performance indicators

- [Hiring Actual vs Plan](/handbook/product/ux/performance-indicators/#hiring-actual-vs-plan)
- [Diversity](/handbook/product/ux/performance-indicators/#diversity)
- [Handbook Update Frequency](/handbook/product/ux/performance-indicators/#handbook-update-frequency)
- [Team Member Retention](/handbook/product/ux/performance-indicators/#team-member-retention)

## Interview Process

- [Screening call](/handbook/hiring/#screening-call) with a recruiter. In this call we will discuss your experience, understand what you are looking for in a UX Research leadership role, talk about your work and approach to user research, discuss your compensation expectations and reasons why you want to join GitLab, and answer any questions you have.
- Interview with a UX Researcher. In this interview, the interviewer will spend a lot of time trying to understand the experiences and challenges you've had as a manager, specific details of any initiatives you've led, the problems you were trying to solve, and the outcomes of these initiatives. Do be prepared to talk about your work and research experience, too.
- Interview with a UX Research Manager. In this interview, we want to get to know how you think about the place of user research within an organization, understand how you define strategy and vision, and understand the size and scope of teams you've managed throughout your career.
- Interview with the Director of Product Design. In this interview, the interviewer will spend a lot of time trying to understand the experience you have as a manager, your ways of ensuring the team is well-positioned to produce research studies that have a strong impact on product strategy, what types of teams you have led, and your management style. The interviewer will also want to understand how you work with cross-functional partners, how you've handled conflict, and how you've dealt with difficult situations in the past.
- Interview with the VP of UX. In this interview, the interviewer will look to understand how you drive strategy, approach difficult conversations, and how you see the role of user research in a cross-functional research and development organization.
