---
title: UX Research Operations Coordinator
---

At GitLab, UX Research Operations Coordinators collaborate with our Product Designers, Product Managers, UX Researchers, and the rest of the community to manage participant recruitment for UX studies. UX Research Operations Coordinators also drive process improvement in research operations at GitLab. UX Research Operations Coordinators report to the UX Research Director. Unless otherwise specified, all UX Research Operations Coordinator roles at GitLab share the following responsibilities and requirements:

## Responsibilities

- Drive all aspects of the UX research operations coordination program across GitLab
- Maintain deep working knowledge of the participant recruitment process
- Use GitLab for the intake of questions, concerns, and requests related to participant recruitment
- Maintain tight communication with team members to relay status of requests
- Anticipate and troubleshoot recruitment challenges as they arise
- Determine the best possible recruitment source for a given study
- Understand the pros and cons of each recruitment source
- Proactively report out key data
- Use participant panels for recruitment
- Stay aware of and implement GDPR (General Data Protection Regulation) policies
- Develop and manage participant panel growth strategies
- Establish best practices for participant recruitment

## Requirements

- [Self-motivated and self-managing](/handbook/values/#efficiency), with strong organizational skills.
- Share our [values](/handbook/values/), and work in accordance with those values.
- Simultaneously manage multiple projects and time-driven tasks
- Strong communication and collaboration skills to keep teams informed on progress
- Critical thinking and creative problem solving
- Adaptability and flexibility
- Empathetic, curious, and open-minded
- Attention to details
- Ability to thrive in a fully remote organization
- Ability to use GitLab

### UX Research Operations Coordinator (Intermediate)

The UX Research Operations Coordinator (Intermediate) reports to a [UX Research Manager](/job-families/product/ux-research-manager/#manager-ux-research).

#### Job Grade

The UX Research Operations Coordinator (Intermediate) is a [grade 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### UX Research Operations Coordinator (Intermediate) Responsibilities

- Manage all aspects of participant recruitment for user experience research studies, including but not limited to: recruiting from multiple sources, outreach, screening, scheduling, participation agreements, privacy, and incentives management.
- Identify team needs and gaps. Continuously examine, experiment, and measure improvements to our research operations and processes.
- Grow, foster, and administer new participant panels.
- Maintain UX research operations handbook documentation with accurate, standardized, and transparent processes and procedures.
- Create, document and follow our recruitment best practices and use the most appropriate databases / tools to filter and screen participants.
- Create and manage libraries of templates for team members to use, for example, but not limited to, recruitment screeners, issue templates, email templates.
- Manage Research Operations budget / credits allocated by tracking and forecasting spending on incentives, credits spent on studies, and working with the UX Research Manager to adjust accordingly.
- Collaborate with Product Designers, Product Managers, and UX Researchers to effectively understand their research recruitment needs and to drive their requests to successful completion.
- Manage relationships with third-party providers, such as recruitment platforms, digital rewards solutions, etc.
- Respond to inquiries from research participants.
- Monitor progress of research operations by creating, maintaining, and communicating monthly reports on key data points such as: budget, number of participants by research study type, forecasting, and other metrics.
- Keep training materials and handbook instructions for Study DRIs / UX Researchers up to date, so they adhere to best practices when conducting their own recruitment.
- Administration of our research toolsets:  Qualtrics, UserTesting.com, Dovetail, Respondent, Rybbon, Rally, etc.
- Work with Procurement, Legal and Security, on onboarding new tools, payments of POs, contract renewals etc.

#### UX Research Operations Coordinator (Intermediate) Requirements

- Willingness to grow SQL skills.
- Exquisite organizational skills: regularly managing multiple research projects at a time.
- Experience in UX Research Operations Coordination or a related role that involves administration and coordination.
- In-depth experience with scheduling sessions and communicating with internal and external participants/stakeholders.
- Excellent written and verbal communication skills.
- Experience with using a ticket-based system to track work requests.
- Able to use GitLab for communication and work management

### Senior UX Research Operations Coordinator

The Senior UX Research Operations Coordinator reports to a [UX Research Manager](/job-families/product/ux-research-manager/#manager-ux-research).

#### Senior UX Research Operations Coordinator Job Grade

The UX Research Operations Coordinator is a [grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Senior UX Research Operations Coordinator Responsibilities

- Extends the UX Research Operations Coordinator (Intermediate) responsibilities.
- Proactively identify, build, and streamline processes that result in efficient research operations.
- Proactively solicit requirements and feedback from Product Designers, Product Managers, and UX Researchers to further optimize research operations.
- Act as the strategic owner of our research participant panels, advancing their overall health, growth, and usage within GitLab.
- Working with the relevant teams to establish, drive, and/or identify social events to grow our participant panel.
- Be the social media ambassador for UX Research at GitLab. Maintain social media accounts that promote our research efforts and aid participant recruitment.
- Formalize the research operations coordination effort into a program of work with extensive processes and documentation to improve visibility and increase efficiency.
- Define and deliver on a UX research operations roadmap that improves efficiency and addresses gaps.
- Evangelize the value of UX research along with completed research efforts and insights across GitLab and to our customers.

#### Senior UX Research Operations Coordinator Requirements

- Extends the UX Research Operations Coordinator (Intermediate) requirements.
- Experience in UX Research Operations Coordination or a related role that involves administration and coordination.

## Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process.

**(1)** Selected candidates will be invited to schedule a 30-minute [screening call](/handbook/hiring/interviewing/#screening-call) with one of our Global Recruiters. In this call, we will discuss your experience, understand what you are looking for in a UX Research Operations Coordinator role, discuss your compensation expectations and reasons why you want to join GitLab, and answer any questions you have.

**(2)** Then you will meet with our UXR Manager, who will talk about your career, experience, go through some scenario-based questions and ensure there's time for your questions too.

**(3)** After that, we'll then invite you to create a 15-minute video presenting a case study on one or two of your most interesting projects. Use a slide deck to support your presentation. We're excited to learn more about your experience and how you've contributed to impactful projects. Your slide deck should include:

- **Context and Objectives:** Briefly describe the project's background, the goals, and the challenges.
- **Your Role and Contributions:** Highlight your specific responsiblities and actions taken to address the challenges.
- **Processes and Tools:** Share the methods, tools, workflows you used to deliver the project.
- **Outcomes and Impact:** Summarize the results of your efforts and the impact on the team or stakeholders.
- **Lessons Learned:** Reflect on what went well, what didn't, and what you would do differently in the future.

> ### Why we ask for a case study
>
> 1. It helps us understand your hands-on experience with research operations or coordination.
> 1. It demonstrates how you approach and solve complex challenges.
> 1. It gives insight into your communication and storytelling skills when presenting your work.
>
> ### What topics it could be about
>
> It could be about complex projects that pose:
>
> - **Recruitment challenges:** Projects where you managed participant recruitment under tight deadlines or with complex criteria.
> - **Process improvement opportunities:** Examples of streamlining workflows, managing compliance, or introducing new tools or methods.
> - **Data organization and insight management challenges:** A project where you handle complex data requests or implement systems to organize research insights effectively.
>
> Or, it could also be about projects that didn't go well overall, in which case you can focus on:
>
> 1. **Challenges:** What went wrong, and why?
> 2. **What could have been done better/differently:** Reflect on alternative approaches or solutions.
> 3. **Enables or Disablers:** What would you put in plae or remove if given another chance?
>
> ### What we're looking for
>
> - **Problem-Solving Skills:** How you approached challenges and found solutions.
> - **Organizational and Time Management Skills:** Your ability to manage tasks, deadlines, and competing priorities.
> - **Collaboration and Communication:** How you worked with researchers or stakeholders and communicated outcomes effectively.
> - **Technical Proficiency:** Your familiarity with tools, workflows, and compliance standards like GDPR.
> - **Reflection and Growth:** Your ability to learn from challenges and improve processes.
>
> ### To keep the presentation relevant, please avoid
>
> - **General descriptions of your role:** Focus on specific projects, not a high-level overview of your day-to-day responsibilities.
> - **Overly technical details:** We don't need an in-depth walkthrough of technical tools or systems unless it's directly relevant to the case study.
> - **Off-topic projects:** Avoid examples unrelated to research operations or coordination, such as projects in unrelated fields or roles.
>
> ### Submitting your case study
>
> - Please share your recording within 10 days of the case study being requested.
> - You can share the recording using either a [private Youtube Link](https://support.google.com/youtube/answer/157177?co=GENIE.Platform%3DDesktop&hl=en), [Google Drive link](https://support.google.com/drive/answer/2494822?co=GENIE.Platform%3DDesktop&hl=en), or a [Loom link](https://www.loom.com/).
>
> ### Some useful resources
>
> - Unsure on where to get started? Check out our [handbook page on recording a presentation in Zoom](/handbook/tools-and-tips/zoom/#how-to-share-a-presentation-in-zoom). A free Zoom account is all you’d need to complete this presentation.
> - Interested in the type of work our UX team does? Check out our [UX Forum on GitLab Unfiltered](https://www.youtube.com/playlist?list=PL05JrBw4t0Kq89nFXtkVviaIfYQPptwJz), review our [UX Research handbook](/handbook/product/ux/ux-research/), and our [UX Department's handbook](/handbook/product/ux/).
> - We work with a [low level of shame](/handbook/values/#self-service-and-self-learning) at GitLab. In this context, this means we don't expect your presentation to be highly polished.
> - Other questions? Want the Recruiter to review your presentation before the review from the Hiring Manager? Don't hesitate to get in touch with the Recruiter who conducted your screening call.

**(4)** You will then meet with a Peer UX Research Ops Coordinator to learn more about your experience and operational expertise. This is a good opportunity for you to ask specific question about the day-to-day of the role too.

**(5)** Your final interview will be with a UX Researcher and focus on collaboration and understanding of research needs.

Successful candidates will then move into the offer process and receive an offer via a Zoom call.

Additional details about our process can be found on our [hiring page](/handbook/hiring/).
