---
title: "UX Researcher"
description: "At GitLab, UX Researchers collaborate with our Product Designers, Product Managers and the rest of the community to assist in determining what features should be built, behave, and priorities."
---

At GitLab, UX Researchers collaborate with our Product Designers, Product Managers and the rest of the community to assist in determining what features should be built, how they should behave, and what the priorities should be.

## Responsibilities

- Be the expert on the users within your allocated area of coverage: know how they use the GitLab, their pain points, their workflows, etc.

- Collaborate with GitLab designers, product managers and engineers on a wide array of research projects.

- Conduct all stages of UX research: identifying, planning, driving, conducting, analyzing, and reporting out insights.

- Communicate out statuses and updates of project work to stakeholders.

- Use a wide variety of qualitative and quantitative research methods to apply to research questions.

- Share research insights in creative ways to increase empathy.
- Produce research insights that result in impact.

## Requirements

- [Self-motivated and self-managing](/handbook/values/#efficiency), with strong organizational skills.

- Passionate about and effective at mentoring others.

- Empathetic, curious and open-minded.

- Able to conduct research in a fully remote setting.

- Able to use GitLab.

- Experience working on enterprise and/or developer tooling products.

- Share our [values](/handbook/values/), and work in accordance with those values.

- Experience with workflows and tooling used by engineering, design, and product teams

## Levels

### Intermediate

The UX Researcher (Intermediate) reports to the Director of User Experience Research.

#### Intermediate Job Grade

The UX Researcher (Intermediate) is a [grade 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Intermediate Responsibilities

- Personally initiate and conduct research within or across your stage groups to build deep foundational knowledge of your coverage areas. Research should consist of a mix of solution validation and problem validation projects.

- Advocate for and socialize actionable insights independently and in a clear and compelling way.

- With the help of your manager, create high-quality deliverables that tell compelling stories integrated with research findings. This is typically accomplished through reports, presentations, video recordings, etc.

- Know your stage groups: understand the technology, experiences, and features of your assigned stage groups. Maintain a thorough knowledge of the direction and vision for your assigned stage groups.

- Know GitLab users in your stage groups: develop a deep empathic understanding of your users, learn about their needs, and identify gaps.

- Show an understanding of your stakeholders by familiarising yourself with their objectives, processes, and obstacles. Apply this knowledge in stakeholder engagement and collaboration, e.g. on planning and prioritisation.

- With the help of your manager and product leadership, effectively prioritize your research efforts across stage groups. Align with Product teams while considering impact, the goals of your stage groups, the broader product direction, and company objectives.

- Demonstrate research impact across **your assigned stage group(s)** through your research efforts

- Respond to solution validation user research inquiries that are escalated by Product Design.

- Guide Product Managers and Product Designers to conduct research with a high degree of rigor. Help them follow defined research processes (for example, handbook procedures, opening and closing issues for research studies, documenting actionable insights, etc).

- Learn from and be mentored by other UX Researchers.

- Participate in some of the research fielded by Senior and/or Staff Researchers to gain knowledge and exposure to more complex research projects.

- Actively contribute to the UX Research team culture by iterating on existing processes and documentation and contributing to peer reviews.

### Senior

The Senior UX Researcher reports to the Director of User Experience Research.

#### Senior Job Grade

The Senior UX Researcher is a [grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Senior Responsibilities

The Intermediate responsibilities, plus the responsibilities below:

- Personally initiate and conduct research projects within your assigned stage groups **and across adjacent stage groups** to build deep foundational knowledge of your areas of coverage. Research should consist of a mix of problem validation, foundational research, and strategic research projects.

- Drive a company-wide research-based program: design or improve upon a methodology (if needed), collect and report out findings.

- Create high-quality deliverables that tell compelling stories integrated with research findings. This is typically accomplished through reports, presentations, video recordings, etc.

- Know your stage groups: understand the technology, experiences, and features of your assigned **and adjacent stage groups**. Maintain a thorough knowledge of the direction and vision for your assigned stages **and stage groups**.

- Business acumen: consider the team's business goals when approaching research projects to ensure alignment.

- Effectively prioritize your research efforts across stage groups and adjacent stage groups. Align with Product teams while considering impact, the goals of your stage groups and adjacent stage groups, the broader product direction, and company objectives.

- Make connections between disparate research initiatives. This can be done by: identifying existing research that supplements a new initiative, looking for commonalities in findings to surface larger "macro" insights, through data triangulation, and/or by combining similar research efforts.

- **Consistently** demonstrate research impact across **your assigned stage group(s)** through your research efforts

- Lead and mentor other Researchers on methods, communication, successful collaboration/working models, and support the mentee's personal and professional growth by collaborating with them on projects, sharing expertise, providing guidance, while offering constructive feedback.

### Staff

The Staff UX Researcher reports to the Director of User Experience Research.

#### Staff Job Grade

The Staff UX Researcher is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Staff Responsibilities

The Senior responsibilities, plus the responsibilities below:

- Through your research, build a knowledge base that positions yourself as a thought leader within GitLab. Demonstrate this through your research insights and by sharing your unique point of view.

- **Proactively and consistently** make connections between disparate research initiatives. This can be done by: identifying existing research that supplements a new initiative, looking for commonalities in findings to surface larger "macro" insights, through data triangulation, and/or by combining similar research efforts.

- Personally initiate and conduct research within stage groups, across stages, **and across GitLab** to build deep foundational knowledge of GitLab users.

- Know GitLab: understand the technology, experiences, and features of the GitLab product. Demonstrate that knowledge by being able to ramp up and conduct research on any portion of the product.

- Know GitLab users: develop a deep empathic understanding of GitLab users in various contexts, learn about their needs, and identify gaps. Demonstrate that knowledge through your research insights and recommendations. **Emphasis on your assigned section(s)**.

- Practice flexibility by leading and partnering with a variety of teams and disciplines with the goal of delivering research insights.

- **Consistently** demonstrate research impact across **your assigned section(s)** through your research efforts.

- **Set the quality standard for the UX Research team** through expert delivery of high-quality artifacts that tell compelling stories integrated with research findings.

- Advocate for and socialize actionable insights in a clear and compelling way **that sets the standard for others conducting research**.

- Identify and address UX research training needs for the Product Division.

- Actively contribute to the UX Research team culture by iterating on existing processes and documentation. Contribute to peer reviews **and create new educational documentation/resources**.

- Actively seek out difficult impediments to our efficiency as a team (process, tooling, etc). Propose and implement solutions that will enable the entire team to work more efficiently and enhance the quality of research practices and deliverables across the team.

- Mentor other Researchers by inviting them to participate in your research projects.

- Provide support to other Researchers, as needed, on their projects by assisting in any phase of a given research project.

### Principal

The Principal UX Researcher reports to the Director of User Experience Research.

#### Principal Job Grade

The Principal UX Researcher is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Principal Responsibilities

The Staff responsibilities, plus the responsibilities below:

- Influence stakeholders to act upon research insights and recommendations

- Proactively and consistently make connections between disparate research initiatives. This can be done by: identifying existing research that supplements a new initiative, looking for commonalities in findings to surface larger "macro" insights, through data triangulation, and/or combining similar research efforts. **Set the standard on how this effectively accomplished for the UX Research team.**

- Know GitLab users: develop a deep empathic understanding of GitLab users in various contexts, learn about their needs, and identify gaps. Demonstrate that knowledge through your research insights and recommendations. **Emphasis on GitLab users who use multiple sections.**

- **Consistently** demonstrate research impact across **multiple sections and teams** through your research efforts

- Effectively prioritize your overall research efforts **by establishing an informed research strategy**. Align **and collaborate** with **section Directors, and VPs** while considering impact, type of research, the goals of stage groups, the broader product direction, and company objectives.

## Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process. Our UX Research interview process is very thorough, designed so you learn as much about us as we learn about you. To learn more about someone who may be conducting the interview, find their job title on our [team page](/handbook/company/team/).

<details>
<Summary> <b>Interview summary</b> </summary>
1. Recruiter Screening Call<br>
2. Scenario Interview<br>
3. Case study<br>
4. UX Research Manager<br>
5. UX Researcher Peer<br>
6. Product Designer / Product Design Manager<br>
7. Product Manager<br>
</details>
<br>

- Selected candidates will be invited to schedule a 30-min [screening call](/handbook/hiring/interviewing/#screening-call) with one of our Global Recruiters or the Hiring Manager. In this call we will discuss your experience, understand what you are looking for in a UX Research role, discuss your compensation expectations, reasons why you want to join GitLab and answer any questions you have.

- The next step will be a 45-min meeting to cover some scenario-based questions where will look to understand how you handle common situations that UX Researchers find.

- After that, we'll invite you to record a case study walkthrough video. The recording is expected to be **20-minutes in duration** and returned **within ten days** of your screening call and scenario-based interview being completed.

<figure class="video_container">
<iframe width="560" height="315" src="https://www.youtube.com/embed/TPMAjrCxJik?si=M-Ww_p4Y_KkpyQMj" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe>
</figure>

<details>
<summary>Video transcript</summary>

Hello, I'm Karen Li, the UX Research Manager at GitLab. Thank you for showing interest in working with us.

Our hiring process consists of multiple steps. This helps us best learn about you. And it's a great opportunity for you to learn about us, too.

You can read all about the details of each steps on this page. But there are just a few things I'd like to highlight about the video task, which may be new to some candidates:

1. Firstly, the video task is probably the best (if not only) opportunity to dive really deep into how you approach research challenges, so choose your case study wisely. It could be foundational, strategic, or problem validation that's complex in nature, anything you are proud of.
1. Secondly, the interviewers will also have access to notes from your previous interview steps. This means you can keep the self introduction to under 1 minute, and allow sufficient time to share the details of the research challenge, your thinking process, and your crafts and skills.
1. And finally, make sure to read all sections below, before constructing your video. We have listed a set of topics that we are interested in below. Anything else you'd like to share is welcome, too. Just make sure to keep the length of the video to 20 minutes.

Once again, thank you for showing your interest, and all the best with your job application.

</details>
<br>

> ### Why we ask for a pre-recorded presentation
>
> 1. It helps create a shared understanding of your work between you and our interviewers ahead of the first team interview.
> 1. It allows us to ask more informed questions about your experience and work during the interview process.
> 1. Generally, we [avoid using meetings as a means to present](/handbook/communication/#common-meeting-problems). Instead, we record presentations, upload to our Unfiltered Youtube channel, and use a meeting as a Q&A. This interview exercise provides you with an opportunity to experience this style of work.
>
> ### Presentation Topics
>
> [This short discussion on our GitLab Unfiltered YouTube playlist](https://youtu.be/VU2BKjGoer4) provides an overview of the topics we'd love to see covered.
>
> 1. A short introduction: who you are, where you're based, your background, and why you're a UX Researcher.
> 1. An overview of one *or* two research studies. We want to understand:
>    - What the research questions are *or* the problems the research aims to address;
>    - Why you chose to present this case study;
>    - The size and the structure of the team (e.g. how many Project Managerss, UX Designers, Developers, UX Researchers);
>    - What your role was, meaning what you personally did or did not do on the project;
>    - How and why you took the approach you did to field the research (and why not other approaches);
>    - How you synthesized the research data to inform product and design decisions;
>    - The final output of your research;
>    - The challenges you faced throughout the project and how you overcame them;
>    - Any high-level findings that you can share while respecting any confidentiality rules in place;
>    - The meaningful business and cultural impact that the research resulted in.
>
> ### What we're looking for
>
> - A recording that is up to 20 minutes in duration and returned to us within ten days of your scenario-based interview being completed.
> - Ideally, one case study you present should be relevant to the work you'd expect do at GitLab. This could be because the case study involved research into the [persona(s)](/handbook/product/personas/#user-personas) you'd study at GitLab, the case study related to the DevOps or Developer tooling industry, the case study relates to the [Stage](/handbook/product/categories/#devops-stages) you're interviewing for, is a case study that went across multiple methods, or was a case study that would be considered complex in nature. Note that at GitLab, UX Researchers at any level are working on [problem validation](/handbook/engineering/ux/ux-research-training/problem-validation-and-methods/), [foundational](/handbook/product/ux/ux-research/foundational-research/) or [strategic](/handbook/product/ux/ux-research/strategic-research-at-gitlab/) research projects, while Product Designers conduct solution validation. We'd like to see a case study that is of problem validation, foundational, or strategic nature.
> - You share the recording using either a [unlisted Youtube link](https://support.google.com/youtube/answer/157177?co=GENIE.Platform%3DDesktop&hl=en), a [Google Drive link](https://support.google.com/drive/answer/2494822?co=GENIE.Platform%3DDesktop&hl=en), or a [Loom link](https://www.loom.com/).
> - Your presentation to address each of the topics listed above.
>
> ## Some useful resources
>
> - Unsure on where to get started? Check out our [handbook page on recording a presentation in Zoom](/handbook/tools-and-tips/zoom/#how-to-share-a-presentation-in-zoom). A free Zoom account is all you'd need to complete this presentation.
> - Interested in the type of work our UX team does? Check out our [UX Forum on GitLab Unfiltered](https://www.youtube.com/playlist?list=PL05JrBw4t0Kq89nFXtkVviaIfYQPptwJz), review our [UX Research handbook](/handbook/product/ux/ux-research/), and our [UX Department's handbook](/handbook/product/ux/).
> - We work with a [low level of shame](/handbook/values/#low-level-of-shame) at GitLab. In this context, this means we don't expect your presentation to be highly polished.
> - Other questions? Want the Recruiter to review your presentation before the review from the Hiring Manager? Don't hesitate to get in touch with the Recruiter who conducted your screening call.

- We will schedule the next stages if the recording indicates your past experiences will lead to your success in a role at GitLab.

- Candidates will be invited to 2 seperate 50-minute interviews:
  - One with a UX Researcher. Overall, this interview aims to understand how you choose your research methods, how you present results, how you work with a wider team of counterparts, and how you determine whether your research resulted in a meaningful business impact. This interview will also look to understand the softer skills you have as a researcher and how you apply those in the real world.
  - The other with the UX Research Manager where we'll focus on your experience researching Developers and working with global team members in an Agile setting. You will also discuss your career, your experiences as a UX Researcher, and the role of UX Research at GitLab.

- Next up are a couple of 50-minute interviews, one with either a Product Design Manager or Product Designer, and the other with a Product Manager. In these interviews, we'll focus on how you collaborate with cross-functional stakeholders and mentor non-researchers in successfully conducting research. These interviews are opportunities for you to understand the stage you will be a part of in more detail, hear a different perspective on the stable counterpart relationship, and ask any questions you have.

- Successful candidates will subsequently be made an offer via Zoom.

Additional details about our process can be found on our [hiring page](/handbook/hiring/).
