---
title: "Customer Success Management"
description: "The Customer Success Management (CSM) team focuses on the themes of align, enable, and expand."
---

The Customer Success Management (CSM) team is accountable for customer adoption, measurable outcomes, customer satisfaction, and creating true customer advocacy.

Additionally, our team serves as liaisons between the customer and the GitLab ecosystem, streamlining collaboration with Product Management, Engineering, Sales, Professional Services, and others. [CSM handbook](/handbook/customer-success/csm).

The Customer Success Manager(CSM) role at GitLab is expected to serve and operate in the following ways and have product and domain expertise.  The depth of knowledge in each area will progress within the CSM career ladder.

## Consultative/Customer Management Knowledge

- Ability to analyze and create actionable insights from product usage data
- Experience guiding customer conversations in order to discover customer goals/objectives
- Consultative approach to customer discovery to ensure customer renewal and identify expansion opportunities and risk
- Risk mitigation and escalation management
- Customer Onboarding: Guiding new customers through the onboarding process to ensure a smooth transition and successful adoption of the product or service
- Ownership of customer adoption and enablement plan
- Experience working with technical teams, including decision makers and practitioners
- Able to manage external and internal stakeholders to agreed timelines and deliverables

## Product and Domain Knowledge

- Up-to-date on recent GitLab releases
- Hands-on knowledge of GitLab
- Ability to convey complex technical concepts to demo GitLab Features addressing specific customer requirements
- Ability to understand and address/navigate complex customer environments (technical construct, integrations, business processes)
- Identified area of GitLab Product specialization, including knowledge of competitive landscape
- Experienced in one or more parts of the software development lifecycle (e.g., architecture, development, testing, implementation, operations)

## Levels

| Role | Grade |
| -- | - |
| [Associate Customer Success Manager](#associate-customer-success-manager) | [Grade 5](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades) |
| [Customer Success Manager](#customer-success-manager-intermediate) | [Grade 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades) |
| [Senior Customer Success Manager](#senior-customer-success-manager) | [Grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades) |
| [Staff Customer Success Manager](#staff-customer-success-manager) | [Grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades) |
| [Manager, Customer Success Managers](#manager-customer-success-managers) | [Grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades) |
| [Senior Manager, Customer Success Managers](#senior-manager-customer-success-managers) | [Grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades) |

### Associate Customer Success Manager

The Associate Customer Success Manager (CSM) reports to the [Manager/Senior Manager, CSM](/job-families/sales/customer-success-management/#manager-of-customer-success-managers)

#### Associate CSM Job Grade

The Associate CSM is a job grade [level 5](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Associate CSM Responsibilities

- Provide immediate onboarding activities
- Work with assigned customers to build Customer Success Plans, establishing critical goals, or other key performance indicators and aid the customer in achieving their goals
- Manage account escalations
- Provide insights with respect to the availability and applicability of new features in GitLab as relevant
- Support GitLab Services in identifying and recommending training opportunities

#### Associate CSM Requirements

- Demonstrated progressive experience in a related function is required with direct customer advocacy and engagement experience in post-sales or professional services functions

### Customer Success Manager (Intermediate)

The Customer Success Manager (CSM) (Intermediate) reports to the [Manager/Senior Manager, CSM](/job-families/sales/customer-success-management/#manager-of-customer-success-managers).

#### CSM (Intermediate) Job Grade

The CSM (Intermediate) is a job grade [level 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### CSM (Intermediate) Responsibilities

- Extends the CSM (Associate) responsibilities
- Establish a trusted/strategic advisor relationship with each assigned customer and drive continued value of our solution and services
- Assist and provide expert deployment, operational best practices, and establishing a GitLab Center of Excellence
- Assist in workshops to help customers leverage the full value of GitLab solution
- Measure and monitor customers' achievement of critical and key performance indicators, reporting both internally to GitLab account stakeholders and externally to Customer Sponsors and Executives
- Translate customer product usage data into actionable advice for customers
- Establish regular touchpoints with assigned customers per the established SLAs, to review progress against strategic and technical objectives

#### CSM (Intermediate) Requirements

- Extends the CSM (Associate) requirements
- Demonstrated progressive experience in a related function is required with direct customer advocacy and engagement experience in post-sales or professional services functions
- Understanding of Git and typical branching strategies
- Knowledge of software development lifecycle and development pipeline
- Understanding of continuous integration, continuous deployment, DevSecOps

### Senior Customer Success Manager

The Senior CSM reports to the [Manager/Senior Manager, CSM](/job-families/sales/customer-success-management/#manager-of-customer-success-managers).

#### Senior CSM Job Grade

The Senior CSM is a job grade [level 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Senior CSM Responsibilities

- Extends the CSM (Intermediate) responsibilities
- Strategize on the overall objectives and long-range goals of the team
- Provide mentorship for Associate and Intermediate CSMs to help them grow their knowledge and provide premium customer experience
- Work cross-departmentally to find solutions to complex scenarios and integration issues
- Demonstrate leadership in new feature and technology adoption and teaching by providing regular enablement and solution overview sessions and documentation for customers and other GitLab team-members
- Foster team collaboration and help increase team expertise
- Maintain deep knowledge of the GitLab platform
- Clearly communicate and drive adoption of complex solutions, with constant attention to promoting "boring solutions"

#### Senior CSM Requirements

- Extends the CSM (Intermediate) requirements
- Ability to translate business requirements into business value, and work with sales and marketing to promote value-driven solutions
- Strong knowledge of Customer Success best practices, with experience in defining process and providing enablement programs to promote adoption in CS and across the company
- Expert in GitLab usage and able to train others in its usage
- Advanced knowledge of software development lifecycle and development pipeline
- Advanced project management experience & skills

### Staff Customer Success Manager

Market Justification: The business need for an individual contributor Staff CSM role is to have a team member who is a subject matter expert in customer engagement, success planning, and driving platform adoption. In addition to working with the customers in their book of business, they provide guidance and coaching to other CSMs and develop improvements to our customer engagement model. In the market, there are over 20 organizations that typically have 2-3 Staff CSMs.

The Staff Customer Success Manager (CSM) reports to the [Manager/Senior Manager/Director, CSM](/job-families/sales/customer-success-management/#manager-csm).

#### Staff CSM Job Grade

The Staff CSM is a job grade [level 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Staff CSM Responsibilities

- Extends the Senior CSM responsibilities
- Owns the customer relationship of a global or large scale enterprise account and actively manages the stakeholder relationship at all levels (i.e., executive, management, technical leaders) including strategic roadmap discussions
- Can develop and nurture relationships and adjust value and adoption messaging according to the levels and interests of customer stakeholders
- Actively searches for additional business cases to expand GitLab usage within the account and its subsidiaries
- Is driven by business needs to look at the whole picture, consults with customers building near and long term solution
- Coaches peers on strategic approaches
- Demonstrates mastery in crafting strategic success plans focused on quantifiable business outcomes and actively coaches others in establishing this practice
- Has proven ability to deeply understand customer health scoring and predictive risk management and is well versed in risk prevention and risk resolution
- Continuously drives communication and customer advocacy into various GitLab departments including Sales, Support, Product and Channel to provide customer insights and ensure an orchestrated customer experience
- Expands personal research combined with best practices across disciplines, actively builds/shares playbooks and customer enablement/expansion workshops focused on driving to greater adoption and value realization
- Identifies and creates solutions to address CS needs, improve effectiveness and efficiency, and delivery to or exceed key customer metrics such as Quantitative Success Plans, Time-to-Value, use case expansion, EBRs delivered, and gross/net retention
- Identifies challenges in CSM group workflows and those extending to other groups, and owns the research, development, and enablement of the resolutions
- Work transparently to surface the problems and allow others to participate in solving them
- Regularly publishes handbook updates describing our practice and our collaboration with other groups and improves/grooms existing content in-line with process and enablement improvements
- Mentor and coach colleague CSM's on one of their accounts for faster onboarding or adoption

#### Staff CSM Requirements

- Extends the Senior CSM requirements
- Experience and a proven track record with the additional responsibilities of a Staff CSM
- Ability to manage executive relationships and discussions (VP/CxO)
- High-performance ability to pitch and execute stage expansions, balancing business and technical and adjusting messaging to audience (technical / exec)
- Skilled in bringing in a SAE/AE/ISR to see through upsell opportunities, whilst maintaining executive overlay and ensuring a positive customer experience
- Technical / DevOps domain expertise
- Proven ability to manage a global/large scale enterprise account
- Excellent moderation and communication skills
- Extensive experience within a technical or account management area

#### Staff CSM Performance Indicators

- Extends the Customer Success KPIs articulated [here](/job-families/sales/customer-success-management/#performance-indicators)
- >5m ARR book of business maintained
- 6 enablement contributions to global CS team per fiscal year
- 2 Use-case specific or Vertical-specific playbooks created, with global team enabled on them, per year

### Manager, Customer Success Managers

The Manager, Customer Success Managers (CSM), reports to the [Director of Customer Success Managers](/job-families/sales/customer-success-management/#director-of-customer-success-managers).

#### Manager, CSM Job Grade

The Manager, CSM is a job grade [level 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Manager, CSM Responsibilities

- Mentor and enable the team to exceed company growth and retention forecasts
- Work with the Customer Success Director to help establish and manage goals and responsibilities for CSMs
- Manage a team of highly motivated, customer-focused CSMs to manage the overall health and care of accounts (e.g., onboarding customers, stage adoption, executive business reviews, and successful renewals)
- Ensure the CSMs exceed GitLab expectations in core knowledge, communication, and execution
- Challenge the team and yourself to learn and grow as trusted advisors to customers continually
- Provide leadership and guidance to coach, motivate and lead the team members to their optimum performance levels and career development, providing timely feedback and development assistance
- Manage resource assignments and staffing levels, including recruitment as needed
- Identify and implement improvements to the processes and tools used
- Develop senior-level relationships with customers
- Partner with other team leaders to ensure the customer is supported in times of escalation
- Develop strong relationships with Engineering and Product to ensure cohesion and shared understanding of goals, initiatives
- Oversee initiatives set forth in [OKRs](/handbook/company/okrs/)
- Work together with the other managers to execute strategies and vision with the Director
- Represent GitLab leadership and reflect our [GitLab values](/handbook/values/) in internal and external interactions

#### Manager, CSM Requirements

- Proven track record in software/technology sales, consulting or customer success
- Proven experience leading teams, driving software adoption, and building and scaling customer success management practices
- Experience with software development lifecycle processes and tools as well as agile and/or DevOps practices
- Knowledgeable with cloud/container technologies (e.g., Kubernetes, Docker), application security (SAST, DAST) and/or cloud deployment models (AWS, GCP, Azure) is a plus
- Proven ability to develop strategies, translate them into initiatives and track successful delivery
- Demonstrated ability to lead managers and successfully manage global, distributed teams across cultures, lines of business, and geographies
- Possession of a strong management presence and leadership ability, with communication and interpersonal skills that inspire and motivate leaders and teams
- Demonstration of operational excellence in analytical thinking, process development and improvement, problem-solving, communication, delegation, and planning
- Ability to collaborate across the organization and with external stakeholders
- Experience successfully working with senior executives (VP/CxO)
- Holds strong operational skills that will drive organizational efficiencies and customer satisfaction
- Comfortable giving and receiving positive and constructive feedback
- Ability to connect technology with measurable business value
- Strategic thinking about business, products, and technical challenges

### Senior Manager, Customer Success Managers

The Senior Manager, Customer Success Managers(CSM) reports to the [Director of Customer Success Managers](/job-families/sales/customer-success-management/#director-of-customer-success-managers).

#### Senior Manager, CSM Job Grade

The Senior Manager, CSM is a job grade [level 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Senior Manager, CSM Responsibilities

- Extends the Manager, CSM responsibilities
- DRI for one or more initiatives beyond the CSM manager role that includes: customer growth, expansion programs, and processes
- Action upon identified opportunities for continuous improvement across the customer lifecycle
- Consistent representation of our values to the customer, our CSM team, and the company as a whole
- Lead in cross-functional work representing customer success in GitLabs more strategic revenue-focused initiatives
- Owns and manages more than just the CSM manager purview - defined by looking for and solving larger team or organizational challenges, and owning initiatives that span wider than the CSM manager role
- Aligned with the objectives of GitLab and is responsible for ensuring that the CSM team as a whole is contributing to our company objectives
- Strategic in thinking to solve challenges for the entire CSM team and make improvements that will positively impact all customers

#### Senior Manager, CSM Requirements

- Extends the Manager, CSM requirements
- Demonstrated progressive management experience leading teams in a software company
- Demonstrated progressive experience leading customer success managers, account management or sales teams with team sizes of 5+ people
- Proven experience leading teams, driving software adoption, and building and scaling customer success management practices

## Specialties

### Public Sector Customer Success Manager (CSM)

#### Public Sector CSM Responsibilities

- Extends the corresponding Customer Success Manager level responsibilities, working exclusively with Public Sector customers

#### Public Sector CSM Requirements

In addition to the corresponding Customer Success Manager level requirements:

- TS/SCI Security Clearance if applicable
- Knowledge of and demonstrated progressive experience with Public Sector customers

## Performance Indicators

- net ARR (i.e., retention and expansion)
- [CSM-related metrics](/handbook/customer-success/csm/).

## Career Ladder

Team members in the Customer Success Management job family may progress through the career ladder; in some instances team members may move to other roles in the Sales organization such as Customer Success Engineer, Customer Success Architect or Solutions Architect.

## Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process. To learn more about someone who may be conducting the interview, find their job title on our [team page](/handbook/company/team/).

### Recruiter Screening

Qualified candidates will be invited to schedule a 30 minute [screening call](/handbook/hiring/interviewing/#screening-call) with one of our Global Recruiters.

### Written Assessment

The assessment is a written questionnaire, completed and submitted prior to interviews with members of the Customer Success team. The Recruiter working with the candidate will provide the written assessment following a successful [recruiter screening interview](#recruiter-screening).

### Hiring Manager Interview

The hiring manager interview is the first of the interviews with the Customer Success team. This interview is with the manager of the team the candidate is applying to join. It is a 30 minute interview.

### Peer Interview

The peer interview is conducted by an individual contributor who is a member of the team the candidate is applying to join. Peer interviewers are selected by the hiring manager. This is a 30 minute interview.

### Panel Interview

The panel interview consists of several members of the Customer Success team. It typically includes the hiring manager and two other team members. This is a 60 minute interview, with the following format:

- Live demonstration based on the guidance provided ahead of the interview by the recruiter
- General discussion and questions from the panel

### Reference and Background Check

Once the candidate has successfully completed all interview stages with positive recommendations at each stage, GitLab will complete [reference checks](/handbook/hiring/interviewing/#reference-check-process) and a [background check](/handbook/hiring/interviewing/#background-checks).

Additional details about our process can be found on our [hiring page](/handbook/hiring/interviewing/).
