---
title: "Professional Services Engineer"
---

Professional Services Engineers engage with customers to provide installation, migration, training, and advisory services. They handle installations ranging from single-node Omnibus installs, to our largest reference architectures utilizing IaC/CaC, migrations from multiple systems to GitLab SaaS or self-hosted, and advisory services across the entire GitLab feature stack.

Professional Services Engineers are expected to be able to interface not only with the customer, but with our GitLab Product/Engineering teams, to find the best route for customer success, and to help drive improvements into GitLab features and processes.

## Levels

| Level | Grade |
| -- | - |
| [Associate Professional Services Engingeer](#associate-professional-services-engineer) | [Grade 5](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades) |
| [Intermediate Professional Services Engingeer](#professional-services-engineer) | [Grade 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades) |
| [Senior Professional Services Engingeer](#senior-professional-services-engineer) | [Grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades) |
| [Senior Manager, Professional Services Engineering](#senior-manager-professional-services-engineering) | [Grade 9](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades) |

## Performance Indicator

- <span style="text-decoration:underline;">PSE: [Billable utilization](/handbook/customer-success/professional-services-engineering/#implementation-plan)</span> target >= 70%

## Professional Experience

At GitLab, due to the pace at which we are moving, people joining our team in an associate role will be expected to have some professional experience in the primary engineering tools of the specialty that they'll be joining. For Professional Services Engineers, this means exposure or work experience using IaC/CaC technologies on one or more of the main cloud providers, as well as experience deploying, maintaining, and administering a GitLab instance.

### Field Functional Competencies

- [Field Functional Competencies](/handbook/sales/training/field-functional-competencies/)

As members of the GitLab field organization, Professional Services Engineers will be expected to exhibit behaviors consistent with these metrics.

#### Customer Focus

- Represents GitLab and GitLab values in public communication around broader initiatives, specific projects, and community contributions
- Works with engagement leads to understand customer needs and metrics for success
- Works with engagement leads and the customer to navigate the customers environment to achieve success
- Communicates confidently with customers and peers in written and verbal communications

#### Solution Focus

- Utilizes technical experience, and specific knowledge on the GitLab environment, to deliver the technical aspects of the engagement
- Works with engagement leads to help the customer map out their DevOps transformation as it relates to GitLab and their tool chain

#### Operational Excellence

- Learns and adopts current Professional Services processes for engagements
- Represents GitLab and GitLab values in public communication around broader initiatives, specific projects, and community contributions
- Liaises with GitLab customer support team to diagnose and troubleshoot support cases when necessary

## Associate Professional Services Engineer

### Responsibilities

- Uses a consultative approach to customer engagements
- Does not focus on just "doing the work"
- Looks for opportunities to help the customer achieve their vision more effectively and efficiently
- Delivers on SOW with guidance from technical architects

  - SOW scope may include:
    - Installation and configuration of GitLab solutions in the customer environment
    - Provide technical training sessions remotely and/or on-site
    - Provide documentation for implementation, guides, maintenance, etc relevant to the customer requirements.
    - Manage creation of new and/or maintenance of existing artifacts and templates for deliverables and training
    - Develop and implement migration plans for customer VCS & data migration
- Contributes to the extension and maintenance of documentation/scripts for implementation and workflow to align with custom requirements

### Requirements

- Professional exposure with one or more IaC/CaC technologies:
  - Terraform
  - Ansible
  - Packer
  - Puppet
  - Chef
- Professional exposure  with one or more cloud providers:
  - AWS
  - GCP
  - Azure
- Proficienct in the English language, both written and verbal, sufficient for success in a remote and largely asynchronous work environment
- Experience using, deploying, or configuring GitLab
- Comfortable working in a fast-paced environment, sometimes with multiple customer engagements at once
- Positive disposition and solution-oriented mindset
- Effective communication skills: [Regularly achieve consensus with peers](/handbook/values/#collaboration), and provide clear status updates
- [Self-motivated and self-managing](/handbook/values/#efficiency), with strong organizational skills
- Shares GitLab[values](/handbook/values/), and work in accordance with those values
- Ability to thrive in a fully remote organization
- ~20% travel may be required

## Professional Services Engineer

### Responsibilities

- Extends the general responsibilities with the following:
- Documents opportunities to help the customer achieve their vision more effectively and efficiently
  - Communicate opportunities to the customer project and account team
- Supports engagement managers on quoting and scoping of SOWs
- Document and implement improvements for Professional Services engagement processes

### Requirements

- Extends the general requirements with the following:
- [Professional experience](/job-families/sales/professional-services-engineer/#professional-experience) with one or more IaC/CaC technologies:
  - Terraform
  - Ansible
  - Packer
  - Puppet
  - Chef
- [Professional experience](/job-families/sales/professional-services-engineer/#professional-experience) with one or more cloud providers:
  - AWS
  - GCP
  - Azure
- Demonstrated capacity to clearly and concisely communicate about complex technical, architectural, and/or organizational problems and propose thorough iterative solutions
- Experience using, deploying, or configuring GitLab
- Ability to advise on GitLab recommendations, and build direction/consensus with the customer to move forward

## Senior Professional Services Engineer

### Responsiblities

- Provide feedback to Project Managers and Engagement Managers make scheduled delivery more consistent
- Continually work with Engagement Managers to streamline and improve delivery
- Exert influence on the overall objectives and long-range goals of your team and Professional Services
- Provide mentorship for Associate and Intermediate Professional Services Engineers to help them grow in their technical responsibilities and remove blockers to their autonomy
- Manage/oversee/deliver on multiple projects, either as the primary engineer, or as a lead providing oversight to other Professional Services Engineers

### Requirements

- Extends the general requirements with the following:
- Proven ability to independently manage a project or projects
- Proven ability to lead and provide direction to other Professional Services Engineers on a project or projects
- Proven ability to "think to the next question" and see the larger picture for customer engagements, and not just the individual task
- Proven ability to consider the business aspects of delivery
- Proven knowledge and mastery with major cloud technologies and public cloud providers
- Mastery with multiple highly available architectures and concepts
documents those opportunities

### Additional Skills

- Development skills in Python, Ruby, or Go
- Long-term experience managing a GitLab installation, preferably with Premium or Ultimate license levels
- Experience with deploying in Kubernetes, deploying at scale, and managing large-scale applications
- Experience in a peak performance organization, preferably a tech startup
- Experience with the GitLab product as a user, contributor, or DevOps maintainer
- Developer platform/tool industry experience
- Experience working with a global or otherwise multicultural team
- Computer science education or equivalent experience

## Senior Manager, Professional Services Engineering

The Senior Manager, Professional Services Engineering reports to the Director, Professional Services.

### Responsibilities

- Work with the Professional Services Director to help establish and manage goals and responsibilities for Professional Services Engineers
- Identify and own improvements to the processes and tools used to drive engineering in Professional Services
- Assist in the development of thought leadership, event-specific, and customer-facing presentations
- Provide leadership and guidance to coach, motivate, and lead services team members to their optimum performance levels and career development
- Manage resource assignments and staffing levels, working with PS Operations, including recruitment as needed
- Review and approve formal statements of work, change requests, and proposals
- Lead delivery of consulting, specifically for the PS Engineers who execute the custom SOWs and SKUs sold to our customers
- Remain knowledgeable and up-to-date on GitLab product releases and features
- Own operational metrics and financial goals, as defined by organizational goals, for the PS Engineering team including:
  - Revenue target
  - Gross margin
  - Engineer utilization and overall attainment
  - CSAT
  - % of projects on time and on budget
- Collaborate with peers in Practice Management, Engagement Management, and Operations to implement efficiency improvements for Professional Services
- Be a trusted advisor to GitLab AEs, SALs, and SAs
- Deliver updates on key Professional Services engagements and initiatives in the Sales and Professional Services forecast calls

### Requirements

- Demonstrated progressive experience managing, leading and/or delivering professional services or customer success
- Demonstrated progressive experience with a subscription-based business model, delivering on-premises and SaaS solutions
- Experience managing technical, cross-functional professional services teams (e.g., consulting, implementation, trainers, project managers) and delivery partners
- Experienced in and with advanced insight to the GitLab platform
- Experienced in giving and receiving positive and constructive feedback
- Adaptive to environmental changes based on project successes and failures
- Experienced in collaborating with other managers and executing strategies
- Proven track record in software/technology sales or consulting and management
- Demonstrated ability to think strategically about business, products, and technical challenges

## Public Sector

The Responsibilities, Requirements, and Additional Sklls for Public Sector Professional Services Engineers are identical to the commensurate Level and Grade of their non-Public Sector peers. The only additional job requirement is the necessary clearance to work on Government Contracts.

## Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process.

- Qualified candidates will be invited to schedule a 30 minute [screening call](/handbook/hiring/#screening-call) with one of our Global Recruiters.
- Next, candidates will be invited to schedule a first interview with the Regional Delivery Manager
Candidates may be invited to schedule an interview with Professional Services Engineer peer or other Professional Service team Manager.
Then, candidates will be required to deliver a demo of GitLab to a panel of Customer Success attendees using the Demo Guide.
Candidates may be invited to additional interviews.
Successful candidates will be made an offer after references are verified.

Additional details about our process can be found on our [hiring page](/handbook/hiring/interviewing/).

## Career Ladder

- The next steps for individual contributors is to move into:
  - A Manager role within this Job Family
  - To a Technical Architect role
- The next steps for a Manager, Professional Services would be to move into a Senior Manager within this Job Family or to the [Professional Services Engagement](/job-families/sales/job-professional-services-engagement-manager/) Job Family or the [Director of Professional Services](/job-families/sales/director-of-professional-services) Job Family.
- The next steps for a Senior Manager, Professional Services would be the [Professional Services Engagement](/job-families/sales/job-professional-services-engagement-manager/) Job Family or the [Director of Professional Services](/job-families/sales/director-of-professional-services) Job Family.
- [Leadership at GitLab](/handbook/company/structure/#director-group)
