---
title: "Technical Instructional Designer"
---

The Technical Instructional Designer is responsible for designing and developing new, engaging, and effective learning solutions and instructional experiences for GitLab customers, partners, and/or sales & customer success professionals that help these audiences achieve desired learning outcomes.

## Responsibilities

- Design and develop experiential learning solutions that support adult learning best practices, address needs identified in a job/task analysis, drive behavior change, and improve performance of GitLab customers, partners, and/or sales teams
- Follow GitLab branding guidelines and standards to ensure content is professional and consistent with corporate look and feel for external audiences
- Create and curate customer learning content using the latest technology and innovative techniques (especially via but not limited to scalable online delivery)
- Build and maintain valued relationships with key stakeholders and external vendors
- Design interactive courseware and video using adult learning theory that appeals to various learning styles and international audiences
- Utilize various modern authoring tools to rapidly build enjoyable, positive learning experiences that are interactive, effective, and technically functional
- Develop instructionally sound knowledge, skill, and job performance-based assessments
- Evaluate the business impact of learning programs through the use of learning and performance metrics
- Gain a working knowledge of the various functional and technological product areas of GitLab
- Closely partner and collaborate with other members of the Field Enablement team to continuously improve existing learning programs based on the latest research in adult education
- Meet all milestones and final deliverables by deadlines; when delays do occur, work with the team to estimate, monitor, adjust, and proactively communicate revised deadlines as needed
- Be a mentor to sales enablement program managers, trainers, and business partners on best practices in instructional design and enablement solutions
- Take on additional projects and responsibilities as needed

## Requirements

- Bachelor's degree required; Master's Degree in Instructional Development, Training Education/Communication is preferred
- Demonstrated progressive related work experience in B2B SaaS customer, partner, and/or sales training instructional design (or equivalent combination of transferable experience and education)
- Deep experience designing and developing learning programs across delivery mediums and content types (mobile learning, e-learning, video, gamification, virtual learning, live simulation, and live classroom)
- Proven experience designing and developing scalable, engaging, online training is a must
- Demonstrated experience working with multiple industry-recognized instructional design models preferred
- Must have the ability to work in an ever-changing, project-driven environment with a strong design sensibility when creating all customer, partner, and sales training and enablement instructional materials
- Strong oral and written communication skills and diverse experience working with internal customers and stakeholders in both live and virtual environments
- Proven ability to clearly articulate complex concepts in simple terms is essential
- Excellent team player
- Must be detail-oriented and have strong project management skills needing minimal supervision
- Experience with a wide range of modern e-learning authoring tools (e.g., recent versions of Adobe Captivate, Articulate 360 Suite, Go Animate, Elucidat, etc.)
- Working knowledge and application experience using reveal.js, Articulate 360, Adobe Creative Suite (Premiere, Captivate, InDesign, Illustrator, Photoshop), and other industry benchmark applications and online multimedia authoring tools
- HTML5, xAPI, mobile learning, and adaptive learning experience desired
- Experience working with a variety of Learning Management and Learning Experience Systems and various virtual meeting management tools such as Zoom is a plus
- Familiarity with statically generated websites is preferred, as we take a [handbook-first](/handbook/about/handbook-usage/#why-handbook-first) approach to Field and Customer Enablement
- Knowledge of the software development life cycle, DevOps, and/or open source software is preferred
- Ability to use GitLab

## Levels

### Technical Instructional Designer (Intermediate)

The Technical Instructional Designer (Intermediate) reports to the [Manager, Technical Instructional Designers](/manager-technical-instructional-designers).

#### Job Grade

The Technical Instructional Designer (Intermediate) is a [grade 6](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Intermediate Responsibilities

- Successfully accomplishes responsibilities with minimal direction or oversight

#### Intermediate Requirements

- Ability to consistently meet deadlines and execute on projects with positive feedback from stakeholders

### Senior Technical Instructional Designer

The Senior Technical Instructional Designer reports to the [Manager, Technical Instructional Designers](/manager-technical-instructional-designers).

#### Job Grade

The Senior Technical Instructional Designer is a [grade 7](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Senior Technical Instructional Designer Responsibilities

- Extends the Technical Instructional Designer (Intermediate) responsibilities
- Works quickly and iteratively on projects with very limited direction from others
- Has extensive knowledge of LMS platforms and interactive demo platforms
- Proven experience designing engaging and effective learning solutions for B2B enterprise sales professionals
- Viewed as a subject matter expert and trusted advisor by key stakeholders
- Innovates and continually improves the delivery of world-class learning solutions
- Regularly shares best practices and provides constructive coaching and feedback to other members of the team

#### Senior Technical Instructional Designer Requirements

- Extends the Technical Instructional Designer (Intermediate) requirements
- Demonstrated progressive experience in an instructional designer role, preferably with expertise in DevOps and/or Open Source
- Self-manages workload to meet deadlines and prioritize accordingly

### Manager, Technical Instructional Designers

The Manager, Technical Instructional Designers reports to the [Senior Director, Digital Success](/job-families/sales/director-customer-programs/).

#### Job Grade

The Manager, Technical Instructional Designers is a [grade 8](/handbook/total-rewards/compensation/compensation-calculator/#gitlab-job-grades).

#### Manager, Technical Instructional Designers Responsibilities

- Lead and develop a team of Technical Instructional Designers through effective hiring, onboarding, and performance management
- Develop and execute the strategic vision for technical learning content across GitLab's product portfolio
- Establish and maintain instructional design standards, best practices, and quality metrics
- Drive the adoption of innovative learning technologies and methodologies
- Manage resource allocation and project prioritization across multiple concurrent initiatives
- Own the team's quarterly OKRs and ensure alignment with company objectives
- Build relationships with key stakeholders across the organization
- Review and approve learning content, providing constructive feedback to improve quality
- Drive continuous improvement in content development processes and methodologies

#### Manager, Technical Instructional Designers Requirements

- Deep understanding of instructional design principles, adult learning theory, and educational technology
- Strong knowledge of learning management systems (LMS) and content development tools
- Experience with data analysis and reporting for learning metrics
- Proven track record of building and leading high-performing instructional design teams
- Strong project management skills with the ability to manage multiple concurrent initiatives
- Experience in budget planning and resource allocation
- Excellent stakeholder management and communication skills
- Ability to translate business objectives into effective learning strategies

## Performance Indicators

- Learning program effectiveness metrics (completion rates, satisfaction scores, knowledge retention)
- Quality and timeliness of learning content deliverables
- On-budget learning solutions delivered
- Team satisfaction and retention metrics
- Achievement of quarterly OKRs
- Stakeholder satisfaction with learning initiatives

## Career Ladder

There are several available options for the Technical Instructional Designer Job Family, including moving into [Customer Success Leadership](/job-families/sales/customer-success-leadership/) (Broader Function) or the [Education Services](/job-families/sales/professional-services-education-services/) Job Family.

## Hiring Process

Candidates for this position can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process. To learn more about someone who may be conducting the interview, find their job title on our [team page](/handbook/company/team/).

- Videoconference (or phone) screen interview with a GitLab Talent Acquisition team member
- Videoconference interviews with 2-3 additional GitLab team members
- Final videoconference interviews with the Director, Digital Customer Success (VP, Customer Success for Manager roles)

Additional details about our process can be found on our [hiring page](/handbook/hiring/).
