---
title: "Measurement Clarity"
summary: "Teams exist to deliver results. This is about achieving objectives. TeamOps' decision-making principles are only useful if you execute and deliver results. **A result is not a one-time event**; rather, delivering a result establishes a new baseline. This allows future iterations to begin. In this way, focusing on execution empowers everyone to contribute to meaningful business outcomes."
weight: 4
canonical_path: "/teamops/measurement-clarity/"
images:
    - /images/opengraph/all-remote.jpg
---

![GitLab TeamOps teamwork illustration](/teamops/images/teamops-illustration_teamwork_purple.png)

{{% alert color="primary" %}}
This page is about one of the four Guiding Principles of TeamOps: Measurement Clarity. To learn more about the other three Principles, return to the main TeamOps page for a [complete overview of TeamOps](https://about.gitlab.com/teamops/), or enroll in the free [TeamOps course](https://levelup.gitlab.com/learn/course/teamops).
{{% /alert %}}

*Outdated workforce supervision tactics often trigger bias and presenteeism. Evaluating productivity differently requires unique methods of recording and managing results.*

Measurement is important in any organization. As Peter Drucker famously said, "If you can't measure it, you can't manage it." But in conventionally managed organizations, too often the model of "successful work" involves physical presence—a team member needs to be in a certain building in order to be "at work."

Teams working via TeamOps should employ methods of measuring productivity, value, and results that *don't* depend on physical supervision as a measure of contribution. Re-prioritizing *what*, *how*, and *when* the organization measures enables a higher frequency of success, greater accountability for objectives, lower workforce discrimination, and wider reach for company communication.

In short: TeamOps treats "work" as something we do, not somewhere we go.

Action tenets of measurement clarity, including real-world examples of each, are below.

## Transparent measurements

Conventional management philosophies glorify "metrics," which is a nonspecific term that often lacks connection to objectives, mission, values, workflows, strategy, or a shared reality. TeamOps prefers [Key Performance Indicators (KPIs)](/handbook/company/kpis/), which are smaller, incremental measures linked to [Objectives and Key Results](/handbook/company/okrs/) (OKRs) that, well, *indicate performance*. These offer greater context for both daily operations and the relevance of ongoing productivity to a function or the entire company.

While KPIs measure smaller units than OKRs do, the former aren't dependent on the latter. In fact, the two should be symbiotic in nature, informing and influencing each other to enhance operational visibility, measurement accuracy, and team empowerment. If you're not creating OKRs to improve KPIs, then you're either missing KPIs or you have the wrong OKRs.

Crucially, under TeamOps every functional department shares its KPIs transparently across the organization. This aids visibility and enables everyone to contribute.

{{% details summary="Examples and resources for transparent measurements" %}}
**Example:** [Chief Executive Officer OKR and KPIs](/handbook/company/okrs/fy23-q3/)

In Q3-FY23 at GitLab, a company OKR was [Improve user and wider-community engagement](/handbook/company/okrs/fy23-q3/). This is the *initiative* to improve a series of KPIs, a subset of which are documented below:

1. Evolve the resident contributor strategy by conducting 5 customer conversations with current "resident contributors" in seat
1. Certify 1,000 team members and 10,000 wider-community members in TeamOps
1. Enhance Corporate Processes and Successful Corporate Development Integration & Prospecting

These are documented in a tool that's accessible to the entire organization. Any team member can see any function's OKRs and KPIs for the quarter, reinforcing the [value of transparency](/handbook/values/#transparency).

**Resource:** [Performance Management on Remote and Hybrid Teams](https://www.workplaceless.com/blog/remote-performance-management) (article)
{{% /details %}}

{{% details summary="Change management support for transparent measurements" %}}
**Quick Start Tips:**

- *Individual:* Confirm that your personal task and project management systems sharing settings are public by default. Inform your team members how and where to access them if they're ever wondering what you're working on.
- *Team:* When starting a new project, define and document the contributions of each team member, and how "success" will be measured both individually and collectively.
- *Company:* In performance review agendas, add a section to revisit (and update, if needed) each team member's weekly, monthly, quarterly, and yearly OKRs and KPIs. Specifically discuss and answer the question, "What does productivity look like in this role?"

**Recommended TeamOps Partner:** [Lance Robbins](https://lancehrobbins.com/) (consultant)
{{% /details %}}

## Measure impact, not activity

Every organizational operational model aims to optimize the efficiency with which teams produce impact. But conventionally managed teams make a critical error when they conflate "efficiency" with "speed." Doing so means *time* often becomes the team's highest priority—and *working activity* become a principal success metric for the organization.

In organizations powered by TeamOps, team members understand that the root of "productivity" is "to produce," and therefore focus on [executing business impact](/handbook/values/#measure-impact-not-activity), rather than executing on [presenteeism](https://language.work/research/killing-time-at-work/). TeamOps therefore encourages success measurements based on outputs, not inputs.

Note that outputs aren't just tangible deliverables. Results include any form of value a team member contributes to the organization's shared reality: helping a teammate, satisfying a customer, shipping code, brainstorming a new idea, writing a revision, or researching a competitor. All quantifiable reports, messages, insights, or submissions are evidence of productivity.

{{% details summary="Examples and resources for measuring impact, not hours" %}}
**Example:** [Measuring impact of GitLab's 10 year campaign](https://gitlab.com/gitlab-com/marketing/corporate_marketing/corporate-marketing/-/issues/5507)

Producing the `10 Years of GitLab` integrated marketing campaign and [associated website](https://web.archive.org/web/20240225183113/https://about.gitlab.com/ten/) demanded a cross-functional effort. Working group members established a GitLab issue to explicitly define [elements to be tracked and measured](https://gitlab.com/gitlab-com/marketing/corporate_marketing/corporate-marketing/-/issues/5507) in order to provide an adequate report of the campaign's overall impact. By focusing on impact over activity spent (or if a given team member was online at a certain time, or in a certain office), everyone involved in the project could focus energy on executing the campaign.

**Resource:** [Time is Not a Measure of Productivity](https://nesslabs.com/time-is-not-a-measure-of-productivity) (article)
{{% /details %}}

{{% details summary="Change management support for measuring impact, not activity" %}}
**Quick Start Tips:**

- *Individual:* When writing your daily to do list, note which three tasks are your highest priority, and use the completion of those tasks to measure "a good day's work." Consider shedding or delegating any tasks that don't directly relate to your OKRs.
- *Team:* Confirm that the assigned objectives and key results (OKRs) of each team member are prominently displayed in each project management plan.
- *Company:* Confirm that your HR or People department is measuring and monitoring presenteeism, and that work location is not being discussed during performance reviews.

**Recommended TeamOps Partner:** [Lance Robbins](https://lancehrobbins.com/) (consultant)
{{% /details %}}

## Definition of done

While often associated with the [Agile](https://www.agilealliance.org/glossary/definition-of-done/) software development movement, "definition of done" is a practice that teams in *any* industry can use to enhance measurement clarity. For organizations practicing TeamOps, developing a definition of done helps teams identify the conclusion of one [iteration](/handbook/values/#iteration) and the beginning of the next. For [software development teams](https://docs.gitlab.com/ee/development/contributing/merge_request_workflow.html?_gl=1*1s8xk24*_ga*MTU4MjYxNTAxOS4xNjc0NjYwMDUy*_ga_ENFH3X7M5Y*MTY3NzI3MTAzMy42Ny4xLjE2NzcyNzI3MDcuMC4wLjA.#definition-of-done), this usually means that the code is verified as working; for other teams, it may mean that a certain output has been created and delivered.

A team's definition of done may not always be the same. It might outline the success criteria for a quarterly OKR, explain when a project or working group should be considered "closed," or enumerate the fulfillment criteria for a small task. Regardless of the scope of impact, clearly [communicating](/teamops/decision-velocity/#low-context-communication) and [documenting](/teamops/shared-reality/#single-source-of-truth-ssot) completion criteria as a definition of done helps TeamOps teams align on methods for measuring and defining success.

Even better, definitions of done are prompts for important [team-building communication](/teamops/shared-reality/#informal-communication). When all of the criteria are complete, that's a signal to your team to review the [contributions each team member has made to the work](/teamops/equal-contributions/), collaboratively brainstorm [future iterations](/handbook/values/#iteration), and celebrate the fulfillment of your [shared reality goals](/teamops/shared-reality/).

{{% details summary="Examples and resources for definition of done" %}}
**Example:** TeamOps Course Updates

Every quarter, GitLab's Workplace team adds new features and enhancements to the [free TeamOps course in LevelUp](https://levelup.gitlab.com/learn/course/teamops). Each [project management plan](https://gitlab.com/gitlab-com/office-of-the-ceo/workplace/teamops-fy24-q1/-/issues/5) includes a Measurement Clarity section outlining a list of completion criteria. This creates a very clear distinction between work that's *In Progress* and *Closed*, and generates a signal to close the issue.

**Resource:** [Definition of Done by Leading Agile](https://www.leadingagile.com/2017/02/definition-of-done/) (article)
{{% /details %}}

{{% details summary="Change management support for definition of done" %}}
**Quick Start Tips:**

- *Individual:* When conducting any kind of retrospective discussion, start the conversation with whether or not the Definition of Done was fulfilled (as a baseline for success measurement), then move on to feedback and learnings.
- *Team:* Create a field in your project management plan template for listing the project's definition of done.
- *Company:* When approving OKRs, include a Definition of Done as a minimum requirement for fulfillment, then supplement with more ambitious goals for the team or individual to work toward.

**Recommended TeamOps Partner:** [Lance Robbins](https://lancehrobbins.com/) (consultant)
{{% /details %}}

## Prioritize due dates over scope

TeamOps may not treat [elapsed time as a success measurement](/teamops/measurement-clarity/#measure-impact-not-activity), but it does require due dates. Under TeamOps, however, due dates aren't a means of creating unnecessary rigidity or measuring the duration of contributions; they exist to force mechanisms that enable teams to execute on decisions and enforce accountability.

An organization practicing TeamOps will always set a due date and, if necessary in light of changing circumstances, will *cut project scope* to meet that due date rather than *postpone* that date. This encourages teams to think [iteratively](/handbook/values/#iteration), recalculate the scope of current work, and better determine which aspects of a project are best saved for future objectives. Working this way limits loss of momentum.

{{% details summary="Examples and resources for prioritize due dates over scope" %}}
**Example:** [Maintaining a monthly release cadence for 10+ years](https://about.gitlab.com/releases/)

As of 2022-12-01, GitLab has [shipped a monthly product release](https://about.gitlab.com/releases/) for 134 consecutive months. That's more than 10 years! A decade of [consistent execution](https://about.gitlab.com/blog/2018/11/21/why-gitlab-uses-a-monthly-release-cycle/) is made possible by [cutting scope](/handbook/values/#set-a-due-date) instead of pushing ship dates.

**Resource:** [Project Scope: How to Meet Deadlines and Keep Stakeholders Happy](https://www.process.st/project-scope/) (article)
{{% /details %}}

{{% details summary="Change management support for prioritize due dates over scope" %}}
**Quick Start Tips:**

- *Individual:* Whenever a status update or project review conversation indicates that a result is falling behind schedule or that contributing team members feel overwhelmed, immediately ask the question, "What can we do to simplify this result so that we can stay on track?"
- *Team:* Confirm that the due date of a project is prominently displayed in each project management plan for your team.
- *Company:* Update your company's onboarding and continuing education programs to include training about how to produce iterative results.

**Recommended TeamOps Partner:** [Lance Robbins](https://lancehrobbins.com/) (consultant)
{{% /details %}}

## Transparent feedback

Achieving measurement clarity involves more than evaluating *whether* your team successfully achieved its goals. It also involves evaluating *how* your team succeeded during the process. So just as a team's measurements should be as [transparent](/teamops/measurement-clarity/#transparent-measurements) as possible, so too should be a team's feedback *about* those results.

[Transparent feedback](/handbook/people-group/guidance-on-feedback/) means that constructive criticism is:

- immediate
- specific
- documented

Like all information shared on a team practicing TeamOps, the impacts and action items a message triggers shouldn't rely on a recipient's subjective memory or interpretation. Sharing feedback is a great start to improving an individual's future work; sharing it transparently means that the entire team can improve together.

To optimize the efficacy of delivered feedback, consider how other TeamOps tenets can support actionability. For example:

- Exercise your [bias for action](/teamops/decision-velocity/#bias-for-action) to share feedback as quickly as possible
- Use [low-context communication](/teamops/decision-velocity/#low-context-communication) by sharing specific examples that support your feedback
- Leverage [asynchronous workflows](/teamops/equal-contributions/#asynchronous-workflows) to allow time for review and reflection
- Encourage [iterative](/handbook/values/#iteration) growth to build up to aspirational goals
- In appropriate scenarios, share feedback (both positive and negative) [publicly](/teamops/shared-reality/#public-by-default) with an entire group whose other members can also learn from the insights.
- As a manager, prioritize building [psychological safety](/teamops/equal-contributions/#psychological-safety) during group collaboration by encouraging healthy controversy and by investing time in [informal communication](/teamops/shared-reality/#informal-communication) to build trust and camaraderie that can withstand negative criticism.

{{% details summary="Examples and resources for transparent feedback" %}}
**Example:** [A member of GitLab's L&D Team Giving Feedback to the CEO](/handbook/people-group/guidance-on-feedback/#guidance-on-giving-and-receiving-feedback)

At GitLab, our mission that [everyone can contribute] even influences our feedback guidelines—suggesting that any team member, at any level, can give feedback to any other team member, at any level. In this video about [Guidance on Giving and Receiving Feedback](/handbook/people-group/guidance-on-feedback/#guidance-on-giving-and-receiving-feedback), the CEO of GitLab, Sid Sijbrandij, discusses this challenge in more detail, and asks for performance feedback from a member of the Learning & Development team.

**Resource:** [Guide to Giving Remote Feedback](https://www.workplaceless.com/blog/guide-to-remote-feedback) (playbook)
{{% /details %}}

{{% details summary="Change management support for transparent feedback" %}}
**Quick Start Tips:**

- *Individual:* Commit to sharing sincere compliments and/or constructive criticism with each of your peers at least once a week. (While you're building the habit, set reminders on your calendar for reminders and accountability.)
- *Team:* Add a section for group feedback into every meeting agenda.
- *Company:* Create a ritual for company leadership to receive and share feedback on certain projects or tasks, to set a top-down example of healthy feedback dynamics.

**Recommended TeamOps Partner:** [Code Traveller HR](codetravellerhr.com) (consultant)
{{% /details %}}

## Cadence

In organizations built on information-based operations, team members' collective sense of stability, security, and well-being is an outgrowth of their knowing when future opportunities to receive and exchange knowledge will occur. A [Single Source of Truth (SSoT)](/teamops/shared-reality/#single-source-of-truth-ssot) and [asynchronous workflows](/teamops/equal-contributions/#asynchronous-workflows) ensure that existing information is continuously accessible. But what about informational *updates*? Not knowing about emerging decisions, forthcoming goals, or adjustments to long-term visions can compromise a team's focus, efficiency, and trust.

This is why establishing a transparent [cadence](/handbook/company/cadence/) for decision-making activities, informational updates, and feedback opportunities is important for teams practicing TeamOps. A regular cadence sets a *pace* for productivity and creates predictable, comfortable intervals for work. Establishing and documenting a cadence for everything from operational workflows and [due dates](/handbook/teamops/measurement-clarity/#prioritize-due-dates-over-scope)  to company announcements and team meetings can prevent the kinds of distraction and burnout that often result from context switching, distractive research, or individual uncertainty.

{{% details summary="Examples and resources for cadence" %}}
**Example:** [GitLab's Quarterly All-Hands Meeting](/handbook/company/gitlab-assembly/)

At the same time each quarter, executive leadership hosts [GitLab Assembly](/handbook/company/gitlab-assembly/)—a company-wide recap of the past quarter's accomplishments, summary of the new quarter's objectives, and an open-floor Q&A for any employee to resolve questions or concerns. Knowing exactly when this meeting will occur, who will be in attendance, and what will be discussed gives GitLab team members full confidence of when they can have direct access to the executive team about company growth.

**Resource:** [How to use a business cadence to promote collaboration](https://web.archive.org/web/20231201100335/https://www.hydra.cloud/en/resources/blog/how-to-use-a-business-cadence-to-promote-collaboration) (article)
{{% /details %}}

{{% details summary="Change management support for cadence" %}}
**Quick Start Tips:**

- *Individual:* Design and document a cadence calendar for personal rituals, such as internal networking, SSoT updates, or operational transparency reporting.
- *Team:* Design and document a cadence calendar for team rituals, such as delivery cycles, team offsites, or performance reviews.
- *Company:* Design and document a cadence calendar for company rituals, such as OKRs, stakeholder meetings, or workforce retreats.

**Recommended TeamOps Partner:** [Lance Robbins](https://lancehrobbins.com/) (consultant)
{{% /details %}}

---

{{< cardpane >}}

{{< panel header="**Home**" header-bg="indigo" >}}
Return to the <a href="https://about.gitlab.com/teamops/">TeamOps homepage</a>.
{{< /panel >}}

{{< panel header="**Next**" header-bg="success" >}}
Restart the TeamOps model by learning about <a href="/teamops/shared-reality/">TeamOps - Shared Reality</a>.
{{< /panel >}}

{{< /cardpane >}}
