---
title: "Secure Product Metrics"
---

This page shows various metrics for the products developed and maintained by
the [Secure Stage](/handbook/product/categories/#sec-section).

We are [actively supporting Common Weakness Enumeration (CWE)](https://gitlab.com/gitlab-org/gitlab/-/issues/300978)
as a standard vulnerability classification system and a common language to discuss software weaknesses.

Using [CWE](https://cwe.mitre.org/) as a foundation has several advantages:

1. CWE is a comprehensive and well-documented system and can be considered as a de-facto standard for discussing software weaknesses.
1. CWE provides mappings to other vulnerability and classification systems and/or rankins (such as [OWASP Top 10](https://owasp.org/Top10/)).
1. CWE provides a stable ontology: definitions can be added but existing definitions do not change (unlike OWASP rankings).

CWE is a hierarchical system with an ontology that is organized in a tree
structure where a parent CWE is more general than its child; a child CWE
captures a vulnerability in more specific terms than its parent.

In contrast to CWE, [OWASP Top 10](https://owasp.org/Top10/) provides a risk
ranking of the most critical security vulnerabilities. The 10 risk categories
change on a regular basis.

The table below shows the mapping between OWASP categories and their CWE
counterparts. Note that the table includes transitive CWE mappings which
are all the CWE mappings that are listed on the [OWASP Top10 website](https://owasp.org/Top10)
including their child-CWEs.

| OWASP | CWEs |
| ----- | ---- |
| A1: [Broken Access Control](https://owasp.org/Top10/A01_2021-Broken_Access_Control) | [8](https://cwe.mitre.org/data/definitions/8.html), [9](https://cwe.mitre.org/data/definitions/9.html), [13](https://cwe.mitre.org/data/definitions/13.html), [15](https://cwe.mitre.org/data/definitions/15.html), [22](https://cwe.mitre.org/data/definitions/22.html), [23](https://cwe.mitre.org/data/definitions/23.html), [24](https://cwe.mitre.org/data/definitions/24.html), [25](https://cwe.mitre.org/data/definitions/25.html), [26](https://cwe.mitre.org/data/definitions/26.html), [27](https://cwe.mitre.org/data/definitions/27.html), [28](https://cwe.mitre.org/data/definitions/28.html), [29](https://cwe.mitre.org/data/definitions/29.html), [30](https://cwe.mitre.org/data/definitions/30.html), [31](https://cwe.mitre.org/data/definitions/31.html), [32](https://cwe.mitre.org/data/definitions/32.html), [33](https://cwe.mitre.org/data/definitions/33.html), [34](https://cwe.mitre.org/data/definitions/34.html), [35](https://cwe.mitre.org/data/definitions/35.html), [36](https://cwe.mitre.org/data/definitions/36.html), [37](https://cwe.mitre.org/data/definitions/37.html), [38](https://cwe.mitre.org/data/definitions/38.html), [39](https://cwe.mitre.org/data/definitions/39.html), [40](https://cwe.mitre.org/data/definitions/40.html), [41](https://cwe.mitre.org/data/definitions/41.html), [42](https://cwe.mitre.org/data/definitions/42.html), [43](https://cwe.mitre.org/data/definitions/43.html), [44](https://cwe.mitre.org/data/definitions/44.html), [45](https://cwe.mitre.org/data/definitions/45.html), [46](https://cwe.mitre.org/data/definitions/46.html), [47](https://cwe.mitre.org/data/definitions/47.html), [48](https://cwe.mitre.org/data/definitions/48.html), [49](https://cwe.mitre.org/data/definitions/49.html), [50](https://cwe.mitre.org/data/definitions/50.html), [51](https://cwe.mitre.org/data/definitions/51.html), [52](https://cwe.mitre.org/data/definitions/52.html), [53](https://cwe.mitre.org/data/definitions/53.html), [54](https://cwe.mitre.org/data/definitions/54.html), [55](https://cwe.mitre.org/data/definitions/55.html), [56](https://cwe.mitre.org/data/definitions/56.html), [57](https://cwe.mitre.org/data/definitions/57.html), [58](https://cwe.mitre.org/data/definitions/58.html), [59](https://cwe.mitre.org/data/definitions/59.html), [61](https://cwe.mitre.org/data/definitions/61.html), [62](https://cwe.mitre.org/data/definitions/62.html), [64](https://cwe.mitre.org/data/definitions/64.html), [65](https://cwe.mitre.org/data/definitions/65.html), [66](https://cwe.mitre.org/data/definitions/66.html), [67](https://cwe.mitre.org/data/definitions/67.html), [69](https://cwe.mitre.org/data/definitions/69.html), [72](https://cwe.mitre.org/data/definitions/72.html), [73](https://cwe.mitre.org/data/definitions/73.html), [94](https://cwe.mitre.org/data/definitions/94.html), [95](https://cwe.mitre.org/data/definitions/95.html), [96](https://cwe.mitre.org/data/definitions/96.html), [97](https://cwe.mitre.org/data/definitions/97.html), [98](https://cwe.mitre.org/data/definitions/98.html), [114](https://cwe.mitre.org/data/definitions/114.html), [134](https://cwe.mitre.org/data/definitions/134.html), [178](https://cwe.mitre.org/data/definitions/178.html), [200](https://cwe.mitre.org/data/definitions/200.html), [201](https://cwe.mitre.org/data/definitions/201.html), [202](https://cwe.mitre.org/data/definitions/202.html), [203](https://cwe.mitre.org/data/definitions/203.html), [204](https://cwe.mitre.org/data/definitions/204.html), [205](https://cwe.mitre.org/data/definitions/205.html), [206](https://cwe.mitre.org/data/definitions/206.html), [207](https://cwe.mitre.org/data/definitions/207.html), [208](https://cwe.mitre.org/data/definitions/208.html), [209](https://cwe.mitre.org/data/definitions/209.html), [210](https://cwe.mitre.org/data/definitions/210.html), [211](https://cwe.mitre.org/data/definitions/211.html), [213](https://cwe.mitre.org/data/definitions/213.html), [214](https://cwe.mitre.org/data/definitions/214.html), [215](https://cwe.mitre.org/data/definitions/215.html), [219](https://cwe.mitre.org/data/definitions/219.html), [220](https://cwe.mitre.org/data/definitions/220.html), [250](https://cwe.mitre.org/data/definitions/250.html), [256](https://cwe.mitre.org/data/definitions/256.html), [257](https://cwe.mitre.org/data/definitions/257.html), [258](https://cwe.mitre.org/data/definitions/258.html), [259](https://cwe.mitre.org/data/definitions/259.html), [260](https://cwe.mitre.org/data/definitions/260.html), [261](https://cwe.mitre.org/data/definitions/261.html), [262](https://cwe.mitre.org/data/definitions/262.html), [263](https://cwe.mitre.org/data/definitions/263.html), [264](https://cwe.mitre.org/data/definitions/264.html), [266](https://cwe.mitre.org/data/definitions/266.html), [267](https://cwe.mitre.org/data/definitions/267.html), [268](https://cwe.mitre.org/data/definitions/268.html), [269](https://cwe.mitre.org/data/definitions/269.html), [270](https://cwe.mitre.org/data/definitions/270.html), [271](https://cwe.mitre.org/data/definitions/271.html), [272](https://cwe.mitre.org/data/definitions/272.html), [273](https://cwe.mitre.org/data/definitions/273.html), [274](https://cwe.mitre.org/data/definitions/274.html), [275](https://cwe.mitre.org/data/definitions/275.html), [276](https://cwe.mitre.org/data/definitions/276.html), [277](https://cwe.mitre.org/data/definitions/277.html), [278](https://cwe.mitre.org/data/definitions/278.html), [279](https://cwe.mitre.org/data/definitions/279.html), [281](https://cwe.mitre.org/data/definitions/281.html), [282](https://cwe.mitre.org/data/definitions/282.html), [283](https://cwe.mitre.org/data/definitions/283.html), [284](https://cwe.mitre.org/data/definitions/284.html), [285](https://cwe.mitre.org/data/definitions/285.html), [286](https://cwe.mitre.org/data/definitions/286.html), [287](https://cwe.mitre.org/data/definitions/287.html), [288](https://cwe.mitre.org/data/definitions/288.html), [289](https://cwe.mitre.org/data/definitions/289.html), [290](https://cwe.mitre.org/data/definitions/290.html), [291](https://cwe.mitre.org/data/definitions/291.html), [293](https://cwe.mitre.org/data/definitions/293.html), [294](https://cwe.mitre.org/data/definitions/294.html), [295](https://cwe.mitre.org/data/definitions/295.html), [296](https://cwe.mitre.org/data/definitions/296.html), [297](https://cwe.mitre.org/data/definitions/297.html), [298](https://cwe.mitre.org/data/definitions/298.html), [299](https://cwe.mitre.org/data/definitions/299.html), [300](https://cwe.mitre.org/data/definitions/300.html), [301](https://cwe.mitre.org/data/definitions/301.html), [302](https://cwe.mitre.org/data/definitions/302.html), [303](https://cwe.mitre.org/data/definitions/303.html), [304](https://cwe.mitre.org/data/definitions/304.html), [305](https://cwe.mitre.org/data/definitions/305.html), [306](https://cwe.mitre.org/data/definitions/306.html), [307](https://cwe.mitre.org/data/definitions/307.html), [308](https://cwe.mitre.org/data/definitions/308.html), [309](https://cwe.mitre.org/data/definitions/309.html), [312](https://cwe.mitre.org/data/definitions/312.html), [313](https://cwe.mitre.org/data/definitions/313.html), [314](https://cwe.mitre.org/data/definitions/314.html), [315](https://cwe.mitre.org/data/definitions/315.html), [316](https://cwe.mitre.org/data/definitions/316.html), [317](https://cwe.mitre.org/data/definitions/317.html), [318](https://cwe.mitre.org/data/definitions/318.html), [321](https://cwe.mitre.org/data/definitions/321.html), [322](https://cwe.mitre.org/data/definitions/322.html), [346](https://cwe.mitre.org/data/definitions/346.html), [350](https://cwe.mitre.org/data/definitions/350.html), [352](https://cwe.mitre.org/data/definitions/352.html), [359](https://cwe.mitre.org/data/definitions/359.html), [370](https://cwe.mitre.org/data/definitions/370.html), [374](https://cwe.mitre.org/data/definitions/374.html), [375](https://cwe.mitre.org/data/definitions/375.html), [377](https://cwe.mitre.org/data/definitions/377.html), [378](https://cwe.mitre.org/data/definitions/378.html), [379](https://cwe.mitre.org/data/definitions/379.html), [386](https://cwe.mitre.org/data/definitions/386.html), [402](https://cwe.mitre.org/data/definitions/402.html), [403](https://cwe.mitre.org/data/definitions/403.html), [419](https://cwe.mitre.org/data/definitions/419.html), [420](https://cwe.mitre.org/data/definitions/420.html), [421](https://cwe.mitre.org/data/definitions/421.html), [422](https://cwe.mitre.org/data/definitions/422.html), [424](https://cwe.mitre.org/data/definitions/424.html), [425](https://cwe.mitre.org/data/definitions/425.html), [426](https://cwe.mitre.org/data/definitions/426.html), [427](https://cwe.mitre.org/data/definitions/427.html), [428](https://cwe.mitre.org/data/definitions/428.html), [433](https://cwe.mitre.org/data/definitions/433.html), [441](https://cwe.mitre.org/data/definitions/441.html), [470](https://cwe.mitre.org/data/definitions/470.html), [472](https://cwe.mitre.org/data/definitions/472.html), [488](https://cwe.mitre.org/data/definitions/488.html), [491](https://cwe.mitre.org/data/definitions/491.html), [492](https://cwe.mitre.org/data/definitions/492.html), [493](https://cwe.mitre.org/data/definitions/493.html), [497](https://cwe.mitre.org/data/definitions/497.html), [498](https://cwe.mitre.org/data/definitions/498.html), [499](https://cwe.mitre.org/data/definitions/499.html), [500](https://cwe.mitre.org/data/definitions/500.html), [502](https://cwe.mitre.org/data/definitions/502.html), [520](https://cwe.mitre.org/data/definitions/520.html), [521](https://cwe.mitre.org/data/definitions/521.html), [522](https://cwe.mitre.org/data/definitions/522.html), [523](https://cwe.mitre.org/data/definitions/523.html), [524](https://cwe.mitre.org/data/definitions/524.html), [525](https://cwe.mitre.org/data/definitions/525.html), [526](https://cwe.mitre.org/data/definitions/526.html), [527](https://cwe.mitre.org/data/definitions/527.html), [528](https://cwe.mitre.org/data/definitions/528.html), [529](https://cwe.mitre.org/data/definitions/529.html), [530](https://cwe.mitre.org/data/definitions/530.html), [531](https://cwe.mitre.org/data/definitions/531.html), [532](https://cwe.mitre.org/data/definitions/532.html), [535](https://cwe.mitre.org/data/definitions/535.html), [536](https://cwe.mitre.org/data/definitions/536.html), [537](https://cwe.mitre.org/data/definitions/537.html), [538](https://cwe.mitre.org/data/definitions/538.html), [539](https://cwe.mitre.org/data/definitions/539.html), [540](https://cwe.mitre.org/data/definitions/540.html), [541](https://cwe.mitre.org/data/definitions/541.html), [548](https://cwe.mitre.org/data/definitions/548.html), [549](https://cwe.mitre.org/data/definitions/549.html), [550](https://cwe.mitre.org/data/definitions/550.html), [551](https://cwe.mitre.org/data/definitions/551.html), [552](https://cwe.mitre.org/data/definitions/552.html), [553](https://cwe.mitre.org/data/definitions/553.html), [555](https://cwe.mitre.org/data/definitions/555.html), [556](https://cwe.mitre.org/data/definitions/556.html), [565](https://cwe.mitre.org/data/definitions/565.html), [566](https://cwe.mitre.org/data/definitions/566.html), [582](https://cwe.mitre.org/data/definitions/582.html), [583](https://cwe.mitre.org/data/definitions/583.html), [593](https://cwe.mitre.org/data/definitions/593.html), [598](https://cwe.mitre.org/data/definitions/598.html), [599](https://cwe.mitre.org/data/definitions/599.html), [601](https://cwe.mitre.org/data/definitions/601.html), [603](https://cwe.mitre.org/data/definitions/603.html), [608](https://cwe.mitre.org/data/definitions/608.html), [612](https://cwe.mitre.org/data/definitions/612.html), [615](https://cwe.mitre.org/data/definitions/615.html), [619](https://cwe.mitre.org/data/definitions/619.html), [620](https://cwe.mitre.org/data/definitions/620.html), [621](https://cwe.mitre.org/data/definitions/621.html), [623](https://cwe.mitre.org/data/definitions/623.html), [627](https://cwe.mitre.org/data/definitions/627.html), [638](https://cwe.mitre.org/data/definitions/638.html), [639](https://cwe.mitre.org/data/definitions/639.html), [640](https://cwe.mitre.org/data/definitions/640.html), [642](https://cwe.mitre.org/data/definitions/642.html), [645](https://cwe.mitre.org/data/definitions/645.html), [647](https://cwe.mitre.org/data/definitions/647.html), [648](https://cwe.mitre.org/data/definitions/648.html), [651](https://cwe.mitre.org/data/definitions/651.html), [668](https://cwe.mitre.org/data/definitions/668.html), [706](https://cwe.mitre.org/data/definitions/706.html), [708](https://cwe.mitre.org/data/definitions/708.html), [732](https://cwe.mitre.org/data/definitions/732.html), [767](https://cwe.mitre.org/data/definitions/767.html), [784](https://cwe.mitre.org/data/definitions/784.html), [798](https://cwe.mitre.org/data/definitions/798.html), [804](https://cwe.mitre.org/data/definitions/804.html), [827](https://cwe.mitre.org/data/definitions/827.html), [836](https://cwe.mitre.org/data/definitions/836.html), [842](https://cwe.mitre.org/data/definitions/842.html), [862](https://cwe.mitre.org/data/definitions/862.html), [863](https://cwe.mitre.org/data/definitions/863.html), [913](https://cwe.mitre.org/data/definitions/913.html), [914](https://cwe.mitre.org/data/definitions/914.html), [915](https://cwe.mitre.org/data/definitions/915.html), [918](https://cwe.mitre.org/data/definitions/918.html), [921](https://cwe.mitre.org/data/definitions/921.html), [922](https://cwe.mitre.org/data/definitions/922.html), [923](https://cwe.mitre.org/data/definitions/923.html), [925](https://cwe.mitre.org/data/definitions/925.html), [926](https://cwe.mitre.org/data/definitions/926.html), [927](https://cwe.mitre.org/data/definitions/927.html), [939](https://cwe.mitre.org/data/definitions/939.html), [940](https://cwe.mitre.org/data/definitions/940.html), [941](https://cwe.mitre.org/data/definitions/941.html), [942](https://cwe.mitre.org/data/definitions/942.html), [1004](https://cwe.mitre.org/data/definitions/1004.html), [1021](https://cwe.mitre.org/data/definitions/1021.html), [1022](https://cwe.mitre.org/data/definitions/1022.html), [1189](https://cwe.mitre.org/data/definitions/1189.html), [1191](https://cwe.mitre.org/data/definitions/1191.html), [1220](https://cwe.mitre.org/data/definitions/1220.html), [1222](https://cwe.mitre.org/data/definitions/1222.html), [1224](https://cwe.mitre.org/data/definitions/1224.html), [1230](https://cwe.mitre.org/data/definitions/1230.html), [1231](https://cwe.mitre.org/data/definitions/1231.html), [1242](https://cwe.mitre.org/data/definitions/1242.html), [1243](https://cwe.mitre.org/data/definitions/1243.html), [1244](https://cwe.mitre.org/data/definitions/1244.html), [1252](https://cwe.mitre.org/data/definitions/1252.html), [1254](https://cwe.mitre.org/data/definitions/1254.html), [1255](https://cwe.mitre.org/data/definitions/1255.html), [1256](https://cwe.mitre.org/data/definitions/1256.html), [1257](https://cwe.mitre.org/data/definitions/1257.html), [1258](https://cwe.mitre.org/data/definitions/1258.html), [1259](https://cwe.mitre.org/data/definitions/1259.html), [1260](https://cwe.mitre.org/data/definitions/1260.html), [1262](https://cwe.mitre.org/data/definitions/1262.html), [1263](https://cwe.mitre.org/data/definitions/1263.html), [1267](https://cwe.mitre.org/data/definitions/1267.html), [1268](https://cwe.mitre.org/data/definitions/1268.html), [1270](https://cwe.mitre.org/data/definitions/1270.html), [1273](https://cwe.mitre.org/data/definitions/1273.html), [1274](https://cwe.mitre.org/data/definitions/1274.html), [1275](https://cwe.mitre.org/data/definitions/1275.html), [1276](https://cwe.mitre.org/data/definitions/1276.html), [1280](https://cwe.mitre.org/data/definitions/1280.html), [1282](https://cwe.mitre.org/data/definitions/1282.html), [1283](https://cwe.mitre.org/data/definitions/1283.html), [1290](https://cwe.mitre.org/data/definitions/1290.html), [1292](https://cwe.mitre.org/data/definitions/1292.html), [1294](https://cwe.mitre.org/data/definitions/1294.html), [1295](https://cwe.mitre.org/data/definitions/1295.html), [1296](https://cwe.mitre.org/data/definitions/1296.html), [1297](https://cwe.mitre.org/data/definitions/1297.html), [1299](https://cwe.mitre.org/data/definitions/1299.html), [1300](https://cwe.mitre.org/data/definitions/1300.html), [1302](https://cwe.mitre.org/data/definitions/1302.html), [1303](https://cwe.mitre.org/data/definitions/1303.html), [1304](https://cwe.mitre.org/data/definitions/1304.html), [1311](https://cwe.mitre.org/data/definitions/1311.html), [1312](https://cwe.mitre.org/data/definitions/1312.html), [1313](https://cwe.mitre.org/data/definitions/1313.html), [1314](https://cwe.mitre.org/data/definitions/1314.html), [1315](https://cwe.mitre.org/data/definitions/1315.html), [1316](https://cwe.mitre.org/data/definitions/1316.html), [1317](https://cwe.mitre.org/data/definitions/1317.html), [1320](https://cwe.mitre.org/data/definitions/1320.html), [1321](https://cwe.mitre.org/data/definitions/1321.html), [1323](https://cwe.mitre.org/data/definitions/1323.html), [1324](https://cwe.mitre.org/data/definitions/1324.html), [1327](https://cwe.mitre.org/data/definitions/1327.html), [1328](https://cwe.mitre.org/data/definitions/1328.html), [1334](https://cwe.mitre.org/data/definitions/1334.html), [1336](https://cwe.mitre.org/data/definitions/1336.html)|
| A2: [Cryptographic Failures](https://owasp.org/Top10/A02_2021-Cryptographic_Failures) | [5](https://cwe.mitre.org/data/definitions/5.html), [6](https://cwe.mitre.org/data/definitions/6.html), [259](https://cwe.mitre.org/data/definitions/259.html), [261](https://cwe.mitre.org/data/definitions/261.html), [296](https://cwe.mitre.org/data/definitions/296.html), [310](https://cwe.mitre.org/data/definitions/310.html), [319](https://cwe.mitre.org/data/definitions/319.html), [321](https://cwe.mitre.org/data/definitions/321.html), [322](https://cwe.mitre.org/data/definitions/322.html), [323](https://cwe.mitre.org/data/definitions/323.html), [324](https://cwe.mitre.org/data/definitions/324.html), [325](https://cwe.mitre.org/data/definitions/325.html), [326](https://cwe.mitre.org/data/definitions/326.html), [327](https://cwe.mitre.org/data/definitions/327.html), [328](https://cwe.mitre.org/data/definitions/328.html), [329](https://cwe.mitre.org/data/definitions/329.html), [330](https://cwe.mitre.org/data/definitions/330.html), [331](https://cwe.mitre.org/data/definitions/331.html), [332](https://cwe.mitre.org/data/definitions/332.html), [333](https://cwe.mitre.org/data/definitions/333.html), [334](https://cwe.mitre.org/data/definitions/334.html), [335](https://cwe.mitre.org/data/definitions/335.html), [336](https://cwe.mitre.org/data/definitions/336.html), [337](https://cwe.mitre.org/data/definitions/337.html), [338](https://cwe.mitre.org/data/definitions/338.html), [339](https://cwe.mitre.org/data/definitions/339.html), [340](https://cwe.mitre.org/data/definitions/340.html), [341](https://cwe.mitre.org/data/definitions/341.html), [342](https://cwe.mitre.org/data/definitions/342.html), [343](https://cwe.mitre.org/data/definitions/343.html), [344](https://cwe.mitre.org/data/definitions/344.html), [347](https://cwe.mitre.org/data/definitions/347.html), [523](https://cwe.mitre.org/data/definitions/523.html), [587](https://cwe.mitre.org/data/definitions/587.html), [720](https://cwe.mitre.org/data/definitions/720.html), [757](https://cwe.mitre.org/data/definitions/757.html), [759](https://cwe.mitre.org/data/definitions/759.html), [760](https://cwe.mitre.org/data/definitions/760.html), [780](https://cwe.mitre.org/data/definitions/780.html), [798](https://cwe.mitre.org/data/definitions/798.html), [804](https://cwe.mitre.org/data/definitions/804.html), [818](https://cwe.mitre.org/data/definitions/818.html), [916](https://cwe.mitre.org/data/definitions/916.html), [1204](https://cwe.mitre.org/data/definitions/1204.html), [1240](https://cwe.mitre.org/data/definitions/1240.html), [1241](https://cwe.mitre.org/data/definitions/1241.html)|
| A3: [Injection](https://owasp.org/Top10/A03_2021-Injection) | [15](https://cwe.mitre.org/data/definitions/15.html), [20](https://cwe.mitre.org/data/definitions/20.html), [37](https://cwe.mitre.org/data/definitions/37.html), [42](https://cwe.mitre.org/data/definitions/42.html), [43](https://cwe.mitre.org/data/definitions/43.html), [45](https://cwe.mitre.org/data/definitions/45.html), [46](https://cwe.mitre.org/data/definitions/46.html), [49](https://cwe.mitre.org/data/definitions/49.html), [50](https://cwe.mitre.org/data/definitions/50.html), [52](https://cwe.mitre.org/data/definitions/52.html), [53](https://cwe.mitre.org/data/definitions/53.html), [54](https://cwe.mitre.org/data/definitions/54.html), [56](https://cwe.mitre.org/data/definitions/56.html), [73](https://cwe.mitre.org/data/definitions/73.html), [74](https://cwe.mitre.org/data/definitions/74.html), [75](https://cwe.mitre.org/data/definitions/75.html), [76](https://cwe.mitre.org/data/definitions/76.html), [77](https://cwe.mitre.org/data/definitions/77.html), [78](https://cwe.mitre.org/data/definitions/78.html), [79](https://cwe.mitre.org/data/definitions/79.html), [80](https://cwe.mitre.org/data/definitions/80.html), [81](https://cwe.mitre.org/data/definitions/81.html), [82](https://cwe.mitre.org/data/definitions/82.html), [83](https://cwe.mitre.org/data/definitions/83.html), [84](https://cwe.mitre.org/data/definitions/84.html), [85](https://cwe.mitre.org/data/definitions/85.html), [86](https://cwe.mitre.org/data/definitions/86.html), [87](https://cwe.mitre.org/data/definitions/87.html), [88](https://cwe.mitre.org/data/definitions/88.html), [89](https://cwe.mitre.org/data/definitions/89.html), [90](https://cwe.mitre.org/data/definitions/90.html), [91](https://cwe.mitre.org/data/definitions/91.html), [93](https://cwe.mitre.org/data/definitions/93.html), [94](https://cwe.mitre.org/data/definitions/94.html), [95](https://cwe.mitre.org/data/definitions/95.html), [96](https://cwe.mitre.org/data/definitions/96.html), [97](https://cwe.mitre.org/data/definitions/97.html), [98](https://cwe.mitre.org/data/definitions/98.html), [99](https://cwe.mitre.org/data/definitions/99.html), [100](https://cwe.mitre.org/data/definitions/100.html), [102](https://cwe.mitre.org/data/definitions/102.html), [103](https://cwe.mitre.org/data/definitions/103.html), [104](https://cwe.mitre.org/data/definitions/104.html), [105](https://cwe.mitre.org/data/definitions/105.html), [106](https://cwe.mitre.org/data/definitions/106.html), [107](https://cwe.mitre.org/data/definitions/107.html), [108](https://cwe.mitre.org/data/definitions/108.html), [109](https://cwe.mitre.org/data/definitions/109.html), [110](https://cwe.mitre.org/data/definitions/110.html), [111](https://cwe.mitre.org/data/definitions/111.html), [112](https://cwe.mitre.org/data/definitions/112.html), [113](https://cwe.mitre.org/data/definitions/113.html), [114](https://cwe.mitre.org/data/definitions/114.html), [116](https://cwe.mitre.org/data/definitions/116.html), [117](https://cwe.mitre.org/data/definitions/117.html), [119](https://cwe.mitre.org/data/definitions/119.html), [120](https://cwe.mitre.org/data/definitions/120.html), [121](https://cwe.mitre.org/data/definitions/121.html), [122](https://cwe.mitre.org/data/definitions/122.html), [123](https://cwe.mitre.org/data/definitions/123.html), [124](https://cwe.mitre.org/data/definitions/124.html), [125](https://cwe.mitre.org/data/definitions/125.html), [126](https://cwe.mitre.org/data/definitions/126.html), [127](https://cwe.mitre.org/data/definitions/127.html), [129](https://cwe.mitre.org/data/definitions/129.html), [130](https://cwe.mitre.org/data/definitions/130.html), [134](https://cwe.mitre.org/data/definitions/134.html), [138](https://cwe.mitre.org/data/definitions/138.html), [140](https://cwe.mitre.org/data/definitions/140.html), [141](https://cwe.mitre.org/data/definitions/141.html), [142](https://cwe.mitre.org/data/definitions/142.html), [143](https://cwe.mitre.org/data/definitions/143.html), [144](https://cwe.mitre.org/data/definitions/144.html), [145](https://cwe.mitre.org/data/definitions/145.html), [146](https://cwe.mitre.org/data/definitions/146.html), [147](https://cwe.mitre.org/data/definitions/147.html), [148](https://cwe.mitre.org/data/definitions/148.html), [149](https://cwe.mitre.org/data/definitions/149.html), [150](https://cwe.mitre.org/data/definitions/150.html), [151](https://cwe.mitre.org/data/definitions/151.html), [152](https://cwe.mitre.org/data/definitions/152.html), [153](https://cwe.mitre.org/data/definitions/153.html), [154](https://cwe.mitre.org/data/definitions/154.html), [155](https://cwe.mitre.org/data/definitions/155.html), [156](https://cwe.mitre.org/data/definitions/156.html), [157](https://cwe.mitre.org/data/definitions/157.html), [158](https://cwe.mitre.org/data/definitions/158.html), [159](https://cwe.mitre.org/data/definitions/159.html), [160](https://cwe.mitre.org/data/definitions/160.html), [161](https://cwe.mitre.org/data/definitions/161.html), [162](https://cwe.mitre.org/data/definitions/162.html), [163](https://cwe.mitre.org/data/definitions/163.html), [164](https://cwe.mitre.org/data/definitions/164.html), [165](https://cwe.mitre.org/data/definitions/165.html), [166](https://cwe.mitre.org/data/definitions/166.html), [167](https://cwe.mitre.org/data/definitions/167.html), [168](https://cwe.mitre.org/data/definitions/168.html), [170](https://cwe.mitre.org/data/definitions/170.html), [179](https://cwe.mitre.org/data/definitions/179.html), [180](https://cwe.mitre.org/data/definitions/180.html), [181](https://cwe.mitre.org/data/definitions/181.html), [184](https://cwe.mitre.org/data/definitions/184.html), [190](https://cwe.mitre.org/data/definitions/190.html), [291](https://cwe.mitre.org/data/definitions/291.html), [384](https://cwe.mitre.org/data/definitions/384.html), [415](https://cwe.mitre.org/data/definitions/415.html), [416](https://cwe.mitre.org/data/definitions/416.html), [441](https://cwe.mitre.org/data/definitions/441.html), [462](https://cwe.mitre.org/data/definitions/462.html), [464](https://cwe.mitre.org/data/definitions/464.html), [466](https://cwe.mitre.org/data/definitions/466.html), [470](https://cwe.mitre.org/data/definitions/470.html), [471](https://cwe.mitre.org/data/definitions/471.html), [472](https://cwe.mitre.org/data/definitions/472.html), [473](https://cwe.mitre.org/data/definitions/473.html), [554](https://cwe.mitre.org/data/definitions/554.html), [564](https://cwe.mitre.org/data/definitions/564.html), [601](https://cwe.mitre.org/data/definitions/601.html), [606](https://cwe.mitre.org/data/definitions/606.html), [607](https://cwe.mitre.org/data/definitions/607.html), [610](https://cwe.mitre.org/data/definitions/610.html), [611](https://cwe.mitre.org/data/definitions/611.html), [621](https://cwe.mitre.org/data/definitions/621.html), [622](https://cwe.mitre.org/data/definitions/622.html), [624](https://cwe.mitre.org/data/definitions/624.html), [626](https://cwe.mitre.org/data/definitions/626.html), [627](https://cwe.mitre.org/data/definitions/627.html), [641](https://cwe.mitre.org/data/definitions/641.html), [643](https://cwe.mitre.org/data/definitions/643.html), [644](https://cwe.mitre.org/data/definitions/644.html), [652](https://cwe.mitre.org/data/definitions/652.html), [680](https://cwe.mitre.org/data/definitions/680.html), [692](https://cwe.mitre.org/data/definitions/692.html), [694](https://cwe.mitre.org/data/definitions/694.html), [781](https://cwe.mitre.org/data/definitions/781.html), [785](https://cwe.mitre.org/data/definitions/785.html), [786](https://cwe.mitre.org/data/definitions/786.html), [787](https://cwe.mitre.org/data/definitions/787.html), [788](https://cwe.mitre.org/data/definitions/788.html), [789](https://cwe.mitre.org/data/definitions/789.html), [790](https://cwe.mitre.org/data/definitions/790.html), [791](https://cwe.mitre.org/data/definitions/791.html), [792](https://cwe.mitre.org/data/definitions/792.html), [793](https://cwe.mitre.org/data/definitions/793.html), [794](https://cwe.mitre.org/data/definitions/794.html), [795](https://cwe.mitre.org/data/definitions/795.html), [796](https://cwe.mitre.org/data/definitions/796.html), [797](https://cwe.mitre.org/data/definitions/797.html), [805](https://cwe.mitre.org/data/definitions/805.html), [806](https://cwe.mitre.org/data/definitions/806.html), [822](https://cwe.mitre.org/data/definitions/822.html), [823](https://cwe.mitre.org/data/definitions/823.html), [824](https://cwe.mitre.org/data/definitions/824.html), [825](https://cwe.mitre.org/data/definitions/825.html), [838](https://cwe.mitre.org/data/definitions/838.html), [914](https://cwe.mitre.org/data/definitions/914.html), [917](https://cwe.mitre.org/data/definitions/917.html), [918](https://cwe.mitre.org/data/definitions/918.html), [943](https://cwe.mitre.org/data/definitions/943.html), [1021](https://cwe.mitre.org/data/definitions/1021.html), [1173](https://cwe.mitre.org/data/definitions/1173.html), [1174](https://cwe.mitre.org/data/definitions/1174.html), [1236](https://cwe.mitre.org/data/definitions/1236.html), [1284](https://cwe.mitre.org/data/definitions/1284.html), [1285](https://cwe.mitre.org/data/definitions/1285.html), [1286](https://cwe.mitre.org/data/definitions/1286.html), [1287](https://cwe.mitre.org/data/definitions/1287.html), [1288](https://cwe.mitre.org/data/definitions/1288.html), [1289](https://cwe.mitre.org/data/definitions/1289.html), [1336](https://cwe.mitre.org/data/definitions/1336.html)|
| A4: [Insecure Design](https://owasp.org/Top10/A04_2021-Insecure_Design) | [5](https://cwe.mitre.org/data/definitions/5.html), [9](https://cwe.mitre.org/data/definitions/9.html), [13](https://cwe.mitre.org/data/definitions/13.html), [15](https://cwe.mitre.org/data/definitions/15.html), [73](https://cwe.mitre.org/data/definitions/73.html), [102](https://cwe.mitre.org/data/definitions/102.html), [105](https://cwe.mitre.org/data/definitions/105.html), [106](https://cwe.mitre.org/data/definitions/106.html), [108](https://cwe.mitre.org/data/definitions/108.html), [109](https://cwe.mitre.org/data/definitions/109.html), [114](https://cwe.mitre.org/data/definitions/114.html), [183](https://cwe.mitre.org/data/definitions/183.html), [209](https://cwe.mitre.org/data/definitions/209.html), [210](https://cwe.mitre.org/data/definitions/210.html), [211](https://cwe.mitre.org/data/definitions/211.html), [213](https://cwe.mitre.org/data/definitions/213.html), [235](https://cwe.mitre.org/data/definitions/235.html), [250](https://cwe.mitre.org/data/definitions/250.html), [256](https://cwe.mitre.org/data/definitions/256.html), [257](https://cwe.mitre.org/data/definitions/257.html), [258](https://cwe.mitre.org/data/definitions/258.html), [259](https://cwe.mitre.org/data/definitions/259.html), [260](https://cwe.mitre.org/data/definitions/260.html), [266](https://cwe.mitre.org/data/definitions/266.html), [267](https://cwe.mitre.org/data/definitions/267.html), [268](https://cwe.mitre.org/data/definitions/268.html), [269](https://cwe.mitre.org/data/definitions/269.html), [270](https://cwe.mitre.org/data/definitions/270.html), [271](https://cwe.mitre.org/data/definitions/271.html), [272](https://cwe.mitre.org/data/definitions/272.html), [273](https://cwe.mitre.org/data/definitions/273.html), [274](https://cwe.mitre.org/data/definitions/274.html), [280](https://cwe.mitre.org/data/definitions/280.html), [302](https://cwe.mitre.org/data/definitions/302.html), [307](https://cwe.mitre.org/data/definitions/307.html), [308](https://cwe.mitre.org/data/definitions/308.html), [309](https://cwe.mitre.org/data/definitions/309.html), [311](https://cwe.mitre.org/data/definitions/311.html), [312](https://cwe.mitre.org/data/definitions/312.html), [313](https://cwe.mitre.org/data/definitions/313.html), [314](https://cwe.mitre.org/data/definitions/314.html), [315](https://cwe.mitre.org/data/definitions/315.html), [316](https://cwe.mitre.org/data/definitions/316.html), [317](https://cwe.mitre.org/data/definitions/317.html), [318](https://cwe.mitre.org/data/definitions/318.html), [319](https://cwe.mitre.org/data/definitions/319.html), [321](https://cwe.mitre.org/data/definitions/321.html), [350](https://cwe.mitre.org/data/definitions/350.html), [419](https://cwe.mitre.org/data/definitions/419.html), [424](https://cwe.mitre.org/data/definitions/424.html), [425](https://cwe.mitre.org/data/definitions/425.html), [426](https://cwe.mitre.org/data/definitions/426.html), [430](https://cwe.mitre.org/data/definitions/430.html), [434](https://cwe.mitre.org/data/definitions/434.html), [444](https://cwe.mitre.org/data/definitions/444.html), [447](https://cwe.mitre.org/data/definitions/447.html), [451](https://cwe.mitre.org/data/definitions/451.html), [455](https://cwe.mitre.org/data/definitions/455.html), [472](https://cwe.mitre.org/data/definitions/472.html), [501](https://cwe.mitre.org/data/definitions/501.html), [520](https://cwe.mitre.org/data/definitions/520.html), [522](https://cwe.mitre.org/data/definitions/522.html), [523](https://cwe.mitre.org/data/definitions/523.html), [525](https://cwe.mitre.org/data/definitions/525.html), [535](https://cwe.mitre.org/data/definitions/535.html), [536](https://cwe.mitre.org/data/definitions/536.html), [537](https://cwe.mitre.org/data/definitions/537.html), [539](https://cwe.mitre.org/data/definitions/539.html), [549](https://cwe.mitre.org/data/definitions/549.html), [550](https://cwe.mitre.org/data/definitions/550.html), [554](https://cwe.mitre.org/data/definitions/554.html), [555](https://cwe.mitre.org/data/definitions/555.html), [556](https://cwe.mitre.org/data/definitions/556.html), [565](https://cwe.mitre.org/data/definitions/565.html), [579](https://cwe.mitre.org/data/definitions/579.html), [598](https://cwe.mitre.org/data/definitions/598.html), [602](https://cwe.mitre.org/data/definitions/602.html), [603](https://cwe.mitre.org/data/definitions/603.html), [614](https://cwe.mitre.org/data/definitions/614.html), [623](https://cwe.mitre.org/data/definitions/623.html), [636](https://cwe.mitre.org/data/definitions/636.html), [637](https://cwe.mitre.org/data/definitions/637.html), [638](https://cwe.mitre.org/data/definitions/638.html), [642](https://cwe.mitre.org/data/definitions/642.html), [646](https://cwe.mitre.org/data/definitions/646.html), [648](https://cwe.mitre.org/data/definitions/648.html), [650](https://cwe.mitre.org/data/definitions/650.html), [653](https://cwe.mitre.org/data/definitions/653.html), [654](https://cwe.mitre.org/data/definitions/654.html), [655](https://cwe.mitre.org/data/definitions/655.html), [656](https://cwe.mitre.org/data/definitions/656.html), [657](https://cwe.mitre.org/data/definitions/657.html), [671](https://cwe.mitre.org/data/definitions/671.html), [784](https://cwe.mitre.org/data/definitions/784.html), [798](https://cwe.mitre.org/data/definitions/798.html), [799](https://cwe.mitre.org/data/definitions/799.html), [807](https://cwe.mitre.org/data/definitions/807.html), [837](https://cwe.mitre.org/data/definitions/837.html), [840](https://cwe.mitre.org/data/definitions/840.html), [841](https://cwe.mitre.org/data/definitions/841.html), [927](https://cwe.mitre.org/data/definitions/927.html), [942](https://cwe.mitre.org/data/definitions/942.html), [1007](https://cwe.mitre.org/data/definitions/1007.html), [1021](https://cwe.mitre.org/data/definitions/1021.html), [1022](https://cwe.mitre.org/data/definitions/1022.html), [1173](https://cwe.mitre.org/data/definitions/1173.html), [1174](https://cwe.mitre.org/data/definitions/1174.html), [1192](https://cwe.mitre.org/data/definitions/1192.html), [1331](https://cwe.mitre.org/data/definitions/1331.html)|
| A5: [Security Misconfiguration](https://owasp.org/Top10/A05_2021-Security_Misconfiguration) | [2](https://cwe.mitre.org/data/definitions/2.html), [7](https://cwe.mitre.org/data/definitions/7.html), [11](https://cwe.mitre.org/data/definitions/11.html), [12](https://cwe.mitre.org/data/definitions/12.html), [13](https://cwe.mitre.org/data/definitions/13.html), [15](https://cwe.mitre.org/data/definitions/15.html), [16](https://cwe.mitre.org/data/definitions/16.html), [258](https://cwe.mitre.org/data/definitions/258.html), [260](https://cwe.mitre.org/data/definitions/260.html), [315](https://cwe.mitre.org/data/definitions/315.html), [520](https://cwe.mitre.org/data/definitions/520.html), [526](https://cwe.mitre.org/data/definitions/526.html), [537](https://cwe.mitre.org/data/definitions/537.html), [541](https://cwe.mitre.org/data/definitions/541.html), [547](https://cwe.mitre.org/data/definitions/547.html), [555](https://cwe.mitre.org/data/definitions/555.html), [611](https://cwe.mitre.org/data/definitions/611.html), [614](https://cwe.mitre.org/data/definitions/614.html), [756](https://cwe.mitre.org/data/definitions/756.html), [776](https://cwe.mitre.org/data/definitions/776.html), [942](https://cwe.mitre.org/data/definitions/942.html), [1004](https://cwe.mitre.org/data/definitions/1004.html), [1032](https://cwe.mitre.org/data/definitions/1032.html), [1174](https://cwe.mitre.org/data/definitions/1174.html)|
| A6: [Vulnerable and Outdated Components](https://owasp.org/Top10/A06_2021-Vulnerable_and_Outdated_Components) | [937](https://cwe.mitre.org/data/definitions/937.html), [1035](https://cwe.mitre.org/data/definitions/1035.html), [1104](https://cwe.mitre.org/data/definitions/1104.html)|
| A7: [Identification and Authentication Failures](https://owasp.org/Top10/A07_2021-Identification_and_Authentication_Failures) | [13](https://cwe.mitre.org/data/definitions/13.html), [255](https://cwe.mitre.org/data/definitions/255.html), [256](https://cwe.mitre.org/data/definitions/256.html), [257](https://cwe.mitre.org/data/definitions/257.html), [258](https://cwe.mitre.org/data/definitions/258.html), [259](https://cwe.mitre.org/data/definitions/259.html), [260](https://cwe.mitre.org/data/definitions/260.html), [261](https://cwe.mitre.org/data/definitions/261.html), [262](https://cwe.mitre.org/data/definitions/262.html), [263](https://cwe.mitre.org/data/definitions/263.html), [287](https://cwe.mitre.org/data/definitions/287.html), [288](https://cwe.mitre.org/data/definitions/288.html), [289](https://cwe.mitre.org/data/definitions/289.html), [290](https://cwe.mitre.org/data/definitions/290.html), [291](https://cwe.mitre.org/data/definitions/291.html), [293](https://cwe.mitre.org/data/definitions/293.html), [294](https://cwe.mitre.org/data/definitions/294.html), [295](https://cwe.mitre.org/data/definitions/295.html), [296](https://cwe.mitre.org/data/definitions/296.html), [297](https://cwe.mitre.org/data/definitions/297.html), [298](https://cwe.mitre.org/data/definitions/298.html), [299](https://cwe.mitre.org/data/definitions/299.html), [300](https://cwe.mitre.org/data/definitions/300.html), [301](https://cwe.mitre.org/data/definitions/301.html), [302](https://cwe.mitre.org/data/definitions/302.html), [303](https://cwe.mitre.org/data/definitions/303.html), [304](https://cwe.mitre.org/data/definitions/304.html), [305](https://cwe.mitre.org/data/definitions/305.html), [306](https://cwe.mitre.org/data/definitions/306.html), [307](https://cwe.mitre.org/data/definitions/307.html), [308](https://cwe.mitre.org/data/definitions/308.html), [309](https://cwe.mitre.org/data/definitions/309.html), [321](https://cwe.mitre.org/data/definitions/321.html), [346](https://cwe.mitre.org/data/definitions/346.html), [350](https://cwe.mitre.org/data/definitions/350.html), [370](https://cwe.mitre.org/data/definitions/370.html), [384](https://cwe.mitre.org/data/definitions/384.html), [425](https://cwe.mitre.org/data/definitions/425.html), [521](https://cwe.mitre.org/data/definitions/521.html), [522](https://cwe.mitre.org/data/definitions/522.html), [523](https://cwe.mitre.org/data/definitions/523.html), [549](https://cwe.mitre.org/data/definitions/549.html), [555](https://cwe.mitre.org/data/definitions/555.html), [593](https://cwe.mitre.org/data/definitions/593.html), [599](https://cwe.mitre.org/data/definitions/599.html), [603](https://cwe.mitre.org/data/definitions/603.html), [613](https://cwe.mitre.org/data/definitions/613.html), [620](https://cwe.mitre.org/data/definitions/620.html), [640](https://cwe.mitre.org/data/definitions/640.html), [645](https://cwe.mitre.org/data/definitions/645.html), [798](https://cwe.mitre.org/data/definitions/798.html), [804](https://cwe.mitre.org/data/definitions/804.html), [836](https://cwe.mitre.org/data/definitions/836.html), [940](https://cwe.mitre.org/data/definitions/940.html), [1216](https://cwe.mitre.org/data/definitions/1216.html), [1299](https://cwe.mitre.org/data/definitions/1299.html), [1324](https://cwe.mitre.org/data/definitions/1324.html)|
| A8: [Software and Data Integrity Failures](https://owasp.org/Top10/A08_2021-Software_and_Data_Integrity_Failures) | [98](https://cwe.mitre.org/data/definitions/98.html), [345](https://cwe.mitre.org/data/definitions/345.html), [346](https://cwe.mitre.org/data/definitions/346.html), [347](https://cwe.mitre.org/data/definitions/347.html), [348](https://cwe.mitre.org/data/definitions/348.html), [349](https://cwe.mitre.org/data/definitions/349.html), [351](https://cwe.mitre.org/data/definitions/351.html), [352](https://cwe.mitre.org/data/definitions/352.html), [353](https://cwe.mitre.org/data/definitions/353.html), [354](https://cwe.mitre.org/data/definitions/354.html), [360](https://cwe.mitre.org/data/definitions/360.html), [422](https://cwe.mitre.org/data/definitions/422.html), [426](https://cwe.mitre.org/data/definitions/426.html), [494](https://cwe.mitre.org/data/definitions/494.html), [502](https://cwe.mitre.org/data/definitions/502.html), [565](https://cwe.mitre.org/data/definitions/565.html), [616](https://cwe.mitre.org/data/definitions/616.html), [646](https://cwe.mitre.org/data/definitions/646.html), [649](https://cwe.mitre.org/data/definitions/649.html), [784](https://cwe.mitre.org/data/definitions/784.html), [827](https://cwe.mitre.org/data/definitions/827.html), [829](https://cwe.mitre.org/data/definitions/829.html), [830](https://cwe.mitre.org/data/definitions/830.html), [915](https://cwe.mitre.org/data/definitions/915.html), [924](https://cwe.mitre.org/data/definitions/924.html), [1293](https://cwe.mitre.org/data/definitions/1293.html), [1321](https://cwe.mitre.org/data/definitions/1321.html)|
| A9: [Security Logging and Monitoring Failures](https://owasp.org/Top10/A09_2021-Security_Logging_and_Monitoring_Failures) | [117](https://cwe.mitre.org/data/definitions/117.html), [223](https://cwe.mitre.org/data/definitions/223.html), [532](https://cwe.mitre.org/data/definitions/532.html), [778](https://cwe.mitre.org/data/definitions/778.html)|
| A10: [Server-Side Request Forgery (SSRF)](https://owasp.org/Top10/A10_2021-Server-Side_Request_Forgery_(SSRF)) | [918](https://cwe.mitre.org/data/definitions/918.html)|

Below you can find the OWASP and CWE coverage for different secure products.
All charts that are displayed below are powered by live anonymized
vulnerability data from our security scans. These are vulnerabilities we are
actively identifying in real-world customer usage of our security scanning
tools.

### OWASP Top 10 2021 Coverage

The chart below depicts the CWEs that map to the [OWASP Top 10 2021](https://owasp.org/www-project-top-ten/).
 All of these CWEs are detected by GitLab's [SAST](https://docs.gitlab.com/ee/user/application_security/sast/)/[DAST](https://docs.gitlab.com/ee/user/application_security/dast/)
and [Dependency Scanning](https://docs.gitlab.com/ee/user/application_security/dependency_scanning/) capabilities.

[_Data unavailable in Tableau_](https://gitlab.com/gitlab-data/tableau/-/issues/330)

### CWE Coverage

#### SAST

The table below shows the combined
[Common Weakness Enumerator (CWE)](https://cwe.mitre.org/) findings reported by
[our SAST analyzers](https://docs.gitlab.com/ee/user/application_security/sast/) on
projects hosted on [gitlab.com](https://gitlab.com/)

[_Data unavailable in Tableau_](https://gitlab.com/gitlab-data/tableau/-/issues/330)

Below you can find a list of which CWEs are detected by each analyzer:

{{% details summary="eslint" %}}

{{% /details %}}

{{% details summary="flawfinder" %}}

{{% /details %}}

{{% details summary="gosec" %}}

{{% /details %}}

{{% details summary="nodejs-scan" %}}

{{% /details %}}

{{% details summary="semgrep" %}}

{{% /details %}}

{{% details summary="spotbugs" %}}

{{% /details %}}

#### DAST

The table below shows the combined
[Common Weakness Enumerator (CWE)](https://cwe.mitre.org/) findings reported by
[our DAST analyzers](https://docs.gitlab.com/ee/user/application_security/dast/) on
projects hosted on [gitlab.com](https://gitlab.com/)

[_Data unavailable in Tableau_](https://gitlab.com/gitlab-data/tableau/-/issues/330)

### GitLab Advisory Database for Dependency Scanning

Statistical information about advisories for dependency scanning is available on the [GitLab Landing Page for Dependency Scanning Advisories](https://advisories.gitlab.com/).
