---
title: "Test Platform Dashboards"
description: "This handbook page serves as a central repository for all our Test Platform dashboard details"
---

> In pursuit of a resilient, efficient, and fortified platform, our Test Platform sub-department provides instrumental
> support through the creation and maintenance of an array of dashboards. These critical tools capture detailed test
> health across the environments, flag performance anomalies, and contribute to rigorous test infrastructure.

## Dashboards

| Category                | Link (Internal Only)                                                                                                                                                                                                                                                                                                                                                                                             | Description                                                                         | DRI                                                                                                                |
|-------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------|
| Test Health             | [E2E Test Status](https://dashboards.quality.gitlab.net/d/tR_SmBDVk/main-runs)                                                                                                                                                                                                                                                                                                                                   | Comprehensive overview of test suite health and status.                             | [Test Engineering](test-engineering-team)                                                                          |
|                         | [Quarantined E2E Tests Dashboard](https://10az.online.tableau.com/#/site/gitlab/views/TestPlatformQuarantinedE2ETestsMetrics/TestPlatform-QuarantinedE2ETestsDashboard?:iid=1)                                                                                                                                                                                                                                   | Shows age and number of Quarantined tests per stage                                 | [Test Engineering](test-engineering-team)                                                |
| Test Tooling            | [E2E Test Execution Time](https://10az.online.tableau.com/#/site/gitlab/views/E2ETestRuntimes_17111139395120/E2Etestruntimemetrics/58847ec0-78b4-4d7c-aa30-e1db9fe87e22/aac170e4-8270-4cf7-89b3-4b9a7d32e10d)                                                                                                                                                                                                    | Metrics and trends on end-to-end test execution times.                              | [Test and Tools Infrastructure](test-and-tools-infrastructure-team)                                                |
|                         | [Test Flakiness (E2E Test)](https://dashboards.quality.gitlab.net/d/edgcentzu45q8b/test-stability-by-group?orgId=1&var-run_type=nightly&var-stage=All&var-product_group=All&from=now-14d&to=now)                                                                                                                                                                                                                 | Analysis of flakiness in end-to-end tests with real-time data.                      | [Test and Tools Infrastructure](test-and-tools-infrastructure-team)                                                |
|                         | [Test Flakiness (Unit, Integration & System Test)](https://10az.online.tableau.com/#/site/gitlab/workbooks/2283052/views)                                                                                                                                                                                                                                                                                        | Statistics on flakiness in feature and unit tests.                                  | [Engineering Productivity](../engineering-productivity)                                                            |
|                         | [Test Economy](https://10az.online.tableau.com/#/site/gitlab/views/DRAFTTestEconomyMetrics/TestEconomyMetricsDashboard?:iid=3)                                                                                                                                                                                                                                                                                   | Insights into the cost-effectiveness of testing processes.                          | [Test and Tools Infrastructure](test-and-tools-infrastructure-team)                                                |
|                         | [Test Infra Availability (E2E Test)](https://dashboards.gitlab.net/d/ci-runners-main/ci-runners3a-overview?orgId=1&var-PROMETHEUS_DS=mimir-gitlab-gprd&var-environment=gprd&var-stage=main&var-shard=qa-runners&from=now-24h&to=now&viewPanel=2211350843) | Dashboard indicating the current availability of E2E test infrastructure.           | [Test and Tools Infrastructure](test-and-tools-infrastructure-team)                                                |
| Test Contribution       | [Developer Contribution To E2E Tests](https://10az.online.tableau.com/#/site/gitlab/views/TestPlatformDeveloperContributionDashboard/TestPlatformDeveloperContributionDashboard?:iid=2)                                                                                                                                                                                                                          | Tracking developer engagement and contributions to E2E tests.                       | [Test Engineering](test-engineering-team) <br> [Test and Tools Infrastructure](test-and-tools-infrastructure-team) |
| Performance Testing     | [GPT Results](https://gitlab.com/gitlab-org/quality/performance/-/wikis/home)                                                                                                                                                                                                                                                                                                                                    | GitLab Performance Tool test results from automated reference environment pipelines | [Self-Managed Platform](/handbook/engineering/infrastructure-platforms/developer-experience/performance-enablement)                                                                |
| Self-Managed Excellence | [Reference Architectures](https://10az.online.tableau.com/#/site/gitlab/views/DRAFTSelf-ManagedExcellenceMetrics/ReferenceArchitectures)                                                                                                                                                                                                                                                                         | Reference Architecture issues created and closed per request type                   | [Self-Managed Platform](/handbook/engineering/infrastructure-platforms/developer-experience/performance-enablement)                                                                |
|                         | [GitLab Environment Toolkit](https://10az.online.tableau.com/#/site/gitlab/views/DRAFTSelf-ManagedExcellenceMetrics/GitlabEnvironmentToolkit)                                                                                                                                                                                                                                                                    | GitLab Environment Toolkit merge requests and issues per type                       | [Self-Managed Platform](/handbook/engineering/infrastructure-platforms/developer-experience/performance-enablement)                                                                |
|                         | [GitLab Performance Tool](https://10az.online.tableau.com/#/site/gitlab/views/DRAFTSelf-ManagedExcellenceMetrics/GitlabPerformanceTool)                                                                                                                                                                                                                                                                          | GitLab Performance Tool merge requests and issues per type                          | [Self-Managed Platform](/handbook/engineering/infrastructure-platforms/developer-experience/performance-enablement)                                                                |
| Bug Tracking            | [Customer Bugs](https://10az.online.tableau.com/#/site/gitlab/views/OpenBugAgeOBA/CustomerBugsDashboard?:iid=1)                                                                                                                                                                                                                                                                                                  | Dynamic tracking of Customer bugs                                                   | [Test Engineering](test-engineering-team)                                                                          |
|                         | [Bug Prioritization](https://10az.online.tableau.com/#/site/gitlab/views/OpenBugAgeOBA/BugPrioritizationDashboard?:iid=1)                                                                                                                                                                                                                                                                                        | Bug prioritization based on burndown trends                                         | [Test Engineering](test-engineering-team)                                                                          |
| Operational Excellence| [Team Operational Trends](https://10az.online.tableau.com/t/gitlab/views/TeamProductivityMetricsforTTI/DashboardwithDocumentation/8c6fdf45-8ebb-4858-95a4-df9f9ef94d34/fb1e8aca-b0fb-45af-ad2b-0463ef51b491) | This dashboard is designed to give us a deeper understanding of Test Platform sub-department's operational effectiveness over time | [Test and Tools Infrastructure](test-and-tools-infrastructure-team) |
| Test Platform On-Call Metrics | [On-call Trends](https://10az.online.tableau.com/t/gitlab/views/TestPlatformTeamOn-CallSETEngagements/TestPlatformOn-CallMetricsDashboard) | Dashboard indicating on-call engagement | [Test and Tools Infrastructure](test-and-tools-infrastructure-team) |

## Contributing to the Dashboards

If you have any questions or suggestions about the dashboard, please contact the respective DRI or submit an issue in
our [tracking system](https://gitlab.com/gitlab-org/quality/quality-engineering/team-tasks/-/issues/new).
