---
title: "Buyer Personas"
---

### Buyer personas

Buyer personas represent the people who serve as the main buyers in an organization or
the champions within an enterprise that drive the buying conversation and
coordinate various teams to make a purchase. We've updated our approach to include persona groups, in addition to specific roles or titles within a group, based on the Jobs To Be Done (JTBD) framework.

![IT Orgchart](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/images/buyerpersonaorgchart-2022-09-29.png)

1. [CIO](#tech-exec-tristan)
1. [App Dev](#app-dev-avery)
1. [Security](#infosec-shiloh)
1. [Platform](#platform-perry)
1. [Compliance](#compliance-cooper)
1. [Release](#release-rory)
1. [PMO](#program-management-payton)
1. [Back Office](#back-office-blake)

Also see [the three tiers on our pricing page](/handbook/company/pricing/#three-tiers).

#### Enterprise IT roles we sell to

While personas describe ideal targets, roles are the real people in job titles you will encounter while selling. Understanding the challenges faced by each role, along with what they care most about, is helpful to deliver the right value proposition to the right person. It will help you know:

1. if they are even someone who may have an interest in GitLab (don't waste time),
1. what questions to ask to learn more and qualify the lead,
1. what value prop they'll want to hear that could get them to a demo, discussion, or POC.

See the [Enterprise IT Roles page](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/enterprise-it-roles/) for more details about who we sell to and how to approach them.

#### Writing for all personas

- When writing content, always remember to use the [GitLab voice](https://design.gitlab.com/brand/overview/#tone-of-voice) regardless of the persona.
- Never alienate other personas. You can appeal to a buyer without buzzword bingo.
- Look at who uses a channel most (twitter & docs: user, webinar linkedin: buyer) when shared (website) guide them /features for users /solutions for buyers.

#### Overall recommendations

- Develop content and build 'persona-lized' buyer's journeys for more efficient targeting
- Rethink messaging to leverage most effective drivers by persona
- Consider alternative content sites (Reddit, Quora, Medium) to target specific personas
- Help champions sell their ideas internally with the resources they say they need (ROI / case studies / real world benefits / hard data / Proof of Concepts)
- Explore opportunities to provide tech education / 'mentoring' to personas with less than 10 years experience (due to lack of mid-level personnel peers / mentors and 16+ years set aging out)
- Note: Although IC developers are no longer driving our growth KPIs, they ARE heavy influencers on buyers—their product adoption and evangelism is critical to expansion and renewals

#### Comparing the personas

![Motivations and challenges for each buyer persona.](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/images/comparison-buyer-persona-motivations-challenges-v3.png)

![How buyer personas collect technical information.](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/images/comparison-how-they-gather-tech-info.png)

---

### Tech Exec Tristan

![techexectristan](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/images/techexectristan.png)

- **Job To Be Done:**

  - Lead the technology vision, strategy, innovation, and execution for the organization

- **Summary:**

  - I'm really motivated by leading organizational change
  - I'm an Influencer and Initiator/Identifier of need for tech purchases but I am very often the decision-maker
  - My biggest challenges are siloed teams and workflows along with the need to increase the speed of development as well as  scaling efficiencies and new ways of working across multiple projects and environments
  - Key messaging concepts to include in the buyer's journey: budget, cost, ROI, cost analysis, value, etc.

- **My Messaging:**

  - Create secure code faster with continuous improvment through accelerated feedback loops
  - Do more with less with built-in support automation and integrations with 3rd-party sevices
  - Enforce compliance, have visibility, and better prepare for audits
  - Have visibility across your entire SDLC and Supply Chain

- **Potential Titles:**

  - CIO/ CTO / CINO / CDO / Founder / Owner / VP

- **Reports to:**

  - CEO / Board

- **Job Responsibilities:**

  - Develop goals and strategies to ensure the IT department runs smoothly and effectively
  - Direct and establish IT-related projects
  - Monitor technology sector changes to discover ways the company can improve and develop
  - Supervise company networks and computer systems to ensure optimal performance
  - Plan and direct implementation of new IT systems

- **Job is Measured by:**

  - Results / Speed (time to market)

- **Goals & Objectives:**

  - Helping IT to play a more strategic role in achieving business objectives (tied to Digital Transformation)

- **Motivated by:**

  - Contributing to solving real problems
  - Leading organizational change
  - Having autonomy / independence
  - Empowering teams without sacrificing security & quality

- **Biggest Challenges:**

  - Siloed teams and workflows
  - The need to increase the speed of development
  - Scaling efficiencies and new ways of working across multiple projects and environments
  - Slow digital transformation initiatives
  - Current processes that do not scale
  - Hiring and training staff with relevant skill sets (skills gap)
  - Retention of people who do not want to work on uninteresting platforms
  - High cost of downtime

- **Sources for Tech Purchasing Decisions:**
  - Primary: Events & Meetups / Conference presos / Case studies / Webinars
  - Secondary: Announcements & Press releases / Websites / Blog posts / Email updates & Newsletters / Whitepapers
  - Tertiary: Podcasts
  - Internal Influencers: Data Consultants / Marketing / C-Suite / Engineering Team / Tech Leads / Developers / Peer Tech Execs

- **Purchasing Roles:**

1. Influencer
1. Decision-maker (relies on users/influencers for renewal decisions)
1. Initiator/Identifier of need
1. User

- **Recommended Buyer's Journey**

  - Awareness: CIO Round Table, Conference Presos, Case studies
  - Considerations: Blog posts, white papers, cusotm website landing page
  - Decision: topical campaigin email with CTA, Podcasts, Press releases/announcements

---

### App Dev Avery

![appdevavery](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/images/appdevavery.png)

- **Job To Be Done:**

  - Drive application and product development activities

- **Summary:**

  - I want to choose the technology/tools I use to do my work
  - I'm mostly an Influencer and Researcher for tech purchases (but sometimes I am the Initiator/Identifier of a need)
  - My biggest challenges are increasing the speed of development and dealing with team silos and workflows while constantly switching between multiple point solutions
  - Key messaging concept: Highlight the developer experience gap vs the integrated One DevSecOps platform as a value proposition

- **My Messaging:**

  - Spend more time coding and less time context switching
  - Receive feedback from security and other teams in the same tool you use for development
  - Get real-time feedback with automated CI tools
  - Easy collaboration for quicker resolution and deployment

- **Potential Titles:**

  - Application Development Executive (VP, etc) / Application Development Director / Application Development Manager / Product Development / Application Developer / Software Developer / Software Engineer

- **Reports to:**

  - Director or VP App Development

- **Job Responsibilities:**

  - Drive application and product development activities
  - Lead a team of full-stack developers
  - Manage the iteration cycle, ensure capacity, and participate in both high-level and detailed design for new product capabilities and improvements
  - Collaborate with architects and developers on specifications, designs, standards, code reviews, and test capabilities
  - Scale efficiencies and new ways of working across multiple projects and environments
  - Establish practices, processes, and platforms, working horizontally across Digital to govern and operationalize new technologies to enable their broad adoption

- **Job is Measured by:**

  - Productivity / Speed

- **Goals & Objectives:**

  - Drive standardization of the production environment
  - Reduce complexity
  - Optimize management of applications
  - Introduce innovative technologies that provide new business capabilities to reduce the technology total cost of ownership and create a competitive advantage

- **Motivated by:**

  - Contributing to solving real problems
  - Career growth/learning (and the ability to fail/learn in a safe environment)
  - Choosing the technology/tools I use to do my work

- **Biggest Challenges:**

  - The need to increase speed of development
  - Siloed teams and workflows
  - Transition to DevOps is challenging for certain legacy workloads and environments
  - Context switching between point solutions

- **Sources for Tech Purchasing Decisions:**

  - Primary: Analyst reports / Conference presos / Tech videos & demos / Webinars / eBooks
  - Secondary: Video stories from similar orgs / Events & Meetups (Developer Relations outreach) / Podcasts / Infographics / Websites
  - Tertiary: Social Media / Emails & Newsletters
  - Internal Influencers: Senior team members / Architects and Developer Advocates / Execs in Engineering and PLM Orgs / CTO / Head of DevOps /

- **Purchasing Role:**

1. Influencer
1. Likely an Initiator / Identifier of Need and Researcher
1. Probably a Researcher
1. Decision-Maker for renewals (but not likely for first order)

- **Buyers Journey:**

  - Awareness: Tech demos, Developer Relations Outreach, Analyst Reports, Webinar
  - Consideration: Customer video testimonials, Local Meetups, Podcast
  - Decision: LinkedIn/twitter, Reddit Threads, Topical email campaigns

---

### InfoSec Shiloh

![infosecshiloh](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/images/infosecshiloh.png)

- **Job To Be Done:**

  - Secure and protect the organization against cyber risks

- **Summary:**

  - Protecting my organization from a constant barrage of global attacks from bad actors drives my work. (And on a personal level, career growth/learning--and the ability to fail/learn in a safe environment--is my biggest motivator)
  - I'm an Influencer and Researcher for tech purchases but I am very often the decision-maker
  - My biggest challenges are dealing with team silos and workflows and the lack of a strong security culture with the risk that entails

- **My Messaging:**

  - GitLab offers one of the broadest breadths of security tools in the industry
  - GitLab helps create a secure DevSecOps framework for the entire organization
  - By enabling Dev to find some security issues, GitLab enables InfoSec to focus on higher priorities
  - GitLab helps organizations extract more value from existing security tools

- **Potential Titles:**

  - CISO / Deputy CISO / Director or VP CyberSecurity / Cloud Security Architect / Information Security Operations Manager / IT Security Manager / Sr. Manager, DevSecOps / Softare Security Engineer / Security Consultant / Information Security Analyst

- **Reports to:**

  - CTO, CIO, CISO, or SVP of Engineering

- **Job Responsibilities:**

  - Drive application and product development activities
  - Monitor ongoing operations and actively hunt for and detect adversaries
  - Build and maintain a security-aware culture
  - Drive adoption and optimization of cyber tool sets for a streamlined user experience – implement appropriate controls while identifying opportunity for automation across the stack
  - Support migration to the public cloud, partnering with technology to implement modern security standards, specifically related to app development and delivery

- **Job is Measured by:**

  - Number of Incidents / Time to Respond & Mitigate

- **Goals & Objectives:**

  - Create and own a confidence-inspiring long-term security vision and strategy
  - Minimize the impact of cyber events and return the organization to normal status quickly

- **Motivated by:**

  - The need to constantly battle attacks by global bad actors
  - Career growth/learning (and the ability to fail/learn in a safe environment)
  - Contributing to solving real problems
  - Leading organizational change

- **Biggest Challenges:**

  - Silo'd teams and workflows
  - Lack of a strong security culture and the risk that entails
  - The disjointed developer experience
  - Tool and process sprawl
  - Securing the software supply chain
  - Continuing skills shortage
  - Lack of security culture prioritization (poor password hygiene leading to credential stuffing)
  - Securing the hybrid workforce with zero-trust

- **Content Sources for Tech Purchasing Decisions:**

  - Primary: Analyst reports / Conference presos / Research reports / Technical videos & demos / Webinars
  - Secondary: Blog posts / eBooks / Video stories from similar organizations / Infographics / Social Media /
  - Tertiary: Podcasts
  - Internal Influencers: C-Suite / Network Administrator / Directors, VPs and senior engineers & analysts / Evaluators / security management teams / CISO / IT SME / User Testing

- **Purchasing Role:**

1. Influencer
1. Researcher
1. Often a Decision-Maker

- **Buyer's Journey:**

  - Awareness:  Tech demo video series, Analyst Reports, Conference Presentations
  - Consideration:  Blog posts, Customer Video Testimonials, Security infographic
  - Decision: LinkedIn/Twitter, Reddit, Podcast

---

### Platform Perry

![platformperry](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/images/platformperry.png)

- **Job To Be Done:**

  - Drive digital transformation, cloud migration / IT modernization, and DevSecOps transformation efforts

- **Summary:**

  - Having autonomy and independence is my biggest motivator
  - While I'm an Influencer, Researcher, and Initiator, I am a strong Decision-Maker — my purchases lead ARR and First Orders for GitLab
  - My biggest challenges are transitioning to DevSecOps due to legacy workloads and environments, siloed teams and workflows, and
scaling efficiencies and new ways of working across multiple projects and environments

- **My Messaging:**

  - GitLab supports your multi-cloud strategy by allowing you to deploy anywhere with no cloud vendor lock-in
  - Implement guardrails to control access to cloud envirionments and incrementally deploy your appliations to the cloud
  - Increase deployment velocity with auomation and CI/CD
  - A single platform improves communications with Dev, Sec, and other departments

- **Potential Titles:**

  - Architect/Manager/Director/VP of: Infrastructure Engineering, Platform, Engineering, Software Operations, IT Operations, CloudOps, Architecture, Systems

- **Reports to:**

  - CIO or VP, Platform / Infrastructure

- **Job Responsibilities:**

  - Drive digital transformation, cloud migration/ IT moderniation, and DevSecOps transformation efforts
  - Design and coordinate implementation of automated solutions to replace or enhance manual processes
  - Collect requirements, researches, and analyzes alternatives, and make recommendations for IT infrastructure solutions
  - Ensure that new IT infrastructure solutions are designed and deployed to meet functional, security and technical requirements

- **Job is Measured by:**

  - Efficiency / Speed

- **Goals & Objectives:**

  - Break down artificial barriers between development and operations teams
  - Improve development velocity via highly integrated, more versatile teams
  - Shift responsibilities like security left, earlier into the development process
  - Automate pipelines from inception to production
  - Ensure platform stability
  - Create "golden paths" to make developer teams productive while maintaining standards--sees need for "guardrails"
  - Support development teams, make them productive and happy
  - Enable Progressive Delivery and modern CI/CD patterns
  - Achieve built in platform security
  - Define and manage Service Level Objectives

- **Motivated by:**

  - Contributing to solving real problems
  - Career growth/learning (and the ability to fail/learn in a safe environment)
  - Having autonomy/independence

- **Biggest Challenges:**

  - Transition to DevOps is challenging for certain legacy workloads and environments
  - Silo'd teams and workflows
  - Scaling efficiencies and new ways of working across multiple projects and environments

- **Content Sources for Tech Purchasing Decisions:**

  - Primary: Technical videos & demos / Conference presos / Analyst reports /B log posts / Case Studies
  - Secondary: Peer review sites / eBooks / Websites / Events & Meetups / Podcasts
  - Tertiary: Social media / Infographics
  - Internal Influencers: User & Quality Testing / PMs / Solutions & Tech Architects / Platform
Engineers / C-Suite / Heads of Engineering & Data Science / DevOps Engineers / Innovation Team / IT Director / Head of Development & Sr. Developers / Peers / Partner companies

- **Purchasing Role:**

  1. Influencer
  1. Probably a researcher
  1. Likely an Initiator / Identifier of Need & Researcher
  1. Decison-Maker: this group is the lead ARR and First Order purchaser of GitLab

- **Recommended Buyer's Journey:**

  - Awareness: Tech demo video servies, case studies, conference presentation
  - Consideration: Peer reviews, customer video testimonials, ebook
  - Decision:  LinkedIn/Twitter, Reddit, Infographic

---

### Compliance Cooper

![compliancecooper](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/images/compliancecooper.png)

- **Job To Be Done:**

  - Maintain the company's legal and ethical integrity

- **Summary:**

  - I'm really motivated by contributing to a greater purpose or mission
  - I'm very often a Decision-Maker but I also am an Influencer, and Initiator
  - My biggest challenges are tool and process sprawl and anything manual / lack of automation

- **My Messaging:**
  - A single platform makes it easier to enforce compliance across the entire software life cycle
  - GitLab can pull reports from all projects, groups, and departments making preparing for audits much easier
  - Vulnerability and Dependency management are easier through SBOM creation, license approvals policies, and security dashboards

- **Potential Titles:**

  - Compliance Officer / Director or Manager: Risk & Regulatory, Audit, Ethics, Governance

- **Reports to:**

  - CEO / COO / CFO / CLO / Head of Compliance

- **Job Responsibilities:**

  - Policy planning, enforcement, and addressing compliance issues as they arise
  - Create and review regulatory compliance documentation
  - Coordinate creation, review, and implementation of policies and procedures resulting from new laws and regulations
  - Apply and interpret audit and compliance requirements for various departments

- **Job is Measured by:**

  - Efficiency / Incidents that do NOT happen

- **Goals & Objectives:**

  - Assess and understand all risks (including risk of failing to meet regulatory compliance obligations) and then develop policies, procedures, and internal controls to keep risk at tolerable levels

- **Motivated by:**

  - Contributing to solving real problems
  - Contributing to a greater purpose/ mission
  - Career growth/learning (and the ability to fail/learn in a safe environment)

- **Biggest Challenges:**

  - Tool and process sprawl
  - Anything manual / lack of automation
  - Silo'd teams and workflows

- **Sources for Tech Purchasing Decisions:**

  - Primary: Announcements & Press releases /Conference presos / Analyst reports / Case studies / Events & Meetups
  - Secondary: Email updates & newsletters / References & testimonials from customers / Blog posts / Peer review sites / Webinars
  - Tertiary: Social media / Podcasts
  - Internal Influencers: Tech management / C-Suite / Peers

- **Purchasing Role:**

  1. Decision-maker
  1. Influencer
  1. Initiator/ Identifier of need

- **Recommended Buyer's Journey**
  - Awareness: Tech demo video series, case studies, conference presentations
  - Consideration: Peer reviews, customer video testimonials, ebook
  - Decision: LinkedIn/ Twitter, Reddit, Infographic

---

### Release Rory

![releaserory](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/images/releaserory.png)

- **Job To Be Done:**

  - Ensure delivery milestones are met on time and with quality

- **Summary:**

  - I'm really motivated by being more efficient and effective
  - I'm an Influencer and Researcher for tech purchases but I am very often the decision-maker
  - My biggest challenges are tool and process sprawl and the volume of required integrations (and associated maintenance). My job also restricts tooling choices (and I don't like the tools I am allowed to use)

- **My Messaging:**

  - A single platform reduces tool sprawl and requires few integrations reducting associated maintenance
  - Establish success delivery porcesses by setting up prodcedural guidelines
  - Ease communication between different teams to build partnerships and develop solutions

- **Potential Titles:**

  - Manager/Director: Release and Change Management / Test, QA / Engagement / Scrum Master

- **Reports to:**

  - Head of Delivery

- **Job Responsibilities:**

  - Coordinates and manages the entire SDLC
  - Ensures teams can work together well to complete projects
  - Identifies functional requirements for each department to ensure the completion of SW development
  - Ensure the team delivers the project on time and according to cusotmer specifications

- **Job is Measured by:**

  - Meeting Delivery Milestones (Velocity) / Quality

- **Goals & Objectives:**

  - Establishing a successful delivery process by setting up procedural guidelines
  - Managing customer expectations by evaluating feedback and instituting necessary changes
  - Ensuring that operations are cost-effective and stay within budget
  - Acting as liaison officer between different teams to build partnerships and develop solutions

- **Motivated by:**

  - Being more efficient / effective
  - Leading organizational change

- **Biggest Challenges:**

  - Tool and process sprawl
  - My job restricts tooling choices (and I don't like the tools I am allowed to use)
  - Volume of required integrations (and associated maintenance)

- **Sources for Tech Purchasing Decisions:**

  - Primary: Announcements & Press releases / Blog posts / Analyst reports / Technical videos & demos / Social media
  - Secondary: eBooks / Case studies / Conference presos
  - Internal Influencers: Infrastructure Team

- **Purchasing Role:**

  1. Influencer
  1. Researcher
  1. Decision-maker

- **Recommended Buyers Journey:**

  - Awareness: Press releases, Blog posts, Tech demos
  - Consideration: ebook, Case studies, Conference presos
  - Decision:  Analyst report, Reddit threads, LinkedIn/Twitter

---

### Program Management Payton

![pmpayton](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/images/pmpayton.png)

- **Job To Be Done:**

  - Plan, govern, and oversee the delivery of new capabilities

- **Summary:**

  - I'm really motivated by being more effective and efficient
  - I'm both an Influencer and Decision-maker
  - My biggest challenges are that the transition to DevSecOps is challenging for certain legacy workloads and environments, the need to increase the speed of development, and the disjointed developer experience

- **My Messaging:**

  - Improve productivity through the use of a single platform to reduce context switching and improve communications
  - Increase the spped of development through the use of automation and CI/CD
  - Gain increased visibility with reporting across the entire project
  - East the tranition to a true DevSecOps framework for legacy applications

- **Potential Titles:**

  - PMO Lead / Agile Coach or Consultant / IT Program Manager / Senior Project Manager

- **Reports to:**

  - Director of Program Mgmt.

- **Job Responsibilities:**

  - Daily program management throughout the program life cycle
  - Define the program governance (controls)
  - Plan the overall program and monitoring the progress
  - Manage the program's budget
  - Manage risks and issues and taking corrective measurements
  - Coordinate the projects and their interdependencies
  - Manage and utilizing resources across projects
  - Manage stakeholder comms

- **Job is Measured by:**

  - Productivity / Efficiency / ROI / Profit Margin / Timeliness

- **Goals & Objectives:**

  - Increase productivity
  - Ensure milestones and delivery
  - Stay on time and on budget

- **Motivated by:**

  - Being more efficient/effective
  - Contributing to a greater purpose/mission
  - Contributing to solving real problems

- **Biggest Challenges:**

  - Transition to DevSecOps is challenging for certain legacy workloads and environments
  - The need to increase the speed of development
  - The disjointed developer experience

- **Sources for Tech Purchasing Decisions:**

  - Primary: Announcements & Press releases / Analyst reports / Blog posts / Conference presos / Video stories from similar organizations
  - Secondary: eBooks / Websites / Whitepapers
  - Tertiary: (Minimally) Webinars / Podcasts
  - Internal Influencers: DevSecOps Consultants / Developers / System Administrators / DBAs / PMO / Security / Product Management

- **Purchasing Role:**

  1. Influencer
  1. Decision-maker

- **Recommended Buyer's Journey:**

  - Awareness: Press releaes, analyst reports, blog posts
  - Consideratoin: Conference presos, customer vidoe testimonials, ebook, custom web landing page
  - Decision: Whitepaper, webinars, podcasts

---

### Back Office Blake

![backofficeblake](/handbook/marketing/brand-and-product-marketing/product-and-solution-marketing/images/backofficeblake.png)

- **Job To Be Done:**

  - Manage, coordinate, and facilitate operational, (and often cross-functional) non-development related business activities

- **Summary:**
  - I'm really motivated by leading organizational change
  - I represent functions like Marketing, Finance, Legal, HR, and Operations and I'm both an Influencer and Decision-maker
  - My biggest challenges are:

    - Tool and process sprawl
    - Anything manual / lack of automation
    - The need to increase the speed of development
    - Siloed teams and workflows
    - Scaling efficiencies and new ways of working across multiple projects and environments
    - Not being able to find/hire/retain the right skill sets

- **My Messaging:**

  - Reduce administrative overhead with fewer contracts to negotiate and maintain
  - Simplify the workflow with fewer tools and less process sprawl
  - Improve cross-team communications with a single tool for all groups
  - Lower overall costs and see up to a 400% ROI

- **Potential Titles:**

  - CFO, VP Finance / Chief Legal Officer / COO / CMO, VP Mktg / CHRO, VP HR / Head of Procurement

- **Reports to:**

  - CEO / President

- **Job Responsibilities:**

  - Managing the procurement approval process
  - LegalOps
  - Everything as Code (Marketing / Training / etc.)
  - Onboarding processes(employees / customers / partners)
  - Project Management
  - Anything that requires SSOT functionality

- **Job is Measured by:**

  - Efficiency / Productivity / (KPIs vary by Division)

- **Goals & Objectives:**

  - Manage business operations effectively and efficiently

- **Motivated by:**

  - Contributing to solving real problems
  - Career growth/learning (and the ability to fail/learn in a safe environment)
  - Leading organizational change

- **Biggest Challenges:**

  - Tool and process sprawl
  - Anything manual / lack of automation
  - The need to increase the speed of development
  - Siloed teams and workflows
  - Scaling efficiencies and new ways of working across multiple projects and environments
  - Not being able to find/hire/retain the right skill sets

- **Sources for Tech purchasing Decisions:**

  - Primary: Analyst reports / Case studies / Blog posts / References & testimonials from customers
/ Websites /Email updates / newsletters
  - Secondary: Announcements & Press releases / Peer review sites / Conference presos
  - Internal Influencers: Internal team / C-level / Software development lead

- **Purchasing Role:**

  1. Influencer
  1. Decision-maker

- **Recommended Buyer's Journey:**

  - Awareness: Analyst reports, Case studies, Customer Video Testimnials, Customer Website Landing Page
  - Cosideration: Press releases, blog posts, conference presos
  - Decision: Peer reviews (G2), Functional 'how-to' webinars, Topical campaigns email w CTA

---

### Content Buyers Use for Tech Research and Decision-Making

- [Analyst report:](https://about.gitlab.com/analysts/gartner-ast22/) Paid resource that provides insights into major business and IT trends and technologies (Gartner, Forrester, IDC, Red Monk, etc.).
- [Announcement/Press release:](https://about.gitlab.com/press/releases/) Official statement to the news media for the purpose of providing information, creating an official statement, or making an announcement directed for public release.
- [Blog post:](https://about.gitlab.com/blog/) Entry/article written on a blog usually including content in the form of text, photos, infographics, or videos.
- [Case study:](https://about.gitlab.com/customers/) Detailed study of a specific subject in its real-world context focused on a person, group, event, or organization.
- [Conference presentation:](https://techstrong.tv/videos/2020-gitlab-commit-virtual/anoop-dawar-christie-lenneville-gitlab-product-keynote) Oral & visual talk or in-depth demonstration communicating technical subject matter to attendees.
- [eBook:](https://about.gitlab.com/resources/ebook-fuel-growth-cicd/) Book composed in or converted to digital format for display on a computer screen or handheld device.
- [Email update/newsletter:](https://drive.google.com/file/d/1tDy7Q_rsPq_PcopVXPPvUAe6NPWui9Sf/view?usp=sharing) Periodically sent email that informs audience of the latest news, tips, or updates relating to products or services (generally, newsletter is informative, while email sales/marketing focused).
- [Event/Meetup:](https://www.youtube.com/watch?v=QGgp2HNTOvs) Organized in-person or virtual activity or gathering for people and communities of similar interests, hobbies, and professions. (May be organized via the Meetup social media platform.)
- [Infographic:](https://drive.google.com/drive/search?q=infographic) Visual image such as a chart or diagram used to represent information or data.
- [Peer review site:](https://www.g2.com/discussions/what-can-gitlab-do) Collection of reviews providing a steady stream of authentic customer feedback that IT professionals use to make tech purchasing decisions.
- [Podcast:](https://about.gitlab.com/blog/2019/07/03/group-conversation-podcast/) Digital audio file made available on the internet for downloading to a computer/mobile device, typically available as a series, new installments of which can be received by subscribers automatically.
- [Reference/testimonial from customer:](https://www.youtube.com/watch?v=pMWXn6NslEE) Person/company that is willing to share positive feedback or story about a products/services or overall customer experience at-large.
- [Research report:](https://www.accenture.com/us-en/insights/interactive/fjord-trends-2022) Publication reporting on the findings of a research project or alternatively scientific observations on or about a subject. (Often published by tech thought leaders like Accenture, Deloitte, etc.)
- [Social media:](https://www.linkedin.com/) Internet-based form of communication. Social media platforms allow users to have conversations, share information and create web content. (Facebook, Twitter, LinkedIn, Tik Tok, Instagram)
- [Technical video/demo:](https://www.youtube.com/watch?v=Rm-tNcskxqY) Highly customized, deep-dive demonstration of a digital product, often presented to the buyer's technical team.
- [Video story from similar organization:](https://www.youtube.com/watch?v=L4zf_QIr4jQ) Recorded talk about how a company's product or service has helped another customer solve a related problem.
- [Webinar:](https://www.youtube.com/watch?v=muIZthUk4_o) Online event hosted by an organization/company and broadcast to a select group of individuals through their computers via the Internet.
- [(Product) Website:](https://about.gitlab.com/) Page on a vendor's website describing a particular product/service and including specific specs and features, information about the manufacturer and brand, etc. .
- [Whitepaper:](https://fbcinc.com/source/virtualhall_images/Convergence/GitLab/modernizing-government-it.pdf) Report/guide that informs readers concisely about a complex issue and presents the issuing body's philosophy on the matter. It is meant to help readers understand an issue, solve a problem, or make a decision.

### Enablement Artifacts

- [Slides](https://docs.google.com/presentation/d/18Cro-xz9k8jHAdnLOLX1Y0QP9pEdkCli_bnnm3oHGWk/edit#slide=id.p1)
- [Video 1](https://drive.google.com/file/d/1e5pojzdV3mdQzqLhXiTYniJNTHuwktxD/view?usp=share_link)
- [Video 2 - updates](https://drive.google.com/file/d/1-Drm1XdBvyO9adU8bjJDqp4z2tjq8W-M/view?usp=share_link)
- [Feedback Issue](https://gitlab.com/gitlab-com/marketing/strategic-marketing/product-marketing/-/issues/6670)
- [Buyer Personas by Stage with Job Titles by Persona Group](https://docs.google.com/spreadsheets/d/1fqv1YHD9fW6KpV0PxS1kAcSTvzZ9Xhu6hRnTUo5YPdo/edit?usp=sharing)
- Slack channel: #buyer-personas

### Enablement Sessions

- Product: 2022-11-01 [Recording](https://gitlab.slack.com/files/U01HVL4CLTX/F0496QE1KBQ/traci_-_buyer_persona_refresh.mp4)
- All Marketing: 2022-11-10 730 pm ET / 1230 am UTC Recording
- Sales Strategy: Scheduled for 2022-11-21 1130 am ET / 430 pm UTC Recording
- Channel/Alliances/Partner: Scheduled for 2022-12-06 1130 am ET /430 pm UTC [Recording](https://youtu.be/AdgiCCRo7LE)
- UX: Scheduled for 2022-11-29 1130 am ET /430 pm UTC [Recording](https://drive.google.com/file/d/15LZFnLAUoSZaUWHEY5ZbxaRhc3BzvQpv/view?usp=share_link)
- Customer Success: Scheduled for 2022-11-30 12 pm ET / 5 pm UTC Recording
- Sales: Rollout at SKO Feb 2023

- Office Hours:
  - 2022-11-15 11 am ET / 4 pm UTC [Notes](https://docs.google.com/document/d/1qbZK3_cwxzyOIqeqYcoZDby-5dibSW6HQT8D4jrMaLw/edit) | [Recording](https://drive.google.com/file/d/1BLlKu_biBzm9g9I8sbUbV7DX0qdBuDFw/view)
  - Scheduled for 2022-12-20 11 am ET / 4 pm UTC Notes | Recording
  - Scheduled for 2023-01-17 11 am ET / 4 pm UTC Notes | Recording
  - Scheduled for 2023-02-21 11 am ET / 4 pm UTC Notes | Recording
  - Scheduled for 2023-03-21 11 am ET / 4 pm UTC Notes | Recording
  - Scheduled for 2023-04-18 11 am ET / 4 pm UTC Notes | Recording

### Deprecated Buyer Videos

Note: for continuity we've historically used these buyer persona descriptions. Consider them deprecated, as the above Buyer Personas are more complete.

1. Director DevOps [video](https://www.youtube.com/watch?v=5_D4brnjwTg), Director DevOps [slide deck](https://docs.google.com/presentation/d/1x-XUhAXkZxl8ZGe4ze9qcWMmrWITc7es1fYNY_OHQQA/) or Director of IT
1. VP IT [video](https://www.youtube.com/watch?v=LUh5eevH3F4), VP IT [Slide Deck](https://docs.google.com/presentation/d/17Ucpgxzt1jSCs83ER4-LdDyEuermpDuriugPNYrz8Rg/) or VP of Engineering
1. Chief Architect [Video](https://www.youtube.com/watch?v=qyELotxsQzY), Chief Architect [slide deck](https://docs.google.com/presentation/d/1KXsozYkimSLlEg3N-sKeN7Muatz_4XimYp-s7_dY1ZM/) or CIO
1. VP Application Development (Persona info from the Just Commit campaign) [video](https://www.youtube.com/watch?v=58qDalA5o6Q&list=PLFGfElNsQthYe-_LZdge1SVc1XEM1bQfG), VP Application Development [slide deck](https://docs.google.com/presentation/d/1pYyAu8ezJZBVLb5k8-E_4Hhtf8w5l11AWhaAxU4GK50/edit#slide=id.g5050420c27_0_0)
1. Chief Information Security Officer or Director of Security (may fund Ultimate upgrade for security capabilities)
