---
title: Promotion Document Style Guide
---

Assembling a case for promotion can be a time-consuming process. The tips and style principles in this guide will help you prepare a document that presents the evidence clearly, requiring fewer review cycles.

The emphasis on quantification over editorialization has a number of benefits for both the reader and the author:

- It's easier to gradually assemble the document over time, and to understand the level of completion at any point.
- The document reads more confidently and, crucially, more objectively.
- Cases for promotion to the same role are more readily comparable to each other and the job family criteria, with consistent tone.
- The presentation is maximally inclusive, requiring less context on the part of the reader.

## Principles for Presenting a Strong Promotion Case

1. Minimize the use of adjectives and adverbs.
   - **Don't**:
     - _"significantly improved the performance of the most important Plan endpoints."_
   - **Do**:
     - _"reduced Time to First Byte (TTFB) by an average of 180ms for the 5 most visited Plan endpoints."_
   - **Why**: Adjectives and adverbs are imprecise and make it difficult for the reader to understand the true impact and the person's exact contribution to it.
1. Ensure quantification is appropriate and meaningful.
   - **Don't**:
     - _"increased page views by 2 million over a 3 month period."_
   - **Do**:
     - _"increased monthly page views by 25% over a 3 month period, from 8 million to 10 million."_
   - **Why**:
     - Ensures that statements pass the "so what" test, requiring no further investigation on the part of the reader.
1. Only use numbered links to list examples, not to describe how the person did something. Instead describe the contribution and link parts of the text.
   - **Don't**
     - _"brought a critical user feature from the architectural stage right through to General Availability (GA) [1,2,3,4,5]."_
   - **Do**
     - _"created an [architecture blueprint], with a [proof of concept implementation] to validate the proposed solution and aid estimation. As a result, the project was delivered on time in 3 MRs [1,2,3]."_
   - **Why**: Avoids the need for the reader to investigate each link individually and figure out for themselves what the person's contribution actually was, often from a large issue or discussion.
1. Focus on ability and impact at the next level.
   - **Don't**:
      - _"[name] delivered several projects on time by identifying quality implications during development, performing reviews and reaching out early when blocked."_ (Intermediate Engineer [Competencies](/handbook/engineering/careers/matrix/intermediate/))
   - **Do**:
      - _"[name] delivered several projects on time by proactively resolving vague requirements, collaborating cross-functionally, and mentoring other team-members in a way that enabled them to contribute."_ (Senior Engineer [Competencies](/handbook/engineering/careers/matrix/senior/))
   - **Why**: Space is limited and detailing contributions at the current level does not materially contribute to the case for promotion.
1. Business Justification should describe how the person's role will change if promoted, and what that means for the business.
   - **Don't**:
     - _"This promotion recognizes [name]'s ability to operate at the next level in their role when required to do so."_
   - **Do**:
     - _"With this promotion, [name] will assume ongoing responsibility for technical architecture, initially accelerating [project 1] as project lead and bringing forward completion of [project 2] and [project 3] by 3 months to the end of Financial Year 2026."_
   - **Why**: Clearly defining the expected role evolution helps demonstrate the business need for the promotion and how investing in it will contribute to the organization's goals.

## Additional Tips for Clarity and Impact

- Avoid unnecessary filler words or phrases:
  - Arguably
  - In order to
  - It should be noted that
  - Due to the fact that
- Expand acronyms first time they appear ("Technical Account Manager (TAM)").
- Double-check that links point to the right resource and that it is available to your expected readership.
- Use bullet points instead of prose.
- Avoid sentences over 30 words.
- Stick to the template. If it asks for two examples, give the two best examples.
