---
title: Tools and Resources
description: "Discover GitLab Solutions Architects' tools and resources"
---

## Tools and Resources

Tools and resources provide infomation to help Solutions Architects to conduct POV or workshops, respond to RFx, manage customer facing activities, support on-going product learning.

### Education and Enablement

As a Solutions Architect, it is important to be continuously learning more about our product and related industry topics. The [education and enablement handbook page](/handbook/customer-success/education-enablement/) provides a dashboard of aggregated resources that we encourage you to use to get up to speed.

### Proof of Value (POV) Guidelines

Proof of Value (POV), formerly known as Proof of Concept, is conducted during the Technical Evaluation stage with Solutions Architects by  prospects or existing customers to assess the required capabilities based on a set of criteria and value drivers. A POV is a collaboration between GitLab and the prospective or existing customer for evaluating GitLab. Information on the POV guidelines, POV types and process can be found on the [Proof of Value (POV) Guidelines](/handbook/solutions-architects/tools-and-resources/pov/) page.

### Asking help from Support Engineering

In case Support required during the pre-sales cycle (for example in case of a POV excercise or in case of potential new deal with an existing customer) Solutions Achitects should use the [Support Super Form](https://support-super-form-gitlab-com-support-support-op-651f22e90ce6d7.gitlab.io/) to open an internal request with Support. In any other cases with existing customers, SAs are advised to ask the customers to open a support ticket themselves.

### SaaS Trials for Existing Customers

Paid customers must set up a new namespace on SaaS when trialing Ultimate.  There are two primary reasons for this:

1. Some paid features are not available in a trial, so a customer might lose functionality they had been using if a trial license is applied
2. GitLab does not have an appropriate mechanism for applying and reverting a trial license on SaaS without the namespace potentially being reverted to free when the trial expires ([see issue](https://gitlab.com/gitlab-org/gitlab/-/issues/12186))

Both situations put customer production GitLab usage at risk if a trial is applied to the SaaS namespace.

Instead, a customer should create a new namespace and trial there.  We have put together some [trial guidelines](/handbook/solutions-architects/tools-and-resources/trial-guidelines/) in order to make the process as seamless as possible for customers.

### Hands-on Workshops

GitLab Solutions Architects conduct hands-on workshops as interactive events for GitLab prospects and customers to learn the GitLab product and DevSecOps capabilities. Workshops may be executed as marketing events or run independently for specific customers. Detail information is provided on the [Hands-on Workshops](/handbook/solutions-architects/tools-and-resources/workshop/) page.

### RFI/RFP Responses

RFx's such as RFI and RFP are common steps in the public sector yet it may be required by enterprise customers to assess, evaluate and procure the software. Solutions architects often participate in the RFP process responding to the technical asks and solutions requirements. Information on responding to the RFx can be found on the [RFI/RFP](/handbook/security/security-assurance/field-security/Field-Security-RFP/) page.

### Stack Overflow for Teams

[Stack Overflow for Teams](https://stackoverflowteams.com/c/gitlab-customer-success/questions) is a knowledge sharing and collaboration tool that helps entire Customer Success organization stay productive, onboard faster, and minimize distractions by unlocking information through collaborative knowledge management.
Everyone in Customer Success organization has access to the Stack Overflow for Teams via Okta and is able to answer questions or provide responses directly via web interface

Additionally, it is possible to interact with Stack Overflow using Slack integration via following commands:

- `/stack ask How do I do X?` to ask a question directly via Slack
- `/stack search [search term]` to search for questions and answers

Slack integration also posts notifications about new questions and answers via `#cs-questions` Slack channel for the entire team to stay up to date and boost participation. Adherent to and in support of GitLab's [efficiency value](/handbook/values/#efficiency) team members should first [search for an existing answer](/handbook/company/culture/all-remote/self-service/) and post a question only if an answer is not readily available.

Stack Overflow for teams replaces older [Customer Success Knowledge Base](https://gitlab.com/gitlab-com/customer-success/solutions-architecture/sa-knowledge-base/), which is considered deprecated and will be removed in the Future.

### Product Releases

Solutions Architects have to keep up the pace of the GitLab monthly product releases to position feature sets and capabilities for the prospect and customer needs while demonstrating the market leading position.

Following links provide product release information to assist in technical discussions and technical evaluation.

- [Upcoming Releases](https://about.gitlab.com/upcoming-releases/)
- [Previous Releases](https://gitlab.com/gitlab-org/gitlab/-/releases)
- [Releases Blog](https://about.gitlab.com/releases/categories/releases/)
- Compare two releases with the [What is New Since? Release Feature Overview Tool](https://gitlab-com.gitlab.io/cs-tools/gitlab-cs-tools/what-is-new-since/?)

### Customer Facing Meeting Tools

Solutions Architects frequently interact with customers for demos, presentations or Q&A. These calls should enable the customer to clearly experience the value of GitLab without distraction or interruption. The below list of tools was compiled by the GitLab SA team as commonly used solutions. Note, this list does not represent a requirement to use any of these products or an endorsement for these products.

- [Muzzle](https://muzzleapp.com/) to mute all notifications prior to beginning a call
- [Tab Resize Chrome plugin](https://chrome.google.com/webstore/detail/tab-resize-split-screen-l/bkpenclhmiealbebdopglffmfdiilejc?hl=en-US) to break tabs into split-screen viewing
- [Screenbrush](https://screenbrush.imagestudiopro.com/) to draw on the screen
- [Toby](https://www.gettoby.com/) or [Tabs Outliner](https://chrome.google.com/webstore/detail/tabs-outliner/eggkanocgddhmamlbiijnphhppkpkmkl) to launch many preset tabs at once
- [Station](https://getstation.com/) to group pages by application in a smart dock
- [MouseBeam](https://geeky.gent/tag/mousebeam/) enables the mouse cursor to use multiple screens like a circle
- [Rectangle](https://rectangleapp.com/) to quickly move and resize windows in macOS using keyboard shortcuts or snap areas
- [Dark Reader](https://darkreader.org/) enables browser dark mode to better fit room lighting
- [Postman](https://www.getpostman.com/) for API interaction
- [Visual Studio Code](https://code.visualstudio.com/) lightweight IDE text editor

#### Related macOS tips

- [Switch between full screen applications](https://www.intego.com/mac-security-blog/how-to-enter-and-exit-full-screen-mode-in-macos/) using the trackpad, Command keys or other options
- Use the [Zoom Accessibility Features](https://www.imore.com/how-use-zoom-mac) to zoom in on targeted screen locations
- [Work in multiple spaces on a single monitor](https://support.apple.com/en-gb/guide/mac-help/mh14112/mac) to keep multiple app windows or browser tabs open in fullscreen mode
  - Enables switching between windows or tabs with trackpad gestures, keeping display screen clean and uncluttered

### Useful Customer Facing Presentations

No two presentations are the same and we often find ourselves mixing and matching content tailored to our Customer's journey. All field and customer facing collateral is hosted on

- [HighSpot](https://gitlab.highspot.com/) (for field teams)
- [Solution Pages](https://about.gitlab.com/solutions/) (for web users)

### O'Reilly Learning Platform

In order to facilitate an environment of learning and development, the Solutions Architect team has access to the [O'Reilly Learning Platform](https://learning.oreilly.com/home/). This education platform contains thousands of books, videos and live learning courses to assist SA's with gaining the knowledge they need to stay competitive.

More information can be found on the [Customer Success Education & Enablement page](/handbook/customer-success/education-enablement/).

### LinkedIn Learning Platform

LinkedIn Learning is another platform with various resources to help SA's during their onboarding journeys.

### Getting started as an associate SA

Here are courses that will facilitate the onboarding process of associate SAs and help them in getting up to speed with the technical concepts required for the role:

**Free for GitLab members**

- The learning path [Become a DevOps Engineer](https://www.linkedin.com/learning/paths/become-a-devops-engineer), particularly the following sections:
  - [DevOps Foundations](https://www.linkedin.com/learning/devops-foundations)
  - [Learning Docker](https://www.linkedin.com/learning/learning-docker-2018)
  - [DevOps Foundations - CI/CD](https://www.linkedin.com/learning/devops-foundations-continuous-delivery-continuous-integration-14449917)

- [Docker for the Absolute Beginner - Hands-On](https://learning.oreilly.com/videos/docker-for-the/9781788991315/)

**Paid**
Paid courses can be expensed as part of the [Growth and Development benefits](/handbook/people-group/learning-and-development/growth-and-development/)

- IBM course on Coursera: [Information Technology (IT) and Cloud Fundamentals Specialization](https://www.coursera.org/specializations/it-cloud-fundamentals)
Especially the module [Introduction to Cloud Computing](https://www.coursera.org/learn/introduction-to-cloud?specialization=it-cloud-fundamentals)

### Data Seeding (Demo Data)

The [GitLab Data Seeder](https://docs.gitlab.com/ee/topics/data_seeder.html) is a tool that Solutions Architects can use to showcase to customers "what good data looks like" in GitLab.
The data that is generated is customizable, time-relative, and can be used on-demand to generate data to demonstrate.

The Demo Data can be showcased on any self-managed instance including Docker, GDK, and customer environments.

### Diagramming Tools

Being able to diagram as-is and to-be workflows and architectures is a key tactic for Solutions Architects to communicate key benefits of a GitLab DevSecOps transformation.  GitLab has made FigJam available for SAs to use and we have [Solutions Architecture Workspace](https://www.figma.com/files/972612628770206748/workspace/1338898741676176280/directory/teams?fuid=1339310988336517144) available for storing our diagrams.
