---
title: "Solutions Architect"
---

Solutions Architects are the trusted advisors to GitLab prospects and clients, showing how the GitLab solutions address client business requirements. Solutions Architects are responsible for driving and managing the technology evaluation and validation stages of the sales process. Solutions Architects are the product advocates for GitLab's Enterprise Edition.  They focus on the technical solution while also understanding the business outcomes the customer is trying to achieve.

The Solutions Architect helps drive value and change with software development for one of the fastest-growing platforms. By applying solution selling and architecture experience from planning to monitoring, the Solutions Architect supports and enables successful adoption of the GitLab platform. Solutions Architects work collaboratively with GitLab's customers across segments, Sales, Engineering, Product Management, and Marketing organizations.

This role provides technical guidance and support throughout the entire sales cycle. Solution Architects can help shape and execute a strategy to build mindshare and broad use of the GitLab platform with customers by becoming the trusted advisor. The ideal candidate must be self-motivated with a proven track record in software/technology sales or consulting. Proficiency in connecting technology solutions to measurable business value is critical to a Solutions Architect. Candidates should also have a demonstrated skill to think strategically about business, products, and technical problems.

To learn more, see the [Solutions Architect handbook](/handbook/solutions-architects/)

## Responsibilities and Requirements

Level role responsibilities and requirements may be extended or overlaid by [Specialty SA Roles](#specialties) when they also apply to a team member.

### Performance Indicators

As with all roles in the Sales Department, the Solutions Architect participates in a subset of the [Sales KPIs](/handbook/company/kpis/#sales-kpis). Key priorities of these roles are to drive new (i.e., new logos) and growth bookings and contribute to sales efficiency.

## Levels

### Associate Solutions Architect

The Assocate Solutions Architect reports to the Manager, Solutions Architect.

#### Associate Solutions Architect Job Grade

The Associate Solutions Architect is a [grade 5](/handbook/total-rewards/compensation/compensation-calculator/#customer-success)

#### Associate Solutions Architect Responsibilities

- Technical expertise: Engage with customers, both onsite and remotely, by providing technical expertise during the pre-sales process. This includes answering customer inquiries, conducting product demonstrations, and explaining the capabilities and benefits of GitLab.
- Sales strategy: Collaborate with the sales team to support the formulation and execution of the sales strategy. Help identify potential opportunities for GitLab adoption and contribute to the development of sales plans and proposals.
- Technical guidance: Contribute to technical evaluations by assisting in proof-of-concept (POC) or proof-of-value (POV) initiatives. Support the team in designing workshops and providing technical guidance during requests for proposal (RFP) or audits.
- Customer relationships: Establish and maintain positive relationships with customers, focusing on building rapport and trust. Collaborate with individuals within customer environments, understand their needs, and assist them in becoming advocates for GitLab.
- Customer feedbacks: Effectively communicate customer feedback, requirements, and challenges to relevant teams (including Product Development, Sales, and Marketing) to drive continuous improvement.
- Market knowledge: Maintain a foundational understanding of technologies related to GitLab's market focus.
- GitLab knowledge: Develop a comprehensive knowledge of the GitLab platform and associated technologies. Stay up to date with product updates, new features, and industry trends related to GitLab.
- Training & Certifications: Aquire industry standard certifications to build up credibility as technical expert.
- Growth & Development: Continuously improve your professional skills with a focus on personal mastery and team learning through activities such as training, reading and seeking mentorship from others.

#### Associate Solutions Architect Requirements

- Technical presentation and communication skills
- Experience in or familiarity with (for the [early-in-career program](/handbook/solutions-architects/career-development/#associate-solution-architecture-program) candidates) the field of information technology or technical pre-sales
- Understanding of the end-to-end software development lifecycle
- Understanding of continuous integration and continuous deployment
- Ability to use GitLab
- Ability to travel if needed and comply with the company's [travel policy](/handbook/finance/travel/)

### Solutions Architect

The Solutions Architect reports to the Manager, Solutions Architect.

#### Solutions Architect Job Grade

The Solutions Architect is a [grade 6](/handbook/total-rewards/compensation/compensation-calculator/#customer-success)

#### Solutions Architect Responsibilities

- Technical expertise: Engage with customers, both onsite and remotely, by providing technical expertise during the pre-sales process. The additional responsibility implies adopting a more mature consultancy and advisor role during the pre-sales process while providing technical assistance and solution guidance.
- Sales strategy: Collaborate with the sales team to go beyond support to formulate and execute a sales strategy to exceed revenue targets through the adoption of GitLab.
- Technical guidance: Be the Directly Responsible Individual ([DRI](/handbook/people-group/directly-responsible-individuals/)) on [Technical Close Plans](/handbook/solutions-architects/sa-practices/technical-close-plan/) and technical evaluations via POC/POV ownership, technical part of tender/audit support, and workshop design.
- Customer relationships: Build deep relationships with people within customer environments to enable them to be GitLab advocates.
- Customer feedbacks: Serve as the customer advocate to other GitLab teams, including Product Development, Sales, and Marketing.
- Market knowledge: Maintain specialty competency in one or more technologies related to GitLab's market focus through activities such as training, certification and creation of working examples for reuse internally and by customers and partners.
- GitLab knowledge: With comprehensive knowledge of the GitLab platform and associated technologies, educate customers of all sizes on the value proposition of GitLab while participating in discussions throughout the organization to ensure successful GitLab deployment.
- Growth & Development: Continuously improve your professional skills with a focus on personal mastery and team learning through activities such as training, reading and seeking mentorship from others.
- Strategic Client Engagement: Run Value Stream Assessments in your account with support of a Senior SA leading the engagement

#### Solutions Architect Requirements

- Extends the Associate Solutions Architect requirements
- Experience with technical pre-sales or as a professional in the field of information technology
- Experience with modern software development or operations and their associated technologies
- Experience with cloud computing and related technologies and practices

### Senior Solutions Architect

The Senior Solutions Architect reports to the Manager, Solutions Architect.

#### Senior Solutions Architect Job Grade

The Senior Solutions Architect is a [grade 7](/handbook/total-rewards/compensation/compensation-calculator/#customer-success)

#### Senior Solutions Architect Responsibilities

- Extends the Solutions Architect responsibilities.
- Solve technical customer issues of broad scope and high complexity.
- Provide mentorship for Solution Architecture team members and remain a current contributor to team-learning initiatives and activities.
- Work cross-departmentally to find solutions to complex scenarios and integration issues.
- Propose improvements and innovation for customer calls and product demonstrations based on current market trends.
- Maintain in-depth knowledge of the entire GitLab application.
- Represent GitLab as a speaker at field events or as an author in GitLab-focused publications and blogs.
- Provide opportunity strategy leveraging market and industry knowledge and trends.
- Drive [Technical Close Plans](/handbook/solutions-architects/sa-practices/technical-close-plan/) without guidance.
- Collaborate with the product team while representing customer requirements and feedback.
- Create Customer Success Plans with customers
- Contribution to Account and Territory Planning Sessions of their region/sub-region
- Regularly enhances GitLab documentation for clarity and accuracy as well as adding new explanations, examples and sections.
- Share subject matter expertise through Slack posts, documentation updates, communities of practice, issue and MR participation and other common GitLab collaboration mechanisms.
- Coach sales team-members on deal qualification when necessary.
- Assists with specific objectives and key result associated tasks
- Leading Value Stream Assessments with your accounts or another team member's, while the team member shadows

#### Senior Solutions Architect Requirements

- Extends the Solutions Architect requirements
- Has experience with the additional responsibilities of a Senior Solutions Architect
- Experience in Workshop facilitation

### Staff Solutions Architect

The Staff Solutions Architect reports to the Manager, Solutions Architect.

#### Staff Solutions Architect Job Grade

The Staff Solutions Architect is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#customer-success)

#### Staff Solutions Architect Responsibilities

- Extends the Senior Solutions Architect responsibilities with a company-wide scope

##### Technical Guidance and Mentorship

- Build and deliver high-value and reusable enablement content that measurably improves the team's effectiveness and execution on a regular basis.
- Sustain mentorship for specific members of the Solutions Architecture team to improve our technical win rate, increase NetARR, fostering a culture of continuous learning and improvement.
- Guide Solution Architect team members through complex customer opportunities and activity.
- Advise Solution Architect team members on [Technical Close Plans](/handbook/solutions-architects/sa-practices/technical-close-plan/) and [Customer Success Planning](/handbook/solutions-architects/sa-practices/customer-success-plan/) strategies and patterns leading to shorter sales cycles and faster product adoption.
- Run high-value SA activity enablement sessions with team members, both new (training) and existing (best practices) (e.g., Value Stream Workshops, Day in the Life, Duo Workshops, etc.)

##### Cross-Functional Collaboration and driving innovation

- Consolidate Field Feedback to drive product roadmap discussions (outside-in) and be informed of the product roadmap for at least one product area, and inform team members of changes to come in the near term.
- Be the DRI for a Subject Matter Expert Group in a region.
- Architect innovative solutions leveraging 3rd party and GitLab technologies that lead to new use cases and revenue opportunities.
- Build connections/relationships with key regional/geo partners, alongside the Ecosystem SA team.

##### Customer Engagement and Solution Ownership

- Serve as the primary technical point of contact for high-value customers, ensuring high customer satisfaction, solution adoption and success rate of renewals or upsells.
- Lead efforts to identify potential risks in architectural design and ensure compliance with industry standards and regulations

##### Thought Leadership and Evangelism

- Maintain a positive personal brand through GitLab-relevant participation in channels such as conferences, blogging, social media, or volunteering for external technical committees or communities of practice.
- Develop and drive the strategic technical vision for large-scale, complex projects, ensuring alignment with GitLab's overall business objectives

#### Staff Solutions Architect Requirements

- Extends the Senior Solutions Architect requirements
- Has experience with the additional responsibilities of a Staff Solutions Architect
- Technical proficiency with deep understanding of cloud architectures (AWS, Azure, GCP), containerization, DevOps practices and modern software development frameworks and languages
- Ability to define clear outcomes and expectations that align with high-level organizational goals.
- Experience leading and mentoring technical and cross-functional teams
- Proven ability to collaborate and communicate effectively with senior stakeholders, including executives and business leaders (internal and external)
- Ability to emphasize thought leadership and strategic decision-making in order to lead initiatives

### Principal Solutions Architect

The Principal Solutions Architect reports to the Manager, Solutions Architect.

#### Principal Solutions Architect Job Grade

The Principal Solutions Architect is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#customer-success)

#### Principal Solutions Architect Responsibilities

- Extends the Staff Solutions Architect responsibilities.
- Create and maintain relationships with customer executives that contribute to large Net ARR deals and customer success.
- Facilitate customer and partner strategy formulation that takes into account the customer or partner's market, business processes, technology portfolio, culture and appetite for change.
- Identify and surface business generation motions within areas of personal subject matter expertise that intersect with GitLab targeted technology sectors.
- Build and maintain select subject matter expertise related to GitLab targeted technology sectors through industry monitoring and participation in external working groups, committees and development projects.
- Keep up to date on GitLab-relevant emerging methodologies and technologies and leverage that knowledge to drive solution strategy and influence product strategy.
- Collaborate with product marketing, engineering, and management on market strategy that results in an improved win rate.
- Creates reusable notional architectures to leverage in [Technical Close Plans](/handbook/solutions-architects/sa-practices/technical-close-plan/).
- Use technical and market knowledge to create solutions and influence product to expand GitLabs revenue base - especially Total Addressable Market (TAM) and Launch Addressable Market (LAM).
- Exert influence on the overall objectives, key results, and other long-range measurable goals and strategies of the team.
- Create reference implementations for 3rd party integrations and effectively communicate the design and it's value to customers, partners and GitLab team members.
- Service assistance requests by GitLab team members and/or Partners as a pre-sales and technical solutions authority for the top ARR clients and top Net ARR opportunities.

#### Principal Solutions Architect Requirements

- Extends the Staff Solutions Architect requirements
- Has experience with the additional responsibilities of a Principal Solutions Architect

### Manager, Solutions Architects

The Manager, Solutions Architects reports to the Director, Solutions Architect.

#### Manager, Solutions Architects Job Grade

The Manager, Solutions Architects is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#customer-success)

#### Manager, Solutions Architects Responsibilities

- Understand and evangelize GitLab's vision, strategy, and values to your team while also translating them for application to team-specific scenarios.
- Grow a highly effective team through hiring, coaching, and retention of personnel.
- Provide continuous feedback to your team members as well as peers and leaders.
- Be accountable for the overall execution of your team while tracking key performance indicators (KPIs).
- Provide clear communication to your team, peers, and leadership on all essential matters.
- Guide by example while performing the responsibilities of a solution architect to drive customer success.
- Work closely with regional sales managers on strategy.

#### Manager, Solutions Architects Requirements

- Extends the Solutions Architect requirements
- Experienced in mentoring people, including giving and receiving constructive feedback
- Experienced in collaborating with other managers and executing strategies
- Previous leadership experience is a plus

### Senior Manager, Solutions Architects

The Senior Manager, Solutions Architects reports to the Director, Solutions Architect.

#### Senior Manager, Solutions Architects Job Grade

The Senior Manager, Solutions Architects is a [grade 9](/handbook/total-rewards/compensation/compensation-calculator/#customer-success)

#### Senior Manager, Solutions Architects Responsibilities

- Extends the Manager, Solutions Architect responsibilities.
- Be the directly responsible person for multiple, high-impact initiatives.
- Provide cross-functional leadership on GitLab's most strategic revenue opportunities.
- Collaborate with SA and cross-departmental leadership to iterate on and improve efficiencies of GitLab practices and execution strategies.

#### Senior Manager, Solutions Architects Requirements

- Extends the Manager, Solutions Architect requirements
- Previous leadership experience with a proven track record of success.
- Previous leadership experience at GitLab is a plus.

### Director, Solutions Architects

The Director, Solutions Architects reports to the VP, Solutions Architecture.

#### Director, Solutions Architects Job Grade

The Director, Solutions Architects is a [grade 10](/handbook/total-rewards/compensation/compensation-calculator/#customer-success)

#### Director, Solutions Architects Responsibilities

- Hire, mentor and develop an exceptional team of Solutions Architects.
- Develop strategies and operations to improve win rates to discovering, articulating, and demonstrating GitLab's solution to deliver on specific customer requirements and desired business outcomes.
- Identify and lead initiatives and programs to scale the organization and its operations for future growth.
- Develop processes and metrics and KPIs to improve effectiveness and efficiency of technical evaluations, workshops, demos, and proof-of-concept engagements.
- Partner with Sales and Partner teams to align on overall strategy and priorities and provide support for specific prospects, customers and partners.
- Develop and foster relationships for key customers at the technical sponsor and executive level.
- Partner with sales leadership to align with and deliver to regional and account plans, strategies and quarterly goals.
- Collaborate with Sales and Customer Success to improve engagement models and ensure the appropriate coverage of prospects and customers.
- Partner with Product, Engineering, Marketing and Services teams to provide feedback to improve products, services and value messaging based on field experiences and feedback.
- Partner with Sales Operations to ensure efficient and ongoing enablement and development of the team.
- Be a role model for GitLab's values and culture.

#### Director, Solutions Architects Requirements

- Demonstrated progressive experience leading technical sales teams (i.e., Solutions Architect and or Sales Engineering teams)
- Demonstrated progressive experience building and leading global teams of managers with team sizes of 30+ team members
- Demonstrated proficiency building and improving strategies and operations to technical assessment processes and team enablement
- Experience with software development lifecycle processes and tools as well as agile and or DevOps practices
- Knowledgeable with cloud technologies (e.g., Kubernetes, Docker), application security (SAST, DAST) and or cloud deployment models (AWS, GCP, Azure)
- Experience selling technical solutions to technical staff, management, and executive stakeholders
- Proven experience partnering with the broader organization (sales, partners, product and engineering, marketing and customer success)
- B.S. in Computer Science, Engineering or equivalent experience

### Senior Director, Solutions Architects

The Senior Director, Solutions Architects reports to the VP, Solutions Architecture.

#### Senior Director, Solutions Architects Job Grade

The Senior Director, Solutions Architects is a [grade 11](/handbook/total-rewards/compensation/compensation-calculator/#customer-success)

#### Senior Director, Solutions Architects Responsibilities

- Extends the Director, Solutions Architect responsibilities

#### Senior Director, Solutions Architects Requirements

- Extends the Director, Solutions Architect requirements
- Demonstrated progressive experience leading technical sales teams (i.e., Solutions Architect and or Sales Engineering teams)
- Demonstrated progressive experience building and leading global teams of managers and directors with team sizes of 50+ team members

### Vice President of Solution Architecture (SA) Job Grade

The Vice President of Solution Architecture is a job grade [12](/handbook/total-rewards/compensation/compensation-calculator/#customer-success).

### Vice President of SA Responsibilities

- Extends the Sr Director of SA responsibilities
- Define and deliver strategies and plans to create and influence GitLab's Go-To-Market strategy and plans, including Sales (strategic and velocity), Marketing, Product, and Partners.
- Provide strategic guidance with prospect and customer accounts for both account influence and growth
- Lead new developments and improvements to improve segment-specific sales strategies and methods globally, including direct and partner-led sales.
- Provide executive sponsorship for strategic accounts
- Develops a clear strategy and vision for their department, inspiring their team through communication in alignment with GitLab's mission, vision, and values.
- Align and influence the executive team and senior leadership with technical and strategic sales and GTM strategies and tactics.

### Vice President of SA Requirements

- Extends the Sr Director of SA requirements
- Demonstrated experience in cross-functional leadership to influence internal organizations on strategic GTM initiatives.
- Track record of successfully building, growing, and scaling global Solution Architect or Sales Engineering teams, delivering to bookings, revenue, and first order goals.
- Ability to influence, negotiate and build consensus with executive and senior management, customers, and partners.
- Brings experience building, scaling, and developing global teams in alignment with GitLab's values.
- Serves as an expert in Solutions Architect for all GitLab segments (Enterprise, Midmarket, SMB) internally and with customers, partners, and industry communities.

---

## Specialties

Specialty responsibilities and requirements may extend or overlay [Level roles](#levels) for a team member who has a specialty role.

### Ecosystem Solutions Architect

#### Ecosystem Solutions Architect Responsibilities

- Since this role deals primarily with partner relationships, any responsibilities in an individual's [Role Level](#levels) that reference customers can also be fulfilled by Ecosystem Partners. If responsibilities appear duplicated, the version in this description has priority due to being more specific to your role.
- Engage in a technical consultancy role for cloud, channel, system integrator, and technology alliance partners, providing technical assistance, guidance, and solutions architecture consulting both remotely and on-site. This involves ensuring the selling and service delivery readiness of GitLab partners, transferring knowledge, and earning "trusted advisor" status with strategic partners.
- Create and maintain relationships with external partner leaders that contribute to large Net ARR deals and customer success.
- Build and deliver solutions, reference implementations, and demos that highlight alliance partners' technologies in conjunction with GitLab. Additionally, contribute to GitLab's customer-facing publications, including whitepapers, blogs, diagrams, reference architectures, and the GitLab Handbook.
- In partnership with the ecosystem sales team, formulate and execute a sales, solution and practice strategy to exceed revenue targets through the delivery of solutions & services that drive the adoption of GitLab.
- Work with Customer Success and Sales teams to ensure the partner is acting in good faith and effectively when delivering GitLab services to a customer.
- Educate partners of all sizes on the value proposition of GitLab, and participate in all levels of discussions throughout the organization to ensure our solution is set up for successful deployment.
- Enable the ecosystem partners to provide technical evaluations via POC/POV ownership, RFP/audit support, and workshop design.
- Capture and share best-practice knowledge amongst the GitLab community and other Ecosystem Solutions Architects.
- Serve as the partner advocate to other GitLab teams, including Product Development, Sales, and Marketing.
- As part of internal and external evangelism, communicate, grow and evolve awareness of applicable partner technology, services, success stories, market trends and best practices.

#### Ecosystem Solutions Architect Requirements

- Extends the Solutions Architect requirements
- Experience building solutions and professional services through partners
- Knowledge of all or most of the following categories in the DevSecOps space: Consulting, Integration, and or Technical Advisory.
- Technical background with key partnerships such as AWS, Google Cloud, Red Hat. Certifications from these vendors is a plus.

### Public Sector Solutions Architect

#### Public Sector Solutions Architect Responsibilities

- Extends the Solutions Architect responsibilities.
- Participate in conferences and trade shows and interacting with government customers in attendance.
- Contribute to the creation of case studies, white papers, and media articles for government customers and or partner.
- Consistently provide world-class customer service during pre-sales, implementation, and post-sales activities.
- Manage all technical aspects of the sales cycle: creating high-quality professional presentations, custom demos, proof of concepts, deliver technical deep-dive sessions & workshops, differentiate GitLab from alternative solutions, answering RFI, RFPs, etc.
- TS/SCI Security Clearance
- Must be located in the Washington DC metro area
- Knowledge and demonstrated progressive experience with Federal customers
- Ability to travel up to 50%
- Understand mono-repo and distributed-repo approaches.

#### Public Sector Solutions Architect Requirements

- Extends the Solutions Architect requirements

### Commercial Solutions Architect

#### Commercial Solutions Architect Responsibilities

- The responsibilities for a Commercial Solutions Architect are the same as a Solutions Architect but support the [Commercial Sales](/handbook/sales/commercial/) by focusing on [SMB and Mid-Market](/handbook/sales/field-operations/gtm-resources/#segmentation) customers.

#### Commercial Solutions Architect Requirements

- The requirements for a Commercial Solutions Architect are the same as a Solutions Architect.

### Field CTO

#### Field CTO Responsibilties

- Extends the responsibilities of Principal Solutions Architect
- Provide executive-level, thought leadership on strategic opportunities (i.e., new logo and growth)
- Curate and manage field feedback, while collaborating with the product team on roadmap and issue prioritization
- Scale and grow regional-level expertise within the field (SAE/AE,SA,CSM) through contributions to enablement and content
- Act as a prospect / customer advocate on DevSecOps transformation initiatives

#### Field CTO Requirements

- Extends the requirements of Principal Solutions Architect
- Significant experience with architecture of enterprise software development workflow
- Experience as CTO is a plus
- Experience delivering information/Cyber Security and compliance related solutions and assessments
- Experience with software development tools, practices, and methodologies
- Strong verbal and written skills with a strong ability to articulate and communicate strategies to all levels in an organization (i.e., executive to staff engineer)
- Ability to use GitLab, including learning GitLab as part of the role

### Field Security Officer

#### Field Security Officer Responsibilities

- Extends the responsibilities of Principal Solutions Architect
- Provide executive-level, security-related thought leadership on strategic opportunities (i.e., new logo and growth)
- Own CISO, CSO, and/or chief security architect relationships in key accounts while providing credible, leading-edge security guidance to help orchestrate their desired outcomes
- Assist account teams with GitLab product security and compliance expertise in order to drive ARR for GitLab while also providing direction on opportunity and account strategies related to selling and expanding with security (e.g., up-tier)
- Act as a prospect / customer advocate on security related matters
- Curate and manage security related field feedback, while collaborating with the product team on issue prioritization
- Contribute to security sales strategy and playbooks in while collaborating with marketing and product teams
- Scale and grow regional-level expertise within the field (SAE/AE,SA,CSM) through contributions to enablement and content
- Bootstrap security Communities of Practice at GitLab for cross-functional collaboration in order to drive ARR for GitLab

#### Field Security Officer Requirements

- Extends the requirements of Principal Solutions Architect
- Significant experience with information technology security is preferred
- Experience as CISO/CSO is a plus
- Experience delivering information/Cyber Security and compliance related solutions and assessments
- Experience with software development tools, practices, and methodologies
- Experience with application vulnerability management and associated regulations (i.e. PCI  DSS, HIPAA, NIST 800-731 and more) and tools (i.e. SAST, DAST, SCA)
- Strong verbal and written skills with a strong ability to articulate and communicate strategies to all levels in an organization (i.e., executive to staff engineer)
- Ability to use GitLab, including learning GitLab as part of the role

### Federal CTO

#### Federal CTO Responsibilities

- Engage with customers in a technical consultancy and advisor role during the pre-sales process while providing technical assistance and solution guidance.
- Provide executive-level DevOps and security-related thought leadership on strategic Public Sector opportunities (i.e., new logo and growth)
- Own CISO, CSO, CTO and/or chief security architect relationships in key Public Sector accounts while providing credible, leading-edge DevSecOps guidance to help orchestrate their desired outcomes
- In partnership with the marketing team, formulate and lead content creation and media engagement opportunities to increase brand awareness.
- With comprehensive knowledge of the GitLab platform and associated technologies, educate customers of all sizes on the value proposition of GitLab while participating in discussions throughout the organization to ensure successful GitLab deployment.
- Guide technical evaluations via POC/POV ownership, RFP/audit support, and workshop design.
- Curate and manage Public Sector DevOps related field feedback, while collaborating with the marketing and product team on issue prioritization
- Contribute to Public Sector sales strategy and playbooks in while collaborating with marketing and product teams
- Scale and grow regional-level expertise within the field (SAE/AE,SA,CSM) through contributions to enablement and content
- Build deep relationships with people within customer environments to enable them to be GitLab advocates.
- Serve as the customer advocate to other GitLab teams, including Product Development, Sales, and Marketing.
- Maintain specialty competency in one or more technologies related to GitLab's market focus through activities such as training, certification and creation of working examples for reuse internally and by customers and partners.

#### Federal CTO Requirements

- Significant experience with DevOps and/or information technology security is preferred
- Experience selling to, supporting, or working within the Public Sector
- Experience independently creating technical marketing content and materials
- Experience delivering information/Cyber Security and compliance related solutions and assessments
- Experience with software development tools, practices, and methodologies
- Strong verbal, written and presentation skills with a strong ability to articulate and communicate technical strategies to all levels in an organization (i.e., executive to staff engineer)
- Experience with technical pre-sales or as a professional in the field of information technology
- Knowledge of the end-to-end software development lifecycle
- Understanding of continuous integration and continuous deployment
- Experience with modern software development or operations and their associated technologies
- Experience with cloud computing and related technologies and practices
- B.Sc. in Computer Science or equivalent experience
- Successful completion of a background check
- Ability to use GitLab, including learning GitLab as part of the role

## Performance Indicators

As with all roles in the Sales Department, the Solutions Archtiect job family participates in a subset the [Sales KPIs](/handbook/company/kpis/#sales-kpis).

- [Net ARR versus Plan (internal)](https://internal.gitlab.com/handbook/company/performance-indicators/sales/#net-arr-vs-plan)

## Career Ladder

A Solution Architect can progress through the various individual contributor levels or leadership roles and associated levels. More on this in the SA [Career Development page](/handbook/solutions-architects/sa-career-development/#career-paths)

---

## Hiring Process

Candidates can expect the hiring process to follow the order below. Please keep in mind that candidates can be declined from the position at any stage of the process. To learn more about someone who may be conducting the interview, find their job title on our [team page](/handbook/company/team/).

### Individual Contributor Hiring Process

- Selected candidates will be invited to schedule a [screening call](/handbook/hiring/#screening-call) with our Global Recruiters.
- Next, candidates will be invited to schedule a first interview with the SA team Manager.
- Candidates may be invited to schedule an interview with a Solutions Architect peer or other SA team Manager.
- Then, candidates will be required to deliver a demo of GitLab to a panel of Customer Success attendees using the [Demo Guide](https://gitlab-com.gitlab.io/customer-success/solutions-architecture/sa-candidate-experience/panel_instructions/).
- Candidates may be invited to additional interviews.
- Successful candidates will be made an offer after references are verified.

### Management Hiring Process

- Selected candidates will be invited to schedule a [screening call](/handbook/hiring/#screening-call) with our Global Recruiters.
- Next, candidates will be invited to schedule a first interview with a Customer Success VP or Director.
- Candidate will then schedule an interview with an SA management peer.
- Then, candidates will present a business plan to include 30/60/90 day approach, outcomes, and metrics.
- Candidates may be invited to additional interviews.
- Successful candidates will be made an offer after references are verified.

Additional details about our process can be found on our [hiring page](/handbook/hiring/interviewing/).

---
